#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*************************************
##Arabic Stop word list for morphology analysis and information retrival
##Version        : 0.6
##Generated at   : 2019/02/03:10:03 
##Author         : Taha Zerrouki
##Web            : http://arabicstopwords.sf.net
##Source         : http://github.com/linuxscout/arabicstopwords
##*************************************

STOPWORDS={u'حم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَمُ', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 0, 'has_definition': 1, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'حم', 'is_defined': 0, 'tanwin': 1}],

 u'غداة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'غَدَاةَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'غداة', 'is_defined': 0, 'tanwin': 0}],

 u'جنوب': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'جَنُوبَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'جنوب', 'is_defined': 0, 'tanwin': 0}],

 u'ذواتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَوَاتَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذواتا', 'is_defined': 0, 'tanwin': 0}],

 u'حي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَيَّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'حي', 'is_defined': 0, 'tanwin': 0}],

 u'لازلنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْنَا', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلنا', 'is_defined': 0, 'tanwin': 0}],

 u'زمان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'زَمَانَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'زمان', 'is_defined': 0, 'tanwin': 0}],

 u'عوض': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عِوَضَ', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'عوض', 'is_defined': 0, 'tanwin': 0}],

 u'بنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِنَا', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بنا', 'is_defined': 0, 'tanwin': 0}],

 u'أجمع': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَجْمَعَ', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'أجمع', 'is_defined': 0, 'tanwin': 0}],

 u'ؤ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ؤ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ؤ', 'is_defined': 0, 'tanwin': 0}],

 u'إيه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إيهِ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إيه', 'is_defined': 0, 'tanwin': 0}],

 u'لدن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَدُنْ', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'لدن', 'is_defined': 0, 'tanwin': 0}],

 u'ها': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'هَا', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ها', 'is_defined': 0, 'tanwin': 0}],

 u'ش': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ش', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ش', 'is_defined': 0, 'tanwin': 0}],

 u'غرب': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'غَرْبَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'غرب', 'is_defined': 0, 'tanwin': 0}],

 u'لازلتم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْتُم', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلتم', 'is_defined': 0, 'tanwin': 0}],

 u'هج': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'هَجْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هج', 'is_defined': 0, 'tanwin': 0}],

 u'هب': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'هَبَّ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'هب', 'is_defined': 0, 'tanwin': 0}],

 u'عسى': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'عَسَى', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'عسى', 'is_defined': 0, 'tanwin': 0}],

 u'ل': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ل', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ل', 'is_defined': 0, 'tanwin': 0}],

 u'آنفا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'آنِفًا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'آنفا', 'is_defined': 0, 'tanwin': 0}],

 u'لازلتن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْتُنَّ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلتن', 'is_defined': 0, 'tanwin': 0}],

 u'هن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هُنَّ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هن', 'is_defined': 0, 'tanwin': 0}],

 u'هم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هُمْ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هم', 'is_defined': 0, 'tanwin': 0}],

 u'هل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَلْ', 'class_word': u'حرف استفهام', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'هل', 'is_defined': 0, 'tanwin': 0}],

 u'هاؤم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَاؤُمُ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاؤم', 'is_defined': 0, 'tanwin': 0}],

 u'ارتد': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'اِرْتَدَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ارتد', 'is_defined': 0, 'tanwin': 0}],

 u'هي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هِي', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هي', 'is_defined': 0, 'tanwin': 0}],

 u'هو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هُوَ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هو', 'is_defined': 0, 'tanwin': 0}],

 u'لازالتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازَالَتَا', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازالتا', 'is_defined': 0, 'tanwin': 0}],

 u'تلكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تِلْكُمَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تلكما', 'is_defined': 0, 'tanwin': 0}],

 u'وقت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'وَقْتَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'وقت', 'is_defined': 0, 'tanwin': 0}],

 u'أولئكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أُولَئِكُمْ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أولئكم', 'is_defined': 0, 'tanwin': 0}],

 u'نحو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'نَحْوَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'نحو', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'نَحوَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'نحو', 'is_defined': 0, 'tanwin': 0}],

 u'حسب': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَسْبُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حسب', 'is_defined': 0, 'tanwin': 0}],

 u'نحن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'نَحْنُ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'نحن', 'is_defined': 0, 'tanwin': 0}],

 u'لئن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَئِنْ', 'class_word': u'حرف شرط', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لئن', 'is_defined': 0, 'tanwin': 0}],

 u'اللذين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَذَيْنِ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللذين', 'is_defined': 1, 'tanwin': 0}],

 u'أب': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَبُ', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 0, 'has_definition': 1, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أب', 'is_defined': 0, 'tanwin': 1}],

 u'أخ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَخُ', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 0, 'has_definition': 1, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أخ', 'is_defined': 0, 'tanwin': 1}],

 u'قبل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'قَبْلَ', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'قبل', 'is_defined': 0, 'tanwin': 0}],

 u'بدون': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِدُونِ', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'بدون', 'is_defined': 0, 'tanwin': 0}],

 u'مادامتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادَامَتَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادامتا', 'is_defined': 0, 'tanwin': 0}],

 u'بئس': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِئْسَ', 'class_word': u'المدح والذم', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'بئس', 'is_defined': 0, 'tanwin': 0}],

 u'د': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'د', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'د', 'is_defined': 0, 'tanwin': 0}],

 u'ذا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَا', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَا', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'ذا', 'is_defined': 0, 'tanwin': 0}],

 u'لعمر': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَعَمْرُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'لعمر', 'is_defined': 0, 'tanwin': 0}],

 u'هاهنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَاهُنَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاهنا', 'is_defined': 0, 'tanwin': 0}],

 u'كما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَمَا', 'class_word': u'حرف تشبيه', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كما', 'is_defined': 0, 'tanwin': 0}],

 u'لستم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْتُم', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لستم', 'is_defined': 0, 'tanwin': 0}],

 u'لستن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْتُنَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لستن', 'is_defined': 0, 'tanwin': 0}],

 u'حتى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَتَّى', 'class_word': u'تعليل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'حتى', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَتَّى', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'حتى', 'is_defined': 0, 'tanwin': 0}],

 u'لدى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَدَى', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'لدى', 'is_defined': 0, 'tanwin': 0}],

 u'ذه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذِهِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذه', 'is_defined': 0, 'tanwin': 0}],

 u'ذي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذِي', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذي', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذِي', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'ذي', 'is_defined': 0, 'tanwin': 0}],

 u'ذو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذُو', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'ذو', 'is_defined': 0, 'tanwin': 0}],

 u'أي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيُّ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أي', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيُّ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أي', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيُّ', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أي', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيُّ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أي', 'is_defined': 0, 'tanwin': 1},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'أي', 'class_word': u'تعليل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أي', 'is_defined': 0, 'tanwin': 0}],

 u'أو': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'أَوْ', 'class_word': u'حرف عطف منفصل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'متبع', 'word': u'أو', 'is_defined': 0, 'tanwin': 0}],

 u'أف': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أُفٍّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أف', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أُفٍّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أف', 'is_defined': 0, 'tanwin': 0}],

 u'أن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنَّ', 'class_word': u'إن و أخواتها', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'أن', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنْ', 'class_word': u'حرف نصب', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'ناصب', 'word': u'أن', 'is_defined': 0, 'tanwin': 0}],

 u'أم': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'أَمْ', 'class_word': u'حرف عطف منفصل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل:اسم', 'action': u'متبع', 'word': u'أم', 'is_defined': 0, 'tanwin': 0}],

 u'نعما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'نِعِمّا', 'class_word': u'المدح والذم', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'نعما', 'is_defined': 0, 'tanwin': 0}],

 u'هيت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هِيتَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هيت', 'is_defined': 0, 'tanwin': 0}],

 u'هيا': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'هَيَّا', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هيا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَيَا', 'class_word': u'حرف نداء', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هيا', 'is_defined': 0, 'tanwin': 0}],

 u'مابرح': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'مَابَرِحَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مابرح', 'is_defined': 0, 'tanwin': 0}],

 u'حينما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حِينَمَا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'حينما', 'is_defined': 0, 'tanwin': 0}],

 u'هلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَلّا', 'class_word': u'حرف تحضيض', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هلا', 'is_defined': 0, 'tanwin': 0}],

 u'إنما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِنَّمَا', 'class_word': u'كافة ومكفوفة', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'إنما', 'is_defined': 0, 'tanwin': 0}],

 u'جعل': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'جَعَلَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'جعل', 'is_defined': 0, 'tanwin': 0}],

 u'كخ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'كِخْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كخ', 'is_defined': 0, 'tanwin': 0}],

 u'ت': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ت', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ت', 'is_defined': 0, 'tanwin': 0}],

 u'عما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَمَّا', 'class_word': u'حرف جر مكفوف', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'عما', 'is_defined': 0, 'tanwin': 0}],

 u'بكن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِكُنَّ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بكن', 'is_defined': 0, 'tanwin': 0}],

 u'بكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِكَمْ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بكم', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِكُمْ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بكم', 'is_defined': 0, 'tanwin': 0}],

 u'مازلنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْنَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلنا', 'is_defined': 0, 'tanwin': 0}],

 u'غ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'غ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'غ', 'is_defined': 0, 'tanwin': 0}],

 u'رويدك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'رُوَيْدَكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'رويدك', 'is_defined': 0, 'tanwin': 0}],

 u'دون': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'دُونَ', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'دون', 'is_defined': 0, 'tanwin': 0}],

 u'أولئك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أُولَئِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أولئك', 'is_defined': 0, 'tanwin': 0}],

 u'كي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَيْ', 'class_word': u'تعليل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'ناصب', 'word': u'كي', 'is_defined': 0, 'tanwin': 0}],

 u'هؤلاء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَؤُلَاءِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هؤلاء', 'is_defined': 0, 'tanwin': 0}],

 u'لها': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَهَا', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لها', 'is_defined': 0, 'tanwin': 0}],

 u'ي': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ي', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ي', 'is_defined': 0, 'tanwin': 0}],

 u'مكانكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَكَانَكُمَا', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مكانكما', 'is_defined': 0, 'tanwin': 0}],

 u'كم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَمْ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كم', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَمْ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كم', 'is_defined': 0, 'tanwin': 0}],

 u'كل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كُلُّ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'كل', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كُلَّ', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'كل', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئتن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْتُنَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئتن', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفككتما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككتما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككتما', 'is_defined': 0, 'tanwin': 0}],

 u'لعل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَعَلَّ', 'class_word': u'إن و أخواتها', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لعل', 'is_defined': 0, 'tanwin': 0}],

 u'إنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِنَّا', 'class_word': u'ناصب ومنصوب', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'إنا', 'is_defined': 0, 'tanwin': 0}],

 u'لازال': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازَالَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لازال', 'is_defined': 0, 'tanwin': 0}],

 u'متى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَتَى', 'class_word': u'اسم استفهام/ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'متى', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَتَى', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'متى', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَتَى', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'متى', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحوا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحُوا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحوا', 'is_defined': 0, 'tanwin': 0}],

 u'خلال': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'خِلَالَ', 'class_word': u'ظرف زمان/مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'خلال', 'is_defined': 0, 'tanwin': 0}],

 u'مازلتن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْتُنَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلتن', 'is_defined': 0, 'tanwin': 0}],

 u'مازلتم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْتُم', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلتم', 'is_defined': 0, 'tanwin': 0}],

 u'ثنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ثَنَا', 'class_word': u'اختصار', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ثنا', 'is_defined': 0, 'tanwin': 0}],

 u'راح': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'رَاحَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'راح', 'is_defined': 0, 'tanwin': 0}],

 u'هلم': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'هَلُمَّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هلم', 'is_defined': 0, 'tanwin': 0}],

 u'لولا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَوْلَا', 'class_word': u'الحروف(حروف)', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لولا', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحتما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحتما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحتما', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْتُ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْتَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مافتئت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْتِ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئَتْ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مافتئت', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئتم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْتُم', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئتم', 'is_defined': 0, 'tanwin': 0}],

 u'تان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تَانِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تان', 'is_defined': 0, 'tanwin': 0}],

 u'مرة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَرَّةً', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'مرة', 'is_defined': 0, 'tanwin': 0}],

 u'أصلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَصْلًا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'أصلا', 'is_defined': 0, 'tanwin': 0}],

 u'وشكان': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وُشْكَانَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وشكان', 'is_defined': 0, 'tanwin': 0}],

 u'كأنما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَأَنَّمَا', 'class_word': u'حرف تشبيه', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كأنما', 'is_defined': 0, 'tanwin': 0}],

 u'إياهما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاهُمَا', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياهما', 'is_defined': 0, 'tanwin': 0}],

 u'أسفل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَسْفَلَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أسفل', 'is_defined': 0, 'tanwin': 0}],

 u'ص': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ص', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ص', 'is_defined': 0, 'tanwin': 0}],

 u'أمامك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَمَامَكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أمامك', 'is_defined': 0, 'tanwin': 0}],

 u'م': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'م', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'م', 'is_defined': 0, 'tanwin': 0}],

 u'مادمتما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمتما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمتما', 'is_defined': 0, 'tanwin': 0}],

 u'إياهم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاهُمْ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياهم', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفكوا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكُّوا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفكوا', 'is_defined': 0, 'tanwin': 0}],

 u'استحال': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'اِسْتَحَالَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'استحال', 'is_defined': 0, 'tanwin': 0}],

 u'إليك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِلَيْكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إليك', 'is_defined': 0, 'tanwin': 0}],

 u'أمسى': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'أَمْسَى', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'أمسى', 'is_defined': 0, 'tanwin': 0}],

 u'انبرى': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'اِنْبَرَى', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'انبرى', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئَتَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئتا', 'is_defined': 0, 'tanwin': 0}],

 u'أنتم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنْتُمْ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنتم', 'is_defined': 0, 'tanwin': 0}],

 u'لازالوا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازَالُوا', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازالوا', 'is_defined': 0, 'tanwin': 0}],

 u'أنتن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنْتُنَّ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنتن', 'is_defined': 0, 'tanwin': 0}],

 u'ليستا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَيْسَتَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ليستا', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفككن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْنَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككن', 'is_defined': 0, 'tanwin': 0}],

 u'أوشك': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'أَوْشَكَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'أوشك', 'is_defined': 0, 'tanwin': 0}],

 u'طفق': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'طَفِقَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'طفق', 'is_defined': 0, 'tanwin': 0}],

 u'لازالت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازَالَتْ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لازالت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازَالَتْ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لازالت', 'is_defined': 0, 'tanwin': 0}],

 u'صه': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'صَهْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'صه', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'صَهٍ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'صه', 'is_defined': 0, 'tanwin': 0}],

 u'لازالا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازَالَا', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازالا', 'is_defined': 0, 'tanwin': 0}],

 u'هناك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هُنَاكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هناك', 'is_defined': 0, 'tanwin': 0}],

 u'ليس': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَيْسَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ليس', 'is_defined': 0, 'tanwin': 0}],

 u'هاذين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَاذَيْنِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاذين', 'is_defined': 0, 'tanwin': 0}],

 u'مازالوا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازَالُوا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازالوا', 'is_defined': 0, 'tanwin': 0}],

 u'إلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إلّا', 'class_word': u'حرف استثناء', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'إلا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِلَّا', 'class_word': u'حرف استثناء', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'', 'word': u'إلا', 'is_defined': 0, 'tanwin': 0}],

 u'سوف': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سَوْفَ', 'class_word': u'حرف استقبال', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'رافع', 'word': u'سوف', 'is_defined': 0, 'tanwin': 0}],

 u'ب': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ب', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ب', 'is_defined': 0, 'tanwin': 0}],

 u'آمين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'آمِينَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'آمين', 'is_defined': 0, 'tanwin': 0}],

 u'آناء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'آنَاءَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'آناء', 'is_defined': 0, 'tanwin': 0}],

 u'هاتين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَاتَيْنِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاتين', 'is_defined': 0, 'tanwin': 0}],

 u'ليت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَيْتَ', 'class_word': u'إن و أخواتها', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ليت', 'is_defined': 0, 'tanwin': 0}],

 u'و': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'و', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'و', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَ', 'class_word': u'حرف عطف منفصل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم فعل', 'action': u'متبع', 'word': u'و', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَ', 'class_word': u'حرف عطف', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'متبع', 'word': u'و', 'is_defined': 0, 'tanwin': 0}],

 u'أكثر': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَكْثَرُ', 'class_word': u'اسم تفضيل', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'أكثر', 'is_defined': 0, 'tanwin': 0}],

 u'إلى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِلَى', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'إلى', 'is_defined': 0, 'tanwin': 0}],

 u'أثناء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَثْنَاءَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أثناء', 'is_defined': 0, 'tanwin': 0}],

 u'ابن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'اِبْنُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'ابن', 'is_defined': 0, 'tanwin': 0}],

 u'بعدئذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَعْدَئِذٍ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'بعدئذ', 'is_defined': 0, 'tanwin': 0}],

 u'فلان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فُلَانٌ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'فلان', 'is_defined': 0, 'tanwin': 0}],

 u'ليل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَيْلَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'ليل', 'is_defined': 0, 'tanwin': 0}],

 u'تين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تَيْنِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تين', 'is_defined': 0, 'tanwin': 0}],

 u'أصبح': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'أَصْبَحَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'أصبح', 'is_defined': 0, 'tanwin': 0}],

 u'لكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَكُمَا', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لكما', 'is_defined': 0, 'tanwin': 0}],

 u'كأين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَأَيَّنَ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كأين', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَأَيْنَ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كأين', 'is_defined': 0, 'tanwin': 0}],

 u'قد': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'قَدْ', 'class_word': u'حرف تحقيق/ توقع', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'عاطل', 'word': u'قد', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفككت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْتُ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْتَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْتِ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككت', 'is_defined': 0, 'tanwin': 0}],

 u'قط': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'قَطُّ', 'class_word': u'ظرف', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'قط', 'is_defined': 0, 'tanwin': 0}],

 u'لحظة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَحْظَةَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'لحظة', 'is_defined': 0, 'tanwin': 0}],

 u'شمال': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'شَمَالَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'شمال', 'is_defined': 0, 'tanwin': 0}],

 u'ثم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ثَمَّ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ثم', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ثُمَّ', 'class_word': u'حرف عطف منفصل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'متبع', 'word': u'ثم', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ثَمَّ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'ثم', 'is_defined': 0, 'tanwin': 0}],

 u'أجل': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'أَجَلْ', 'class_word': u'حرف جواب', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أجل', 'is_defined': 0, 'tanwin': 0}],

 u'عليك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَلَيْكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'عليك', 'is_defined': 0, 'tanwin': 0}],

 u'دونك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'دُونَكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'دونك', 'is_defined': 0, 'tanwin': 0}],

 u'ذلكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَلَكُمَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذلكما', 'is_defined': 0, 'tanwin': 0}],

 u'حما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَمَا', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حما', 'is_defined': 0, 'tanwin': 0}],

 u'أنت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنْتَ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنْتِ', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنت', 'is_defined': 0, 'tanwin': 0}],

 u'التي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الَّتِي', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'التي', 'is_defined': 1, 'tanwin': 0}],

 u'أوه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَوَّهْ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أوه', 'is_defined': 0, 'tanwin': 0}],

 u'أنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنَا', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنَّا', 'class_word': u'ناصب ومنصوب', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'عاطل', 'word': u'أنا', 'is_defined': 0, 'tanwin': 0}],

 u'مثل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مِثْلُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'مثل', 'is_defined': 0, 'tanwin': 0}],

 u'هذين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَذَيْنِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هذين', 'is_defined': 0, 'tanwin': 0}],

 u'س': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'س', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'س', 'is_defined': 0, 'tanwin': 0}],

 u'لازلتما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْتُمَا', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلتما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْتُمَا', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلتما', 'is_defined': 0, 'tanwin': 0}],

 u'ك': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ك', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ك', 'is_defined': 0, 'tanwin': 0}],

 u'أنى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنَّى', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنى', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنَّى', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنى', 'is_defined': 0, 'tanwin': 0}],

 u'حمو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَمُو', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حمو', 'is_defined': 0, 'tanwin': 0}],

 u'حمي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَمِي', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حمي', 'is_defined': 0, 'tanwin': 0}],

 u'هما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هُمَا', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هما', 'is_defined': 0, 'tanwin': 0}],

 u'جير': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'جَيْرِ', 'class_word': u'حرف جواب', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'جير', 'is_defined': 0, 'tanwin': 0}],

 u'أبدا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَبَدًا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'أبدا', 'is_defined': 0, 'tanwin': 0}],

 u'اللذان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَذَانِ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللذان', 'is_defined': 1, 'tanwin': 0}],

 u'عند': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عِنْدَ', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'عند', 'is_defined': 0, 'tanwin': 0}],

 u'ظل': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'ظَلَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ظل', 'is_defined': 0, 'tanwin': 0}],

 u'سرعان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سُرْعَانَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'سرعان', 'is_defined': 0, 'tanwin': 0}],

 u'خلف': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'خَلْفَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'خلف', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'خَلْفَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'خلف', 'is_defined': 0, 'tanwin': 0}],

 u'تحول': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'تَحَوَّلَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'تحول', 'is_defined': 0, 'tanwin': 0}],

 u'هاته': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَاتِهِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاته', 'is_defined': 0, 'tanwin': 0}],

 u'هاتي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَاتِي', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاتي', 'is_defined': 0, 'tanwin': 0}],

 u'حوالى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَوَالَى', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حوالى', 'is_defined': 0, 'tanwin': 0}],

 u'جلل': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'جَلَلْ', 'class_word': u'حرف جواب', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'جلل', 'is_defined': 0, 'tanwin': 0}],

 u'تينك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تَيْنِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تينك', 'is_defined': 0, 'tanwin': 0}],

 u'أولاء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أُولَاءِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أولاء', 'is_defined': 0, 'tanwin': 0}],

 u'آنذاك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'آنَذَاكَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'آنذاك', 'is_defined': 0, 'tanwin': 0}],

 u'بعد': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَعْدَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'بعد', 'is_defined': 0, 'tanwin': 0}],

 u'حين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حِينَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حين', 'is_defined': 0, 'tanwin': 0}],

 u'ذيت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَيْتَ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذيت', 'is_defined': 0, 'tanwin': 0}],

 u'أيان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيَّانَ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أيان', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيَّانَ', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أيان', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيَّانَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'أيان', 'is_defined': 0, 'tanwin': 0}],

 u'قلما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'قَلَّمَا', 'class_word': u'فعل جامد', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'قلما', 'is_defined': 0, 'tanwin': 0}],

 u'مازالا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازَالَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازالا', 'is_defined': 0, 'tanwin': 0}],

 u'خ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'خ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'خ', 'is_defined': 0, 'tanwin': 0}],

 u'إزاء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِزَاءَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'إزاء', 'is_defined': 0, 'tanwin': 0}],

 u'بعض': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَعْضُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'بعض', 'is_defined': 0, 'tanwin': 1}],

 u'فيما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فِيمَا', 'class_word': u'حرف استفهام', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'فيما', 'is_defined': 0, 'tanwin': 0}],

 u'لنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَنَا', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لنا', 'is_defined': 0, 'tanwin': 0}],

 u'مكانكن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَكَانَكُنَّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مكانكن', 'is_defined': 0, 'tanwin': 0}],

 u'تلكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تِلْكُمْ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تلكم', 'is_defined': 0, 'tanwin': 0}],

 u'ذين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَيْنِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذين', 'is_defined': 0, 'tanwin': 0}],

 u'اللائي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَائِي', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللائي', 'is_defined': 1, 'tanwin': 0}],

 u'تلقاء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تِلْقَاءَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'تلقاء', 'is_defined': 0, 'tanwin': 0}],

 u'خلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'خَلَا', 'class_word': u'حرف استثناء', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'خلا', 'is_defined': 0, 'tanwin': 0}],

 u'حيث': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَيْثُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'حيث', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئوا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئُوا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئوا', 'is_defined': 0, 'tanwin': 0}],

 u'صار': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'صَارَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'صار', 'is_defined': 0, 'tanwin': 0}],

 u'أينما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيْنَمَا', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أينما', 'is_defined': 0, 'tanwin': 0}],

 u'يمين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'يَمِينَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'يمين', 'is_defined': 0, 'tanwin': 0}],

 u'رب': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'رُبَّ', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'رب', 'is_defined': 0, 'tanwin': 0}],

 u'ماذا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَاذَا', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ماذا', 'is_defined': 0, 'tanwin': 0}],

 u'لست': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْتَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لست', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْتُ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لست', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْتِ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لست', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْنَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئن', 'is_defined': 0, 'tanwin': 0}],

 u'ذان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَانِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذان', 'is_defined': 0, 'tanwin': 0}],

 u'إياه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاهُ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياه', 'is_defined': 0, 'tanwin': 0}],

 u'ذاك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَاكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذاك', 'is_defined': 0, 'tanwin': 0}],

 u'ة': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ة', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ة', 'is_defined': 0, 'tanwin': 0}],

 u'ن': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ن', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ن', 'is_defined': 0, 'tanwin': 0}],

 u'حذار': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَذَارِ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'حذار', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفكتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَّتَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفكتا', 'is_defined': 0, 'tanwin': 0}],

 u'ع': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ع', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ع', 'is_defined': 0, 'tanwin': 0}],

 u'مادمتم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْتُم', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمتم', 'is_defined': 0, 'tanwin': 0}],

 u'مادمتن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْتُنَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمتن', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْنَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحنا', 'is_defined': 0, 'tanwin': 0}],

 u'ى': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ى', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ى', 'is_defined': 0, 'tanwin': 0}],

 u'ذات': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَاتُ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'جار', 'word': u'ذات', 'is_defined': 0, 'tanwin': 0}],

 u'واها': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَاهاً', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'واها', 'is_defined': 0, 'tanwin': 0}],

 u'أما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَمَّا', 'class_word': u'حرف شرط وتفصيل وتوكيد', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَمَا', 'class_word': u'حرف عرض', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أما', 'is_defined': 0, 'tanwin': 0}],

 u'جدا': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'جِدًّا', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'جدا', 'is_defined': 0, 'tanwin': 0}],

 u'أمد': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَمَدَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'أمد', 'is_defined': 0, 'tanwin': 0}],

 u'اللواتي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَوَاتِي', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللواتي', 'is_defined': 1, 'tanwin': 0}],

 u'أمس': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَمْسِ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أمس', 'is_defined': 0, 'tanwin': 0}],

 u'لسن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْنَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لسن', 'is_defined': 0, 'tanwin': 0}],

 u'معاذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَعَاذَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'معاذ', 'is_defined': 0, 'tanwin': 0}],

 u'الذين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الَّذِينَ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'الذين', 'is_defined': 1, 'tanwin': 0}],

 u'حيثما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَيْثُمَا', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'حيثما', 'is_defined': 0, 'tanwin': 0}],

 u'تحت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تَحْتَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'تحت', 'is_defined': 0, 'tanwin': 0}],

 u'غير': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'غَيْرَ', 'class_word': u'استثناء', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'غير', 'is_defined': 0, 'tanwin': 0}],

 u'حاشا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَاشَا', 'class_word': u'حرف استثناء', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حاشا', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئ': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'مَافَتِئَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مافتئ', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحتن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْتُنَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحتن', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحتم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْتُم', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحتم', 'is_defined': 0, 'tanwin': 0}],

 u'أمام': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَمَامَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 1, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أمام', 'is_defined': 0, 'tanwin': 0}],

 u'ج': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ج', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ج', 'is_defined': 0, 'tanwin': 0}],

 u'أضحى': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'أَضْحَى', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'أضحى', 'is_defined': 0, 'tanwin': 0}],

 u'اللتيا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَتَيَّا', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللتيا', 'is_defined': 1, 'tanwin': 0}],

 u'هاتان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَاتَانِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاتان', 'is_defined': 0, 'tanwin': 0}],

 u'هكذا': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'هَكَذَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هكذا', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحَتَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحتا', 'is_defined': 0, 'tanwin': 0}],

 u'كلتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كِلْتَا', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كلتا', 'is_defined': 0, 'tanwin': 0}],

 u'بضع': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِضْعَ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'بضع', 'is_defined': 0, 'tanwin': 0}],

 u'انقلب': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'اِنْقَلَبَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'انقلب', 'is_defined': 0, 'tanwin': 0}],

 u'اللتين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَتَيْنِ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللتين', 'is_defined': 1, 'tanwin': 0}],

 u'ساء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سَاءَ', 'class_word': u'المدح والذم', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ساء', 'is_defined': 0, 'tanwin': 0}],

 u'لستما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لستما', 'is_defined': 0, 'tanwin': 0}],

 u'إليكن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِلَيْكُنَّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إليكن', 'is_defined': 0, 'tanwin': 0}],

 u'إليكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِلَيْكُمْ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إليكم', 'is_defined': 0, 'tanwin': 0}],

 u'غدا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'غَدًا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'غدا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'غَدَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'غدا', 'is_defined': 0, 'tanwin': 0}],

 u'حاي': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'حَايْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'حاي', 'is_defined': 0, 'tanwin': 0}],

 u'كلما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كُلَّمَا', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كلما', 'is_defined': 0, 'tanwin': 0}],

 u'تبدل': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'تَبَدَّلَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'تبدل', 'is_defined': 0, 'tanwin': 0}],

 u'مكانكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَكَانَكُمْ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مكانكم', 'is_defined': 0, 'tanwin': 0}],

 u'كذلك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَذَلِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كذلك', 'is_defined': 0, 'tanwin': 0}],

 u'شتان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'شَتَّانَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'شتان', 'is_defined': 0, 'tanwin': 0}],

 u'الآن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْآنَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'الآن', 'is_defined': 1, 'tanwin': 0}],

 u'أولالك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أُولَالِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أولالك', 'is_defined': 0, 'tanwin': 0}],

 u'إياي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّايَ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياي', 'is_defined': 0, 'tanwin': 0}],

 u'ممن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مِمَّنْ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ممن', 'is_defined': 0, 'tanwin': 0}],

 u'إياك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاكَ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياك', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاكِ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياك', 'is_defined': 0, 'tanwin': 0}],

 u'كيت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَيْتَ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كيت', 'is_defined': 0, 'tanwin': 0}],

 u'بعدما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَعْدَمَا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'بعدما', 'is_defined': 0, 'tanwin': 0}],

 u'اخلولق': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'اِخْلَوْلَقَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'اخلولق', 'is_defined': 0, 'tanwin': 0}],

 u'حرى': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'حَرَى', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'حرى', 'is_defined': 0, 'tanwin': 0}],

 u'مادمنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْنَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمنا', 'is_defined': 0, 'tanwin': 0}],

 u'ط': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ط', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ط', 'is_defined': 0, 'tanwin': 0}],

 u'ه': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ه', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ه', 'is_defined': 0, 'tanwin': 0}],

 u'عاد': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'عَادَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'عاد', 'is_defined': 0, 'tanwin': 0}],

 u'كيف': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَيْفَ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كيف', 'is_defined': 0, 'tanwin': 0}],

 u'إياكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاكُمْ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياكم', 'is_defined': 0, 'tanwin': 0}],

 u'إياكن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاكُنَّ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياكن', 'is_defined': 0, 'tanwin': 0}],

 u'سبحان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سُبْحَانَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'سبحان', 'is_defined': 0, 'tanwin': 0}],

 u'هذان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَذَانِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هذان', 'is_defined': 0, 'tanwin': 0}],

 u'أقبل': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'أَقْبَلَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'أقبل', 'is_defined': 0, 'tanwin': 0}],

 u'الألاء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْأَلَاءُ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'الألاء', 'is_defined': 1, 'tanwin': 0}],

 u'مما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مِمَّا', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مما', 'is_defined': 0, 'tanwin': 0}],

 u'ليسوا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَيْسُوا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ليسوا', 'is_defined': 0, 'tanwin': 0}],

 u'لما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَمَّا', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'لما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَمَّا', 'class_word': u'حرف جزم', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'جازم', 'word': u'لما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَمَّا', 'class_word': u'ظرف', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لما', 'is_defined': 0, 'tanwin': 0}],

 u'ضحوة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ضَحْوَةً', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'ضحوة', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحا', 'is_defined': 0, 'tanwin': 0}],

 u'آها': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'آهاً', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'آها', 'is_defined': 0, 'tanwin': 0}],

 u'ماداموا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادَامُوا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماداموا', 'is_defined': 0, 'tanwin': 0}],

 u'آ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'آ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'آ', 'is_defined': 0, 'tanwin': 0}],

 u'كاد': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'كَادَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'كاد', 'is_defined': 0, 'tanwin': 0}],

 u'عل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَلًّ', 'class_word': u'إن و أخواتها', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'عل', 'is_defined': 0, 'tanwin': 0}],

 u'عن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَنْ', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'عن', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئتما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئتما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئتما', 'is_defined': 0, 'tanwin': 0}],

 u'ز': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ز', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ز', 'is_defined': 0, 'tanwin': 0}],

 u'لازلت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْتُ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْتَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْتِ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلت', 'is_defined': 0, 'tanwin': 0}],

 u'بيد': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَيْدَ', 'class_word': u'استثناء', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بيد', 'is_defined': 0, 'tanwin': 0}],

 u'ق': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ق', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ق', 'is_defined': 0, 'tanwin': 0}],

 u'ظ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ظ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ظ', 'is_defined': 0, 'tanwin': 0}],

 u'ماداما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادَامَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماداما', 'is_defined': 0, 'tanwin': 0}],

 u'كان': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'كَانَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'كان', 'is_defined': 0, 'tanwin': 0}],

 u'كلاهما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كِلَاهُمَا', 'class_word': u'توكيد', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كلاهما', 'is_defined': 0, 'tanwin': 0}],

 u'بين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَيْنَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'بين', 'is_defined': 0, 'tanwin': 0}],

 u'هيهات': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'هَيْهَاتَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هيهات', 'is_defined': 0, 'tanwin': 0}],

 u'إذا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِذَا', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'إذا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إذاً', 'class_word': u'اسم شرط', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إذا', 'is_defined': 0, 'tanwin': 0}],

 u'إياكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاكُمَا', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياكما', 'is_defined': 0, 'tanwin': 0}],

 u'الذي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الَّذِي', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'الذي', 'is_defined': 1, 'tanwin': 0}],

 u'بل': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'بَلْ', 'class_word': u'حرف عطف منفصل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'متبع', 'word': u'بل', 'is_defined': 0, 'tanwin': 0}],

 u'نخ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'نَخْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'نخ', 'is_defined': 0, 'tanwin': 0}],

 u'طاق': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'طَاقْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'طاق', 'is_defined': 0, 'tanwin': 0}],

 u'أبو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَبُو', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أبو', 'is_defined': 0, 'tanwin': 0}],

 u'أبي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَبِي', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أبي', 'is_defined': 0, 'tanwin': 0}],

 u'هذا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَذَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هذا', 'is_defined': 0, 'tanwin': 0}],

 u'لاسيما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لاسِيَّمَا', 'class_word': u'استثناء', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لاسيما', 'is_defined': 0, 'tanwin': 0}],

 u'هنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هُنَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هنا', 'is_defined': 0, 'tanwin': 0}],

 u'ساءما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سَاءَمَا', 'class_word': u'المدح والذم', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ساءما', 'is_defined': 0, 'tanwin': 0}],

 u'ذينك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَيْنِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذينك', 'is_defined': 0, 'tanwin': 0}],

 u'آه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'آهٍ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'آه', 'is_defined': 0, 'tanwin': 0}],

 u'ساعة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سَاعَةَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'ساعة', 'is_defined': 0, 'tanwin': 0}],

 u'ح': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ح', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ح', 'is_defined': 0, 'tanwin': 0}],

 u'ابتدأ': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'ابْتَدَأَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ابتدأ', 'is_defined': 0, 'tanwin': 0}],

 u'صباح': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'صَبَاحَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'صباح', 'is_defined': 0, 'tanwin': 0}],

 u'ضمن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ضِمْنَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'ضمن', 'is_defined': 0, 'tanwin': 0}],

 u'لكيلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لِكَيْلَا', 'class_word': u'حرف تعليل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'ناصب', 'word': u'لكيلا', 'is_defined': 0, 'tanwin': 0}],

 u'بمن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِمَنْ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بمن', 'is_defined': 0, 'tanwin': 0}],

 u'كيفما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَيْفَمَا', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كيفما', 'is_defined': 0, 'tanwin': 0}],

 u'سوى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سِوَى', 'class_word': u'استثناء', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'سوى', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'سِوَى', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'سوى', 'is_defined': 0, 'tanwin': 0}],

 u'إياها': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاهَا', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياها', 'is_defined': 0, 'tanwin': 0}],

 u'تانك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تَانِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تانك', 'is_defined': 0, 'tanwin': 0}],

 u'أقل': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَقَلُّ', 'class_word': u'اسم تفضيل', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'أقل', 'is_defined': 0, 'tanwin': 0}],

 u'إليكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِلَيْكُمَا', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إليكما', 'is_defined': 0, 'tanwin': 0}],

 u'لئلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لِئَلَّا', 'class_word': u'حرف نصب', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'ناصب', 'word': u'لئلا', 'is_defined': 0, 'tanwin': 0}],

 u'كذا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَذَا', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كذا', 'is_defined': 0, 'tanwin': 0}],

 u'آض': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'آضَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'آض', 'is_defined': 0, 'tanwin': 0}],

 u'بما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِمَا', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بما', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفكا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَّا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفكا', 'is_defined': 0, 'tanwin': 0}],

 u'فيم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فِيمَ', 'class_word': u'حرف استفهام', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'فيم', 'is_defined': 0, 'tanwin': 0}],

 u'إياهن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّاهُنَّ', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إياهن', 'is_defined': 0, 'tanwin': 0}],

 u'فا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فَا', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'فا', 'is_defined': 0, 'tanwin': 0}],

 u'هذي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَذِي', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هذي', 'is_defined': 0, 'tanwin': 0}],

 u'أبا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَبَا', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أبا', 'is_defined': 0, 'tanwin': 0}],

 u'هذه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هَذِهِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هذه', 'is_defined': 0, 'tanwin': 0}],

 u'تجاه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تُجَاهَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'تجاه', 'is_defined': 0, 'tanwin': 0}],

 u'شطر': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'شَطْرَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'شطر', 'is_defined': 0, 'tanwin': 0}],

 u'حينئذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حِينَئِذٍ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'حينئذ', 'is_defined': 0, 'tanwin': 0}],

 u'أيضا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيْضًا', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'أيضا', 'is_defined': 0, 'tanwin': 0}],

 u'شرق': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'شَرْقَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'شرق', 'is_defined': 0, 'tanwin': 0}],

 u'رجع': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'رَجَعَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'رجع', 'is_defined': 0, 'tanwin': 0}],

 u'عامة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَامَّةَ', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'عامة', 'is_defined': 0, 'tanwin': 0}],

 u'إذن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِذَنْ', 'class_word': u'حرف جواب', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إذن', 'is_defined': 0, 'tanwin': 0}],

 u'غروب': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'غُرُوبَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'غروب', 'is_defined': 0, 'tanwin': 0}],

 u'عندما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عِنْدَمَا', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'عندما', 'is_defined': 0, 'tanwin': 0}],

 u'وراءك': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَرَاءَكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وراءك', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَرَاءَكِ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وراءك', 'is_defined': 0, 'tanwin': 0}],

 u'إذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِذْ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'إذ', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِذْ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'إذ', 'is_defined': 0, 'tanwin': 0}],

 u'ألا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَلَا', 'class_word': u'حرف عرض', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ألا', 'is_defined': 0, 'tanwin': 0}],

 u'لكي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لِكَيْ', 'class_word': u'حرف تعليل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'ناصب', 'word': u'لكي', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْتُ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْتَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْتِ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحَتْ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مابرحت', 'is_defined': 0, 'tanwin': 0}],

 u'لكن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَكِنَّ', 'class_word': u'إن و أخواتها', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لكن', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَكِنْ', 'class_word': u'حرف استدراك', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'لكن', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَكُنَّ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لكن', 'is_defined': 0, 'tanwin': 0}],

 u'لكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَكُمْ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لكم', 'is_defined': 0, 'tanwin': 0}],

 u'يومئذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'يَوْمَئِذٍ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'يومئذ', 'is_defined': 0, 'tanwin': 0}],

 u'لكنما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَكِنَّمَا', 'class_word': u'كافة ومكفوفة', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'لكنما', 'is_defined': 0, 'tanwin': 0}],

 u'قبلما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'قَبْلَمَا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'قبلما', 'is_defined': 0, 'tanwin': 0}],

 u'بي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِي', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بي', 'is_defined': 0, 'tanwin': 0}],

 u'ذ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ذ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذ', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفككنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْنَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككنا', 'is_defined': 0, 'tanwin': 0}],

 u'بك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِكَ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بك', 'is_defined': 0, 'tanwin': 0}],

 u'بن': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'بْن', 'class_word': u'وصل الأعلام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'بن', 'is_defined': 0, 'tanwin': 0}],

 u'به': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِهِ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'به', 'is_defined': 0, 'tanwin': 0}],

 u'اللتان': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَتَانِ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللتان', 'is_defined': 1, 'tanwin': 0}],

 u'ماانفككتم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْتُم', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككتم', 'is_defined': 0, 'tanwin': 0}],

 u'تارة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تَارَةً', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'تارة', 'is_defined': 0, 'tanwin': 0}],

 u'بس': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'بَسّْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بس', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَسْ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بس', 'is_defined': 0, 'tanwin': 0}],

 u'مابرحن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَابَرِحْنَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مابرحن', 'is_defined': 0, 'tanwin': 0}],

 u'فقط': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فَقَطْ', 'class_word': u'', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'فقط', 'is_defined': 0, 'tanwin': 0}],

 u'أنشأ': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'أَنْشَأَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'أنشأ', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفككتن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَكْتُنَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'ماانفككتن', 'is_defined': 0, 'tanwin': 0}],

 u'بخ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بخٍ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بخ', 'is_defined': 0, 'tanwin': 0}],

 u'مثلما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مِثْلَمَا', 'class_word': u'جار ومجرور', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'مثلما', 'is_defined': 0, 'tanwin': 0}],

 u'شبه': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'شِبْهُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'شبه', 'is_defined': 0, 'tanwin': 0}],

 u'بها': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِهَا', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بها', 'is_defined': 0, 'tanwin': 0}],

 u'مازلتما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلتما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْتُمَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلتما', 'is_defined': 0, 'tanwin': 0}],

 u'فوق': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فَوْقَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'فوق', 'is_defined': 0, 'tanwin': 0}],

 u'شهر': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'شَهْرَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'شهر', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفكت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَااِنْفَكَّتْ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ماانفكت', 'is_defined': 0, 'tanwin': 0}],

 u'إي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِي', 'class_word': u'حرف جواب', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إي', 'is_defined': 0, 'tanwin': 0}],

 u'اللاتي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْلَاتِي', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'اللاتي', 'is_defined': 1, 'tanwin': 0}],

 u'مازال': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'مَازَالَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مازال', 'is_defined': 0, 'tanwin': 0}],

 u'إن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِنَّ', 'class_word': u'إن و أخواتها', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'إن', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِنْ', 'class_word': u'المشبهة بليس', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'إن', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِنْ', 'class_word': u'حرف جزم', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'جازم', 'word': u'إن', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِنْ', 'class_word': u'حرف شرط', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إن', 'is_defined': 0, 'tanwin': 0}],

 u'كأن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَأَنَّ', 'class_word': u'إن و أخواتها', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'كأن', 'is_defined': 0, 'tanwin': 0}],

 u'كليهما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كِلَيْهِمَا', 'class_word': u'توكيد', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كليهما', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئا', 'is_defined': 0, 'tanwin': 0}],

 u'كليكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كِلَيْكُمَا', 'class_word': u'توكيد', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كليكما', 'is_defined': 0, 'tanwin': 0}],

 u'شرع': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'شَرَعَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'شرع', 'is_defined': 0, 'tanwin': 0}],

 u'ليسا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَيْسَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ليسا', 'is_defined': 0, 'tanwin': 0}],

 u'مكانك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَكَانَكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مكانك', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَكَانَكِ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مكانك', 'is_defined': 0, 'tanwin': 0}],

 u'ليست': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَيْسَتْ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ليست', 'is_defined': 0, 'tanwin': 0}],

 u'وي': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَيْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وي', 'is_defined': 0, 'tanwin': 0}],

 u'أعلى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَعْلَى', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أعلى', 'is_defined': 0, 'tanwin': 0}],

 u'لسنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَسْنَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لسنا', 'is_defined': 0, 'tanwin': 0}],

 u'ثمة': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ثَمَّةَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ثمة', 'is_defined': 0, 'tanwin': 0}],

 u'لات': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَاتَ', 'class_word': u'المشبهة بليس', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لات', 'is_defined': 0, 'tanwin': 0}],

 u'حسبما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَسْبَمَا', 'class_word': u'جار ومجرور', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'حسبما', 'is_defined': 0, 'tanwin': 0}],

 u'ث': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ث', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ث', 'is_defined': 0, 'tanwin': 0}],

 u'طالما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'طَالَمَا', 'class_word': u'فعل جامد', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'طالما', 'is_defined': 0, 'tanwin': 0}],

 u'ذوا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَوَا', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذوا', 'is_defined': 0, 'tanwin': 0}],

 u'مع': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَعَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'مع', 'is_defined': 0, 'tanwin': 0}],

 u'ماانفك': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'مَااِنْفَكَّ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ماانفك', 'is_defined': 0, 'tanwin': 0}],

 u'نفس': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'نَفْسُ', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'نفس', 'is_defined': 0, 'tanwin': 0}],

 u'مذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مُذْ', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'مذ', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مُذْ', 'class_word': u'ظرف زمان', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مذ', 'is_defined': 0, 'tanwin': 0}],

 u'بكما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِكُمَا', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بكما', 'is_defined': 0, 'tanwin': 0}],

 u'ذوي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَوِي', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'جار', 'word': u'ذوي', 'is_defined': 0, 'tanwin': 0}],

 u'ذوو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَوُو', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'جار', 'word': u'ذوو', 'is_defined': 0, 'tanwin': 0}],

 u'مه': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'مَهْ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مه', 'is_defined': 0, 'tanwin': 0}],

 u'من': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَنْ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'من', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَنْ', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'من', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَنْ', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'من', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مِنْ', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'من', 'is_defined': 0, 'tanwin': 0}],

 u'حبذا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَبَّذَا', 'class_word': u'المدح والذم', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'حبذا', 'is_defined': 0, 'tanwin': 0}],

 u'مادام': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'مَادَامَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مادام', 'is_defined': 0, 'tanwin': 0}],

 u'عدا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَدَا', 'class_word': u'حرف استثناء', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'عدا', 'is_defined': 0, 'tanwin': 0}],

 u'بينما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَيْنَمَا', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'بينما', 'is_defined': 0, 'tanwin': 0}],

 u'وراء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'وَرَاءَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 1, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'وراء', 'is_defined': 0, 'tanwin': 0}],

 u'بات': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'بَاتَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'بات', 'is_defined': 0, 'tanwin': 0}],

 u'عدس': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'عَدَسْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'عدس', 'is_defined': 0, 'tanwin': 0}],

 u'وا': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَا', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَا', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وا', 'is_defined': 0, 'tanwin': 0}],

 u'كلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كِلَا', 'class_word': u'توكيد', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كلا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَلَّا', 'class_word': u'حرف ردع', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كلا', 'is_defined': 0, 'tanwin': 0}],

 u'على': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَلَى', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'على', 'is_defined': 0, 'tanwin': 0}],

 u'علق': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'عَلِقَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'علق', 'is_defined': 0, 'tanwin': 0}],

 u'مازلن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْنَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلن', 'is_defined': 0, 'tanwin': 0}],

 u'حار': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'حَارَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'حار', 'is_defined': 0, 'tanwin': 0}],

 u'وراءكن': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَرَاءَكُنَّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وراءكن', 'is_defined': 0, 'tanwin': 0}],

 u'مازالتا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازَالَتَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازالتا', 'is_defined': 0, 'tanwin': 0}],

 u'وراءكم': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَرَاءَكُمْ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وراءكم', 'is_defined': 0, 'tanwin': 0}],

 u'مادمت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْتُ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْتَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْتِ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمت', 'is_defined': 0, 'tanwin': 0}],

 u'أخي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَخِي', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أخي', 'is_defined': 0, 'tanwin': 0}],

 u'أخو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَخُو', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أخو', 'is_defined': 0, 'tanwin': 0}],

 u'قام': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'قَامَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'قام', 'is_defined': 0, 'tanwin': 0}],

 u'ئ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ئ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ئ', 'is_defined': 0, 'tanwin': 0}],

 u'إذما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إَذْمَا', 'class_word': u'حرف شرط', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إذما', 'is_defined': 0, 'tanwin': 0}],

 u'أين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيْنَ', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أين', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيْنَ', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أين', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيْنَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'أين', 'is_defined': 0, 'tanwin': 0}],

 u'بطآن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بُطْآنَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بطآن', 'is_defined': 0, 'tanwin': 0}],

 u'الألى': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'الْأُلَى', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'الألى', 'is_defined': 1, 'tanwin': 0}],

 u'ض': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ض', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ض', 'is_defined': 0, 'tanwin': 0}],

 u'ذلكم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَلِكُمْ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذلكم', 'is_defined': 0, 'tanwin': 0}],

 u'ذلكن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَلِكُنَّ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذلكن', 'is_defined': 0, 'tanwin': 0}],

 u'أية': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيَّةُ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أية', 'is_defined': 0, 'tanwin': 0}],

 u'نعم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'نَعَمْ', 'class_word': u'الحروف(حروف)', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'نعم', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'نِعْمَ', 'class_word': u'المدح والذم', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'نعم', 'is_defined': 0, 'tanwin': 0}],

 u'أيا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَيَا', 'class_word': u'حرف نداء', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أيا', 'is_defined': 0, 'tanwin': 0}],

 u'هاك': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'هَاكَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هاك', 'is_defined': 0, 'tanwin': 0}],

 u'ذواتي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَوَاتَيْ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذواتي', 'is_defined': 0, 'tanwin': 0}],

 u'مازلت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْتُ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْتَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلت', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَازِلْتِ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مازلت', 'is_defined': 0, 'tanwin': 0}],

 u'آنئذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'آنَئِذٍ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'آنئذ', 'is_defined': 0, 'tanwin': 0}],

 u'أخذ': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'أَخَذَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'أخذ', 'is_defined': 0, 'tanwin': 0}],

 u'ذلك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَلِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذلك', 'is_defined': 0, 'tanwin': 0}],

 u'عندئذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عِنْدَئِذٍ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'عاطل', 'word': u'عندئذ', 'is_defined': 0, 'tanwin': 0}],

 u'أخا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَخَا', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'أخا', 'is_defined': 0, 'tanwin': 0}],

 u'ويكأن': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَيْكَأَنَّ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'ويكأن', 'is_defined': 0, 'tanwin': 0}],

 u'إيانا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِيَّانَا', 'class_word': u'ضمير منفصل منصوب', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إيانا', 'is_defined': 0, 'tanwin': 0}],

 u'كرب': [{'has_conjuction': 1, 'has_conjugation': 1, 'vocalized': u'كَرِبَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'كرب', 'is_defined': 0, 'tanwin': 0}],

 u'لي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لِي', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لي', 'is_defined': 0, 'tanwin': 0}],

 u'لو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَوْ', 'class_word': u'الحروف(حروف)', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لو', 'is_defined': 0, 'tanwin': 0}],

 u'لن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَنْ', 'class_word': u'الحروف(حروف)', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لن', 'is_defined': 0, 'tanwin': 0}],

 u'له': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَهُ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'له', 'is_defined': 0, 'tanwin': 0}],

 u'لم': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَمْ', 'class_word': u'حرف جزم', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'جازم', 'word': u'لم', 'is_defined': 0, 'tanwin': 0}],

 u'لك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَكَ', 'class_word': u'ضمير متصل مجرور', 'type_word': u'ضمير', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لك', 'is_defined': 0, 'tanwin': 0}],

 u'بلا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِلَا', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'بلا', 'is_defined': 0, 'tanwin': 0}],

 u'مادمن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادُمْنَ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مادمن', 'is_defined': 0, 'tanwin': 0}],

 u'ذانك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'ذَانِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ذانك', 'is_defined': 0, 'tanwin': 0}],

 u'إما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'إِمَّا', 'class_word': u'حرف تخيير وتفصيل', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'إما', 'is_defined': 0, 'tanwin': 0}],

 u'هنالك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'هُنَالِكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'هنالك', 'is_defined': 0, 'tanwin': 0}],

 u'مادامت': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَادَامَتْ', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'مادامت', 'is_defined': 0, 'tanwin': 0}],

 u'ء': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ء', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ء', 'is_defined': 0, 'tanwin': 0}],

 u'ريث': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'رَيْثَ', 'class_word': u'ظرف', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'ريث', 'is_defined': 0, 'tanwin': 0}],

 u'طق': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'طَقْ', 'class_word': u'اسم صوت', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'طق', 'is_defined': 0, 'tanwin': 0}],

 u'جميع': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'جَمِيعَ', 'class_word': u'اسم إضافة', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'جميع', 'is_defined': 0, 'tanwin': 1},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'جَمِيعَ', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'جميع', 'is_defined': 0, 'tanwin': 0}],

 u'حول': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'حَوْلَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'حول', 'is_defined': 0, 'tanwin': 0}],

 u'ر': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ر', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ر', 'is_defined': 0, 'tanwin': 0}],

 u'مهما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَهْمَا', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'مهما', 'is_defined': 0, 'tanwin': 0}],

 u'تي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تِي', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تي', 'is_defined': 0, 'tanwin': 0}],

 u'كأي': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'كَأَيٍّ', 'class_word': u'كناية', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'كأي', 'is_defined': 0, 'tanwin': 0}],

 u'لوما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَوْمَا', 'class_word': u'الحروف(حروف)', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لوما', 'is_defined': 0, 'tanwin': 0}],

 u'ته': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تِهِ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ته', 'is_defined': 0, 'tanwin': 0}],

 u'ف': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'ف', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ف', 'is_defined': 0, 'tanwin': 0}],

 u'فو': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فُو', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'فو', 'is_defined': 0, 'tanwin': 1}],

 u'في': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فِي', 'class_word': u'الأسماء الخمسة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'في', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'فِي', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'في', 'is_defined': 0, 'tanwin': 0}],

 u'أ': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'أ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أ', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'أ', 'class_word': u'حرف ابجدي', 'type_word': u'حرف ابجدي', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أ', 'is_defined': 0, 'tanwin': 0}],

 u'أول': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَوَّلَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'أول', 'is_defined': 0, 'tanwin': 0}],

 u'مافتئنا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَافَتِئْنَا', 'class_word': u'كان و أخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'مافتئنا', 'is_defined': 0, 'tanwin': 0}],

 u'مساء': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَسَاءَ', 'class_word': u'ظرف زمان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'مساء', 'is_defined': 0, 'tanwin': 0}],

 u'بماذا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بِمَاذَا', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بماذا', 'is_defined': 0, 'tanwin': 0}],

 u'عين': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'عَيْنَ', 'class_word': u'توكيد', 'type_word': u'اسم', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 1, 'object_type': u'', 'action': u'', 'word': u'عين', 'is_defined': 0, 'tanwin': 0}],

 u'لا': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَا', 'class_word': u'المشبهة بليس', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'لا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَا', 'class_word': u'نافية للجنس', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'لا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَا', 'class_word': u'ناهية', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'جازم', 'word': u'لا', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَا', 'class_word': u'نافية', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'فعل', 'action': u'رافع', 'word': u'لا', 'is_defined': 0, 'tanwin': 0}],

 u'جنب': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'جَنْبَ', 'class_word': u'ظرف مكان', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 1, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 1, 'object_type': u'اسم', 'action': u'جار', 'word': u'جنب', 'is_defined': 0, 'tanwin': 0}],

 u'تلك': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'تِلْكَ', 'class_word': u'اسم إشارة', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 1, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'تلك', 'is_defined': 0, 'tanwin': 0}],

 u'بله': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'بَلْهَ', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بله', 'is_defined': 0, 'tanwin': 0}],

 u'منذ': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مُنْذُ', 'class_word': u'حرف جر', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'جار', 'word': u'منذ', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مُنْذُ', 'class_word': u'ظرف زمان', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'منذ', 'is_defined': 0, 'tanwin': 0}],

 u'أنتما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'أَنْتُمَا', 'class_word': u'ضمير منفصل', 'type_word': u'ضمير', 'has_qasam': 1, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'أنتما', 'is_defined': 0, 'tanwin': 0}],

 u'وراءكما': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'وَرَاءَكُما', 'class_word': u'اسم فعل', 'type_word': u'اسم فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'وراءكما', 'is_defined': 0, 'tanwin': 0}],

 u'لازلن': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'لَازِلْنَ', 'class_word': u'كاد و اخواتها', 'type_word': u'فعل', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 1, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'ناصب', 'word': u'لازلن', 'is_defined': 0, 'tanwin': 0}],

 u'ما': [{'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَا', 'class_word': u'اسم الاستفهام', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَا', 'class_word': u'اسم الشرط', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَا', 'class_word': u'اسم موصول', 'type_word': u'اسم', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'ما', 'is_defined': 0, 'tanwin': 0},
 {'has_conjuction': 1, 'has_conjugation': 0, 'vocalized': u'مَا', 'class_word': u'المشبهة بليس', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'اسم', 'action': u'رافع', 'word': u'ما', 'is_defined': 0, 'tanwin': 0}],

 u'بلى': [{'has_conjuction': 0, 'has_conjugation': 0, 'vocalized': u'بَلَى', 'class_word': u'حرف جواب', 'type_word': u'حرف', 'has_qasam': 0, 'is_inflected': 0, 'has_preposition': 0, 'has_definition': 0, 'has_interrog': 0, 'need': u'', 'has_pronoun': 0, 'object_type': u'', 'action': u'', 'word': u'بلى', 'is_defined': 0, 'tanwin': 0}]}
