#!/usr/bin/env python
# -*- coding: utf-8 -*-
#*************************************
##Arabic Stop word list for morphology analysis and information retrival
##Version        : 0.6
##Generated at   : 2019/02/03:10:03 
##Author         : Taha Zerrouki
##Web            : http://arabicstopwords.sf.net
##Source         : http://github.com/linuxscout/arabicstopwords
##*************************************

STOPWORDS={u'وعداهم': [{'vocalized': u'وعداهم', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'عدا'}],

 u'جنبنا': [{'vocalized': u'جنبنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'فباللتين': [{'vocalized': u'فباللتين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'وبماذا': [{'vocalized': u'وبماذا', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بماذا', 'encletic': u'', 'type': u'اسم', 'original': u'بماذا'}],

 u'وأخونا': [{'vocalized': u'وأخونا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخو'}],

 u'وكبعضكما': [{'vocalized': u'وكبعضكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'وعدانا': [{'vocalized': u'وعدانا', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'عدا'}],

 u'أفكعيننا': [{'vocalized': u'أفكعيننا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'فإنهم': [{'vocalized': u'فإنهم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'فإنهن': [{'vocalized': u'فإنهن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'ولنا': [{'vocalized': u'ولنا', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لنا', 'encletic': u'', 'type': u'ضمير', 'original': u'لنا'}],

 u'كغربكن': [{'vocalized': u'كغربكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'بأنهما': [{'vocalized': u'بأنهما', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'أفبنفس': [{'vocalized': u'أفبنفس', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فبتلكم': [{'vocalized': u'فبتلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أفبكلهما': [{'vocalized': u'أفبكلهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'فلشرقها': [{'vocalized': u'فلشرقها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'وكبعضنا': [{'vocalized': u'وكبعضنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'وبحسبكما': [{'vocalized': u'وبحسبكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'عليهما': [{'vocalized': u'عليهما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'بكلتا': [{'vocalized': u'بكلتا', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفبهنالك': [{'vocalized': u'أفبهنالك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'لحسبي': [{'vocalized': u'لحسبي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'لحسبي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أإلينا': [{'vocalized': u'أإلينا', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'وكابننا': [{'vocalized': u'وكابننا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'بفينا': [{'vocalized': u'بفينا', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'}],

 u'لحسبك': [{'vocalized': u'لحسبك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فلشرقهن': [{'vocalized': u'فلشرقهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'فلشرقهم': [{'vocalized': u'فلشرقهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'فبأخي': [{'vocalized': u'فبأخي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'ولست': [{'vocalized': u'ولست', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'ولست', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'ولست', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'}],

 u'فلإليه': [{'vocalized': u'فلإليه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'بغير': [{'vocalized': u'بغير', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'فباللتيا': [{'vocalized': u'فباللتيا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'ولكلكما': [{'vocalized': u'ولكلكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فلشهرهما': [{'vocalized': u'فلشهرهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'بأقلنا': [{'vocalized': u'بأقلنا', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'فإنها': [{'vocalized': u'فإنها', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'فلأخيكما': [{'vocalized': u'فلأخيكما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'ألعن': [{'vocalized': u'ألعن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'ألعل': [{'vocalized': u'ألعل', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام', 'stem': u'لعل', 'encletic': u'', 'type': u'حرف', 'original': u'لعل'}],

 u'أفكبعضكما': [{'vocalized': u'أفكبعضكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أوعينكم': [{'vocalized': u'أوعينكم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'فكأقل': [{'vocalized': u'فكأقل', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'فلنفسهن': [{'vocalized': u'فلنفسهن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أوعينكن': [{'vocalized': u'أوعينكن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'ولعنهن': [{'vocalized': u'ولعنهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'ولعلينا': [{'vocalized': u'ولعلينا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'ولعنهم': [{'vocalized': u'ولعنهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'أفلغيرهم': [{'vocalized': u'أفلغيرهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيرهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أفلغيرهن': [{'vocalized': u'أفلغيرهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيرهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'ألإنها': [{'vocalized': u'ألإنها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'أخاه': [{'vocalized': u'أخاه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخا'}],

 u'ولأقلك': [{'vocalized': u'ولأقلك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'أخاي': [{'vocalized': u'أخاي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخا'},
 {'vocalized': u'أخاي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخا'}],

 u'وسويهن': [{'vocalized': u'وسويهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'ولأثناءي': [{'vocalized': u'ولأثناءي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'ولأثناءي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفلكأنها': [{'vocalized': u'أفلكأنها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'ولأقلي': [{'vocalized': u'ولأقلي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'ولأقلي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'إلى': [{'vocalized': u'إلى', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'فلتلقاءها': [{'vocalized': u'فلتلقاءها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولغرب': [{'vocalized': u'ولغرب', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'ألازلتن': [{'vocalized': u'ألازلتن', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتن'}],

 u'وكغيره': [{'vocalized': u'وكغيره', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'وكغيرك': [{'vocalized': u'وكغيرك', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'وليتكن': [{'vocalized': u'وليتكن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-كن', 'type': u'حرف', 'original': u'ليت'}],

 u'وليتكم': [{'vocalized': u'وليتكم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-كم', 'type': u'حرف', 'original': u'ليت'}],

 u'وكغيري': [{'vocalized': u'وكغيري', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'وكغيري', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'وعندكم': [{'vocalized': u'وعندكم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عند'}],

 u'أثناءكم': [{'vocalized': u'أثناءكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'فشطركم': [{'vocalized': u'فشطركم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'فشطركن': [{'vocalized': u'فشطركن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'فلتلقاءهم': [{'vocalized': u'فلتلقاءهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ومعاذهما': [{'vocalized': u'ومعاذهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-هما', 'type': u'اسم', 'original': u'معاذ'}],

 u'فلتلقاءهن': [{'vocalized': u'فلتلقاءهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أوكعينكما': [{'vocalized': u'أوكعينكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'سبحانكما': [{'vocalized': u'سبحانكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سبحان'}],

 u'فبجميعك': [{'vocalized': u'فبجميعك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعك', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أخوه': [{'vocalized': u'أخوه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخو'}],

 u'فبجميعه': [{'vocalized': u'فبجميعه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعه', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'فلكنكما': [{'vocalized': u'فلكنكما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنكما', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لكن'}],

 u'أخوي': [{'vocalized': u'أخوي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخو'},
 {'vocalized': u'أخوي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخو'}],

 u'فبجميعي': [{'vocalized': u'فبجميعي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'لكنما': [{'vocalized': u'لكنما', 'procletic': u'', 'tags': u'حرف;كافة ومكفوفة', 'stem': u'لكنما', 'encletic': u'', 'type': u'حرف', 'original': u'لكنما'}],

 u'وكحمي': [{'vocalized': u'وكحمي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'فلدنه': [{'vocalized': u'فلدنه', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدن'}],

 u'فكهناك': [{'vocalized': u'فكهناك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'ألأجمعهن': [{'vocalized': u'ألأجمعهن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكأجمعي': [{'vocalized': u'أكأجمعي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أكأجمعي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكهاتين': [{'vocalized': u'فكهاتين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'فبنفسكما': [{'vocalized': u'فبنفسكما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'بشبه': [{'vocalized': u'بشبه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'حواليكن': [{'vocalized': u'حواليكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حوالى'}],

 u'بتلقاءنا': [{'vocalized': u'بتلقاءنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أكأجمعه': [{'vocalized': u'أكأجمعه', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'فأبينا': [{'vocalized': u'فأبينا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'فذانك': [{'vocalized': u'فذانك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أفلغيرها': [{'vocalized': u'أفلغيرها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيرها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'ألإنهن': [{'vocalized': u'ألإنهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'ألإنهم': [{'vocalized': u'ألإنهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'وكحميكما': [{'vocalized': u'وكحميكما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'أفلكأنهم': [{'vocalized': u'أفلكأنهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'وسويها': [{'vocalized': u'وسويها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أفكلتا': [{'vocalized': u'أفكلتا', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفلكأنهن': [{'vocalized': u'أفلكأنهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'أولنحوكما': [{'vocalized': u'أولنحوكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'وأجمعكم': [{'vocalized': u'وأجمعكم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأجمعكن': [{'vocalized': u'وأجمعكن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفوراءهم': [{'vocalized': u'أفوراءهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'أفوراءهن': [{'vocalized': u'أفوراءهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'بذينك': [{'vocalized': u'بذينك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'أوكلما': [{'vocalized': u'أوكلما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام', 'stem': u'كلما', 'encletic': u'', 'type': u'اسم', 'original': u'كلما'}],

 u'أتلك': [{'vocalized': u'أتلك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'وكشبهكما': [{'vocalized': u'وكشبهكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'أونحونا': [{'vocalized': u'أونحونا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'ولأثناءهما': [{'vocalized': u'ولأثناءهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'شمالكن': [{'vocalized': u'شمالكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'وكعين': [{'vocalized': u'وكعين', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'وبساعتكما': [{'vocalized': u'وبساعتكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلقلما': [{'vocalized': u'فلقلما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'فبأبيهن': [{'vocalized': u'فبأبيهن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'فزمانهن': [{'vocalized': u'فزمانهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'فزمانهم': [{'vocalized': u'فزمانهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'فمعنا': [{'vocalized': u'فمعنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'أوبعينكما': [{'vocalized': u'أوبعينكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'أفلستم': [{'vocalized': u'أفلستم', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لستم', 'encletic': u'', 'type': u'فعل', 'original': u'لستم'}],

 u'فلإنه': [{'vocalized': u'فلإنه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'أذين': [{'vocalized': u'أذين', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'فلإنك': [{'vocalized': u'فلإنك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'وغروبنا': [{'vocalized': u'وغروبنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'أبعضها': [{'vocalized': u'أبعضها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'ولسن': [{'vocalized': u'ولسن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لسن', 'encletic': u'', 'type': u'فعل', 'original': u'لسن'}],

 u'أمنكن': [{'vocalized': u'أمنكن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'فلإني': [{'vocalized': u'فلإني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'فلإني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'أمنكم': [{'vocalized': u'أمنكم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'فلأجمعي': [{'vocalized': u'فلأجمعي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'كجنوبه': [{'vocalized': u'كجنوبه', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'فزمانها': [{'vocalized': u'فزمانها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'فبأبيها': [{'vocalized': u'فبأبيها', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'كجنوبك': [{'vocalized': u'كجنوبك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلأجمعك': [{'vocalized': u'فلأجمعك', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'بعدنا': [{'vocalized': u'بعدنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعد'}],

 u'أفكحسب': [{'vocalized': u'أفكحسب', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'فلأجمعه': [{'vocalized': u'فلأجمعه', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'كجنوبي': [{'vocalized': u'كجنوبي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'كجنوبي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'متى': [{'vocalized': u'متى', 'procletic': u'', 'tags': u'اسم;اسم استفهام/ظرف زمان', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'},
 {'vocalized': u'متى', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'},
 {'vocalized': u'متى', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'}],

 u'فعندكم': [{'vocalized': u'فعندكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عند'}],

 u'فكعينكما': [{'vocalized': u'فكعينكما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فعندكن': [{'vocalized': u'فعندكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عند'}],

 u'فبأية': [{'vocalized': u'فبأية', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'أفوراءها': [{'vocalized': u'أفوراءها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'ثنا': [{'vocalized': u'ثنا', 'procletic': u'', 'tags': u'فعل;اختصار', 'stem': u'ثنا', 'encletic': u'', 'type': u'فعل', 'original': u'ثنا'}],

 u'أفلعلى': [{'vocalized': u'أفلعلى', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'أفهكذا': [{'vocalized': u'أفهكذا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هكذا', 'encletic': u'', 'type': u'اسم', 'original': u'هكذا'}],

 u'بجنب': [{'vocalized': u'بجنب', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'وكشرقي': [{'vocalized': u'وكشرقي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'وكشرقي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'ومازال': [{'vocalized': u'ومازال', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازال', 'encletic': u'', 'type': u'فعل', 'original': u'مازال'}],

 u'فكبعضهما': [{'vocalized': u'فكبعضهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'وكشرقه': [{'vocalized': u'وكشرقه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'فلفوقكن': [{'vocalized': u'فلفوقكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'ضمني': [{'vocalized': u'ضمني', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ضمن'},
 {'vocalized': u'ضمني', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ضمن'}],

 u'وكشرقك': [{'vocalized': u'وكشرقك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'لعمرها': [{'vocalized': u'لعمرها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لعمر'}],

 u'فاللتيا': [{'vocalized': u'فاللتيا', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'فبأننا': [{'vocalized': u'فبأننا', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'لشهرهن': [{'vocalized': u'لشهرهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'لشهرهم': [{'vocalized': u'لشهرهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'فجميعهما': [{'vocalized': u'فجميعهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعهما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'حموي': [{'vocalized': u'حموي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمو'},
 {'vocalized': u'حموي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمو'}],

 u'فبسويه': [{'vocalized': u'فبسويه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'ولحسبكن': [{'vocalized': u'ولحسبكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'حموه': [{'vocalized': u'حموه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمو'}],

 u'ولحسبكم': [{'vocalized': u'ولحسبكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفككلهما': [{'vocalized': u'أفككلهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'أوكجميعنا': [{'vocalized': u'أوكجميعنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'أخاهن': [{'vocalized': u'أخاهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخا'}],

 u'أخاهم': [{'vocalized': u'أخاهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخا'}],

 u'بأثناءه': [{'vocalized': u'بأثناءه', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'للتيا': [{'vocalized': u'للتيا', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'ألعلينا': [{'vocalized': u'ألعلينا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'بأثناءي': [{'vocalized': u'بأثناءي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'بأثناءي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولجميعنا': [{'vocalized': u'ولجميعنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعنا', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'لحسبه': [{'vocalized': u'لحسبه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'فبسويك': [{'vocalized': u'فبسويك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'وشرع': [{'vocalized': u'وشرع', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'شرع', 'encletic': u'', 'type': u'فعل', 'original': u'شرع'}],

 u'فحموكن': [{'vocalized': u'فحموكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمو'}],

 u'وللحظتنا': [{'vocalized': u'وللحظتنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'فحموكم': [{'vocalized': u'فحموكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمو'}],

 u'فكلحظتنا': [{'vocalized': u'فكلحظتنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبأقلنا': [{'vocalized': u'وبأقلنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'أخلفكما': [{'vocalized': u'أخلفكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'أخاها': [{'vocalized': u'أخاها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخا'}],

 u'فقلما': [{'vocalized': u'فقلما', 'procletic': u'ف-', 'tags': u'فعل;فعل جامد;عطف', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'للتين': [{'vocalized': u'للتين', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'أفإليه': [{'vocalized': u'أفإليه', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'أفإليك': [{'vocalized': u'أفإليك', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'لتلك': [{'vocalized': u'لتلك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'ألكليكما': [{'vocalized': u'ألكليكما', 'procletic': u'أ-ل-', 'tags': u'حرف;توكيد;مجرور;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'فمما': [{'vocalized': u'فمما', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'مما', 'encletic': u'', 'type': u'اسم', 'original': u'مما'}],

 u'فذوينا': [{'vocalized': u'فذوينا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'وهلا': [{'vocalized': u'وهلا', 'procletic': u'و-', 'tags': u'حرف;حرف تحضيض;عطف', 'stem': u'هلا', 'encletic': u'', 'type': u'حرف', 'original': u'هلا'}],

 u'فبفينا': [{'vocalized': u'فبفينا', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'}],

 u'لعمرهم': [{'vocalized': u'لعمرهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لعمر'}],

 u'لعمرهن': [{'vocalized': u'لعمرهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لعمر'}],

 u'ولغيركن': [{'vocalized': u'ولغيركن', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيركن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'ولغيركم': [{'vocalized': u'ولغيركم', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيركم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'لازالوا': [{'vocalized': u'لازالوا', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالوا'}],

 u'أفليست': [{'vocalized': u'أفليست', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليست', 'encletic': u'', 'type': u'فعل', 'original': u'ليست'}],

 u'لشهرها': [{'vocalized': u'لشهرها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'وآناء': [{'vocalized': u'وآناء', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آناء', 'encletic': u'', 'type': u'اسم', 'original': u'آناء'}],

 u'أفليسا': [{'vocalized': u'أفليسا', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليسا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسا'}],

 u'أونفس': [{'vocalized': u'أونفس', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أولذاك': [{'vocalized': u'أولذاك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'ماانفككن': [{'vocalized': u'ماانفككن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككن', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككن'}],

 u'وبلحظتك': [{'vocalized': u'وبلحظتك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفتحتها': [{'vocalized': u'أفتحتها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'أونفسهن': [{'vocalized': u'أونفسهن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أونفسهم': [{'vocalized': u'أونفسهم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'وجنوبك': [{'vocalized': u'وجنوبك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكشرقنا': [{'vocalized': u'وكشرقنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'أوذواتا': [{'vocalized': u'أوذواتا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذواتا', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتا'}],

 u'فيمينهم': [{'vocalized': u'فيمينهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'وكأثناءكم': [{'vocalized': u'وكأثناءكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'فخلفكن': [{'vocalized': u'فخلفكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'ولذاتها': [{'vocalized': u'ولذاتها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'وكأثناءكن': [{'vocalized': u'وكأثناءكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'لازالت': [{'vocalized': u'لازالت', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'},
 {'vocalized': u'لازالت', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'}],

 u'لعينكما': [{'vocalized': u'لعينكما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'ولغروبي': [{'vocalized': u'ولغروبي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'ولغروبي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'لازالا': [{'vocalized': u'لازالا', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازالا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالا'}],

 u'أفإنهن': [{'vocalized': u'أفإنهن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'وكحسبكن': [{'vocalized': u'وكحسبكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'وكحسبكم': [{'vocalized': u'وكحسبكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفإنهم': [{'vocalized': u'أفإنهم', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'أوسويهم': [{'vocalized': u'أوسويهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوسويهن': [{'vocalized': u'أوسويهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'بالتي': [{'vocalized': u'بالتي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'لنحوه': [{'vocalized': u'لنحوه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوه', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'لأيهن': [{'vocalized': u'لأيهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'لأيهم': [{'vocalized': u'لأيهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'ولليلكما': [{'vocalized': u'ولليلكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'لنحوي': [{'vocalized': u'لنحوي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'أفطالما': [{'vocalized': u'أفطالما', 'procletic': u'أ-ف-', 'tags': u'فعل;فعل جامد;عطف;استفهام', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'أوسويها': [{'vocalized': u'أوسويها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلعين': [{'vocalized': u'أفلعين', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعين', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'أغيرهما': [{'vocalized': u'أغيرهما', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'بنحو': [{'vocalized': u'بنحو', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحو', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فبأسفلي': [{'vocalized': u'فبأسفلي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'فبأسفلي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'وتلقاءنا': [{'vocalized': u'وتلقاءنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولغروبك': [{'vocalized': u'ولغروبك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'ابن': [{'vocalized': u'ابن', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'لأيها': [{'vocalized': u'لأيها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'تين': [{'vocalized': u'تين', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'أبعض': [{'vocalized': u'أبعض', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'أفتحتهم': [{'vocalized': u'أفتحتهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'ألمثلهما': [{'vocalized': u'ألمثلهما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'أفتحتهن': [{'vocalized': u'أفتحتهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'أونفسها': [{'vocalized': u'أونفسها', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أإليهما': [{'vocalized': u'أإليهما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'فلإليك': [{'vocalized': u'فلإليك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'ماانفككت': [{'vocalized': u'ماانفككت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'},
 {'vocalized': u'ماانفككت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'},
 {'vocalized': u'ماانفككت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'}],

 u'تجاهنا': [{'vocalized': u'تجاهنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تجاه'}],

 u'ولذاتهم': [{'vocalized': u'ولذاتهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'ولذاتهن': [{'vocalized': u'ولذاتهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'وكأنكما': [{'vocalized': u'وكأنكما', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنكما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'أفلإليهما': [{'vocalized': u'أفلإليهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'ومابرحتما': [{'vocalized': u'ومابرحتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتما', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتما'},
 {'vocalized': u'ومابرحتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتما', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتما'}],

 u'أفإنها': [{'vocalized': u'أفإنها', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'ساعتكن': [{'vocalized': u'ساعتكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلجميع': [{'vocalized': u'فلجميع', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميع', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميع', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميع', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'لغربه': [{'vocalized': u'لغربه', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'فكساعتهما': [{'vocalized': u'فكساعتهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلعامتكم': [{'vocalized': u'فلعامتكم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أكذا': [{'vocalized': u'أكذا', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام', 'stem': u'كذا', 'encletic': u'', 'type': u'اسم', 'original': u'كذا'}],

 u'أوعامتنا': [{'vocalized': u'أوعامتنا', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'معنا': [{'vocalized': u'معنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'أوذانك': [{'vocalized': u'أوذانك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أكلكما': [{'vocalized': u'أكلكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلكما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'ولكنما': [{'vocalized': u'ولكنما', 'procletic': u'و-', 'tags': u'حرف;كافة ومكفوفة;عطف', 'stem': u'لكنما', 'encletic': u'', 'type': u'حرف', 'original': u'لكنما'}],

 u'أكذاك': [{'vocalized': u'أكذاك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'بينهم': [{'vocalized': u'بينهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بين'}],

 u'بينهن': [{'vocalized': u'بينهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بين'}],

 u'فبنفسكم': [{'vocalized': u'فبنفسكم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'أعليكما': [{'vocalized': u'أعليكما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'أمنهما': [{'vocalized': u'أمنهما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'وأيتهما': [{'vocalized': u'وأيتهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'بأعلى': [{'vocalized': u'بأعلى', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'بأعلي': [{'vocalized': u'بأعلي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'بأعلي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'أوعنها': [{'vocalized': u'أوعنها', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'مثلهم': [{'vocalized': u'مثلهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'مثلهن': [{'vocalized': u'مثلهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'أوجميعهما': [{'vocalized': u'أوجميعهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعهما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفبمثلي': [{'vocalized': u'أفبمثلي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفبمثلي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'فكجنبي': [{'vocalized': u'فكجنبي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'فكجنبي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'بينها': [{'vocalized': u'بينها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بين'}],

 u'أفبمثله': [{'vocalized': u'أفبمثله', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'ألأناهما': [{'vocalized': u'ألأناهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'فكجنبه': [{'vocalized': u'فكجنبه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'أفبمثلك': [{'vocalized': u'أفبمثلك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'فعامتها': [{'vocalized': u'فعامتها', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'أفأجمعنا': [{'vocalized': u'أفأجمعنا', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكجنبك': [{'vocalized': u'فكجنبك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'فلأنتم': [{'vocalized': u'فلأنتم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'فلأنتن': [{'vocalized': u'فلأنتن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'وبلحظتي': [{'vocalized': u'وبلحظتي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'وبلحظتي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'فيمينها': [{'vocalized': u'فيمينها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'أوعنهن': [{'vocalized': u'أوعنهن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أوعنهم': [{'vocalized': u'أوعنهم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'مثلها': [{'vocalized': u'مثلها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'بأجمعكما': [{'vocalized': u'بأجمعكما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولأصبح': [{'vocalized': u'ولأصبح', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أصبح', 'encletic': u'', 'type': u'فعل', 'original': u'أصبح'}],

 u'أكذي': [{'vocalized': u'أكذي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'أعامتهما': [{'vocalized': u'أعامتهما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أفبعض': [{'vocalized': u'أفبعض', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'فكخلفها': [{'vocalized': u'فكخلفها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'أوأمامك': [{'vocalized': u'أوأمامك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'وإنكما': [{'vocalized': u'وإنكما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'ألأجمعها': [{'vocalized': u'ألأجمعها', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'غروبهم': [{'vocalized': u'غروبهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'غروبهن': [{'vocalized': u'غروبهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'أولعين': [{'vocalized': u'أولعين', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعين', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'بوقتنا': [{'vocalized': u'بوقتنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'فكليلكن': [{'vocalized': u'فكليلكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'وخلفكن': [{'vocalized': u'وخلفكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'ولابن': [{'vocalized': u'ولابن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'فرويدك': [{'vocalized': u'فرويدك', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'رويدك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'رويدك'}],

 u'أفسوينا': [{'vocalized': u'أفسوينا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'فلساعته': [{'vocalized': u'فلساعته', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'فحول': [{'vocalized': u'فحول', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'حول', 'encletic': u'', 'type': u'اسم', 'original': u'حول'}],

 u'لقام': [{'vocalized': u'لقام', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'قام', 'encletic': u'', 'type': u'فعل', 'original': u'قام'}],

 u'لذاتهن': [{'vocalized': u'لذاتهن', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'أإنكن': [{'vocalized': u'أإنكن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'فلذويهما': [{'vocalized': u'فلذويهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أإنكم': [{'vocalized': u'أإنكم', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'أومن': [{'vocalized': u'أومن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم موصول;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'أومن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'وكسوينا': [{'vocalized': u'وكسوينا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلفيي': [{'vocalized': u'أفلفيي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'أفلفيي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'كأثناءها': [{'vocalized': u'كأثناءها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'أوغيركم': [{'vocalized': u'أوغيركم', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أوغيركن': [{'vocalized': u'أوغيركن', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'لظل': [{'vocalized': u'لظل', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'ظل', 'encletic': u'', 'type': u'فعل', 'original': u'ظل'}],

 u'أومما': [{'vocalized': u'أومما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم الاستفهام;عطف;استفهام', 'stem': u'مما', 'encletic': u'', 'type': u'اسم', 'original': u'مما'}],

 u'أليمينهن': [{'vocalized': u'أليمينهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'أليمينهم': [{'vocalized': u'أليمينهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'أومع': [{'vocalized': u'أومع', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'أوبجميعكم': [{'vocalized': u'أوبجميعكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'وكأبيكن': [{'vocalized': u'وكأبيكن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'أوبجميعكن': [{'vocalized': u'أوبجميعكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'كأثناءهم': [{'vocalized': u'كأثناءهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'كأثناءهن': [{'vocalized': u'كأثناءهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'صار': [{'vocalized': u'صار', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'صار', 'encletic': u'', 'type': u'فعل', 'original': u'صار'}],

 u'باللتين': [{'vocalized': u'باللتين', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'أفبعينكما': [{'vocalized': u'أفبعينكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فبأبي': [{'vocalized': u'فبأبي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'حماكم': [{'vocalized': u'حماكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حما'}],

 u'وكأبيكم': [{'vocalized': u'وكأبيكم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'فكغروبنا': [{'vocalized': u'فكغروبنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'ذووهما': [{'vocalized': u'ذووهما', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوو'}],

 u'وبغير': [{'vocalized': u'وبغير', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'ولأقله': [{'vocalized': u'ولأقله', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'فلحميكم': [{'vocalized': u'فلحميكم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'أفمعه': [{'vocalized': u'أفمعه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'أمثلهما': [{'vocalized': u'أمثلهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فلجنبهما': [{'vocalized': u'فلجنبهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'لته': [{'vocalized': u'لته', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'لتي': [{'vocalized': u'لتي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'فبغربك': [{'vocalized': u'فبغربك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'أكثرهم': [{'vocalized': u'أكثرهم', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'كهاتين': [{'vocalized': u'كهاتين', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'وبعينها': [{'vocalized': u'وبعينها', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'كأعليهما': [{'vocalized': u'كأعليهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'وأثناءكن': [{'vocalized': u'وأثناءكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'كلحظتها': [{'vocalized': u'كلحظتها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'وحتى': [{'vocalized': u'وحتى', 'procletic': u'و-', 'tags': u'حرف;تعليل;عطف', 'stem': u'حتى', 'encletic': u'', 'type': u'حرف', 'original': u'حتى'},
 {'vocalized': u'وحتى', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'حتى', 'encletic': u'', 'type': u'حرف', 'original': u'حتى'}],

 u'كخلفكما': [{'vocalized': u'كخلفكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'مافتئوا': [{'vocalized': u'مافتئوا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئوا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئوا'}],

 u'وحماك': [{'vocalized': u'وحماك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حما'}],

 u'أبغيركم': [{'vocalized': u'أبغيركم', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أبغيركن': [{'vocalized': u'أبغيركن', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'فلراح': [{'vocalized': u'فلراح', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'راح', 'encletic': u'', 'type': u'فعل', 'original': u'راح'}],

 u'ولشبهكن': [{'vocalized': u'ولشبهكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'وأبوهم': [{'vocalized': u'وأبوهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبو'}],

 u'أوكلك': [{'vocalized': u'أوكلك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلك', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'جنوبهما': [{'vocalized': u'جنوبهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوكله': [{'vocalized': u'أوكله', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكله', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'بأخي': [{'vocalized': u'بأخي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'ولساعتهما': [{'vocalized': u'ولساعتهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'وخلالك': [{'vocalized': u'وخلالك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلال'}],

 u'وسويهم': [{'vocalized': u'وسويهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'فأسفلك': [{'vocalized': u'فأسفلك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'وأصبح': [{'vocalized': u'وأصبح', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'أصبح', 'encletic': u'', 'type': u'فعل', 'original': u'أصبح'}],

 u'أفلبعضهما': [{'vocalized': u'أفلبعضهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'فأسفلي': [{'vocalized': u'فأسفلي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'فأسفلي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولهناك': [{'vocalized': u'ولهناك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أوكلا': [{'vocalized': u'أوكلا', 'procletic': u'أ-و-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'}],

 u'ألأنت': [{'vocalized': u'ألأنت', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'ألأنت', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'فكجنوبك': [{'vocalized': u'فكجنوبك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'كوقته': [{'vocalized': u'كوقته', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'وبعامتك': [{'vocalized': u'وبعامتك', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'ألأنا': [{'vocalized': u'ألأنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'ألأنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'حينئذ': [{'vocalized': u'حينئذ', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'حينئذ', 'encletic': u'', 'type': u'اسم', 'original': u'حينئذ'}],

 u'فعامتنا': [{'vocalized': u'فعامتنا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أكثرها': [{'vocalized': u'أكثرها', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'وبعينهن': [{'vocalized': u'وبعينهن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'وبعينهم': [{'vocalized': u'وبعينهم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أبشبهكما': [{'vocalized': u'أبشبهكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'ولذواتي': [{'vocalized': u'ولذواتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'وكجنوبنا': [{'vocalized': u'وكجنوبنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'وفيكما': [{'vocalized': u'وفيكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيكما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'كلحظتهم': [{'vocalized': u'كلحظتهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلكرب': [{'vocalized': u'فلكرب', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كرب', 'encletic': u'', 'type': u'فعل', 'original': u'كرب'}],

 u'أولكليهما': [{'vocalized': u'أولكليهما', 'procletic': u'أ-و-ل-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'فكأبينا': [{'vocalized': u'فكأبينا', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'وأثناءه': [{'vocalized': u'وأثناءه', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'فكذويهما': [{'vocalized': u'فكذويهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'ألنحوك': [{'vocalized': u'ألنحوك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'وأولئك': [{'vocalized': u'وأولئك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'ألنحوه': [{'vocalized': u'ألنحوه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'ألنحوي': [{'vocalized': u'ألنحوي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ألنحوي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'أعامتها': [{'vocalized': u'أعامتها', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'أفنحوكن': [{'vocalized': u'أفنحوكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'وبالذين': [{'vocalized': u'وبالذين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'أفكلكما': [{'vocalized': u'أفكلكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلكما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'أفنحوكم': [{'vocalized': u'أفنحوكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'لشبهها': [{'vocalized': u'لشبهها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'فلغروبنا': [{'vocalized': u'فلغروبنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'وكجنبهما': [{'vocalized': u'وكجنبهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'فجعل': [{'vocalized': u'فجعل', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'جعل', 'encletic': u'', 'type': u'فعل', 'original': u'جعل'}],

 u'فكمثلها': [{'vocalized': u'فكمثلها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'فلغيرنا': [{'vocalized': u'فلغيرنا', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيرنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أفلأجمعهما': [{'vocalized': u'أفلأجمعهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولسويها': [{'vocalized': u'ولسويها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'وكالذين': [{'vocalized': u'وكالذين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'كفيها': [{'vocalized': u'كفيها', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'}],

 u'لسويهن': [{'vocalized': u'لسويهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'لسويهم': [{'vocalized': u'لسويهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'وإليكم': [{'vocalized': u'وإليكم', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليكم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكم'},
 {'vocalized': u'وإليكم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'وإليكن': [{'vocalized': u'وإليكن', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليكن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكن'},
 {'vocalized': u'وإليكن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'أفعامتها': [{'vocalized': u'أفعامتها', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'فلإلى': [{'vocalized': u'فلإلى', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'ولنفسهما': [{'vocalized': u'ولنفسهما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'فلإلي': [{'vocalized': u'فلإلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'فلإلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'فشطركما': [{'vocalized': u'فشطركما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'أولوراءهن': [{'vocalized': u'أولوراءهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'أولوراءهم': [{'vocalized': u'أولوراءهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'بأخينا': [{'vocalized': u'بأخينا', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'لسويها': [{'vocalized': u'لسويها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'لتينك': [{'vocalized': u'لتينك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'فبأثناءهن': [{'vocalized': u'فبأثناءهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'أويمين': [{'vocalized': u'أويمين', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'بشطري': [{'vocalized': u'بشطري', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'بشطري', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'أولوراءها': [{'vocalized': u'أولوراءها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'بشطره': [{'vocalized': u'بشطره', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'فكشطركما': [{'vocalized': u'فكشطركما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'بشطرك': [{'vocalized': u'بشطرك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'فكذوينا': [{'vocalized': u'فكذوينا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'شطرهما': [{'vocalized': u'شطرهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'بغروبكم': [{'vocalized': u'بغروبكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'أعامتهم': [{'vocalized': u'أعامتهم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'فباللذين': [{'vocalized': u'فباللذين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'بغروبكن': [{'vocalized': u'بغروبكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'فكليله': [{'vocalized': u'فكليله', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'فببعضهما': [{'vocalized': u'فببعضهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'وعنك': [{'vocalized': u'وعنك', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'لشبههم': [{'vocalized': u'لشبههم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبههم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'لشبههن': [{'vocalized': u'لشبههن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبههن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلوراءكم': [{'vocalized': u'أفلوراءكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'فكمثلهن': [{'vocalized': u'فكمثلهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'فكمثلهم': [{'vocalized': u'فكمثلهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'فبساعتنا': [{'vocalized': u'فبساعتنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'فعند': [{'vocalized': u'فعند', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'عند', 'encletic': u'', 'type': u'اسم', 'original': u'عند'}],

 u'وببعضي': [{'vocalized': u'وببعضي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'وببعضي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'وغربه': [{'vocalized': u'وغربه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'وغربي': [{'vocalized': u'وغربي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'وغربي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'وببعضك': [{'vocalized': u'وببعضك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'وسوف': [{'vocalized': u'وسوف', 'procletic': u'و-', 'tags': u'حرف;حرف استقبال;عطف', 'stem': u'سوف', 'encletic': u'', 'type': u'حرف', 'original': u'سوف'}],

 u'وببعضه': [{'vocalized': u'وببعضه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'لوقتهما': [{'vocalized': u'لوقتهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'أعامتي': [{'vocalized': u'أعامتي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أعامتي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'أوببعض': [{'vocalized': u'أوببعض', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'ولأكثرنا': [{'vocalized': u'ولأكثرنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'أوبنحوهم': [{'vocalized': u'أوبنحوهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أوبنحوهن': [{'vocalized': u'أوبنحوهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'أوهاذين': [{'vocalized': u'أوهاذين', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'كذانك': [{'vocalized': u'كذانك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'فلسويها': [{'vocalized': u'فلسويها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'بأنكما': [{'vocalized': u'بأنكما', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'خلالي': [{'vocalized': u'خلالي', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلال'},
 {'vocalized': u'خلالي', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلال'}],

 u'ولأبي': [{'vocalized': u'ولأبي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'ومنهما': [{'vocalized': u'ومنهما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'خلاله': [{'vocalized': u'خلاله', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلال'}],

 u'خلالك': [{'vocalized': u'خلالك', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلال'}],

 u'أبوهن': [{'vocalized': u'أبوهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبو'}],

 u'أبوهم': [{'vocalized': u'أبوهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبو'}],

 u'ألأمامه': [{'vocalized': u'ألأمامه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'أولنفسك': [{'vocalized': u'أولنفسك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'أولأمامه': [{'vocalized': u'أولأمامه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'ألأمامك': [{'vocalized': u'ألأمامك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'ومتى': [{'vocalized': u'ومتى', 'procletic': u'و-', 'tags': u'اسم;اسم استفهام/ظرف زمان;عطف', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'},
 {'vocalized': u'ومتى', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'},
 {'vocalized': u'ومتى', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'}],

 u'ولليلك': [{'vocalized': u'ولليلك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'أولنحوهم': [{'vocalized': u'أولنحوهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'ألأمامي': [{'vocalized': u'ألأمامي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'ألأمامي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'أولنحوهن': [{'vocalized': u'أولنحوهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'فبشبهنا': [{'vocalized': u'فبشبهنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'فلسويهم': [{'vocalized': u'فلسويهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'وكحمينا': [{'vocalized': u'وكحمينا', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'فتحتهما': [{'vocalized': u'فتحتهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'ألنفسهن': [{'vocalized': u'ألنفسهن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'ألنفسهم': [{'vocalized': u'ألنفسهم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'ألديكما': [{'vocalized': u'ألديكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدى'}],

 u'أبوها': [{'vocalized': u'أبوها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبو'}],

 u'أوكذلك': [{'vocalized': u'أوكذلك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'},
 {'vocalized': u'أوكذلك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'كذلك', 'encletic': u'', 'type': u'اسم', 'original': u'كذلك'}],

 u'أولنحوها': [{'vocalized': u'أولنحوها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'وبتلقاء': [{'vocalized': u'وبتلقاء', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ومعاذك': [{'vocalized': u'ومعاذك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ك', 'type': u'اسم', 'original': u'معاذ'}],

 u'أخوك': [{'vocalized': u'أخوك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخو'}],

 u'بأيتهن': [{'vocalized': u'بأيتهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'كجنبه': [{'vocalized': u'كجنبه', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'ومعاذه': [{'vocalized': u'ومعاذه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ه', 'type': u'اسم', 'original': u'معاذ'}],

 u'فكاللاتي': [{'vocalized': u'فكاللاتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'تجاههن': [{'vocalized': u'تجاههن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تجاه'}],

 u'ومعاذي': [{'vocalized': u'ومعاذي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ي', 'type': u'اسم', 'original': u'معاذ'},
 {'vocalized': u'ومعاذي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ي', 'type': u'اسم', 'original': u'معاذ'}],

 u'ولاسيما': [{'vocalized': u'ولاسيما', 'procletic': u'و-', 'tags': u'حرف;استثناء;عطف', 'stem': u'لاسيما', 'encletic': u'', 'type': u'حرف', 'original': u'لاسيما'}],

 u'ولسويهم': [{'vocalized': u'ولسويهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكحسبي': [{'vocalized': u'أوكحسبي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أوكحسبي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'كفيهم': [{'vocalized': u'كفيهم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'}],

 u'بغيركن': [{'vocalized': u'بغيركن', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'بغيركم': [{'vocalized': u'بغيركم', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أوكحسبك': [{'vocalized': u'أوكحسبك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبنحوها': [{'vocalized': u'أوبنحوها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'أوكحسبه': [{'vocalized': u'أوكحسبه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أفعامتي': [{'vocalized': u'أفعامتي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفعامتي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فلأجمعهم': [{'vocalized': u'فلأجمعهم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكأولئك': [{'vocalized': u'أكأولئك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'فبحيث': [{'vocalized': u'فبحيث', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'فمعاذه': [{'vocalized': u'فمعاذه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ه', 'type': u'اسم', 'original': u'معاذ'}],

 u'أنحوهما': [{'vocalized': u'أنحوهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'كبعضكما': [{'vocalized': u'كبعضكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'ومعاذكما': [{'vocalized': u'ومعاذكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-كما', 'type': u'اسم', 'original': u'معاذ'}],

 u'أوأجمعنا': [{'vocalized': u'أوأجمعنا', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'للحظتي': [{'vocalized': u'للحظتي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'للحظتي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'للألى': [{'vocalized': u'للألى', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'فبعضهم': [{'vocalized': u'فبعضهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'فغيركما': [{'vocalized': u'فغيركما', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فبعضهن': [{'vocalized': u'فبعضهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'للحظتك': [{'vocalized': u'للحظتك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلبعضها': [{'vocalized': u'فلبعضها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'أولازلتم': [{'vocalized': u'أولازلتم', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتم'}],

 u'للحظته': [{'vocalized': u'للحظته', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'أوبغيرنا': [{'vocalized': u'أوبغيرنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'جميعك': [{'vocalized': u'جميعك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعك', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'فلشبه': [{'vocalized': u'فلشبه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'جميعه': [{'vocalized': u'جميعه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعه', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'حميه': [{'vocalized': u'حميه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'أفلفيهما': [{'vocalized': u'أفلفيهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'جميعي': [{'vocalized': u'جميعي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'حميي': [{'vocalized': u'حميي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'حميي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'فلغربكم': [{'vocalized': u'فلغربكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'ببعضهما': [{'vocalized': u'ببعضهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'وبكلها': [{'vocalized': u'وبكلها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلها', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'فابتدأ': [{'vocalized': u'فابتدأ', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'ابتدأ', 'encletic': u'', 'type': u'فعل', 'original': u'ابتدأ'}],

 u'فشرق': [{'vocalized': u'فشرق', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'أبجميعهما': [{'vocalized': u'أبجميعهما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعهما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أوبذي': [{'vocalized': u'أوبذي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'أفكلا': [{'vocalized': u'أفكلا', 'procletic': u'أ-ف-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'}],

 u'بالذي': [{'vocalized': u'بالذي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'فشرع': [{'vocalized': u'فشرع', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'شرع', 'encletic': u'', 'type': u'فعل', 'original': u'شرع'}],

 u'أبعامتهن': [{'vocalized': u'أبعامتهن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'أولعلينا': [{'vocalized': u'أولعلينا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'فكشرقك': [{'vocalized': u'فكشرقك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'كزمانكما': [{'vocalized': u'كزمانكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'ألأجمعهم': [{'vocalized': u'ألأجمعهم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوليمينهما': [{'vocalized': u'أوليمينهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'وبكلهن': [{'vocalized': u'وبكلهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلهن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'وبكلهم': [{'vocalized': u'وبكلهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلهم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'لشبههما': [{'vocalized': u'لشبههما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبههما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فعننا': [{'vocalized': u'فعننا', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'أفكلك': [{'vocalized': u'أفكلك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلك', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'أفكله': [{'vocalized': u'أفكله', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكله', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'وبجميعنا': [{'vocalized': u'وبجميعنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعنا', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'لشمال': [{'vocalized': u'لشمال', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'فحينما': [{'vocalized': u'فحينما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'حينما', 'encletic': u'', 'type': u'اسم', 'original': u'حينما'}],

 u'وكأجمعي': [{'vocalized': u'وكأجمعي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'وكأجمعي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'وهيا': [{'vocalized': u'وهيا', 'procletic': u'و-', 'tags': u'حرف;حرف نداء;عطف', 'stem': u'هيا', 'encletic': u'', 'type': u'حرف', 'original': u'هيا'}],

 u'وكأجمعه': [{'vocalized': u'وكأجمعه', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'وهيت': [{'vocalized': u'وهيت', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'هيت', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هيت'}],

 u'وكأجمعك': [{'vocalized': u'وكأجمعك', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'وفيما': [{'vocalized': u'وفيما', 'procletic': u'و-', 'tags': u'حرف;حرف استفهام;عطف', 'stem': u'فيما', 'encletic': u'', 'type': u'حرف', 'original': u'فيما'}],

 u'أفمثله': [{'vocalized': u'أفمثله', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'كغربه': [{'vocalized': u'كغربه', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'أفمثلك': [{'vocalized': u'أفمثلك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'فبعضها': [{'vocalized': u'فبعضها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'فلبعضهن': [{'vocalized': u'فلبعضهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'فلبعضهم': [{'vocalized': u'فلبعضهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفمثلي': [{'vocalized': u'أفمثلي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفمثلي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أوأولاء': [{'vocalized': u'أوأولاء', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'أكأجمعك': [{'vocalized': u'أكأجمعك', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'لشطرهما': [{'vocalized': u'لشطرهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'يمينهم': [{'vocalized': u'يمينهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'يمينهن': [{'vocalized': u'يمينهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'أبه': [{'vocalized': u'أبه', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'به', 'encletic': u'', 'type': u'ضمير', 'original': u'به'}],

 u'أبو': [{'vocalized': u'أبو', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أبو', 'encletic': u'', 'type': u'اسم', 'original': u'أبو'}],

 u'أولعيننا': [{'vocalized': u'أولعيننا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعيننا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'أبي': [{'vocalized': u'أبي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'أبي', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'بي', 'encletic': u'', 'type': u'ضمير', 'original': u'بي'}],

 u'أوليس': [{'vocalized': u'أوليس', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليس', 'encletic': u'', 'type': u'فعل', 'original': u'ليس'}],

 u'ولعنها': [{'vocalized': u'ولعنها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'أوبها': [{'vocalized': u'أوبها', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بها', 'encletic': u'', 'type': u'ضمير', 'original': u'بها'}],

 u'فليلكن': [{'vocalized': u'فليلكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'غربكم': [{'vocalized': u'غربكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'لأقلها': [{'vocalized': u'لأقلها', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'غربكن': [{'vocalized': u'غربكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'فبزمان': [{'vocalized': u'فبزمان', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'حواليكم': [{'vocalized': u'حواليكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حوالى'}],

 u'أوكحسبها': [{'vocalized': u'أوكحسبها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'فككلك': [{'vocalized': u'فككلك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلك', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'وكعامتكم': [{'vocalized': u'وكعامتكم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أفأجمعكما': [{'vocalized': u'أفأجمعكما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فتجاه': [{'vocalized': u'فتجاه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'تجاه', 'encletic': u'', 'type': u'اسم', 'original': u'تجاه'}],

 u'فككله': [{'vocalized': u'فككله', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككله', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'مادمتن': [{'vocalized': u'مادمتن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمتن', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتن'}],

 u'تجاهكما': [{'vocalized': u'تجاهكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تجاه'}],

 u'ولأيكم': [{'vocalized': u'ولأيكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'ولأيكن': [{'vocalized': u'ولأيكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'كسوينا': [{'vocalized': u'كسوينا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'ابتدأ': [{'vocalized': u'ابتدأ', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'ابتدأ', 'encletic': u'', 'type': u'فعل', 'original': u'ابتدأ'}],

 u'أوكشبهه': [{'vocalized': u'أوكشبهه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'فكابنه': [{'vocalized': u'فكابنه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'أولهذه': [{'vocalized': u'أولهذه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'أوكشبهك': [{'vocalized': u'أوكشبهك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'فكابنك': [{'vocalized': u'فكابنك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'أولمعي': [{'vocalized': u'أولمعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'أولمعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'سوى': [{'vocalized': u'سوى', 'procletic': u'', 'tags': u'اسم;استثناء', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'سوى', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'سوي': [{'vocalized': u'سوي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'سوي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكشبهي': [{'vocalized': u'أوكشبهي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أوكشبهي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'وراح': [{'vocalized': u'وراح', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'راح', 'encletic': u'', 'type': u'فعل', 'original': u'راح'}],

 u'أولمعك': [{'vocalized': u'أولمعك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'فكابني': [{'vocalized': u'فكابني', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'فكابني', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'ففيما': [{'vocalized': u'ففيما', 'procletic': u'ف-', 'tags': u'حرف;حرف استفهام;عطف', 'stem': u'فيما', 'encletic': u'', 'type': u'حرف', 'original': u'فيما'}],

 u'فنفسهما': [{'vocalized': u'فنفسهما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'فبضعكما': [{'vocalized': u'فبضعكما', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بضع'}],

 u'ولزمان': [{'vocalized': u'ولزمان', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'وغربها': [{'vocalized': u'وغربها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'لأبيكما': [{'vocalized': u'لأبيكما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'أوهذه': [{'vocalized': u'أوهذه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'وأعلى': [{'vocalized': u'وأعلى', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبذاك': [{'vocalized': u'فبذاك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'وأعلي': [{'vocalized': u'وأعلي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'وأعلي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'كحيث': [{'vocalized': u'كحيث', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'أعنكن': [{'vocalized': u'أعنكن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'أعنكم': [{'vocalized': u'أعنكم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'أفلأنت': [{'vocalized': u'أفلأنت', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'أفلأنت', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'وإياهم': [{'vocalized': u'وإياهم', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياهم', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهم'}],

 u'أبا': [{'vocalized': u'أبا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أبا', 'encletic': u'', 'type': u'اسم', 'original': u'أبا'}],

 u'أفلأنا': [{'vocalized': u'أفلأنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'أفلأنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'أوبهن': [{'vocalized': u'أوبهن', 'procletic': u'أ-و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أوبهم': [{'vocalized': u'أوبهم', 'procletic': u'أ-و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'لأقلهن': [{'vocalized': u'لأقلهن', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'أفلهما': [{'vocalized': u'أفلهما', 'procletic': u'أ-ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'},
 {'vocalized': u'أفلهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'لأقلهم': [{'vocalized': u'لأقلهم', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'وبجنبهما': [{'vocalized': u'وبجنبهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'أكذلكما': [{'vocalized': u'أكذلكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'أوإنهما': [{'vocalized': u'أوإنهما', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'أوبهي': [{'vocalized': u'أوبهي', 'procletic': u'أ-و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'أوكحسبهن': [{'vocalized': u'أوكحسبهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'أفنحونا': [{'vocalized': u'أفنحونا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'ولمنهن': [{'vocalized': u'ولمنهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'وأقلكما': [{'vocalized': u'وأقلكما', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'إذن': [{'vocalized': u'إذن', 'procletic': u'', 'tags': u'حرف;حرف جواب', 'stem': u'إذن', 'encletic': u'', 'type': u'حرف', 'original': u'إذن'}],

 u'أوبعضنا': [{'vocalized': u'أوبعضنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'وبأية': [{'vocalized': u'وبأية', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'ولقلما': [{'vocalized': u'ولقلما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'لكي': [{'vocalized': u'لكي', 'procletic': u'', 'tags': u'حرف;حرف تعليل', 'stem': u'لكي', 'encletic': u'', 'type': u'حرف', 'original': u'لكي'}],

 u'وبأبيهن': [{'vocalized': u'وبأبيهن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'وبأبيهم': [{'vocalized': u'وبأبيهم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'وكشطرنا': [{'vocalized': u'وكشطرنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'لكن': [{'vocalized': u'لكن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها', 'stem': u'لكن', 'encletic': u'', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكن', 'procletic': u'', 'tags': u'حرف;حرف استدراك', 'stem': u'لكن', 'encletic': u'', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكن', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'لكن', 'encletic': u'', 'type': u'ضمير', 'original': u'لكن'}],

 u'لكل': [{'vocalized': u'لكل', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكل', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكل', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكل', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'لكم': [{'vocalized': u'لكم', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'لكم', 'encletic': u'', 'type': u'ضمير', 'original': u'لكم'}],

 u'فيمينكن': [{'vocalized': u'فيمينكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'ولشبهنا': [{'vocalized': u'ولشبهنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'أولفيي': [{'vocalized': u'أولفيي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'أولفيي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'أفلفيك': [{'vocalized': u'أفلفيك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'فبلحظتهن': [{'vocalized': u'فبلحظتهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفكتينك': [{'vocalized': u'أفكتينك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'وبأبيها': [{'vocalized': u'وبأبيها', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'فكساعتهم': [{'vocalized': u'فكساعتهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'لأكثرهما': [{'vocalized': u'لأكثرهما', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'فشمالكما': [{'vocalized': u'فشمالكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'وكوقته': [{'vocalized': u'وكوقته', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'مثلما': [{'vocalized': u'مثلما', 'procletic': u'', 'tags': u'اسم;جار ومجرور', 'stem': u'مثلما', 'encletic': u'', 'type': u'اسم', 'original': u'مثلما'}],

 u'وكوقتك': [{'vocalized': u'وكوقتك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'بذوينا': [{'vocalized': u'بذوينا', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكوقتي': [{'vocalized': u'وكوقتي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'وكوقتي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'كأسفلكم': [{'vocalized': u'كأسفلكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'كأسفلكن': [{'vocalized': u'كأسفلكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكذويكم': [{'vocalized': u'وكذويكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكذويكن': [{'vocalized': u'وكذويكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولمنها': [{'vocalized': u'ولمنها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'مازال': [{'vocalized': u'مازال', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازال', 'encletic': u'', 'type': u'فعل', 'original': u'مازال'}],

 u'مادمتم': [{'vocalized': u'مادمتم', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمتم', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتم'}],

 u'أكعامتي': [{'vocalized': u'أكعامتي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أكعامتي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'لذواتي': [{'vocalized': u'لذواتي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'وبأيي': [{'vocalized': u'وبأيي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وبأيي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'أكعامته': [{'vocalized': u'أكعامته', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'وبأيه': [{'vocalized': u'وبأيه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'ولتلك': [{'vocalized': u'ولتلك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'أكعامتك': [{'vocalized': u'أكعامتك', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'وبأيك': [{'vocalized': u'وبأيك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'وغربهن': [{'vocalized': u'وغربهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'بأنهن': [{'vocalized': u'بأنهن', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'بأنهم': [{'vocalized': u'بأنهم', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'فلمعكما': [{'vocalized': u'فلمعكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'رجع': [{'vocalized': u'رجع', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'رجع', 'encletic': u'', 'type': u'فعل', 'original': u'رجع'}],

 u'فأنانا': [{'vocalized': u'فأنانا', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'أفليس': [{'vocalized': u'أفليس', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليس', 'encletic': u'', 'type': u'فعل', 'original': u'ليس'}],

 u'ولليله': [{'vocalized': u'ولليله', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'فلكلهما': [{'vocalized': u'فلكلهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'أفلعليك': [{'vocalized': u'أفلعليك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'ولعسى': [{'vocalized': u'ولعسى', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'عسى', 'encletic': u'', 'type': u'فعل', 'original': u'عسى'}],

 u'ئ': [{'vocalized': u'ئ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ئ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ئ'}],

 u'بهنالك': [{'vocalized': u'بهنالك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'وأخانا': [{'vocalized': u'وأخانا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخا'}],

 u'بدونهم': [{'vocalized': u'بدونهم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بدون'}],

 u'ولشمالهما': [{'vocalized': u'ولشمالهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'أفمننا': [{'vocalized': u'أفمننا', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'أوهو': [{'vocalized': u'أوهو', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'فبذاتكم': [{'vocalized': u'فبذاتكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'فبذاتكن': [{'vocalized': u'فبذاتكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أوأجمعكما': [{'vocalized': u'أوأجمعكما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولحسبهم': [{'vocalized': u'أولحسبهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أولحسبهن': [{'vocalized': u'أولحسبهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'أوهم': [{'vocalized': u'أوهم', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أوهن': [{'vocalized': u'أوهن', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'وأيتكم': [{'vocalized': u'وأيتكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'وأيتكن': [{'vocalized': u'وأيتكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'وكهما': [{'vocalized': u'وكهما', 'procletic': u'و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'أبتلك': [{'vocalized': u'أبتلك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'كجنوبهن': [{'vocalized': u'كجنوبهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'كجنوبهم': [{'vocalized': u'كجنوبهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'بشرقه': [{'vocalized': u'بشرقه', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'ولحميه': [{'vocalized': u'ولحميه', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'لحظتها': [{'vocalized': u'لحظتها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'بهذين': [{'vocalized': u'بهذين', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'وبأكثركن': [{'vocalized': u'وبأكثركن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'وبأكثركم': [{'vocalized': u'وبأكثركم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'أوراءكما': [{'vocalized': u'أوراءكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'أولحسبها': [{'vocalized': u'أولحسبها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'ولحميي': [{'vocalized': u'ولحميي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'ولحميي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'وأباكما': [{'vocalized': u'وأباكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبا'}],

 u'ألشبه': [{'vocalized': u'ألشبه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'لعليه': [{'vocalized': u'لعليه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'لليله': [{'vocalized': u'لليله', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'لعليك': [{'vocalized': u'لعليك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'لأضحى': [{'vocalized': u'لأضحى', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أضحى', 'encletic': u'', 'type': u'فعل', 'original': u'أضحى'}],

 u'لليلي': [{'vocalized': u'لليلي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'لليلي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'كجنوبها': [{'vocalized': u'كجنوبها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'ولغربهن': [{'vocalized': u'ولغربهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'فأباهما': [{'vocalized': u'فأباهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبا'}],

 u'أكذين': [{'vocalized': u'أكذين', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'بأنها': [{'vocalized': u'بأنها', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'ولغربهم': [{'vocalized': u'ولغربهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'ولشمالكما': [{'vocalized': u'ولشمالكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'ولستم': [{'vocalized': u'ولستم', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لستم', 'encletic': u'', 'type': u'فعل', 'original': u'لستم'}],

 u'وبشرقكما': [{'vocalized': u'وبشرقكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'ولزمانه': [{'vocalized': u'ولزمانه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'وزمانهما': [{'vocalized': u'وزمانهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'ولزمانك': [{'vocalized': u'ولزمانك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'أولكأنكما': [{'vocalized': u'أولكأنكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'فعندنا': [{'vocalized': u'فعندنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عند'}],

 u'بتلقاءه': [{'vocalized': u'بتلقاءه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'بتلقاءك': [{'vocalized': u'بتلقاءك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فجميعهم': [{'vocalized': u'فجميعهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعهم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أمامنا': [{'vocalized': u'أمامنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'وكخلف': [{'vocalized': u'وكخلف', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'بتلقاءي': [{'vocalized': u'بتلقاءي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'بتلقاءي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'لنفسهما': [{'vocalized': u'لنفسهما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'ولعينه': [{'vocalized': u'ولعينه', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أفببعض': [{'vocalized': u'أفببعض', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'ولعينك': [{'vocalized': u'ولعينك', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'كغيرهما': [{'vocalized': u'كغيرهما', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'ولعيني': [{'vocalized': u'ولعيني', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعيني', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعيني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعيني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وهنالك': [{'vocalized': u'وهنالك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'حولهم': [{'vocalized': u'حولهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حول'}],

 u'وبنحونا': [{'vocalized': u'وبنحونا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحونا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أولذانك': [{'vocalized': u'أولذانك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'فجنبها': [{'vocalized': u'فجنبها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'وعنده': [{'vocalized': u'وعنده', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عند'}],

 u'فلأسفله': [{'vocalized': u'فلأسفله', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'أولحسبي': [{'vocalized': u'أولحسبي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أولحسبي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلعينكما': [{'vocalized': u'أفلعينكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'أفبنحوكم': [{'vocalized': u'أفبنحوكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أفبنحوكن': [{'vocalized': u'أفبنحوكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'أولحسبه': [{'vocalized': u'أولحسبه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أولإننا': [{'vocalized': u'أولإننا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'أولحسبك': [{'vocalized': u'أولحسبك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فشهركم': [{'vocalized': u'فشهركم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'فشهركن': [{'vocalized': u'فشهركن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'لأسفلي': [{'vocalized': u'لأسفلي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'لأسفلي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوبنفسكن': [{'vocalized': u'أوبنفسكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'فلأثناءنا': [{'vocalized': u'فلأثناءنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'أولأناهما': [{'vocalized': u'أولأناهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'لأسفله': [{'vocalized': u'لأسفله', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'بالألاء': [{'vocalized': u'بالألاء', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'وبساعتكن': [{'vocalized': u'وبساعتكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلغيرهما': [{'vocalized': u'فلغيرهما', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيرهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فلعيننا': [{'vocalized': u'فلعيننا', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعيننا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'بذاتكم': [{'vocalized': u'بذاتكم', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'بذاتكن': [{'vocalized': u'بذاتكن', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أفلستن': [{'vocalized': u'أفلستن', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لستن', 'encletic': u'', 'type': u'فعل', 'original': u'لستن'}],

 u'ولذانك': [{'vocalized': u'ولذانك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'ولأمامك': [{'vocalized': u'ولأمامك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'كلنا': [{'vocalized': u'كلنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلنا', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أوليمينهم': [{'vocalized': u'أوليمينهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'أوليمينهن': [{'vocalized': u'أوليمينهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'حموكم': [{'vocalized': u'حموكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمو'}],

 u'فلليل': [{'vocalized': u'فلليل', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'وباللذين': [{'vocalized': u'وباللذين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'فلفوقهن': [{'vocalized': u'فلفوقهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'أبحسبها': [{'vocalized': u'أبحسبها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأكثر': [{'vocalized': u'وكأكثر', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'لفوقكما': [{'vocalized': u'لفوقكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'أولكلكما': [{'vocalized': u'أولكلكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فذي': [{'vocalized': u'فذي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'},
 {'vocalized': u'فذي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فذو': [{'vocalized': u'فذو', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'ذو', 'encletic': u'', 'type': u'اسم', 'original': u'ذو'}],

 u'أوإليكما': [{'vocalized': u'أوإليكما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'أولغيركما': [{'vocalized': u'أولغيركما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيركما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فبهذين': [{'vocalized': u'فبهذين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'فذه': [{'vocalized': u'فذه', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'أبعيني': [{'vocalized': u'أبعيني', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أبعيني', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'تحتكما': [{'vocalized': u'تحتكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'أفبهاتين': [{'vocalized': u'أفبهاتين', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'فأخو': [{'vocalized': u'فأخو', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخو', 'encletic': u'', 'type': u'اسم', 'original': u'أخو'}],

 u'أولكأنكم': [{'vocalized': u'أولكأنكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'أولكأنكن': [{'vocalized': u'أولكأنكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'أفكمثلكم': [{'vocalized': u'أفكمثلكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفكمثلكن': [{'vocalized': u'أفكمثلكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'بشرقنا': [{'vocalized': u'بشرقنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'فلعلنا': [{'vocalized': u'فلعلنا', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لعل'}],

 u'أناكن': [{'vocalized': u'أناكن', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'فكأسفلي': [{'vocalized': u'فكأسفلي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'فكأسفلي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'أناكم': [{'vocalized': u'أناكم', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'وبلا': [{'vocalized': u'وبلا', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'بلا', 'encletic': u'', 'type': u'حرف', 'original': u'بلا'}],

 u'فكأسفلك': [{'vocalized': u'فكأسفلك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'ف': [{'vocalized': u'ف', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ف', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ف'}],

 u'أفوراءك': [{'vocalized': u'أفوراءك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'أفوراءه': [{'vocalized': u'أفوراءه', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'فأخا': [{'vocalized': u'فأخا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخا', 'encletic': u'', 'type': u'اسم', 'original': u'أخا'}],

 u'أفوراءي': [{'vocalized': u'أفوراءي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'أفوراءي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'وبذلكن': [{'vocalized': u'وبذلكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'وبذلكم': [{'vocalized': u'وبذلكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'فبشرقكن': [{'vocalized': u'فبشرقكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'فلديكما': [{'vocalized': u'فلديكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدى'}],

 u'فبشرقكم': [{'vocalized': u'فبشرقكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'فلمعي': [{'vocalized': u'فلمعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'فلمعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'فخلفي': [{'vocalized': u'فخلفي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فلمعه': [{'vocalized': u'فلمعه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'فخلفه': [{'vocalized': u'فخلفه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'فلمعك': [{'vocalized': u'فلمعك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'فخلفك': [{'vocalized': u'فخلفك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'أفلتلك': [{'vocalized': u'أفلتلك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'لحظة': [{'vocalized': u'لحظة', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'أونحوي': [{'vocalized': u'أونحوي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أونحوي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'أبحسبهم': [{'vocalized': u'أبحسبهم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فإنما': [{'vocalized': u'فإنما', 'procletic': u'ف-', 'tags': u'حرف;كافة ومكفوفة;عطف', 'stem': u'إنما', 'encletic': u'', 'type': u'حرف', 'original': u'إنما'}],

 u'أبحسبهن': [{'vocalized': u'أبحسبهن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'فحيثما': [{'vocalized': u'فحيثما', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'حيثما', 'encletic': u'', 'type': u'اسم', 'original': u'حيثما'}],

 u'ولحظتكما': [{'vocalized': u'ولحظتكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'فهاؤم': [{'vocalized': u'فهاؤم', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'هاؤم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هاؤم'}],

 u'أويمينهما': [{'vocalized': u'أويمينهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'معاذي': [{'vocalized': u'معاذي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-ي', 'type': u'اسم', 'original': u'معاذ'},
 {'vocalized': u'معاذي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-ي', 'type': u'اسم', 'original': u'معاذ'}],

 u'وببعضنا': [{'vocalized': u'وببعضنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'فذا': [{'vocalized': u'فذا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'فذا', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'فذا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'معاذه': [{'vocalized': u'معاذه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-ه', 'type': u'اسم', 'original': u'معاذ'}],

 u'آنفا': [{'vocalized': u'آنفا', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'آنفا', 'encletic': u'', 'type': u'اسم', 'original': u'آنفا'}],

 u'أفكجميعهما': [{'vocalized': u'أفكجميعهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلذي': [{'vocalized': u'أفلذي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'حولها': [{'vocalized': u'حولها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حول'}],

 u'ولجنوبنا': [{'vocalized': u'ولجنوبنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'ألكأنما': [{'vocalized': u'ألكأنما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'فمافتئا': [{'vocalized': u'فمافتئا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئا'}],

 u'حماها': [{'vocalized': u'حماها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حما'}],

 u'فكحسبهن': [{'vocalized': u'فكحسبهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'غروبكم': [{'vocalized': u'غروبكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'غروبكن': [{'vocalized': u'غروبكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'فكحسبهم': [{'vocalized': u'فكحسبهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أولأمام': [{'vocalized': u'أولأمام', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'وخلفهم': [{'vocalized': u'وخلفهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'وخلفهن': [{'vocalized': u'وخلفهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أونحوك': [{'vocalized': u'أونحوك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'وكبعضهما': [{'vocalized': u'وكبعضهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'وإياكما': [{'vocalized': u'وإياكما', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياكما', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكما'}],

 u'فكساعتي': [{'vocalized': u'فكساعتي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'فكساعتي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكساعته': [{'vocalized': u'فكساعته', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'أولعينهما': [{'vocalized': u'أولعينهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'وفاها': [{'vocalized': u'وفاها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فا'}],

 u'فحينه': [{'vocalized': u'فحينه', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حين'}],

 u'فكساعتك': [{'vocalized': u'فكساعتك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'لدينا': [{'vocalized': u'لدينا', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدى'}],

 u'وبكم': [{'vocalized': u'وبكم', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بكم', 'encletic': u'', 'type': u'اسم', 'original': u'بكم'},
 {'vocalized': u'وبكم', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بكم', 'encletic': u'', 'type': u'ضمير', 'original': u'بكم'}],

 u'وبكل': [{'vocalized': u'وبكل', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكل', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'وبكن': [{'vocalized': u'وبكن', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بكن', 'encletic': u'', 'type': u'ضمير', 'original': u'بكن'}],

 u'وعسى': [{'vocalized': u'وعسى', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'عسى', 'encletic': u'', 'type': u'فعل', 'original': u'عسى'}],

 u'أليمينكن': [{'vocalized': u'أليمينكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'أليمينكم': [{'vocalized': u'أليمينكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'أولكأن': [{'vocalized': u'أولكأن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'أشمالهما': [{'vocalized': u'أشمالهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'فلخلفك': [{'vocalized': u'فلخلفك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'وفاهم': [{'vocalized': u'وفاهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فا'}],

 u'كاللاتي': [{'vocalized': u'كاللاتي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'أولكلك': [{'vocalized': u'أولكلك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'بدونكم': [{'vocalized': u'بدونكم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بدون'}],

 u'فبشهركما': [{'vocalized': u'فبشهركما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'أوكشبههما': [{'vocalized': u'أوكشبههما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فأولئكم': [{'vocalized': u'فأولئكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'أفوراءهما': [{'vocalized': u'أفوراءهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'وقد': [{'vocalized': u'وقد', 'procletic': u'و-', 'tags': u'حرف;حرف تحقيق/ توقع;عطف', 'stem': u'قد', 'encletic': u'', 'type': u'حرف', 'original': u'قد'}],

 u'ألسويه': [{'vocalized': u'ألسويه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'ألسويك': [{'vocalized': u'ألسويك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'وكأخيي': [{'vocalized': u'وكأخيي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'وكأخيي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'كأثناءكم': [{'vocalized': u'كأثناءكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'كأثناءكن': [{'vocalized': u'كأثناءكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'حماهم': [{'vocalized': u'حماهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حما'}],

 u'حماهن': [{'vocalized': u'حماهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حما'}],

 u'فكحسبها': [{'vocalized': u'فكحسبها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'أففلان': [{'vocalized': u'أففلان', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام', 'stem': u'فلان', 'encletic': u'', 'type': u'اسم', 'original': u'فلان'}],

 u'ولأيتهم': [{'vocalized': u'ولأيتهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'وقط': [{'vocalized': u'وقط', 'procletic': u'و-', 'tags': u'حرف;ظرف;عطف', 'stem': u'قط', 'encletic': u'', 'type': u'حرف', 'original': u'قط'}],

 u'ولكلهما': [{'vocalized': u'ولكلهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'وبجنبكن': [{'vocalized': u'وبجنبكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'ولأقبل': [{'vocalized': u'ولأقبل', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أقبل', 'encletic': u'', 'type': u'فعل', 'original': u'أقبل'}],

 u'أفلأولاء': [{'vocalized': u'أفلأولاء', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'ألأولئكم': [{'vocalized': u'ألأولئكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'بعينكما': [{'vocalized': u'بعينكما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'وكهناك': [{'vocalized': u'وكهناك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'وفوقهم': [{'vocalized': u'وفوقهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'فلأجمعنا': [{'vocalized': u'فلأجمعنا', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفكمثله': [{'vocalized': u'أفكمثله', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'أفكمثلك': [{'vocalized': u'أفكمثلك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'ببعض': [{'vocalized': u'ببعض', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'أفكمثلي': [{'vocalized': u'أفكمثلي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفكمثلي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'فكأخينا': [{'vocalized': u'فكأخينا', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'فحميك': [{'vocalized': u'فحميك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'وللحظته': [{'vocalized': u'وللحظته', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'فحميه': [{'vocalized': u'فحميه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'وللحظتي': [{'vocalized': u'وللحظتي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'وللحظتي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'فكأنما': [{'vocalized': u'فكأنما', 'procletic': u'ف-', 'tags': u'حرف;حرف تشبيه;عطف', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'فحميي': [{'vocalized': u'فحميي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'فحميي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'أفلأمامه': [{'vocalized': u'أفلأمامه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'تحتك': [{'vocalized': u'تحتك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'ففوقي': [{'vocalized': u'ففوقي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'ففوقي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'فبشرقنا': [{'vocalized': u'فبشرقنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'لمثلكما': [{'vocalized': u'لمثلكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أوماذا': [{'vocalized': u'أوماذا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم الاستفهام;عطف;استفهام', 'stem': u'ماذا', 'encletic': u'', 'type': u'اسم', 'original': u'ماذا'}],

 u'ولخلفنا': [{'vocalized': u'ولخلفنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'فلأناي': [{'vocalized': u'فلأناي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'فلأناي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'كخلف': [{'vocalized': u'كخلف', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'ولوقتنا': [{'vocalized': u'ولوقتنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'وأكثرنا': [{'vocalized': u'وأكثرنا', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'ومرة': [{'vocalized': u'ومرة', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'مرة', 'encletic': u'', 'type': u'اسم', 'original': u'مرة'}],

 u'كنفسك': [{'vocalized': u'كنفسك', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'ألبعضهما': [{'vocalized': u'ألبعضهما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'كنفسه': [{'vocalized': u'كنفسه', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'وبشطركن': [{'vocalized': u'وبشطركن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'كنفسي': [{'vocalized': u'كنفسي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'كنفسي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'وبشطركم': [{'vocalized': u'وبشطركم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'أفبعامتهما': [{'vocalized': u'أفبعامتهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أفككلنا': [{'vocalized': u'أفككلنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'وبعينكن': [{'vocalized': u'وبعينكن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'وبعينكم': [{'vocalized': u'وبعينكم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'فلتحتنا': [{'vocalized': u'فلتحتنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'بأجمعنا': [{'vocalized': u'بأجمعنا', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'فهاته': [{'vocalized': u'فهاته', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'ألمن': [{'vocalized': u'ألمن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم موصول;مجرور;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'ألمن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'وكل': [{'vocalized': u'وكل', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكل', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'وحواليهن': [{'vocalized': u'وحواليهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حوالى'}],

 u'فكفيكن': [{'vocalized': u'فكفيكن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'}],

 u'وكم': [{'vocalized': u'وكم', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'كم', 'encletic': u'', 'type': u'اسم', 'original': u'كم'},
 {'vocalized': u'وكم', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'كم', 'encletic': u'', 'type': u'اسم', 'original': u'كم'}],

 u'فهاتي': [{'vocalized': u'فهاتي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'لعنهن': [{'vocalized': u'لعنهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'ألمثلكم': [{'vocalized': u'ألمثلكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فإنكم': [{'vocalized': u'فإنكم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'فإنكن': [{'vocalized': u'فإنكن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'ألمثلكن': [{'vocalized': u'ألمثلكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'فكشطرنا': [{'vocalized': u'فكشطرنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'بعامتي': [{'vocalized': u'بعامتي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'بعامتي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'أكأنهما': [{'vocalized': u'أكأنهما', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'أوبشبهها': [{'vocalized': u'أوبشبهها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'ليمين': [{'vocalized': u'ليمين', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'لفوقه': [{'vocalized': u'لفوقه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'أولفيها': [{'vocalized': u'أولفيها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'فلفوقكم': [{'vocalized': u'فلفوقكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'كتلقاء': [{'vocalized': u'كتلقاء', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولوراءهن': [{'vocalized': u'ولوراءهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'أولئك': [{'vocalized': u'أولئك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'أببعضكم': [{'vocalized': u'أببعضكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أببعضكن': [{'vocalized': u'أببعضكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبشبههن': [{'vocalized': u'أوبشبههن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أوبشبههم': [{'vocalized': u'أوبشبههم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'بليلنا': [{'vocalized': u'بليلنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'فلشرقكن': [{'vocalized': u'فلشرقكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'فبأسفلهم': [{'vocalized': u'فبأسفلهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'فلشرقكم': [{'vocalized': u'فلشرقكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'أفوقهما': [{'vocalized': u'أفوقهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'ولإلينا': [{'vocalized': u'ولإلينا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'ألما': [{'vocalized': u'ألما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'اسم', 'original': u'لما'},
 {'vocalized': u'ألما', 'procletic': u'أ-', 'tags': u'حرف;حرف جزم;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'},
 {'vocalized': u'ألما', 'procletic': u'أ-', 'tags': u'حرف;ظرف;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'}],

 u'بشبهي': [{'vocalized': u'بشبهي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'بشبهي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'ولقد': [{'vocalized': u'ولقد', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'قد', 'encletic': u'', 'type': u'حرف', 'original': u'قد'}],

 u'بشبهه': [{'vocalized': u'بشبهه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'بشبهك': [{'vocalized': u'بشبهك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلنفس': [{'vocalized': u'أفلنفس', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفس', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أوكأنك': [{'vocalized': u'أوكأنك', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'فلأصبح': [{'vocalized': u'فلأصبح', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أصبح', 'encletic': u'', 'type': u'فعل', 'original': u'أصبح'}],

 u'ألمع': [{'vocalized': u'ألمع', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'وللاتي': [{'vocalized': u'وللاتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'فكأني': [{'vocalized': u'فكأني', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأني', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'فكأني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'أولا': [{'vocalized': u'أولا', 'procletic': u'أ-و-', 'tags': u'حرف;المشبهة بليس;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'أولا', 'procletic': u'أ-و-', 'tags': u'حرف;نافية للجنس;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'أولا', 'procletic': u'أ-و-', 'tags': u'حرف;ناهية;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'أولا', 'procletic': u'أ-و-', 'tags': u'حرف;نافية;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'}],

 u'أبجميع': [{'vocalized': u'أبجميع', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميع', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'فلتلقاءهما': [{'vocalized': u'فلتلقاءهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فكأنك': [{'vocalized': u'فكأنك', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنك', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'أبك': [{'vocalized': u'أبك', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'بك', 'encletic': u'', 'type': u'ضمير', 'original': u'بك'}],

 u'فبخلفي': [{'vocalized': u'فبخلفي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فبخلفي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فكأنه': [{'vocalized': u'فكأنه', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنه', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'نحوكما': [{'vocalized': u'نحوكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فرجع': [{'vocalized': u'فرجع', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'رجع', 'encletic': u'', 'type': u'فعل', 'original': u'رجع'}],

 u'فلأمامي': [{'vocalized': u'فلأمامي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'فلأمامي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'فبلحظتها': [{'vocalized': u'فبلحظتها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلأمامه': [{'vocalized': u'فلأمامه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'كعامتك': [{'vocalized': u'كعامتك', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'فلأمامك': [{'vocalized': u'فلأمامك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'كعامته': [{'vocalized': u'كعامته', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'عداهما': [{'vocalized': u'عداهما', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'عدا'}],

 u'أكغيري': [{'vocalized': u'أكغيري', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أكغيري', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أكغيره': [{'vocalized': u'أكغيره', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أوبذين': [{'vocalized': u'أوبذين', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'أكغيرك': [{'vocalized': u'أكغيرك', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'وبأيتكما': [{'vocalized': u'وبأيتكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'فشبههما': [{'vocalized': u'فشبههما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فأنتم': [{'vocalized': u'فأنتم', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'أوراءها': [{'vocalized': u'أوراءها', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'أفكتلكم': [{'vocalized': u'أفكتلكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'عينهم': [{'vocalized': u'عينهم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'عينهن': [{'vocalized': u'عينهن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'أولشبهكن': [{'vocalized': u'أولشبهكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أولشبهكم': [{'vocalized': u'أولشبهكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'وحسبي': [{'vocalized': u'وحسبي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'وحسبي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أبيكما': [{'vocalized': u'أبيكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'أوراءهم': [{'vocalized': u'أوراءهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'أوراءهن': [{'vocalized': u'أوراءهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'أكنفسي': [{'vocalized': u'أكنفسي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أكنفسي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'فلتلقاءكم': [{'vocalized': u'فلتلقاءكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أكنفسه': [{'vocalized': u'أكنفسه', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'عينها': [{'vocalized': u'عينها', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فلتلقاءكن': [{'vocalized': u'فلتلقاءكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'كفيكن': [{'vocalized': u'كفيكن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'}],

 u'أكنفسك': [{'vocalized': u'أكنفسك', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'كفيكم': [{'vocalized': u'كفيكم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'}],

 u'أبضعكما': [{'vocalized': u'أبضعكما', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بضع'}],

 u'أفلإليكما': [{'vocalized': u'أفلإليكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'فدون': [{'vocalized': u'فدون', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'دون', 'encletic': u'', 'type': u'اسم', 'original': u'دون'}],

 u'جنوبها': [{'vocalized': u'جنوبها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'وسبحانكما': [{'vocalized': u'وسبحانكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سبحان'}],

 u'لإنكما': [{'vocalized': u'لإنكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'فلعامة': [{'vocalized': u'فلعامة', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامة', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'ولغيرهن': [{'vocalized': u'ولغيرهن', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيرهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أفلكأنكم': [{'vocalized': u'أفلكأنكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'أفلكأنكن': [{'vocalized': u'أفلكأنكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'لبعضنا': [{'vocalized': u'لبعضنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'بضعي': [{'vocalized': u'بضعي', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'},
 {'vocalized': u'بضعي', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'}],

 u'فمافتئنا': [{'vocalized': u'فمافتئنا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئنا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئنا'}],

 u'بضعه': [{'vocalized': u'بضعه', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بضع'}],

 u'وكأيتك': [{'vocalized': u'وكأيتك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'بضعك': [{'vocalized': u'بضعك', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بضع'}],

 u'فبحسبهما': [{'vocalized': u'فبحسبهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أتحت': [{'vocalized': u'أتحت', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'فوراءهم': [{'vocalized': u'فوراءهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'فلبعضكن': [{'vocalized': u'فلبعضكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'فلبعضكم': [{'vocalized': u'فلبعضكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'فلهذين': [{'vocalized': u'فلهذين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'ألمعهم': [{'vocalized': u'ألمعهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'فبأسفلها': [{'vocalized': u'فبأسفلها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفيهما': [{'vocalized': u'أفيهما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'لنحو': [{'vocalized': u'لنحو', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحو', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فلفوقهما': [{'vocalized': u'فلفوقهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'أببعض': [{'vocalized': u'أببعض', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'أوكغيرهم': [{'vocalized': u'أوكغيرهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أوكغيرهن': [{'vocalized': u'أوكغيرهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'ألنحونا': [{'vocalized': u'ألنحونا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'بأثناءك': [{'vocalized': u'بأثناءك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولتلقاءهم': [{'vocalized': u'ولتلقاءهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولتلقاءهن': [{'vocalized': u'ولتلقاءهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفبهناك': [{'vocalized': u'أفبهناك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أفبحسبنا': [{'vocalized': u'أفبحسبنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأنه': [{'vocalized': u'وكأنه', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنه', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'وغروبها': [{'vocalized': u'وغروبها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'وكأنك': [{'vocalized': u'وكأنك', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنك', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'وابنكن': [{'vocalized': u'وابنكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'فكشبههما': [{'vocalized': u'فكشبههما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'وابنكم': [{'vocalized': u'وابنكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'خلالكم': [{'vocalized': u'خلالكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلال'}],

 u'خلالكن': [{'vocalized': u'خلالكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلال'}],

 u'وكأني': [{'vocalized': u'وكأني', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأني', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'وكأني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'أيمينك': [{'vocalized': u'أيمينك', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'أيمينه': [{'vocalized': u'أيمينه', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'ولتلقاءها': [{'vocalized': u'ولتلقاءها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أيميني': [{'vocalized': u'أيميني', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'أيميني', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'أوكأن': [{'vocalized': u'أوكأن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'فلابنكما': [{'vocalized': u'فلابنكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'أولعنك': [{'vocalized': u'أولعنك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'ولفوقنا': [{'vocalized': u'ولفوقنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'وبنفسنا': [{'vocalized': u'وبنفسنا', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'لأبيها': [{'vocalized': u'لأبيها', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'ساعة': [{'vocalized': u'ساعة', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبكلكن': [{'vocalized': u'وبكلكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلكن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'وبكلكم': [{'vocalized': u'وبكلكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلكم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'بأكثرهما': [{'vocalized': u'بأكثرهما', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفلطالما': [{'vocalized': u'أفلطالما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'بها': [{'vocalized': u'بها', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'بها', 'encletic': u'', 'type': u'ضمير', 'original': u'بها'}],

 u'وذاتي': [{'vocalized': u'وذاتي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'وذاتي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'أولعنه': [{'vocalized': u'أولعنه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'كغربهما': [{'vocalized': u'كغربهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'وهنا': [{'vocalized': u'وهنا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هنا', 'encletic': u'', 'type': u'اسم', 'original': u'هنا'}],

 u'فحاشاهما': [{'vocalized': u'فحاشاهما', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'حاشا'}],

 u'أوكغيرها': [{'vocalized': u'أوكغيرها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'وفوقهما': [{'vocalized': u'وفوقهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'ومعهما': [{'vocalized': u'ومعهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'فمنذ': [{'vocalized': u'فمنذ', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'منذ', 'encletic': u'', 'type': u'حرف', 'original': u'منذ'},
 {'vocalized': u'فمنذ', 'procletic': u'ف-', 'tags': u'حرف;ظرف زمان;عطف', 'stem': u'منذ', 'encletic': u'', 'type': u'حرف', 'original': u'منذ'}],

 u'أعنها': [{'vocalized': u'أعنها', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'يمينكم': [{'vocalized': u'يمينكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'يمينكن': [{'vocalized': u'يمينكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'وفوقها': [{'vocalized': u'وفوقها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'أكأجمعها': [{'vocalized': u'أكأجمعها', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلشهر': [{'vocalized': u'فلشهر', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'وكفيكم': [{'vocalized': u'وكفيكم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'}],

 u'لتحتكما': [{'vocalized': u'لتحتكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'فليمينهن': [{'vocalized': u'فليمينهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'ألذينك': [{'vocalized': u'ألذينك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'التي': [{'vocalized': u'التي', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'فبشرقهما': [{'vocalized': u'فبشرقهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'وخلاهن': [{'vocalized': u'وخلاهن', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'خلا'}],

 u'وكفيكن': [{'vocalized': u'وكفيكن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'}],

 u'ولأجمعكن': [{'vocalized': u'ولأجمعكن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأبوكما': [{'vocalized': u'وأبوكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبو'}],

 u'أوبذاك': [{'vocalized': u'أوبذاك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'ولأيتها': [{'vocalized': u'ولأيتها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'أولأناكن': [{'vocalized': u'أولأناكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'وخلاها': [{'vocalized': u'وخلاها', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'خلا'}],

 u'أولأناكم': [{'vocalized': u'أولأناكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'فلتلقاءه': [{'vocalized': u'فلتلقاءه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ألسويهما': [{'vocalized': u'ألسويهما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'أوبضعها': [{'vocalized': u'أوبضعها', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بضع'}],

 u'فلتلقاءك': [{'vocalized': u'فلتلقاءك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'جير': [{'vocalized': u'جير', 'procletic': u'', 'tags': u'حرف;حرف جواب', 'stem': u'جير', 'encletic': u'', 'type': u'حرف', 'original': u'جير'}],

 u'فكجنبكم': [{'vocalized': u'فكجنبكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'فكجنبكن': [{'vocalized': u'فكجنبكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'فلتلقاءي': [{'vocalized': u'فلتلقاءي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'فلتلقاءي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولحميكن': [{'vocalized': u'ولحميكن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'فبنفسنا': [{'vocalized': u'فبنفسنا', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أوجميعكما': [{'vocalized': u'أوجميعكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعكما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أوبضعكن': [{'vocalized': u'أوبضعكن', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بضع'}],

 u'أوبضعكم': [{'vocalized': u'أوبضعكم', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بضع'}],

 u'وكأسفلهما': [{'vocalized': u'وكأسفلهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'فبأجمعك': [{'vocalized': u'فبأجمعك', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أعنهن': [{'vocalized': u'أعنهن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أعنهم': [{'vocalized': u'أعنهم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'أوكحسبكم': [{'vocalized': u'أوكحسبكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'فكأنهما': [{'vocalized': u'فكأنهما', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنهما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'فمني': [{'vocalized': u'فمني', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'فمني', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'أوكحسبكن': [{'vocalized': u'أوكحسبكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فلهؤلاء': [{'vocalized': u'فلهؤلاء', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'أكأجمعهن': [{'vocalized': u'أكأجمعهن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'هاته': [{'vocalized': u'هاته', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'لشهر': [{'vocalized': u'لشهر', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'هاتي': [{'vocalized': u'هاتي', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'ألأولاء': [{'vocalized': u'ألأولاء', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'فمنه': [{'vocalized': u'فمنه', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'فلشطرهما': [{'vocalized': u'فلشطرهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'كأسفل': [{'vocalized': u'كأسفل', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'أإنا': [{'vocalized': u'أإنا', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'ولأجمعكم': [{'vocalized': u'ولأجمعكم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ساعتهن': [{'vocalized': u'ساعتهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'ككليهما': [{'vocalized': u'ككليهما', 'procletic': u'ك-', 'tags': u'حرف;توكيد;مجرور', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'فكفي': [{'vocalized': u'فكفي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'}],

 u'ألتحتها': [{'vocalized': u'ألتحتها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'ولوراء': [{'vocalized': u'ولوراء', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'لأسفل': [{'vocalized': u'لأسفل', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'بمثلكن': [{'vocalized': u'بمثلكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'بمثلكم': [{'vocalized': u'بمثلكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفبسويه': [{'vocalized': u'أفبسويه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أبانا': [{'vocalized': u'أبانا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبا'}],

 u'فخلفهن': [{'vocalized': u'فخلفهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'فخلفهم': [{'vocalized': u'فخلفهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'أفبسويك': [{'vocalized': u'أفبسويك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'لأمامكما': [{'vocalized': u'لأمامكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'أكهنالك': [{'vocalized': u'أكهنالك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'وكحميي': [{'vocalized': u'وكحميي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'وكحميي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'أوسويكم': [{'vocalized': u'أوسويكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوسويكن': [{'vocalized': u'أوسويكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'حسبها': [{'vocalized': u'حسبها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'وبحميهن': [{'vocalized': u'وبحميهن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'فبضعهن': [{'vocalized': u'فبضعهن', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بضع'}],

 u'فبضعهم': [{'vocalized': u'فبضعهم', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بضع'}],

 u'وبحميهم': [{'vocalized': u'وبحميهم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'وكحميه': [{'vocalized': u'وكحميه', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'وبجميعكما': [{'vocalized': u'وبجميعكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعكما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفبكليكما': [{'vocalized': u'أفبكليكما', 'procletic': u'أ-ف-ب-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'لازالتا': [{'vocalized': u'لازالتا', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالتا'}],

 u'بجنوبكما': [{'vocalized': u'بجنوبكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوكغيرهما': [{'vocalized': u'أوكغيرهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فبمثله': [{'vocalized': u'فبمثله', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'حينها': [{'vocalized': u'حينها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حين'}],

 u'فبمثلك': [{'vocalized': u'فبمثلك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'فبضعها': [{'vocalized': u'فبضعها', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بضع'}],

 u'وبحميها': [{'vocalized': u'وبحميها', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'أكنفسنا': [{'vocalized': u'أكنفسنا', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'وهاؤم': [{'vocalized': u'وهاؤم', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'هاؤم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هاؤم'}],

 u'فبمثلي': [{'vocalized': u'فبمثلي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فبمثلي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أإنك': [{'vocalized': u'أإنك', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'ببعضنا': [{'vocalized': u'ببعضنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'أإنه': [{'vocalized': u'أإنه', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'أإني': [{'vocalized': u'أإني', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'أإني', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'ساعتها': [{'vocalized': u'ساعتها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'وهاتين': [{'vocalized': u'وهاتين', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'كعامتي': [{'vocalized': u'كعامتي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'كعامتي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'وكشبهنا': [{'vocalized': u'وكشبهنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'فكأيتهم': [{'vocalized': u'فكأيتهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'أوبأجمعك': [{'vocalized': u'أوبأجمعك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلبعض': [{'vocalized': u'أفلبعض', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعض', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'ألعنها': [{'vocalized': u'ألعنها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'وكليلك': [{'vocalized': u'وكليلك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'ففوقه': [{'vocalized': u'ففوقه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'وكعينكما': [{'vocalized': u'وكعينكما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فخلفها': [{'vocalized': u'فخلفها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'ففوقك': [{'vocalized': u'ففوقك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'ولوراءها': [{'vocalized': u'ولوراءها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'ومساء': [{'vocalized': u'ومساء', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'مساء', 'encletic': u'', 'type': u'اسم', 'original': u'مساء'}],

 u'وبعدكما': [{'vocalized': u'وبعدكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعد'}],

 u'كلحظة': [{'vocalized': u'كلحظة', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'لانقلب': [{'vocalized': u'لانقلب', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'انقلب', 'encletic': u'', 'type': u'فعل', 'original': u'انقلب'}],

 u'فببعضه': [{'vocalized': u'فببعضه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'بأكثركن': [{'vocalized': u'بأكثركن', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'شطره': [{'vocalized': u'شطره', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'فببعضك': [{'vocalized': u'فببعضك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'شطرك': [{'vocalized': u'شطرك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'أولعليكم': [{'vocalized': u'أولعليكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'فببعضي': [{'vocalized': u'فببعضي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فببعضي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'كأيهما': [{'vocalized': u'كأيهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'شطري': [{'vocalized': u'شطري', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'شطري', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'لإليك': [{'vocalized': u'لإليك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'ففيهما': [{'vocalized': u'ففيهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيهما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'فاللتين': [{'vocalized': u'فاللتين', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'فغربهم': [{'vocalized': u'فغربهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'وكغروبكما': [{'vocalized': u'وكغروبكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'فكليلنا': [{'vocalized': u'فكليلنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'أفعامتكم': [{'vocalized': u'أفعامتكم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'فأمامهما': [{'vocalized': u'فأمامهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'أفبعين': [{'vocalized': u'أفبعين', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'وبينهم': [{'vocalized': u'وبينهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بين'}],

 u'ماانفكتا': [{'vocalized': u'ماانفكتا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفكتا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكتا'}],

 u'أفشبهكم': [{'vocalized': u'أفشبهكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'أفشبهكن': [{'vocalized': u'أفشبهكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'لأيكن': [{'vocalized': u'لأيكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'لأيكم': [{'vocalized': u'لأيكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'فكغروبها': [{'vocalized': u'فكغروبها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'ولعلى': [{'vocalized': u'ولعلى', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'ولعلي': [{'vocalized': u'ولعلي', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'ولعلي', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'ولعلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'ولعلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'بعدما': [{'vocalized': u'بعدما', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'بعدما', 'encletic': u'', 'type': u'اسم', 'original': u'بعدما'}],

 u'ى': [{'vocalized': u'ى', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ى', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ى'}],

 u'ولعله': [{'vocalized': u'ولعله', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لعل'}],

 u'ولعلق': [{'vocalized': u'ولعلق', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'علق', 'encletic': u'', 'type': u'فعل', 'original': u'علق'}],

 u'واها': [{'vocalized': u'واها', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'واها', 'encletic': u'', 'type': u'اسم فعل', 'original': u'واها'}],

 u'وبجنبنا': [{'vocalized': u'وبجنبنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'وحاشاي': [{'vocalized': u'وحاشاي', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'حاشا'},
 {'vocalized': u'وحاشاي', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'حاشا'}],

 u'أولو': [{'vocalized': u'أولو', 'procletic': u'أ-و-', 'tags': u'حرف;الحروف(حروف);عطف;استفهام', 'stem': u'لو', 'encletic': u'', 'type': u'حرف', 'original': u'لو'}],

 u'وحاشاه': [{'vocalized': u'وحاشاه', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'حاشا'}],

 u'وحاشاك': [{'vocalized': u'وحاشاك', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'حاشا'}],

 u'وكذلكم': [{'vocalized': u'وكذلكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'وكذلكن': [{'vocalized': u'وكذلكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'فعداي': [{'vocalized': u'فعداي', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'عدا'},
 {'vocalized': u'فعداي', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'عدا'}],

 u'فلأضحى': [{'vocalized': u'فلأضحى', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أضحى', 'encletic': u'', 'type': u'فعل', 'original': u'أضحى'}],

 u'ألإلينا': [{'vocalized': u'ألإلينا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'لأخي': [{'vocalized': u'لأخي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'فزمانكما': [{'vocalized': u'فزمانكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'فعداك': [{'vocalized': u'فعداك', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'عدا'}],

 u'أفلإليكم': [{'vocalized': u'أفلإليكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'كأكثركما': [{'vocalized': u'كأكثركما', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'فعداه': [{'vocalized': u'فعداه', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'عدا'}],

 u'كأعليكن': [{'vocalized': u'كأعليكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'كأعليكم': [{'vocalized': u'كأعليكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'أفكليكما': [{'vocalized': u'أفكليكما', 'procletic': u'أ-ف-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'وكزماني': [{'vocalized': u'وكزماني', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'وكزماني', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'أفكمثلكما': [{'vocalized': u'أفكمثلكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'حموهن': [{'vocalized': u'حموهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمو'}],

 u'أفسويك': [{'vocalized': u'أفسويك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'حموهم': [{'vocalized': u'حموهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمو'}],

 u'وكزمانك': [{'vocalized': u'وكزمانك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'وكزمانه': [{'vocalized': u'وكزمانه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'وبضع': [{'vocalized': u'وبضع', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'بضع', 'encletic': u'', 'type': u'اسم', 'original': u'بضع'}],

 u'لهذا': [{'vocalized': u'لهذا', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'أكنفسكم': [{'vocalized': u'أكنفسكم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'وبساعتها': [{'vocalized': u'وبساعتها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلتحتهن': [{'vocalized': u'فلتحتهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'فلفوقكما': [{'vocalized': u'فلفوقكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'فحموي': [{'vocalized': u'فحموي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمو'},
 {'vocalized': u'فحموي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمو'}],

 u'وكأجمعها': [{'vocalized': u'وكأجمعها', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'والألى': [{'vocalized': u'والألى', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'ألشمالهما': [{'vocalized': u'ألشمالهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'بذاتنا': [{'vocalized': u'بذاتنا', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'فحموك': [{'vocalized': u'فحموك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمو'}],

 u'ألعلكما': [{'vocalized': u'ألعلكما', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لعل'}],

 u'ولأمامكما': [{'vocalized': u'ولأمامكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'معاذهم': [{'vocalized': u'معاذهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-هم', 'type': u'اسم', 'original': u'معاذ'}],

 u'معاذهن': [{'vocalized': u'معاذهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-هن', 'type': u'اسم', 'original': u'معاذ'}],

 u'ولليل': [{'vocalized': u'ولليل', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'لابتدأ': [{'vocalized': u'لابتدأ', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'ابتدأ', 'encletic': u'', 'type': u'فعل', 'original': u'ابتدأ'}],

 u'اللتيا': [{'vocalized': u'اللتيا', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'أفثم': [{'vocalized': u'أفثم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'}],

 u'لفيكما': [{'vocalized': u'لفيكما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'ألوراءنا': [{'vocalized': u'ألوراءنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'ألعينكما': [{'vocalized': u'ألعينكما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'وكأجمعهم': [{'vocalized': u'وكأجمعهم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأيتهم': [{'vocalized': u'وأيتهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'وأيتهن': [{'vocalized': u'وأيتهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'وكأجمعهن': [{'vocalized': u'وكأجمعهن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفبنفسكما': [{'vocalized': u'أفبنفسكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'ومافتئتن': [{'vocalized': u'ومافتئتن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتن', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتن'}],

 u'ومافتئتم': [{'vocalized': u'ومافتئتم', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتم', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتم'}],

 u'فحميها': [{'vocalized': u'فحميها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'معاذها': [{'vocalized': u'معاذها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-ها', 'type': u'اسم', 'original': u'معاذ'}],

 u'بوقتهما': [{'vocalized': u'بوقتهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'اللتين': [{'vocalized': u'اللتين', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'بذويهما': [{'vocalized': u'بذويهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكعيننا': [{'vocalized': u'فكعيننا', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'أومثلهما': [{'vocalized': u'أومثلهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'وكأعليهما': [{'vocalized': u'وكأعليهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فحماكما': [{'vocalized': u'فحماكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حما'}],

 u'فلأكثركم': [{'vocalized': u'فلأكثركم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلأكثركن': [{'vocalized': u'فلأكثركن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلديك': [{'vocalized': u'فلديك', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدى'}],

 u'فخلفكم': [{'vocalized': u'فخلفكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'فلديه': [{'vocalized': u'فلديه', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدى'}],

 u'لهذه': [{'vocalized': u'لهذه', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'وبساعتهن': [{'vocalized': u'وبساعتهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبساعتهم': [{'vocalized': u'وبساعتهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلابن': [{'vocalized': u'فلابن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'وبشهرهم': [{'vocalized': u'وبشهرهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'لهذي': [{'vocalized': u'لهذي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'ألهم': [{'vocalized': u'ألهم', 'procletic': u'أ-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'},
 {'vocalized': u'ألهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'ألهن': [{'vocalized': u'ألهن', 'procletic': u'أ-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'},
 {'vocalized': u'ألهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'فبتلكما': [{'vocalized': u'فبتلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'وكجنبنا': [{'vocalized': u'وكجنبنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'وبفيكم': [{'vocalized': u'وبفيكم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'}],

 u'أشمالكما': [{'vocalized': u'أشمالكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'ألهو': [{'vocalized': u'ألهو', 'procletic': u'أ-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'},
 {'vocalized': u'ألهو', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'ألهي': [{'vocalized': u'ألهي', 'procletic': u'أ-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'},
 {'vocalized': u'ألهي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'بغربهما': [{'vocalized': u'بغربهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'وككلها': [{'vocalized': u'وككلها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلها', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'لجنوب': [{'vocalized': u'لجنوب', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'ولشمالنا': [{'vocalized': u'ولشمالنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'فكأجمعكم': [{'vocalized': u'فكأجمعكم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوذاك': [{'vocalized': u'أوذاك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'فكعين': [{'vocalized': u'فكعين', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'أفكمثلهم': [{'vocalized': u'أفكمثلهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفكمثلهن': [{'vocalized': u'أفكمثلهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'فلستم': [{'vocalized': u'فلستم', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لستم', 'encletic': u'', 'type': u'فعل', 'original': u'لستم'}],

 u'فلجنوبنا': [{'vocalized': u'فلجنوبنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'أولبعضها': [{'vocalized': u'أولبعضها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'أفبهم': [{'vocalized': u'أفبهم', 'procletic': u'أ-ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'فبشرقها': [{'vocalized': u'فبشرقها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'وجنوب': [{'vocalized': u'وجنوب', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفكمثلها': [{'vocalized': u'أفكمثلها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'وعما': [{'vocalized': u'وعما', 'procletic': u'و-', 'tags': u'حرف;حرف جر مكفوف;عطف', 'stem': u'عما', 'encletic': u'', 'type': u'حرف', 'original': u'عما'}],

 u'فبعيننا': [{'vocalized': u'فبعيننا', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'أولبعضهم': [{'vocalized': u'أولبعضهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أولبعضهن': [{'vocalized': u'أولبعضهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'بوقت': [{'vocalized': u'بوقت', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'فلعليك': [{'vocalized': u'فلعليك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'فبشرقهن': [{'vocalized': u'فبشرقهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'ولزمانكما': [{'vocalized': u'ولزمانكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'فلعليه': [{'vocalized': u'فلعليه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'أبعضكن': [{'vocalized': u'أبعضكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أبعضكم': [{'vocalized': u'أبعضكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'ألها': [{'vocalized': u'ألها', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'لها', 'encletic': u'', 'type': u'ضمير', 'original': u'لها'}],

 u'فكأعلي': [{'vocalized': u'فكأعلي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'فكأعلي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'سوينا': [{'vocalized': u'سوينا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'ولمعنا': [{'vocalized': u'ولمعنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'فأثناءهما': [{'vocalized': u'فأثناءهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'أككليكما': [{'vocalized': u'أككليكما', 'procletic': u'أ-ك-', 'tags': u'حرف;توكيد;مجرور;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'فعلينا': [{'vocalized': u'فعلينا', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'وككلهم': [{'vocalized': u'وككلهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلهم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'ولذلكن': [{'vocalized': u'ولذلكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'ولذلكم': [{'vocalized': u'ولذلكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'وككلهن': [{'vocalized': u'وككلهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلهن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'بجميعهما': [{'vocalized': u'بجميعهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعهما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'لشبهكم': [{'vocalized': u'لشبهكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'لشبهكن': [{'vocalized': u'لشبهكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أهاته': [{'vocalized': u'أهاته', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'ومعاذها': [{'vocalized': u'ومعاذها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ها', 'type': u'اسم', 'original': u'معاذ'}],

 u'أهاتي': [{'vocalized': u'أهاتي', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'ولشهركن': [{'vocalized': u'ولشهركن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'فاللائي': [{'vocalized': u'فاللائي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'وللحظتهن': [{'vocalized': u'وللحظتهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'فمازالوا': [{'vocalized': u'فمازالوا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالوا'}],

 u'أكنحونا': [{'vocalized': u'أكنحونا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'فحولكن': [{'vocalized': u'فحولكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حول'}],

 u'ولشهركم': [{'vocalized': u'ولشهركم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'فبلحظتهم': [{'vocalized': u'فبلحظتهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'أوبذلك': [{'vocalized': u'أوبذلك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'ذاتنا': [{'vocalized': u'ذاتنا', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'كأية': [{'vocalized': u'كأية', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'فلجميعنا': [{'vocalized': u'فلجميعنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعنا', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وكالألى': [{'vocalized': u'وكالألى', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'ز': [{'vocalized': u'ز', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ز', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ز'}],

 u'لسويكن': [{'vocalized': u'لسويكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلنحوكم': [{'vocalized': u'أفلنحوكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلنحوكن': [{'vocalized': u'أفلنحوكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'لسويكم': [{'vocalized': u'لسويكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أأولاء': [{'vocalized': u'أأولاء', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'وإليهم': [{'vocalized': u'وإليهم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'وإليهن': [{'vocalized': u'وإليهن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'فلأعليه': [{'vocalized': u'فلأعليه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'أفلفيكما': [{'vocalized': u'أفلفيكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'لنحوك': [{'vocalized': u'لنحوك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'فبأثناءكم': [{'vocalized': u'فبأثناءكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبأخينا': [{'vocalized': u'وبأخينا', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'فبأثناءكن': [{'vocalized': u'فبأثناءكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'أببعضكما': [{'vocalized': u'أببعضكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'فكذلكما': [{'vocalized': u'فكذلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'فيميننا': [{'vocalized': u'فيميننا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'ولحميكم': [{'vocalized': u'ولحميكم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'أوتحت': [{'vocalized': u'أوتحت', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'أوبأجمعكما': [{'vocalized': u'أوبأجمعكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أخيي': [{'vocalized': u'أخيي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'أخيي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'ككلتا': [{'vocalized': u'ككلتا', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'شرقهم': [{'vocalized': u'شرقهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'وليمينهن': [{'vocalized': u'وليمينهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'أوذين': [{'vocalized': u'أوذين', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'وإليها': [{'vocalized': u'وإليها', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'فانا': [{'vocalized': u'فانا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فا'}],

 u'أخيه': [{'vocalized': u'أخيه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'فتلقاءهن': [{'vocalized': u'فتلقاءهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ومعاذهم': [{'vocalized': u'ومعاذهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-هم', 'type': u'اسم', 'original': u'معاذ'}],

 u'ومعاذهن': [{'vocalized': u'ومعاذهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-هن', 'type': u'اسم', 'original': u'معاذ'}],

 u'وليمينهم': [{'vocalized': u'وليمينهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'فأعليك': [{'vocalized': u'فأعليك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'قبلما': [{'vocalized': u'قبلما', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'قبلما', 'encletic': u'', 'type': u'اسم', 'original': u'قبلما'}],

 u'أفبأولئكم': [{'vocalized': u'أفبأولئكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'فأنكم': [{'vocalized': u'فأنكم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'فأعليه': [{'vocalized': u'فأعليه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'أعامتكم': [{'vocalized': u'أعامتكم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أعامتكن': [{'vocalized': u'أعامتكن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أفيميننا': [{'vocalized': u'أفيميننا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'أوكلهن': [{'vocalized': u'أوكلهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلهن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أوكلهم': [{'vocalized': u'أوكلهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلهم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'فكحمي': [{'vocalized': u'فكحمي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'ذلكما': [{'vocalized': u'ذلكما', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'أفإليكما': [{'vocalized': u'أفإليكما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'كالتي': [{'vocalized': u'كالتي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'فبسوي': [{'vocalized': u'فبسوي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'فبسوي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'فبسوى': [{'vocalized': u'فبسوى', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أبعضهما': [{'vocalized': u'أبعضهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'وكاللتيا': [{'vocalized': u'وكاللتيا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'حينهن': [{'vocalized': u'حينهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حين'}],

 u'أولحسب': [{'vocalized': u'أولحسب', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'لتبدل': [{'vocalized': u'لتبدل', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'تبدل', 'encletic': u'', 'type': u'فعل', 'original': u'تبدل'}],

 u'كابن': [{'vocalized': u'كابن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'فبتلقاء': [{'vocalized': u'فبتلقاء', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'لإننا': [{'vocalized': u'لإننا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'ولأجمعه': [{'vocalized': u'ولأجمعه', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولأجمعك': [{'vocalized': u'ولأجمعك', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولنحوكم': [{'vocalized': u'أولنحوكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أفنفسكما': [{'vocalized': u'أفنفسكما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'أولنحوكن': [{'vocalized': u'أولنحوكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'فلذات': [{'vocalized': u'فلذات', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'ووراءنا': [{'vocalized': u'ووراءنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'أفلكأنه': [{'vocalized': u'أفلكأنه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'بأيتي': [{'vocalized': u'بأيتي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'بأيتي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'أفلمثلك': [{'vocalized': u'أفلمثلك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلكما': [{'vocalized': u'أفلكما', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لكما', 'encletic': u'', 'type': u'ضمير', 'original': u'لكما'}],

 u'أفلمثله': [{'vocalized': u'أفلمثله', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثله', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'فبجميعكما': [{'vocalized': u'فبجميعكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعكما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلأولئكم': [{'vocalized': u'أفلأولئكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'أفلمثلي': [{'vocalized': u'أفلمثلي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أوبذلكما': [{'vocalized': u'أوبذلكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'فلسويكن': [{'vocalized': u'فلسويكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'فلسويكم': [{'vocalized': u'فلسويكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'بعضكما': [{'vocalized': u'بعضكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'ضمنكما': [{'vocalized': u'ضمنكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ضمن'}],

 u'ألنفسكن': [{'vocalized': u'ألنفسكن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'ألنفسكم': [{'vocalized': u'ألنفسكم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'فلولا': [{'vocalized': u'فلولا', 'procletic': u'ف-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لولا', 'encletic': u'', 'type': u'حرف', 'original': u'لولا'}],

 u'ككلكم': [{'vocalized': u'ككلكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلكم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'فلذاك': [{'vocalized': u'فلذاك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'أوكلها': [{'vocalized': u'أوكلها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلها', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'وكذاتهما': [{'vocalized': u'وكذاتهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'فككلي': [{'vocalized': u'فككلي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'حينك': [{'vocalized': u'حينك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حين'}],

 u'فبذلكما': [{'vocalized': u'فبذلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'أولهاتين': [{'vocalized': u'أولهاتين', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'أفكغيرهما': [{'vocalized': u'أفكغيرهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فحذار': [{'vocalized': u'فحذار', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'حذار', 'encletic': u'', 'type': u'اسم فعل', 'original': u'حذار'}],

 u'بأقلهم': [{'vocalized': u'بأقلهم', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'فغربها': [{'vocalized': u'فغربها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'وغيرها': [{'vocalized': u'وغيرها', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'وكاللتين': [{'vocalized': u'وكاللتين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'فخلاكما': [{'vocalized': u'فخلاكما', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'خلا'}],

 u'أيضا': [{'vocalized': u'أيضا', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'أيضا', 'encletic': u'', 'type': u'اسم', 'original': u'أيضا'}],

 u'بليله': [{'vocalized': u'بليله', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'لوقته': [{'vocalized': u'لوقته', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'أولمنه': [{'vocalized': u'أولمنه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'فليمينكم': [{'vocalized': u'فليمينكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'لوقتك': [{'vocalized': u'لوقتك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'أولمنك': [{'vocalized': u'أولمنك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'كأينا': [{'vocalized': u'كأينا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'أولمني': [{'vocalized': u'أولمني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'أولمني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'لوقتي': [{'vocalized': u'لوقتي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'لوقتي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'أخلفهما': [{'vocalized': u'أخلفهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'فكخلفكم': [{'vocalized': u'فكخلفكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'بضعكم': [{'vocalized': u'بضعكم', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بضع'}],

 u'بخلفكما': [{'vocalized': u'بخلفكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'وكغروبكم': [{'vocalized': u'وكغروبكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'وبغربكن': [{'vocalized': u'وبغربكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'وبغربكم': [{'vocalized': u'وبغربكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'وكغروبكن': [{'vocalized': u'وكغروبكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'ففيهم': [{'vocalized': u'ففيهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيهم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'ففيهن': [{'vocalized': u'ففيهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيهن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'مابرحا': [{'vocalized': u'مابرحا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحا'}],

 u'بعامته': [{'vocalized': u'بعامته', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'بي': [{'vocalized': u'بي', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'بي', 'encletic': u'', 'type': u'ضمير', 'original': u'بي'}],

 u'لذويهم': [{'vocalized': u'لذويهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'ألأنانا': [{'vocalized': u'ألأنانا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'لذويهن': [{'vocalized': u'لذويهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفلذينك': [{'vocalized': u'أفلذينك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'فكأجمعها': [{'vocalized': u'فكأجمعها', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'بن': [{'vocalized': u'بن', 'procletic': u'', 'tags': u'اسم;وصل الأعلام', 'stem': u'بن', 'encletic': u'', 'type': u'اسم', 'original': u'بن'}],

 u'به': [{'vocalized': u'به', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'به', 'encletic': u'', 'type': u'ضمير', 'original': u'به'}],

 u'اللتان': [{'vocalized': u'اللتان', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللتان', 'encletic': u'', 'type': u'اسم', 'original': u'اللتان'}],

 u'ووقتكما': [{'vocalized': u'ووقتكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'فبأولاء': [{'vocalized': u'فبأولاء', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'بعامتك': [{'vocalized': u'بعامتك', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'بس': [{'vocalized': u'بس', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'بس', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بس'},
 {'vocalized': u'بس', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'بس', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بس'}],

 u'مابرحن': [{'vocalized': u'مابرحن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحن', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحن'}],

 u'ففيها': [{'vocalized': u'ففيها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيها', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'لغيري': [{'vocalized': u'لغيري', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيري', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيري', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيري', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'لذويها': [{'vocalized': u'لذويها', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولأعلينا': [{'vocalized': u'ولأعلينا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'فكأجمعهن': [{'vocalized': u'فكأجمعهن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'لغيره': [{'vocalized': u'لغيره', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيره', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'فكأجمعهم': [{'vocalized': u'فكأجمعهم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'لغيرك': [{'vocalized': u'لغيرك', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيرك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'ليتنا': [{'vocalized': u'ليتنا', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-نا', 'type': u'حرف', 'original': u'ليت'}],

 u'أفكسويكما': [{'vocalized': u'أفكسويكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'فأثناءك': [{'vocalized': u'فأثناءك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'ألتلكما': [{'vocalized': u'ألتلكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'أجمعك': [{'vocalized': u'أجمعك', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'فشرقهما': [{'vocalized': u'فشرقهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'أجمعه': [{'vocalized': u'أجمعه', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أجمعي': [{'vocalized': u'أجمعي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أجمعي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'كأبينا': [{'vocalized': u'كأبينا', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'بليلكما': [{'vocalized': u'بليلكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'فاللذين': [{'vocalized': u'فاللذين', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'قد': [{'vocalized': u'قد', 'procletic': u'', 'tags': u'حرف;حرف تحقيق/ توقع', 'stem': u'قد', 'encletic': u'', 'type': u'حرف', 'original': u'قد'}],

 u'أففوقك': [{'vocalized': u'أففوقك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'كأكثركن': [{'vocalized': u'كأكثركن', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'كأكثركم': [{'vocalized': u'كأكثركم', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'وراءها': [{'vocalized': u'وراءها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'أوشبهكن': [{'vocalized': u'أوشبهكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'فللحظتنا': [{'vocalized': u'فللحظتنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'فعينها': [{'vocalized': u'فعينها', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'أوشبهكم': [{'vocalized': u'أوشبهكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'فلهاتين': [{'vocalized': u'فلهاتين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'كمثل': [{'vocalized': u'كمثل', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'شطركما': [{'vocalized': u'شطركما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'فببعضكما': [{'vocalized': u'فببعضكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أوأمامهم': [{'vocalized': u'أوأمامهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'أوأمامهن': [{'vocalized': u'أوأمامهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'وغروبي': [{'vocalized': u'وغروبي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'وغروبي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'ألمثل': [{'vocalized': u'ألمثل', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثل', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'وغروبك': [{'vocalized': u'وغروبك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'حسبما': [{'vocalized': u'حسبما', 'procletic': u'', 'tags': u'اسم;جار ومجرور', 'stem': u'حسبما', 'encletic': u'', 'type': u'اسم', 'original': u'حسبما'}],

 u'لجميعنا': [{'vocalized': u'لجميعنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعنا', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'فكجنوبها': [{'vocalized': u'فكجنوبها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'ليمينهن': [{'vocalized': u'ليمينهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'فكلحظته': [{'vocalized': u'فكلحظته', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'لتحتكن': [{'vocalized': u'لتحتكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'بحسبكن': [{'vocalized': u'بحسبكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'بحسبكم': [{'vocalized': u'بحسبكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلفوقهن': [{'vocalized': u'أفلفوقهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'أفلفوقهم': [{'vocalized': u'أفلفوقهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'فكلحظتي': [{'vocalized': u'فكلحظتي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'فكلحظتي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'ونحوك': [{'vocalized': u'ونحوك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'ولكي': [{'vocalized': u'ولكي', 'procletic': u'و-', 'tags': u'حرف;حرف تعليل;عطف', 'stem': u'لكي', 'encletic': u'', 'type': u'حرف', 'original': u'لكي'}],

 u'ونحوه': [{'vocalized': u'ونحوه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'ونحوي': [{'vocalized': u'ونحوي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلمننا': [{'vocalized': u'أفلمننا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'وأمامهن': [{'vocalized': u'وأمامهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'وأمامهم': [{'vocalized': u'وأمامهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'أفلفوقها': [{'vocalized': u'أفلفوقها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'أفكعامتهم': [{'vocalized': u'أفكعامتهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'فأباكما': [{'vocalized': u'فأباكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبا'}],

 u'وأسفلكما': [{'vocalized': u'وأسفلكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوككلتا': [{'vocalized': u'أوككلتا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'فعينهم': [{'vocalized': u'فعينهم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أفلهناك': [{'vocalized': u'أفلهناك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'فعينهن': [{'vocalized': u'فعينهن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'وبعضكن': [{'vocalized': u'وبعضكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أإلى': [{'vocalized': u'أإلى', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'أإلي': [{'vocalized': u'أإلي', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'أإلي', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'وبعضكم': [{'vocalized': u'وبعضكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'ولسوينا': [{'vocalized': u'ولسوينا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلفيكن': [{'vocalized': u'أفلفيكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'فلمعنا': [{'vocalized': u'فلمعنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'أولشمالكن': [{'vocalized': u'أولشمالكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'أوأمامها': [{'vocalized': u'أوأمامها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'ولأخيه': [{'vocalized': u'ولأخيه', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'ولأخيك': [{'vocalized': u'ولأخيك', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'ولفيهن': [{'vocalized': u'ولفيهن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'ولفيهم': [{'vocalized': u'ولفيهم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'ولأخيي': [{'vocalized': u'ولأخيي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'ولأخيي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'كأسفلها': [{'vocalized': u'كأسفلها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبأثناءنا': [{'vocalized': u'وبأثناءنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'أوبمثلكما': [{'vocalized': u'أوبمثلكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'وكذويها': [{'vocalized': u'وكذويها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولمنكن': [{'vocalized': u'ولمنكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'ولمنكم': [{'vocalized': u'ولمنكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'كحمينا': [{'vocalized': u'كحمينا', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'بأيها': [{'vocalized': u'بأيها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'فلأناكم': [{'vocalized': u'فلأناكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'فلأناكن': [{'vocalized': u'فلأناكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'وأمامكن': [{'vocalized': u'وأمامكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'فكأنكما': [{'vocalized': u'فكأنكما', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنكما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'ولأثناءك': [{'vocalized': u'ولأثناءك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلتي': [{'vocalized': u'فلتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'كغروبهما': [{'vocalized': u'كغروبهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'بأجمعها': [{'vocalized': u'بأجمعها', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألإليكما': [{'vocalized': u'ألإليكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'فلته': [{'vocalized': u'فلته', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'أفلكلكما': [{'vocalized': u'أفلكلكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'بأيهن': [{'vocalized': u'بأيهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'بأيهم': [{'vocalized': u'بأيهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'فتبدل': [{'vocalized': u'فتبدل', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'تبدل', 'encletic': u'', 'type': u'فعل', 'original': u'تبدل'}],

 u'ولعنك': [{'vocalized': u'ولعنك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'ألنحو': [{'vocalized': u'ألنحو', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'ألنحن': [{'vocalized': u'ألنحن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'ولعني': [{'vocalized': u'ولعني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'ولعني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'أفلديه': [{'vocalized': u'أفلديه', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدى'}],

 u'وأمامهما': [{'vocalized': u'وأمامهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'أفلديك': [{'vocalized': u'أفلديك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدى'}],

 u'فبذاتكما': [{'vocalized': u'فبذاتكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'وكأيتكما': [{'vocalized': u'وكأيتكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'لتلقاءكما': [{'vocalized': u'لتلقاءكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفغيرهما': [{'vocalized': u'أفغيرهما', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'ولفيها': [{'vocalized': u'ولفيها', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'ولتلكما': [{'vocalized': u'ولتلكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'ولمثلهما': [{'vocalized': u'ولمثلهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'عليك': [{'vocalized': u'عليك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'عليك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'عليك'},
 {'vocalized': u'عليك', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'كأسفلهن': [{'vocalized': u'كأسفلهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكذويهم': [{'vocalized': u'وكذويهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكذويهن': [{'vocalized': u'وكذويهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبأقله': [{'vocalized': u'وبأقله', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'فجنبنا': [{'vocalized': u'فجنبنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'وكأخيه': [{'vocalized': u'وكأخيه', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'كأولئك': [{'vocalized': u'كأولئك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'فلهما': [{'vocalized': u'فلهما', 'procletic': u'ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'},
 {'vocalized': u'فلهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'وكشطر': [{'vocalized': u'وكشطر', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'أبيي': [{'vocalized': u'أبيي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'أبيي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'فكشهرهما': [{'vocalized': u'فكشهرهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'للحظتهم': [{'vocalized': u'للحظتهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبابن': [{'vocalized': u'فبابن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'للحظتهن': [{'vocalized': u'للحظتهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'بأنكن': [{'vocalized': u'بأنكن', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'بأنكم': [{'vocalized': u'بأنكم', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'وبخلفكم': [{'vocalized': u'وبخلفكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'أفبكله': [{'vocalized': u'أفبكله', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكله', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'وبخلفكن': [{'vocalized': u'وبخلفكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'أفبكلي': [{'vocalized': u'أفبكلي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'تحتهما': [{'vocalized': u'تحتهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'فلعننا': [{'vocalized': u'فلعننا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'فبأكثركما': [{'vocalized': u'فبأكثركما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'وأية': [{'vocalized': u'وأية', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'فبذاتهم': [{'vocalized': u'فبذاتهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'فبذاتهن': [{'vocalized': u'فبذاتهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'فكنحو': [{'vocalized': u'فكنحو', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحو', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'أوأناهما': [{'vocalized': u'أوأناهما', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'تي': [{'vocalized': u'تي', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'وبأكثرها': [{'vocalized': u'وبأكثرها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'وكأولئكم': [{'vocalized': u'وكأولئكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'فبزمانهم': [{'vocalized': u'فبزمانهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'ته': [{'vocalized': u'ته', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'وبفي': [{'vocalized': u'وبفي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'}],

 u'أمامهما': [{'vocalized': u'أمامهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'أوكسوينا': [{'vocalized': u'أوكسوينا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'فبجنوبكما': [{'vocalized': u'فبجنوبكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'فعينكن': [{'vocalized': u'فعينكن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فكأيتنا': [{'vocalized': u'فكأيتنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'فبذاتها': [{'vocalized': u'فبذاتها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'باللاتي': [{'vocalized': u'باللاتي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'أهذان': [{'vocalized': u'أهذان', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هذان', 'encletic': u'', 'type': u'اسم', 'original': u'هذان'}],

 u'وبأكثرهن': [{'vocalized': u'وبأكثرهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'وبأكثرهم': [{'vocalized': u'وبأكثرهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'أوبكلهما': [{'vocalized': u'أوبكلهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'وأجمعي': [{'vocalized': u'وأجمعي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'وأجمعي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألكأنكم': [{'vocalized': u'ألكأنكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'ألكأنكن': [{'vocalized': u'ألكأنكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'وأجمعك': [{'vocalized': u'وأجمعك', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأجمعه': [{'vocalized': u'وأجمعه', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'للحظتها': [{'vocalized': u'للحظتها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'ألعليكن': [{'vocalized': u'ألعليكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'ألعليكم': [{'vocalized': u'ألعليكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'أفذلكن': [{'vocalized': u'أفذلكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أفذلكم': [{'vocalized': u'أفذلكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'فجنبكما': [{'vocalized': u'فجنبكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'فكمن': [{'vocalized': u'فكمن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'فبغروبه': [{'vocalized': u'فبغروبه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'وكنحوه': [{'vocalized': u'وكنحوه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'وكأولالك': [{'vocalized': u'وكأولالك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'وبغربنا': [{'vocalized': u'وبغربنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'فبغروبك': [{'vocalized': u'فبغروبك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'وكنحوك': [{'vocalized': u'وكنحوك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'بوقتها': [{'vocalized': u'بوقتها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'وكنحوي': [{'vocalized': u'وكنحوي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'فبغروبي': [{'vocalized': u'فبغروبي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'فبغروبي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'أفنفسنا': [{'vocalized': u'أفنفسنا', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أولإنه': [{'vocalized': u'أولإنه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'بمثلهن': [{'vocalized': u'بمثلهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'بمثلهم': [{'vocalized': u'بمثلهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أولإنك': [{'vocalized': u'أولإنك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'أفكلها': [{'vocalized': u'أفكلها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلها', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'وشهره': [{'vocalized': u'وشهره', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'أفكلهما': [{'vocalized': u'أفكلهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلهما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'بشبهنا': [{'vocalized': u'بشبهنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'أولإني': [{'vocalized': u'أولإني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'أولإني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'فمافتئ': [{'vocalized': u'فمافتئ', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئ', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئ'}],

 u'لخلفها': [{'vocalized': u'لخلفها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'فكذاتهم': [{'vocalized': u'فكذاتهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'فكذاتهن': [{'vocalized': u'فكذاتهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'فلإنكم': [{'vocalized': u'فلإنكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'فلإنكن': [{'vocalized': u'فلإنكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'بمثلها': [{'vocalized': u'بمثلها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'أفأمامهما': [{'vocalized': u'أفأمامهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'ولتينك': [{'vocalized': u'ولتينك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'أفكلهن': [{'vocalized': u'أفكلهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلهن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أولأناي': [{'vocalized': u'أولأناي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'أولأناي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'أفكلهم': [{'vocalized': u'أفكلهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلهم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أفكنحوهما': [{'vocalized': u'أفكنحوهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'فوقكما': [{'vocalized': u'فوقكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'وبنفسهما': [{'vocalized': u'وبنفسهما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'لخلفهن': [{'vocalized': u'لخلفهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'بعين': [{'vocalized': u'بعين', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'أوعنكما': [{'vocalized': u'أوعنكما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'حسبكم': [{'vocalized': u'حسبكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'حسبكن': [{'vocalized': u'حسبكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'أسويكن': [{'vocalized': u'أسويكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أسويكم': [{'vocalized': u'أسويكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكنحوك': [{'vocalized': u'أوكنحوك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'لأخينا': [{'vocalized': u'لأخينا', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'فمثلكما': [{'vocalized': u'فمثلكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أولغيرنا': [{'vocalized': u'أولغيرنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيرنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أفوراءكما': [{'vocalized': u'أفوراءكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'أوبهؤلاء': [{'vocalized': u'أوبهؤلاء', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'حسب': [{'vocalized': u'حسب', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'بوقتهن': [{'vocalized': u'بوقتهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'بوقتهم': [{'vocalized': u'بوقتهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'فبساعتهن': [{'vocalized': u'فبساعتهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'ألتحتكن': [{'vocalized': u'ألتحتكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'ألتحتكم': [{'vocalized': u'ألتحتكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'كأعليهن': [{'vocalized': u'كأعليهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'كأعليهم': [{'vocalized': u'كأعليهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'للواتي': [{'vocalized': u'للواتي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'كوقت': [{'vocalized': u'كوقت', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'ويكأنهما': [{'vocalized': u'ويكأنهما', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-هما', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'أفيمينهما': [{'vocalized': u'أفيمينهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'فبفيي': [{'vocalized': u'فبفيي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فبفيي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'}],

 u'شمالي': [{'vocalized': u'شمالي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'شمالي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'وماانفككن': [{'vocalized': u'وماانفككن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككن', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككن'}],

 u'فبفيك': [{'vocalized': u'فبفيك', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'}],

 u'فبفيه': [{'vocalized': u'فبفيه', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'}],

 u'بأكثرهم': [{'vocalized': u'بأكثرهم', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'بأكثرهن': [{'vocalized': u'بأكثرهن', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفكأولئك': [{'vocalized': u'أفكأولئك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'فلكنهن': [{'vocalized': u'فلكنهن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنهن', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لكن'}],

 u'فلكنهم': [{'vocalized': u'فلكنهم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنهم', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لكن'}],

 u'فأن': [{'vocalized': u'فأن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فأن', 'procletic': u'ف-', 'tags': u'حرف;حرف نصب;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'أوكمثلهما': [{'vocalized': u'أوكمثلهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فأي': [{'vocalized': u'فأي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فأي', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فأي', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فأي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'وتلكما': [{'vocalized': u'وتلكما', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'لإلى': [{'vocalized': u'لإلى', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'لجنوبكم': [{'vocalized': u'لجنوبكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'لجنوبكن': [{'vocalized': u'لجنوبكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'لإلي': [{'vocalized': u'لإلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'لإلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'فلشمالهم': [{'vocalized': u'فلشمالهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'فلنفسكما': [{'vocalized': u'فلنفسكما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'وعندها': [{'vocalized': u'وعندها', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عند'}],

 u'ولأكثر': [{'vocalized': u'ولأكثر', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلكنها': [{'vocalized': u'فلكنها', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنها', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لكن'}],

 u'وإياه': [{'vocalized': u'وإياه', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياه', 'encletic': u'', 'type': u'ضمير', 'original': u'إياه'}],

 u'أفبهاته': [{'vocalized': u'أفبهاته', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'فبضعكن': [{'vocalized': u'فبضعكن', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بضع'}],

 u'فبضعكم': [{'vocalized': u'فبضعكم', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بضع'}],

 u'وبحميكم': [{'vocalized': u'وبحميكم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'أفبهاتي': [{'vocalized': u'أفبهاتي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'أوذي': [{'vocalized': u'أوذي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فأخ': [{'vocalized': u'فأخ', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخ', 'encletic': u'', 'type': u'اسم', 'original': u'أخ'}],

 u'فله': [{'vocalized': u'فله', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'له', 'encletic': u'', 'type': u'ضمير', 'original': u'له'}],

 u'وبأيتكم': [{'vocalized': u'وبأيتكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'وخلالكما': [{'vocalized': u'وخلالكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلال'}],

 u'أيتي': [{'vocalized': u'أيتي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'أيتي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'أفكشبهنا': [{'vocalized': u'أفكشبهنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'فلمنه': [{'vocalized': u'فلمنه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'فباللواتي': [{'vocalized': u'فباللواتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'ألستم': [{'vocalized': u'ألستم', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لستم', 'encletic': u'', 'type': u'فعل', 'original': u'لستم'}],

 u'فلمنك': [{'vocalized': u'فلمنك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'ولأخيكما': [{'vocalized': u'ولأخيكما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'فلإليهما': [{'vocalized': u'فلإليهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'فلمني': [{'vocalized': u'فلمني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'فلمني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'نعما': [{'vocalized': u'نعما', 'procletic': u'', 'tags': u'فعل;المدح والذم', 'stem': u'نعما', 'encletic': u'', 'type': u'فعل', 'original': u'نعما'}],

 u'أفسوي': [{'vocalized': u'أفسوي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أفسوي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'نخ': [{'vocalized': u'نخ', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'نخ', 'encletic': u'', 'type': u'اسم فعل', 'original': u'نخ'}],

 u'أوبعامة': [{'vocalized': u'أوبعامة', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أفسوى': [{'vocalized': u'أفسوى', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'وكحسب': [{'vocalized': u'وكحسب', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأثناء': [{'vocalized': u'وكأثناء', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'أقلما': [{'vocalized': u'أقلما', 'procletic': u'أ-', 'tags': u'فعل;فعل جامد;استفهام', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'وجنبنا': [{'vocalized': u'وجنبنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'بأكثرها': [{'vocalized': u'بأكثرها', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'كأثناءي': [{'vocalized': u'كأثناءي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'كأثناءي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفبسويكم': [{'vocalized': u'أفبسويكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أفبسويكن': [{'vocalized': u'أفبسويكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'كنفسها': [{'vocalized': u'كنفسها', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'فبذين': [{'vocalized': u'فبذين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'ولجنوبه': [{'vocalized': u'ولجنوبه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'كأثناءك': [{'vocalized': u'كأثناءك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلأبينا': [{'vocalized': u'فلأبينا', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'وعليهم': [{'vocalized': u'وعليهم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'وبذوينا': [{'vocalized': u'وبذوينا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبذويك': [{'vocalized': u'وبذويك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبذويه': [{'vocalized': u'وبذويه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبهاذين': [{'vocalized': u'وبهاذين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'وبذويي': [{'vocalized': u'وبذويي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'وبذويي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكحسبكن': [{'vocalized': u'فكحسبكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فوقتكم': [{'vocalized': u'فوقتكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'فوقتكن': [{'vocalized': u'فوقتكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'فكحسبكم': [{'vocalized': u'فكحسبكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'فأعلى': [{'vocalized': u'فأعلى', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'ألأجمعه': [{'vocalized': u'ألأجمعه', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكأجمع': [{'vocalized': u'أكأجمع', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'بغربه': [{'vocalized': u'بغربه', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'ألأجمعك': [{'vocalized': u'ألأجمعك', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولأناكما': [{'vocalized': u'أولأناكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'بغربي': [{'vocalized': u'بغربي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'بغربي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'وكخلفهم': [{'vocalized': u'وكخلفهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'أفشبهها': [{'vocalized': u'أفشبهها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'وبأسفلهما': [{'vocalized': u'وبأسفلهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'ألأجمعي': [{'vocalized': u'ألأجمعي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'فمابرحنا': [{'vocalized': u'فمابرحنا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحنا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحنا'}],

 u'وكأعليها': [{'vocalized': u'وكأعليها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولإليهما': [{'vocalized': u'ولإليهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'فلحسبكن': [{'vocalized': u'فلحسبكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فلحسبكم': [{'vocalized': u'فلحسبكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'غ': [{'vocalized': u'غ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'غ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'غ'}],

 u'لشمالهن': [{'vocalized': u'لشمالهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'جميعنا': [{'vocalized': u'جميعنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعنا', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'لشمالهم': [{'vocalized': u'لشمالهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'فلحرى': [{'vocalized': u'فلحرى', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'حرى', 'encletic': u'', 'type': u'فعل', 'original': u'حرى'}],

 u'أفشبههم': [{'vocalized': u'أفشبههم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'أفبشبهكم': [{'vocalized': u'أفبشبهكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'وكساعته': [{'vocalized': u'وكساعته', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلازال': [{'vocalized': u'فلازال', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازال', 'encletic': u'', 'type': u'فعل', 'original': u'لازال'}],

 u'وفاكم': [{'vocalized': u'وفاكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فا'}],

 u'وفاكن': [{'vocalized': u'وفاكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فا'}],

 u'أوكأجمعنا': [{'vocalized': u'أوكأجمعنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكسوينا': [{'vocalized': u'أكسوينا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'ولستما': [{'vocalized': u'ولستما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لستما', 'encletic': u'', 'type': u'فعل', 'original': u'لستما'}],

 u'كنفسهم': [{'vocalized': u'كنفسهم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'كنفسهن': [{'vocalized': u'كنفسهن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'فخلفهما': [{'vocalized': u'فخلفهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'فلنحونا': [{'vocalized': u'فلنحونا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحونا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'وخلفهما': [{'vocalized': u'وخلفهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'فكالذين': [{'vocalized': u'فكالذين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'هلم': [{'vocalized': u'هلم', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'هلم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هلم'}],

 u'لسويك': [{'vocalized': u'لسويك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فكذلك': [{'vocalized': u'فكذلك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'},
 {'vocalized': u'فكذلك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'كذلك', 'encletic': u'', 'type': u'اسم', 'original': u'كذلك'}],

 u'لسويه': [{'vocalized': u'لسويه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'لآض': [{'vocalized': u'لآض', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'آض', 'encletic': u'', 'type': u'فعل', 'original': u'آض'}],

 u'أفليمينهما': [{'vocalized': u'أفليمينهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'وذووي': [{'vocalized': u'وذووي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوو'},
 {'vocalized': u'وذووي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوو'}],

 u'وذووه': [{'vocalized': u'وذووه', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوو'}],

 u'أبنفسهما': [{'vocalized': u'أبنفسهما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'ولأنهما': [{'vocalized': u'ولأنهما', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'أفتلكما': [{'vocalized': u'أفتلكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'ألخلفهن': [{'vocalized': u'ألخلفهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'وبأيتهما': [{'vocalized': u'وبأيتهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'بأثناءهم': [{'vocalized': u'بأثناءهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبشطرها': [{'vocalized': u'وبشطرها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'بأثناءهن': [{'vocalized': u'بأثناءهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'بحمي': [{'vocalized': u'بحمي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'أثمة': [{'vocalized': u'أثمة', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ثمة', 'encletic': u'', 'type': u'اسم', 'original': u'ثمة'}],

 u'بذاتكما': [{'vocalized': u'بذاتكما', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'وبها': [{'vocalized': u'وبها', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بها', 'encletic': u'', 'type': u'ضمير', 'original': u'بها'}],

 u'فكأثناءكم': [{'vocalized': u'فكأثناءكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'بشطركما': [{'vocalized': u'بشطركما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'وبذاتهم': [{'vocalized': u'وبذاتهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'فكأثناءكن': [{'vocalized': u'فكأثناءكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبذاتهن': [{'vocalized': u'وبذاتهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'فبتينك': [{'vocalized': u'فبتينك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'أفعينهن': [{'vocalized': u'أفعينهن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'أفعينهم': [{'vocalized': u'أفعينهم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'ولشرق': [{'vocalized': u'ولشرق', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'ولزمانهما': [{'vocalized': u'ولزمانهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'فلأخيهما': [{'vocalized': u'فلأخيهما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'أفتلكم': [{'vocalized': u'أفتلكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أفمثلما': [{'vocalized': u'أفمثلما', 'procletic': u'أ-ف-', 'tags': u'اسم;جار ومجرور;عطف;استفهام', 'stem': u'مثلما', 'encletic': u'', 'type': u'اسم', 'original': u'مثلما'}],

 u'فذاتهما': [{'vocalized': u'فذاتهما', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'أذاك': [{'vocalized': u'أذاك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'وبهم': [{'vocalized': u'وبهم', 'procletic': u'و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'ألوراءهما': [{'vocalized': u'ألوراءهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'وبهن': [{'vocalized': u'وبهن', 'procletic': u'و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'وبهو': [{'vocalized': u'وبهو', 'procletic': u'و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'وبهي': [{'vocalized': u'وبهي', 'procletic': u'و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'فأيتي': [{'vocalized': u'فأيتي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'فأيتي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'وبذاتها': [{'vocalized': u'وبذاتها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'ولشرع': [{'vocalized': u'ولشرع', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'شرع', 'encletic': u'', 'type': u'فعل', 'original': u'شرع'}],

 u'أفعينها': [{'vocalized': u'أفعينها', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'وتجاهك': [{'vocalized': u'وتجاهك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تجاه'}],

 u'وكزمانكما': [{'vocalized': u'وكزمانكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'وتجاهه': [{'vocalized': u'وتجاهه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تجاه'}],

 u'أفبذلكما': [{'vocalized': u'أفبذلكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'وتجاهي': [{'vocalized': u'وتجاهي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تجاه'},
 {'vocalized': u'وتجاهي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تجاه'}],

 u'ففاك': [{'vocalized': u'ففاك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فا'}],

 u'وعليها': [{'vocalized': u'وعليها', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'وثم': [{'vocalized': u'وثم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'},
 {'vocalized': u'وثم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'}],

 u'كأكثري': [{'vocalized': u'كأكثري', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'كأكثري', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'كأجمع': [{'vocalized': u'كأجمع', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'ساعتي': [{'vocalized': u'ساعتي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'ساعتي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'كأكثرك': [{'vocalized': u'كأكثرك', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'ساعته': [{'vocalized': u'ساعته', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'كأكثره': [{'vocalized': u'كأكثره', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'ساعتك': [{'vocalized': u'ساعتك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبشطرهن': [{'vocalized': u'وبشطرهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'بينكما': [{'vocalized': u'بينكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بين'}],

 u'بأثناءها': [{'vocalized': u'بأثناءها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبشطرهم': [{'vocalized': u'وبشطرهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'ويمين': [{'vocalized': u'ويمين', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'أفكعامتهما': [{'vocalized': u'أفكعامتهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلعنكما': [{'vocalized': u'أفلعنكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'فوقتهم': [{'vocalized': u'فوقتهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'لنفسنا': [{'vocalized': u'لنفسنا', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'وكليهما': [{'vocalized': u'وكليهما', 'procletic': u'و-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'فللذين': [{'vocalized': u'فللذين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'},
 {'vocalized': u'فللذين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'وباللتين': [{'vocalized': u'وباللتين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'فتلقاءنا': [{'vocalized': u'فتلقاءنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أبعامتنا': [{'vocalized': u'أبعامتنا', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أكبعضك': [{'vocalized': u'أكبعضك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فكليل': [{'vocalized': u'فكليل', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'أكبعضه': [{'vocalized': u'أكبعضه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'أكبعضي': [{'vocalized': u'أكبعضي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أكبعضي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'بتلقاءكما': [{'vocalized': u'بتلقاءكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبأكثرهم': [{'vocalized': u'فبأكثرهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فبأكثرهن': [{'vocalized': u'فبأكثرهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكشهره': [{'vocalized': u'فكشهره', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'فأوشك': [{'vocalized': u'فأوشك', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أوشك', 'encletic': u'', 'type': u'فعل', 'original': u'أوشك'}],

 u'كذاك': [{'vocalized': u'كذاك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'فكشهرك': [{'vocalized': u'فكشهرك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'ولإنهن': [{'vocalized': u'ولإنهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'ولإنهم': [{'vocalized': u'ولإنهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'أتلكم': [{'vocalized': u'أتلكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'فهناك': [{'vocalized': u'فهناك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'وبأننا': [{'vocalized': u'وبأننا', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'بالذين': [{'vocalized': u'بالذين', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'وكأعليه': [{'vocalized': u'وكأعليه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولحميها': [{'vocalized': u'ولحميها', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'أكذواتي': [{'vocalized': u'أكذواتي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'أحسبكن': [{'vocalized': u'أحسبكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'كشرقنا': [{'vocalized': u'كشرقنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'أفكأجمعنا': [{'vocalized': u'أفكأجمعنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولعن': [{'vocalized': u'ولعن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'تحت': [{'vocalized': u'تحت', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'ولعل': [{'vocalized': u'ولعل', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'لعل', 'encletic': u'', 'type': u'حرف', 'original': u'لعل'}],

 u'وليلكم': [{'vocalized': u'وليلكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'ولإنها': [{'vocalized': u'ولإنها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'كذات': [{'vocalized': u'كذات', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'فأيكم': [{'vocalized': u'فأيكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'ولغدا': [{'vocalized': u'ولغدا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'غدا', 'encletic': u'', 'type': u'فعل', 'original': u'غدا'}],

 u'لليلكما': [{'vocalized': u'لليلكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'وخلفكم': [{'vocalized': u'وخلفكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'ولحميهن': [{'vocalized': u'ولحميهن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'ولأمامهما': [{'vocalized': u'ولأمامهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'ولحميهم': [{'vocalized': u'ولحميهم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'كأقلكم': [{'vocalized': u'كأقلكم', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'أفمهما': [{'vocalized': u'أفمهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم الشرط;عطف;استفهام', 'stem': u'مهما', 'encletic': u'', 'type': u'اسم', 'original': u'مهما'}],

 u'فليتهم': [{'vocalized': u'فليتهم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-هم', 'type': u'حرف', 'original': u'ليت'}],

 u'لذاته': [{'vocalized': u'لذاته', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'شرقكم': [{'vocalized': u'شرقكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'فليتهن': [{'vocalized': u'فليتهن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-هن', 'type': u'حرف', 'original': u'ليت'}],

 u'شرقكن': [{'vocalized': u'شرقكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'وباللتيا': [{'vocalized': u'وباللتيا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'ومعاذكم': [{'vocalized': u'ومعاذكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-كم', 'type': u'اسم', 'original': u'معاذ'}],

 u'ومعاذكن': [{'vocalized': u'ومعاذكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-كن', 'type': u'اسم', 'original': u'معاذ'}],

 u'لعنكما': [{'vocalized': u'لعنكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'لأمام': [{'vocalized': u'لأمام', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'فبأكثرها': [{'vocalized': u'فبأكثرها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكوقتهن': [{'vocalized': u'فكوقتهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'كتانك': [{'vocalized': u'كتانك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'فكوقتهم': [{'vocalized': u'فكوقتهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'فلأخينا': [{'vocalized': u'فلأخينا', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'فكجنوبه': [{'vocalized': u'فكجنوبه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'وغيرهما': [{'vocalized': u'وغيرهما', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'ألفوق': [{'vocalized': u'ألفوق', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'فكجنوبي': [{'vocalized': u'فكجنوبي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'فكجنوبي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوكلكن': [{'vocalized': u'أوكلكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلكن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أوكلكم': [{'vocalized': u'أوكلكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلكم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'كعيني': [{'vocalized': u'كعيني', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'كعيني', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'كعينه': [{'vocalized': u'كعينه', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'فلأمسى': [{'vocalized': u'فلأمسى', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أمسى', 'encletic': u'', 'type': u'فعل', 'original': u'أمسى'}],

 u'كعينك': [{'vocalized': u'كعينك', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'فأقلك': [{'vocalized': u'فأقلك', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'أفحسبك': [{'vocalized': u'أفحسبك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'حما': [{'vocalized': u'حما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'حما', 'encletic': u'', 'type': u'اسم', 'original': u'حما'}],

 u'فأقله': [{'vocalized': u'فأقله', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'أفحسبه': [{'vocalized': u'أفحسبه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'فلنحوكما': [{'vocalized': u'فلنحوكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'أفحسبي': [{'vocalized': u'أفحسبي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أفحسبي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'فأقلي': [{'vocalized': u'فأقلي', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'فأقلي', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'أفلنحوها': [{'vocalized': u'أفلنحوها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'بأقلك': [{'vocalized': u'بأقلك', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'بأقله': [{'vocalized': u'بأقله', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'بأقلي': [{'vocalized': u'بأقلي', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'بأقلي', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'وماانفككت': [{'vocalized': u'وماانفككت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'},
 {'vocalized': u'وماانفككت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'},
 {'vocalized': u'وماانفككت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'}],

 u'بعدك': [{'vocalized': u'بعدك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعد'}],

 u'فللتي': [{'vocalized': u'فللتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'بعده': [{'vocalized': u'بعده', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعد'}],

 u'أفلنحوهم': [{'vocalized': u'أفلنحوهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلنحوهن': [{'vocalized': u'أفلنحوهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'أكليكما': [{'vocalized': u'أكليكما', 'procletic': u'أ-', 'tags': u'حرف;توكيد;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'حمو': [{'vocalized': u'حمو', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'حمو', 'encletic': u'', 'type': u'اسم', 'original': u'حمو'}],

 u'حمي': [{'vocalized': u'حمي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'أفعامتكما': [{'vocalized': u'أفعامتكما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'وكأن': [{'vocalized': u'وكأن', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'وكأن', 'procletic': u'و-ك-', 'tags': u'حرف;حرف نصب;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'وماانفك': [{'vocalized': u'وماانفك', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفك', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفك'}],

 u'وكأي': [{'vocalized': u'وكأي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وكأي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وكأي', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'كأي', 'encletic': u'', 'type': u'اسم', 'original': u'كأي'}],

 u'أفعليهن': [{'vocalized': u'أفعليهن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'فكوقتها': [{'vocalized': u'فكوقتها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'أفمعنا': [{'vocalized': u'أفمعنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'وحوالى': [{'vocalized': u'وحوالى', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'حوالى', 'encletic': u'', 'type': u'اسم', 'original': u'حوالى'}],

 u'وحوالي': [{'vocalized': u'وحوالي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حوالى'},
 {'vocalized': u'وحوالي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حوالى'}],

 u'وأبوهما': [{'vocalized': u'وأبوهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبو'}],

 u'وبخلفي': [{'vocalized': u'وبخلفي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وبخلفي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'سبحانه': [{'vocalized': u'سبحانه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سبحان'}],

 u'وبخلف': [{'vocalized': u'وبخلف', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'سبحانك': [{'vocalized': u'سبحانك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سبحان'}],

 u'لأمامه': [{'vocalized': u'لأمامه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'فمثلما': [{'vocalized': u'فمثلما', 'procletic': u'ف-', 'tags': u'اسم;جار ومجرور;عطف', 'stem': u'مثلما', 'encletic': u'', 'type': u'اسم', 'original': u'مثلما'}],

 u'بعامتنا': [{'vocalized': u'بعامتنا', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'سبحاني': [{'vocalized': u'سبحاني', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سبحان'},
 {'vocalized': u'سبحاني', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سبحان'}],

 u'أعليه': [{'vocalized': u'أعليه', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'شرقي': [{'vocalized': u'شرقي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'شرقي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'أفليميني': [{'vocalized': u'أفليميني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'أفليميني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'أعليك': [{'vocalized': u'أعليك', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'لنفسي': [{'vocalized': u'لنفسي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'لنفسه': [{'vocalized': u'لنفسه', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'أليمينها': [{'vocalized': u'أليمينها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'فابنهما': [{'vocalized': u'فابنهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'لنفسك': [{'vocalized': u'لنفسك', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'لأمامك': [{'vocalized': u'لأمامك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'أكحسبهما': [{'vocalized': u'أكحسبهما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أوكغيركن': [{'vocalized': u'أوكغيركن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'لأجمعنا': [{'vocalized': u'لأجمعنا', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكعامتهم': [{'vocalized': u'فكعامتهم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'ككليكما': [{'vocalized': u'ككليكما', 'procletic': u'ك-', 'tags': u'حرف;توكيد;مجرور', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'ولأنك': [{'vocalized': u'ولأنك', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'فبعض': [{'vocalized': u'فبعض', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'أوكأنهما': [{'vocalized': u'أوكأنهما', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'فبليله': [{'vocalized': u'فبليله', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'أعنه': [{'vocalized': u'أعنه', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'فبليلك': [{'vocalized': u'فبليلك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'أبحسب': [{'vocalized': u'أبحسب', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'بغيرهما': [{'vocalized': u'بغيرهما', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'خلف': [{'vocalized': u'خلف', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلف', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'أعني': [{'vocalized': u'أعني', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'أعني', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'أولكن': [{'vocalized': u'أولكن', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لكن', 'encletic': u'', 'type': u'ضمير', 'original': u'لكن'}],

 u'أومننا': [{'vocalized': u'أومننا', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'وبوقت': [{'vocalized': u'وبوقت', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'تان': [{'vocalized': u'تان', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تان', 'encletic': u'', 'type': u'اسم', 'original': u'تان'}],

 u'ولتلقاءكم': [{'vocalized': u'ولتلقاءكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولتلقاءكن': [{'vocalized': u'ولتلقاءكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكأقل': [{'vocalized': u'وكأقل', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'وكغروبه': [{'vocalized': u'وكغروبه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'عامتكما': [{'vocalized': u'عامتكما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'وبوقتهم': [{'vocalized': u'وبوقتهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'أولكم': [{'vocalized': u'أولكم', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لكم', 'encletic': u'', 'type': u'ضمير', 'original': u'لكم'}],

 u'وبدونهما': [{'vocalized': u'وبدونهما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بدون'}],

 u'تلقاء': [{'vocalized': u'تلقاء', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'خلا': [{'vocalized': u'خلا', 'procletic': u'', 'tags': u'فعل;حرف استثناء', 'stem': u'خلا', 'encletic': u'', 'type': u'فعل', 'original': u'خلا'}],

 u'أوكأولاء': [{'vocalized': u'أوكأولاء', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'وغداة': [{'vocalized': u'وغداة', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'غداة', 'encletic': u'', 'type': u'اسم', 'original': u'غداة'}],

 u'وكغروبك': [{'vocalized': u'وكغروبك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'وكأعليكم': [{'vocalized': u'وكأعليكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'وكأعليكن': [{'vocalized': u'وكأعليكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فكجميع': [{'vocalized': u'فكجميع', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميع', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'فكتلقاءهما': [{'vocalized': u'فكتلقاءهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفشمالنا': [{'vocalized': u'أفشمالنا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'فنفسهم': [{'vocalized': u'فنفسهم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلنفسكن': [{'vocalized': u'أفلنفسكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلنفسكم': [{'vocalized': u'أفلنفسكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'باللتيا': [{'vocalized': u'باللتيا', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'أوأولئكم': [{'vocalized': u'أوأولئكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'ولعامتكم': [{'vocalized': u'ولعامتكم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'ولعامتكن': [{'vocalized': u'ولعامتكن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'فحولكما': [{'vocalized': u'فحولكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حول'}],

 u'وعندي': [{'vocalized': u'وعندي', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عند'},
 {'vocalized': u'وعندي', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عند'}],

 u'أكبعضها': [{'vocalized': u'أكبعضها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'فكجنبها': [{'vocalized': u'فكجنبها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'أكأجمعكم': [{'vocalized': u'أكأجمعكم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكأجمعكن': [{'vocalized': u'أكأجمعكن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'فبدونكما': [{'vocalized': u'فبدونكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بدون'}],

 u'فحينكما': [{'vocalized': u'فحينكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حين'}],

 u'فمنها': [{'vocalized': u'فمنها', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'وبأكثر': [{'vocalized': u'وبأكثر', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'أوكأننا': [{'vocalized': u'أوكأننا', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'أفبتلكما': [{'vocalized': u'أفبتلكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'وابنها': [{'vocalized': u'وابنها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'وعدا': [{'vocalized': u'وعدا', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف', 'stem': u'عدا', 'encletic': u'', 'type': u'فعل', 'original': u'عدا'}],

 u'فبعامتهما': [{'vocalized': u'فبعامتهما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'وحموكم': [{'vocalized': u'وحموكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمو'}],

 u'فبمثلكن': [{'vocalized': u'فبمثلكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'فبمثلكم': [{'vocalized': u'فبمثلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'وحموكن': [{'vocalized': u'وحموكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمو'}],

 u'وخلاكن': [{'vocalized': u'وخلاكن', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'خلا'}],

 u'وخلاكم': [{'vocalized': u'وخلاكم', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'خلا'}],

 u'أفلتحتهما': [{'vocalized': u'أفلتحتهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'أولبعضهما': [{'vocalized': u'أولبعضهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'أولأناها': [{'vocalized': u'أولأناها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'وابنهن': [{'vocalized': u'وابنهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'وابنهم': [{'vocalized': u'وابنهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'خلالهم': [{'vocalized': u'خلالهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلال'}],

 u'خلالهن': [{'vocalized': u'خلالهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلال'}],

 u'أجمعها': [{'vocalized': u'أجمعها', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'سويهما': [{'vocalized': u'سويهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'أهما': [{'vocalized': u'أهما', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'وحموهما': [{'vocalized': u'وحموهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمو'}],

 u'بوقتك': [{'vocalized': u'بوقتك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'بوقته': [{'vocalized': u'بوقته', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'بوقتي': [{'vocalized': u'بوقتي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'بوقتي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'أولأناهن': [{'vocalized': u'أولأناهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'لمعكما': [{'vocalized': u'لمعكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'فلفيه': [{'vocalized': u'فلفيه', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'وبمثلي': [{'vocalized': u'وبمثلي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'وبمثلي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'فكجنبهم': [{'vocalized': u'فكجنبهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'فكجنبهن': [{'vocalized': u'فكجنبهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'وبمثله': [{'vocalized': u'وبمثله', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'ومافتئنا': [{'vocalized': u'ومافتئنا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئنا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئنا'}],

 u'وبمثلك': [{'vocalized': u'وبمثلك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أتحتنا': [{'vocalized': u'أتحتنا', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'كابنهما': [{'vocalized': u'كابنهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'فمنهم': [{'vocalized': u'فمنهم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فمنهن': [{'vocalized': u'فمنهن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'لسويكما': [{'vocalized': u'لسويكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'أفككليهما': [{'vocalized': u'أفككليهما', 'procletic': u'أ-ف-ك-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'وأعليكم': [{'vocalized': u'وأعليكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'وأعليكن': [{'vocalized': u'وأعليكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'أسويكما': [{'vocalized': u'أسويكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'لأنا': [{'vocalized': u'لأنا', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'لأنا', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'وبأقل': [{'vocalized': u'وبأقل', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'أولكلكم': [{'vocalized': u'أولكلكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أولكلكن': [{'vocalized': u'أولكلكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'ألغيره': [{'vocalized': u'ألغيره', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيره', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'ولفيكن': [{'vocalized': u'ولفيكن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'فلخلفي': [{'vocalized': u'فلخلفي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'ألغيرك': [{'vocalized': u'ألغيرك', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيرك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'وكشطركما': [{'vocalized': u'وكشطركما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'ككل': [{'vocalized': u'ككل', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككل', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'أفكغيركما': [{'vocalized': u'أفكغيركما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'أقلهن': [{'vocalized': u'أقلهن', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'حماهما': [{'vocalized': u'حماهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حما'}],

 u'ألغيري': [{'vocalized': u'ألغيري', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيري', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيري', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيري', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'فهي': [{'vocalized': u'فهي', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'لإليكن': [{'vocalized': u'لإليكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'أكهناك': [{'vocalized': u'أكهناك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أولسوينا': [{'vocalized': u'أولسوينا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'ولابنهما': [{'vocalized': u'ولابنهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'ولأناهما': [{'vocalized': u'ولأناهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'فبجنبها': [{'vocalized': u'فبجنبها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'فبجنب': [{'vocalized': u'فبجنب', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'لإنك': [{'vocalized': u'لإنك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'ألعينهما': [{'vocalized': u'ألعينهما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فلأناهن': [{'vocalized': u'فلأناهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'لإنه': [{'vocalized': u'لإنه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'أفلشمالنا': [{'vocalized': u'أفلشمالنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'لإني': [{'vocalized': u'لإني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'لإني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'فسرعان': [{'vocalized': u'فسرعان', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'سرعان', 'encletic': u'', 'type': u'اسم فعل', 'original': u'سرعان'}],

 u'وشطركما': [{'vocalized': u'وشطركما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'فلحميهما': [{'vocalized': u'فلحميهما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'أوبشبهك': [{'vocalized': u'أوبشبهك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'فهل': [{'vocalized': u'فهل', 'procletic': u'ف-', 'tags': u'حرف;حرف استفهام;عطف', 'stem': u'هل', 'encletic': u'', 'type': u'حرف', 'original': u'هل'}],

 u'أوبشبهه': [{'vocalized': u'أوبشبهه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'معاذهما': [{'vocalized': u'معاذهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-هما', 'type': u'اسم', 'original': u'معاذ'}],

 u'فخلا': [{'vocalized': u'فخلا', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف', 'stem': u'خلا', 'encletic': u'', 'type': u'فعل', 'original': u'خلا'}],

 u'أوبشبهي': [{'vocalized': u'أوبشبهي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أوبشبهي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلفوقكن': [{'vocalized': u'أفلفوقكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'بدوننا': [{'vocalized': u'بدوننا', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بدون'}],

 u'فبينكن': [{'vocalized': u'فبينكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بين'}],

 u'فلأناها': [{'vocalized': u'فلأناها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'أفكذينك': [{'vocalized': u'أفكذينك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'لإنا': [{'vocalized': u'لإنا', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'عندنا': [{'vocalized': u'عندنا', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عند'}],

 u'فلحظته': [{'vocalized': u'فلحظته', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'أوهنا': [{'vocalized': u'أوهنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هنا', 'encletic': u'', 'type': u'اسم', 'original': u'هنا'}],

 u'لأنانا': [{'vocalized': u'لأنانا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'لأبي': [{'vocalized': u'لأبي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'أفلأمام': [{'vocalized': u'أفلأمام', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'وكلهما': [{'vocalized': u'وكلهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلهما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'غدا': [{'vocalized': u'غدا', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'غدا', 'encletic': u'', 'type': u'اسم', 'original': u'غدا'},
 {'vocalized': u'غدا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'غدا', 'encletic': u'', 'type': u'فعل', 'original': u'غدا'}],

 u'غروبها': [{'vocalized': u'غروبها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'فكمثل': [{'vocalized': u'فكمثل', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'أفبجميعهما': [{'vocalized': u'أفبجميعهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'كذواتي': [{'vocalized': u'كذواتي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'ولهذين': [{'vocalized': u'ولهذين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'فلساعتهما': [{'vocalized': u'فلساعتهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أقلها': [{'vocalized': u'أقلها', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'أفكنفسنا': [{'vocalized': u'أفكنفسنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'كشبهي': [{'vocalized': u'كشبهي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'كشبهي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'فبذلك': [{'vocalized': u'فبذلك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'ألعليهن': [{'vocalized': u'ألعليهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'فيكما': [{'vocalized': u'فيكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيكما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'ألعليهم': [{'vocalized': u'ألعليهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'كشبهك': [{'vocalized': u'كشبهك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'كذلك': [{'vocalized': u'كذلك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'},
 {'vocalized': u'كذلك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'كذلك', 'encletic': u'', 'type': u'اسم', 'original': u'كذلك'}],

 u'كشبهه': [{'vocalized': u'كشبهه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'أوفيي': [{'vocalized': u'أوفيي', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'أوفيي', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'فكتلقاء': [{'vocalized': u'فكتلقاء', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وله': [{'vocalized': u'وله', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'له', 'encletic': u'', 'type': u'ضمير', 'original': u'له'}],

 u'ولن': [{'vocalized': u'ولن', 'procletic': u'و-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لن', 'encletic': u'', 'type': u'حرف', 'original': u'لن'}],

 u'ألكأنها': [{'vocalized': u'ألكأنها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'ولك': [{'vocalized': u'ولك', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لك', 'encletic': u'', 'type': u'ضمير', 'original': u'لك'}],

 u'ولمنك': [{'vocalized': u'ولمنك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'للحظتكم': [{'vocalized': u'للحظتكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'أوفوقه': [{'vocalized': u'أوفوقه', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'للحظتكن': [{'vocalized': u'للحظتكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'ولي': [{'vocalized': u'ولي', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لي', 'encletic': u'', 'type': u'ضمير', 'original': u'لي'}],

 u'ولو': [{'vocalized': u'ولو', 'procletic': u'و-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لو', 'encletic': u'', 'type': u'حرف', 'original': u'لو'}],

 u'وبخلفهم': [{'vocalized': u'وبخلفهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'بأكثر': [{'vocalized': u'بأكثر', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'ونعم': [{'vocalized': u'ونعم', 'procletic': u'و-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'نعم', 'encletic': u'', 'type': u'حرف', 'original': u'نعم'},
 {'vocalized': u'ونعم', 'procletic': u'و-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'نعم', 'encletic': u'', 'type': u'فعل', 'original': u'نعم'}],

 u'ولمنه': [{'vocalized': u'ولمنه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'أولأنتم': [{'vocalized': u'أولأنتم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'ولأيهما': [{'vocalized': u'ولأيهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'أولأنتن': [{'vocalized': u'أولأنتن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'كشرقكما': [{'vocalized': u'كشرقكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'أولديكم': [{'vocalized': u'أولديكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدى'}],

 u'لدنها': [{'vocalized': u'لدنها', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدن'}],

 u'وبمن': [{'vocalized': u'وبمن', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بمن', 'encletic': u'', 'type': u'اسم', 'original': u'بمن'},
 {'vocalized': u'وبمن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'وماذا': [{'vocalized': u'وماذا', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'ماذا', 'encletic': u'', 'type': u'اسم', 'original': u'ماذا'}],

 u'فلكلتا': [{'vocalized': u'فلكلتا', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'},
 {'vocalized': u'فلكلتا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'ولحميكما': [{'vocalized': u'ولحميكما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'فبأثناءهما': [{'vocalized': u'فبأثناءهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكتلقاءنا': [{'vocalized': u'وكتلقاءنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أككليهما': [{'vocalized': u'أككليهما', 'procletic': u'أ-ك-', 'tags': u'حرف;توكيد;مجرور;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'هذان': [{'vocalized': u'هذان', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هذان', 'encletic': u'', 'type': u'اسم', 'original': u'هذان'}],

 u'وبما': [{'vocalized': u'وبما', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بما', 'encletic': u'', 'type': u'اسم', 'original': u'بما'}],

 u'لدنهن': [{'vocalized': u'لدنهن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدن'}],

 u'لدنهم': [{'vocalized': u'لدنهم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدن'}],

 u'فلانبرى': [{'vocalized': u'فلانبرى', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'انبرى', 'encletic': u'', 'type': u'فعل', 'original': u'انبرى'}],

 u'باللائي': [{'vocalized': u'باللائي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'وكجميعنا': [{'vocalized': u'وكجميعنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعنا', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وبأيتكن': [{'vocalized': u'وبأيتكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'ألكأنهم': [{'vocalized': u'ألكأنهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'وكغربه': [{'vocalized': u'وكغربه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'ألكأنهن': [{'vocalized': u'ألكأنهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'فينا': [{'vocalized': u'فينا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فينا', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'واللتان': [{'vocalized': u'واللتان', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللتان', 'encletic': u'', 'type': u'اسم', 'original': u'اللتان'}],

 u'لعليكما': [{'vocalized': u'لعليكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'أولازلتن': [{'vocalized': u'أولازلتن', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتن'}],

 u'أفلفوقكما': [{'vocalized': u'أفلفوقكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'ولجميعكما': [{'vocalized': u'ولجميعكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'لغيركما': [{'vocalized': u'لغيركما', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيركما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فلشمالهما': [{'vocalized': u'فلشمالهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'أبذواتي': [{'vocalized': u'أبذواتي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'وشرقك': [{'vocalized': u'وشرقك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'أفكنحوكم': [{'vocalized': u'أفكنحوكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'ولديكم': [{'vocalized': u'ولديكم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدى'}],

 u'ولديكن': [{'vocalized': u'ولديكن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدى'}],

 u'أفكنحوكن': [{'vocalized': u'أفكنحوكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'وشرقي': [{'vocalized': u'وشرقي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'وشرقي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'فأجمعهم': [{'vocalized': u'فأجمعهم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فأجمعهن': [{'vocalized': u'فأجمعهن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلأكثرها': [{'vocalized': u'فلأكثرها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'أكنفسهن': [{'vocalized': u'أكنفسهن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أكنفسهم': [{'vocalized': u'أكنفسهم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'أولنفسكم': [{'vocalized': u'أولنفسكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'خلفكما': [{'vocalized': u'خلفكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'لذويكما': [{'vocalized': u'لذويكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أكثرهن': [{'vocalized': u'أكثرهن', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'واللذان': [{'vocalized': u'واللذان', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللذان', 'encletic': u'', 'type': u'اسم', 'original': u'اللذان'}],

 u'أفكشبه': [{'vocalized': u'أفكشبه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'فذان': [{'vocalized': u'فذان', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذان', 'encletic': u'', 'type': u'اسم', 'original': u'ذان'}],

 u'معاذكم': [{'vocalized': u'معاذكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-كم', 'type': u'اسم', 'original': u'معاذ'}],

 u'معاذكن': [{'vocalized': u'معاذكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-كن', 'type': u'اسم', 'original': u'معاذ'}],

 u'وعامتي': [{'vocalized': u'وعامتي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'وعامتي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فذاك': [{'vocalized': u'فذاك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'فكأنها': [{'vocalized': u'فكأنها', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنها', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'ووقته': [{'vocalized': u'ووقته', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'فكلحظتها': [{'vocalized': u'فكلحظتها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلذاتنا': [{'vocalized': u'فلذاتنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'ولبعضكن': [{'vocalized': u'ولبعضكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'ولبعضكم': [{'vocalized': u'ولبعضكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'فأمامنا': [{'vocalized': u'فأمامنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'فذات': [{'vocalized': u'فذات', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'بضعهما': [{'vocalized': u'بضعهما', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بضع'}],

 u'أفمثلكن': [{'vocalized': u'أفمثلكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'أببعضهما': [{'vocalized': u'أببعضهما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'كغربكم': [{'vocalized': u'كغربكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'أفمثلكم': [{'vocalized': u'أفمثلكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فكأنهم': [{'vocalized': u'فكأنهم', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنهم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'فكأنهن': [{'vocalized': u'فكأنهن', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنهن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'فبتلقاءي': [{'vocalized': u'فبتلقاءي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'فبتلقاءي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أويميننا': [{'vocalized': u'أويميننا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'وأعليهم': [{'vocalized': u'وأعليهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبتلقاءك': [{'vocalized': u'فبتلقاءك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبمثلنا': [{'vocalized': u'وبمثلنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'فبتلقاءه': [{'vocalized': u'فبتلقاءه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفلديكما': [{'vocalized': u'أفلديكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدى'}],

 u'فلدني': [{'vocalized': u'فلدني', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدن'},
 {'vocalized': u'فلدني', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدن'}],

 u'فلأكثرهم': [{'vocalized': u'فلأكثرهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلأكثرهن': [{'vocalized': u'فلأكثرهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فأجمعها': [{'vocalized': u'فأجمعها', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكنفسها': [{'vocalized': u'أكنفسها', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'فلدنك': [{'vocalized': u'فلدنك', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدن'}],

 u'وأعليهن': [{'vocalized': u'وأعليهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فلستما': [{'vocalized': u'فلستما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لستما', 'encletic': u'', 'type': u'فعل', 'original': u'لستما'}],

 u'فبعضكما': [{'vocalized': u'فبعضكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'ألكل': [{'vocalized': u'ألكل', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكل', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكل', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكل', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'ألكم': [{'vocalized': u'ألكم', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'لكم', 'encletic': u'', 'type': u'ضمير', 'original': u'لكم'}],

 u'وكهاتين': [{'vocalized': u'وكهاتين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'أفلبعضنا': [{'vocalized': u'أفلبعضنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'تحتها': [{'vocalized': u'تحتها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'ولولا': [{'vocalized': u'ولولا', 'procletic': u'و-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لولا', 'encletic': u'', 'type': u'حرف', 'original': u'لولا'}],

 u'بزمان': [{'vocalized': u'بزمان', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'أفبنفسكم': [{'vocalized': u'أفبنفسكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'وسبحاننا': [{'vocalized': u'وسبحاننا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سبحان'}],

 u'وبزمانه': [{'vocalized': u'وبزمانه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'ضمنه': [{'vocalized': u'ضمنه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ضمن'}],

 u'وأبيكما': [{'vocalized': u'وأبيكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'ضمنك': [{'vocalized': u'ضمنك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ضمن'}],

 u'بجميع': [{'vocalized': u'بجميع', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميع', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'فكأثناءهما': [{'vocalized': u'فكأثناءهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'كتين': [{'vocalized': u'كتين', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'أفذواتا': [{'vocalized': u'أفذواتا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذواتا', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتا'}],

 u'فيمينهن': [{'vocalized': u'فيمينهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'صباح': [{'vocalized': u'صباح', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'صباح', 'encletic': u'', 'type': u'اسم', 'original': u'صباح'}],

 u'فظل': [{'vocalized': u'فظل', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ظل', 'encletic': u'', 'type': u'فعل', 'original': u'ظل'}],

 u'أوكعامتهما': [{'vocalized': u'أوكعامتهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'كأجمعهما': [{'vocalized': u'كأجمعهما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفذواتي': [{'vocalized': u'أفذواتي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'وكمثلكن': [{'vocalized': u'وكمثلكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'وكمثلكم': [{'vocalized': u'وكمثلكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فهاذين': [{'vocalized': u'فهاذين', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أونحن': [{'vocalized': u'أونحن', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'وذويكما': [{'vocalized': u'وذويكما', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'كليل': [{'vocalized': u'كليل', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'ووراءهن': [{'vocalized': u'ووراءهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'أونحو': [{'vocalized': u'أونحو', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فلساعتكم': [{'vocalized': u'فلساعتكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلساعتكن': [{'vocalized': u'فلساعتكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'لتلقاءي': [{'vocalized': u'لتلقاءي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'لتلقاءي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أوكلي': [{'vocalized': u'أوكلي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'أعلي': [{'vocalized': u'أعلي', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعلي', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعلي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'أعلي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'لتلقاءك': [{'vocalized': u'لتلقاءك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبليلكم': [{'vocalized': u'فبليلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'فمادامتا': [{'vocalized': u'فمادامتا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادامتا', 'encletic': u'', 'type': u'فعل', 'original': u'مادامتا'}],

 u'لتلقاءه': [{'vocalized': u'لتلقاءه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أومثلنا': [{'vocalized': u'أومثلنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'أفمعي': [{'vocalized': u'أفمعي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'أفمعي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'ووراءهم': [{'vocalized': u'ووراءهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'أولبعضكم': [{'vocalized': u'أولبعضكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أولبعضكن': [{'vocalized': u'أولبعضكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفمعك': [{'vocalized': u'أفمعك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'أبعضهن': [{'vocalized': u'أبعضهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أبعضهم': [{'vocalized': u'أبعضهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'فأخيهما': [{'vocalized': u'فأخيهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'أفإليهما': [{'vocalized': u'أفإليهما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'كسوى': [{'vocalized': u'كسوى', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'وككلكم': [{'vocalized': u'وككلكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلكم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'وأبوهن': [{'vocalized': u'وأبوهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبو'}],

 u'وككلكن': [{'vocalized': u'وككلكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلكن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أوشبهه': [{'vocalized': u'أوشبهه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'أفوراءكن': [{'vocalized': u'أفوراءكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'وهما': [{'vocalized': u'وهما', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'أوشبهك': [{'vocalized': u'أوشبهك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أوليست': [{'vocalized': u'أوليست', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليست', 'encletic': u'', 'type': u'فعل', 'original': u'ليست'}],

 u'ألفيي': [{'vocalized': u'ألفيي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'ألفيي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'ألفيه': [{'vocalized': u'ألفيه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'أوليسا': [{'vocalized': u'أوليسا', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليسا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسا'}],

 u'أوشبهي': [{'vocalized': u'أوشبهي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أوشبهي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'أأناي': [{'vocalized': u'أأناي', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'أأناي', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'ألفيك': [{'vocalized': u'ألفيك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'وبوقتهما': [{'vocalized': u'وبوقتهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'عليها': [{'vocalized': u'عليها', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'أفلوراءكن': [{'vocalized': u'أفلوراءكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'وتجاهها': [{'vocalized': u'وتجاهها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تجاه'}],

 u'أفلإنكما': [{'vocalized': u'أفلإنكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'بخلفهما': [{'vocalized': u'بخلفهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'بوقتكن': [{'vocalized': u'بوقتكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'وليتها': [{'vocalized': u'وليتها', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ها', 'type': u'حرف', 'original': u'ليت'}],

 u'أفلأنتن': [{'vocalized': u'أفلأنتن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'أفلأنتم': [{'vocalized': u'أفلأنتم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'يومئذ': [{'vocalized': u'يومئذ', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'يومئذ', 'encletic': u'', 'type': u'اسم', 'original': u'يومئذ'}],

 u'بضعكن': [{'vocalized': u'بضعكن', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بضع'}],

 u'وبهنالك': [{'vocalized': u'وبهنالك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فلمن': [{'vocalized': u'فلمن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'فلمن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'ألازالت': [{'vocalized': u'ألازالت', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'}],

 u'بخلفي': [{'vocalized': u'بخلفي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'بخلفي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'وتحتهما': [{'vocalized': u'وتحتهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'ولهؤلاء': [{'vocalized': u'ولهؤلاء', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'وليتهن': [{'vocalized': u'وليتهن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-هن', 'type': u'حرف', 'original': u'ليت'}],

 u'وليتهم': [{'vocalized': u'وليتهم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-هم', 'type': u'حرف', 'original': u'ليت'}],

 u'ألشمالهم': [{'vocalized': u'ألشمالهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'لشهرنا': [{'vocalized': u'لشهرنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'فلوقت': [{'vocalized': u'فلوقت', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'أفلخلفهما': [{'vocalized': u'أفلخلفهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'فلأسفلكما': [{'vocalized': u'فلأسفلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'فتجاهكن': [{'vocalized': u'فتجاهكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تجاه'}],

 u'فتجاهكم': [{'vocalized': u'فتجاهكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تجاه'}],

 u'فبجنبي': [{'vocalized': u'فبجنبي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'فبجنبي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'فساعتكما': [{'vocalized': u'فساعتكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفلعليه': [{'vocalized': u'أفلعليه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'لحمينا': [{'vocalized': u'لحمينا', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'ألجميع': [{'vocalized': u'ألجميع', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميع', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميع', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميع', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'أوكذين': [{'vocalized': u'أوكذين', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'أوبمثلنا': [{'vocalized': u'أوبمثلنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'بشرقك': [{'vocalized': u'بشرقك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'عليهن': [{'vocalized': u'عليهن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'عليهم': [{'vocalized': u'عليهم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'وتجاههن': [{'vocalized': u'وتجاههن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تجاه'}],

 u'وتجاههم': [{'vocalized': u'وتجاههم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تجاه'}],

 u'ولاخلولق': [{'vocalized': u'ولاخلولق', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'اخلولق', 'encletic': u'', 'type': u'فعل', 'original': u'اخلولق'}],

 u'وأينما': [{'vocalized': u'وأينما', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أينما', 'encletic': u'', 'type': u'اسم', 'original': u'أينما'}],

 u'أولعامتهما': [{'vocalized': u'أولعامتهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'لأنهما': [{'vocalized': u'لأنهما', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'أوعينهما': [{'vocalized': u'أوعينهما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فبأيهن': [{'vocalized': u'فبأيهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'فبأيهم': [{'vocalized': u'فبأيهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'لحسبكما': [{'vocalized': u'لحسبكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'أعلى': [{'vocalized': u'أعلى', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعلى', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولغيره': [{'vocalized': u'ولغيره', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيره', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'فلفوقهم': [{'vocalized': u'فلفوقهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'ولغيرك': [{'vocalized': u'ولغيرك', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيرك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'ولغيرها': [{'vocalized': u'ولغيرها', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيرها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'ولغيري': [{'vocalized': u'ولغيري', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيري', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيري', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيري', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'لشهركن': [{'vocalized': u'لشهركن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'لشهركم': [{'vocalized': u'لشهركم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'تلقاءهما': [{'vocalized': u'تلقاءهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفغيرهن': [{'vocalized': u'أفغيرهن', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أفغيرهم': [{'vocalized': u'أفغيرهم', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'فلسن': [{'vocalized': u'فلسن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لسن', 'encletic': u'', 'type': u'فعل', 'original': u'لسن'}],

 u'أولكله': [{'vocalized': u'أولكله', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكله', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكله', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكله', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'ولحسبهن': [{'vocalized': u'ولحسبهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'ولحسبهم': [{'vocalized': u'ولحسبهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أكشبههن': [{'vocalized': u'أكشبههن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أكشبههم': [{'vocalized': u'أكشبههم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'أخاكن': [{'vocalized': u'أخاكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخا'}],

 u'أولكلي': [{'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'أخاكم': [{'vocalized': u'أخاكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخا'}],

 u'وأبوها': [{'vocalized': u'وأبوها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبو'}],

 u'وأولئكم': [{'vocalized': u'وأولئكم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'بليلهما': [{'vocalized': u'بليلهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'أفغيرها': [{'vocalized': u'أفغيرها', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'فمازلنا': [{'vocalized': u'فمازلنا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'مازلنا'}],

 u'بمثل': [{'vocalized': u'بمثل', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'ولحسبها': [{'vocalized': u'ولحسبها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'أكشبهها': [{'vocalized': u'أكشبهها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'فبتانك': [{'vocalized': u'فبتانك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'فلست': [{'vocalized': u'فلست', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'فلست', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'فلست', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'}],

 u'ولأقلنا': [{'vocalized': u'ولأقلنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'أوكأني': [{'vocalized': u'أوكأني', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'أوكأني', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'أفلتينك': [{'vocalized': u'أفلتينك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'فبأيها': [{'vocalized': u'فبأيها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'أوكأنه': [{'vocalized': u'أوكأنه', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'ألهما': [{'vocalized': u'ألهما', 'procletic': u'أ-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'},
 {'vocalized': u'ألهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'وأناكما': [{'vocalized': u'وأناكما', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'فلفوقها': [{'vocalized': u'فلفوقها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'لعمركم': [{'vocalized': u'لعمركم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لعمر'}],

 u'لعمركن': [{'vocalized': u'لعمركن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لعمر'}],

 u'وشمال': [{'vocalized': u'وشمال', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'أككلهما': [{'vocalized': u'أككلهما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلهما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'ولغيرهم': [{'vocalized': u'ولغيرهم', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيرهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أفمنكما': [{'vocalized': u'أفمنكما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'فاللذان': [{'vocalized': u'فاللذان', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللذان', 'encletic': u'', 'type': u'اسم', 'original': u'اللذان'}],

 u'فمعاذهم': [{'vocalized': u'فمعاذهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-هم', 'type': u'اسم', 'original': u'معاذ'}],

 u'فمعاذهن': [{'vocalized': u'فمعاذهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-هن', 'type': u'اسم', 'original': u'معاذ'}],

 u'فلشطرنا': [{'vocalized': u'فلشطرنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'فكغربكم': [{'vocalized': u'فكغربكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'وبأولئك': [{'vocalized': u'وبأولئك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'ألأجمعهما': [{'vocalized': u'ألأجمعهما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'عما': [{'vocalized': u'عما', 'procletic': u'', 'tags': u'حرف;حرف جر مكفوف', 'stem': u'عما', 'encletic': u'', 'type': u'حرف', 'original': u'عما'}],

 u'فليمينهم': [{'vocalized': u'فليمينهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'فبجميع': [{'vocalized': u'فبجميع', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميع', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'أخي': [{'vocalized': u'أخي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'ولإنا': [{'vocalized': u'ولإنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'أخو': [{'vocalized': u'أخو', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أخو', 'encletic': u'', 'type': u'اسم', 'original': u'أخو'}],

 u'فلجنوبهما': [{'vocalized': u'فلجنوبهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبهم': [{'vocalized': u'فبهم', 'procletic': u'ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'وكساعتك': [{'vocalized': u'وكساعتك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'أولمثلها': [{'vocalized': u'أولمثلها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'ولجنوبها': [{'vocalized': u'ولجنوبها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'لابننا': [{'vocalized': u'لابننا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'وكهذا': [{'vocalized': u'وكهذا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'ففيكم': [{'vocalized': u'ففيكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيكم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'ففيكن': [{'vocalized': u'ففيكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيكن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'ض': [{'vocalized': u'ض', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ض', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ض'}],

 u'فبكن': [{'vocalized': u'فبكن', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بكن', 'encletic': u'', 'type': u'ضمير', 'original': u'بكن'}],

 u'أوبضع': [{'vocalized': u'أوبضع', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام', 'stem': u'بضع', 'encletic': u'', 'type': u'اسم', 'original': u'بضع'}],

 u'وكغروبهن': [{'vocalized': u'وكغروبهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'لساعتهما': [{'vocalized': u'لساعتهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكأعليه': [{'vocalized': u'فكأعليه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'أولمثلهم': [{'vocalized': u'أولمثلهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أولمثلهن': [{'vocalized': u'أولمثلهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'ولنحونا': [{'vocalized': u'ولنحونا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحونا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'كأبي': [{'vocalized': u'كأبي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'أفأنتن': [{'vocalized': u'أفأنتن', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'أفأنتم': [{'vocalized': u'أفأنتم', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'ولنفسهم': [{'vocalized': u'ولنفسهم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'وبعدما': [{'vocalized': u'وبعدما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بعدما', 'encletic': u'', 'type': u'اسم', 'original': u'بعدما'}],

 u'أفسويه': [{'vocalized': u'أفسويه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'وكهذه': [{'vocalized': u'وكهذه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'هاك': [{'vocalized': u'هاك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'هاك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هاك'}],

 u'مازلنا': [{'vocalized': u'مازلنا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'مازلنا'}],

 u'وكهذي': [{'vocalized': u'وكهذي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'وكغروبها': [{'vocalized': u'وكغروبها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'فلفوق': [{'vocalized': u'فلفوق', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'فكنحوكما': [{'vocalized': u'فكنحوكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'أضحى': [{'vocalized': u'أضحى', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'أضحى', 'encletic': u'', 'type': u'فعل', 'original': u'أضحى'}],

 u'مازالوا': [{'vocalized': u'مازالوا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالوا'}],

 u'فمعاذها': [{'vocalized': u'فمعاذها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ها', 'type': u'اسم', 'original': u'معاذ'}],

 u'أوكعامتكم': [{'vocalized': u'أوكعامتكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أولعليهم': [{'vocalized': u'أولعليهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'أخذ': [{'vocalized': u'أخذ', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'أخذ', 'encletic': u'', 'type': u'فعل', 'original': u'أخذ'}],

 u'أوكعامتكن': [{'vocalized': u'أوكعامتكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'فإنكما': [{'vocalized': u'فإنكما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'وحماكما': [{'vocalized': u'وحماكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حما'}],

 u'أفبمثلكم': [{'vocalized': u'أفبمثلكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفبمثلكن': [{'vocalized': u'أفبمثلكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'ولإني': [{'vocalized': u'ولإني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'ولإني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'أخا': [{'vocalized': u'أخا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أخا', 'encletic': u'', 'type': u'اسم', 'original': u'أخا'}],

 u'فبوقته': [{'vocalized': u'فبوقته', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'ولإنك': [{'vocalized': u'ولإنك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'فليمينها': [{'vocalized': u'فليمينها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'ولإنه': [{'vocalized': u'ولإنه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'أوكذاك': [{'vocalized': u'أوكذاك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'بذواتي': [{'vocalized': u'بذواتي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'وكساعتهما': [{'vocalized': u'وكساعتهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبشهرها': [{'vocalized': u'وبشهرها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'ولغروب': [{'vocalized': u'ولغروب', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'لإلينا': [{'vocalized': u'لإلينا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'فككل': [{'vocalized': u'فككل', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككل', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'ألذين': [{'vocalized': u'ألذين', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'أفلذلكن': [{'vocalized': u'أفلذلكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'لحسبهما': [{'vocalized': u'لحسبهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أوأمامكن': [{'vocalized': u'أوأمامكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'أفلذلكم': [{'vocalized': u'أفلذلكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'أوشبههن': [{'vocalized': u'أوشبههن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أوشبههم': [{'vocalized': u'أوشبههم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'أونفسكما': [{'vocalized': u'أونفسكما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'ولهنالك': [{'vocalized': u'ولهنالك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فكلحظتهم': [{'vocalized': u'فكلحظتهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبجنوبهن': [{'vocalized': u'فبجنوبهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'ولليلهم': [{'vocalized': u'ولليلهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'بعضه': [{'vocalized': u'بعضه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبغيركما': [{'vocalized': u'أوبغيركما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فبأقلهما': [{'vocalized': u'فبأقلهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'أوكلهما': [{'vocalized': u'أوكلهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلهما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'أفكعامتها': [{'vocalized': u'أفكعامتها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'ولبعضه': [{'vocalized': u'ولبعضه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'ولبعضك': [{'vocalized': u'ولبعضك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فلجعل': [{'vocalized': u'فلجعل', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'جعل', 'encletic': u'', 'type': u'فعل', 'original': u'جعل'}],

 u'أبعينك': [{'vocalized': u'أبعينك', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أفبجميعنا': [{'vocalized': u'أفبجميعنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'ولبعضي': [{'vocalized': u'ولبعضي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فمعه': [{'vocalized': u'فمعه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'فمعك': [{'vocalized': u'فمعك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'وغيرهن': [{'vocalized': u'وغيرهن', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'ولدنهما': [{'vocalized': u'ولدنهما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدن'}],

 u'وغيرهم': [{'vocalized': u'وغيرهم', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أفكعامتهن': [{'vocalized': u'أفكعامتهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فمعي': [{'vocalized': u'فمعي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'فمعي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'أفغير': [{'vocalized': u'أفغير', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'ولذويكم': [{'vocalized': u'ولذويكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولذويكن': [{'vocalized': u'ولذويكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'تحتهن': [{'vocalized': u'تحتهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'فبحميهما': [{'vocalized': u'فبحميهما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'فبجنوبهما': [{'vocalized': u'فبجنوبهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'أأولئكم': [{'vocalized': u'أأولئكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'وبعضك': [{'vocalized': u'وبعضك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'لساعتها': [{'vocalized': u'لساعتها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبعضه': [{'vocalized': u'وبعضه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'وبعضي': [{'vocalized': u'وبعضي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'وبعضي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'إنكم': [{'vocalized': u'إنكم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'إنكن': [{'vocalized': u'إنكن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'تلك': [{'vocalized': u'تلك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'فعنهم': [{'vocalized': u'فعنهم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'فعينكم': [{'vocalized': u'فعينكم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أوشبهها': [{'vocalized': u'أوشبهها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'أولأولالك': [{'vocalized': u'أولأولالك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فلأثناءكم': [{'vocalized': u'فلأثناءكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبشطرهما': [{'vocalized': u'وبشطرهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'أفلنفسها': [{'vocalized': u'أفلنفسها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'غداة': [{'vocalized': u'غداة', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'غداة', 'encletic': u'', 'type': u'اسم', 'original': u'غداة'}],

 u'فبحسبنا': [{'vocalized': u'فبحسبنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'كساعتنا': [{'vocalized': u'كساعتنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفهناك': [{'vocalized': u'أفهناك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أولسويك': [{'vocalized': u'أولسويك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فبنفسه': [{'vocalized': u'فبنفسه', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'نفسكما': [{'vocalized': u'نفسكما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'أولسويه': [{'vocalized': u'أولسويه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أأنتما': [{'vocalized': u'أأنتما', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'لهنالك': [{'vocalized': u'لهنالك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'وجنبهما': [{'vocalized': u'وجنبهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'فخلاكم': [{'vocalized': u'فخلاكم', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'خلا'}],

 u'أفلكأنما': [{'vocalized': u'أفلكأنما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'فخلاكن': [{'vocalized': u'فخلاكن', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'خلا'}],

 u'بزمانها': [{'vocalized': u'بزمانها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'فأقل': [{'vocalized': u'فأقل', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'فشبهكن': [{'vocalized': u'فشبهكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'فشبهكم': [{'vocalized': u'فشبهكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'أعين': [{'vocalized': u'أعين', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'فلبعضكما': [{'vocalized': u'فلبعضكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلمني': [{'vocalized': u'أفلمني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'أفلمني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'حاشاكم': [{'vocalized': u'حاشاكم', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'حاشا'}],

 u'حاشاكن': [{'vocalized': u'حاشاكن', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'حاشا'}],

 u'أفلمنك': [{'vocalized': u'أفلمنك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'وتلكم': [{'vocalized': u'وتلكم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'فلساعة': [{'vocalized': u'فلساعة', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفلمنه': [{'vocalized': u'أفلمنه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'بزمانهن': [{'vocalized': u'بزمانهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'بزمانهم': [{'vocalized': u'بزمانهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'أوبأجمع': [{'vocalized': u'أوبأجمع', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'وكأعليهم': [{'vocalized': u'وكأعليهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'وكأعليهن': [{'vocalized': u'وكأعليهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'وكتلكما': [{'vocalized': u'وكتلكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'لذلك': [{'vocalized': u'لذلك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'فليست': [{'vocalized': u'فليست', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليست', 'encletic': u'', 'type': u'فعل', 'original': u'ليست'}],

 u'أفلنفسهن': [{'vocalized': u'أفلنفسهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلنفسهم': [{'vocalized': u'أفلنفسهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'ومعكما': [{'vocalized': u'ومعكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'فغربنا': [{'vocalized': u'فغربنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'فليسا': [{'vocalized': u'فليسا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليسا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسا'}],

 u'ألشمالك': [{'vocalized': u'ألشمالك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'ففلان': [{'vocalized': u'ففلان', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'فلان', 'encletic': u'', 'type': u'اسم', 'original': u'فلان'}],

 u'فهما': [{'vocalized': u'فهما', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'لمنكن': [{'vocalized': u'لمنكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'كأسفلك': [{'vocalized': u'كأسفلك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'ووراءهما': [{'vocalized': u'ووراءهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'فبعينهما': [{'vocalized': u'فبعينهما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'ويكأنكما': [{'vocalized': u'ويكأنكما', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-كما', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'أفوراء': [{'vocalized': u'أفوراء', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'لوقتكما': [{'vocalized': u'لوقتكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'لاخلولق': [{'vocalized': u'لاخلولق', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'اخلولق', 'encletic': u'', 'type': u'فعل', 'original': u'اخلولق'}],

 u'ألشماله': [{'vocalized': u'ألشماله', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'بأبيكما': [{'vocalized': u'بأبيكما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'أوفلان': [{'vocalized': u'أوفلان', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام', 'stem': u'فلان', 'encletic': u'', 'type': u'اسم', 'original': u'فلان'}],

 u'أينا': [{'vocalized': u'أينا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'فبجنوبي': [{'vocalized': u'فبجنوبي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'فبجنوبي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبحميي': [{'vocalized': u'فبحميي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'فبحميي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'فبحميه': [{'vocalized': u'فبحميه', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'فبجنوبه': [{'vocalized': u'فبجنوبه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'ألشمالي': [{'vocalized': u'ألشمالي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'ألشمالي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'فبحميك': [{'vocalized': u'فبحميك', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'فبجنوبك': [{'vocalized': u'فبجنوبك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفلعامة': [{'vocalized': u'أفلعامة', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامة', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'ونحونا': [{'vocalized': u'ونحونا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحونا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'فماانفك': [{'vocalized': u'فماانفك', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفك', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفك'}],

 u'فكشهركم': [{'vocalized': u'فكشهركم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'أفلدى': [{'vocalized': u'أفلدى', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام', 'stem': u'لدى', 'encletic': u'', 'type': u'اسم', 'original': u'لدى'}],

 u'فغيرها': [{'vocalized': u'فغيرها', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'أفلدي': [{'vocalized': u'أفلدي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'},
 {'vocalized': u'أفلدي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'}],

 u'أوإلينا': [{'vocalized': u'أوإلينا', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'وحموهم': [{'vocalized': u'وحموهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمو'}],

 u'فبمثلهن': [{'vocalized': u'فبمثلهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'فبمثلهم': [{'vocalized': u'فبمثلهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'وحموهن': [{'vocalized': u'وحموهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمو'}],

 u'ألديهما': [{'vocalized': u'ألديهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدى'}],

 u'أفمنهما': [{'vocalized': u'أفمنهما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'فلعل': [{'vocalized': u'فلعل', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'لعل', 'encletic': u'', 'type': u'حرف', 'original': u'لعل'}],

 u'فلعن': [{'vocalized': u'فلعن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'فغروبكما': [{'vocalized': u'فغروبكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'فغيرهم': [{'vocalized': u'فغيرهم', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'فغيرهن': [{'vocalized': u'فغيرهن', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أولنفسكن': [{'vocalized': u'أولنفسكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أغيرنا': [{'vocalized': u'أغيرنا', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فبمثلها': [{'vocalized': u'فبمثلها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'حسبهما': [{'vocalized': u'حسبهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'وحموها': [{'vocalized': u'وحموها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمو'}],

 u'فكأعلينا': [{'vocalized': u'فكأعلينا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'وتحتنا': [{'vocalized': u'وتحتنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'ألإنهما': [{'vocalized': u'ألإنهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'كأجمعكن': [{'vocalized': u'كأجمعكن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلمعي': [{'vocalized': u'أفلمعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'أفلمعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'أفلسويك': [{'vocalized': u'أفلسويك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فأسفلها': [{'vocalized': u'فأسفلها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'وببعضهما': [{'vocalized': u'وببعضهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'لحميك': [{'vocalized': u'لحميك', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'أفلمعك': [{'vocalized': u'أفلمعك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'كسوي': [{'vocalized': u'كسوي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'كسوي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'فمنكم': [{'vocalized': u'فمنكم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'فمنكن': [{'vocalized': u'فمنكن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'أفلمعه': [{'vocalized': u'أفلمعه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'فكذاتكما': [{'vocalized': u'فكذاتكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'وليميني': [{'vocalized': u'وليميني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'وليميني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'كمثلنا': [{'vocalized': u'كمثلنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'بوقتكم': [{'vocalized': u'بوقتكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'أولديها': [{'vocalized': u'أولديها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدى'}],

 u'بحسب': [{'vocalized': u'بحسب', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'وليمينه': [{'vocalized': u'وليمينه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'أأناك': [{'vocalized': u'أأناك', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'أسويها': [{'vocalized': u'أسويها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'وليمينك': [{'vocalized': u'وليمينك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'أعلينا': [{'vocalized': u'أعلينا', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعلينا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'ومنكم': [{'vocalized': u'ومنكم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'نحوك': [{'vocalized': u'نحوك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'ومنكن': [{'vocalized': u'ومنكن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'فبأثناءها': [{'vocalized': u'فبأثناءها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'فبهؤلاء': [{'vocalized': u'فبهؤلاء', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'إنما': [{'vocalized': u'إنما', 'procletic': u'', 'tags': u'حرف;كافة ومكفوفة', 'stem': u'إنما', 'encletic': u'', 'type': u'حرف', 'original': u'إنما'}],

 u'وخلالهما': [{'vocalized': u'وخلالهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلال'}],

 u'ولحظتنا': [{'vocalized': u'ولحظتنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'ألدينا': [{'vocalized': u'ألدينا', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدى'}],

 u'بأبيكن': [{'vocalized': u'بأبيكن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'بأبيكم': [{'vocalized': u'بأبيكم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'أفبأجمعهما': [{'vocalized': u'أفبأجمعهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوأمامكما': [{'vocalized': u'أوأمامكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'فأثناءكن': [{'vocalized': u'فأثناءكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلإنها': [{'vocalized': u'فلإنها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'فكشبهكم': [{'vocalized': u'فكشبهكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'فلابننا': [{'vocalized': u'فلابننا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'فكشبهكن': [{'vocalized': u'فكشبهكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'شمالكم': [{'vocalized': u'شمالكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'أنحوكما': [{'vocalized': u'أنحوكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'ومكانك': [{'vocalized': u'ومكانك', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانك'},
 {'vocalized': u'ومكانك', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانك'}],

 u'أفبذواتي': [{'vocalized': u'أفبذواتي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'كالألاء': [{'vocalized': u'كالألاء', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'أذينك': [{'vocalized': u'أذينك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'فلإنهم': [{'vocalized': u'فلإنهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'فبأعليكم': [{'vocalized': u'فبأعليكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبأعليكن': [{'vocalized': u'فبأعليكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فلإنهن': [{'vocalized': u'فلإنهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'ويمينكما': [{'vocalized': u'ويمينكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'فأخينا': [{'vocalized': u'فأخينا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'أفكلكن': [{'vocalized': u'أفكلكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلكن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أفكلكم': [{'vocalized': u'أفكلكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلكم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'لحظتكما': [{'vocalized': u'لحظتكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفكحسبنا': [{'vocalized': u'أفكحسبنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'لخلفكم': [{'vocalized': u'لخلفكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'لخلفكن': [{'vocalized': u'لخلفكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'أكهاتي': [{'vocalized': u'أكهاتي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'أنفسنا': [{'vocalized': u'أنفسنا', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'وبزماننا': [{'vocalized': u'وبزماننا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'أكهاته': [{'vocalized': u'أكهاته', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'ووراءها': [{'vocalized': u'ووراءها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'أسويهن': [{'vocalized': u'أسويهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'أسويهم': [{'vocalized': u'أسويهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أبسويكما': [{'vocalized': u'أبسويكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'أأناه': [{'vocalized': u'أأناه', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'أفهنا': [{'vocalized': u'أفهنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هنا', 'encletic': u'', 'type': u'اسم', 'original': u'هنا'}],

 u'فحاشاي': [{'vocalized': u'فحاشاي', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'حاشا'},
 {'vocalized': u'فحاشاي', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'حاشا'}],

 u'أوكعينكم': [{'vocalized': u'أوكعينكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'فحاشاه': [{'vocalized': u'فحاشاه', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'حاشا'}],

 u'فحاشاك': [{'vocalized': u'فحاشاك', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'حاشا'}],

 u'فشرقكن': [{'vocalized': u'فشرقكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'فبجنوبكم': [{'vocalized': u'فبجنوبكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبجنوبكن': [{'vocalized': u'فبجنوبكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبحميكن': [{'vocalized': u'فبحميكن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'فبحميكم': [{'vocalized': u'فبحميكم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'أوكسويه': [{'vocalized': u'أوكسويه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'فمافتئتم': [{'vocalized': u'فمافتئتم', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتم', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتم'}],

 u'أوكسويك': [{'vocalized': u'أوكسويك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'أكسويك': [{'vocalized': u'أكسويك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'أكسويه': [{'vocalized': u'أكسويه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'وبكما': [{'vocalized': u'وبكما', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بكما', 'encletic': u'', 'type': u'ضمير', 'original': u'بكما'}],

 u'أوكأجمعي': [{'vocalized': u'أوكأجمعي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أوكأجمعي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوكأجمعه': [{'vocalized': u'أوكأجمعه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولنفسها': [{'vocalized': u'ولنفسها', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أوكأجمعك': [{'vocalized': u'أوكأجمعك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبغيرنا': [{'vocalized': u'وبغيرنا', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فاي': [{'vocalized': u'فاي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فا'},
 {'vocalized': u'فاي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فا'}],

 u'وبأجمع': [{'vocalized': u'وبأجمع', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'فاه': [{'vocalized': u'فاه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فا'}],

 u'أوأجمعك': [{'vocalized': u'أوأجمعك', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'فاك': [{'vocalized': u'فاك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فا'}],

 u'فلكنكن': [{'vocalized': u'فلكنكن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنكن', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لكن'}],

 u'فلكنكم': [{'vocalized': u'فلكنكم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنكم', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لكن'}],

 u'فبحميها': [{'vocalized': u'فبحميها', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'وحولهما': [{'vocalized': u'وحولهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حول'}],

 u'لجنوبهم': [{'vocalized': u'لجنوبهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'لجنوبهن': [{'vocalized': u'لجنوبهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فأقلنا': [{'vocalized': u'فأقلنا', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'فبشرق': [{'vocalized': u'فبشرق', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'فكذاتكم': [{'vocalized': u'فكذاتكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'فبأثناءهم': [{'vocalized': u'فبأثناءهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'أسويه': [{'vocalized': u'أسويه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'فكذاتكن': [{'vocalized': u'فكذاتكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أسويك': [{'vocalized': u'أسويك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلشمالهما': [{'vocalized': u'أفلشمالهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'أوأجمعي': [{'vocalized': u'أوأجمعي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أوأجمعي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'فليلك': [{'vocalized': u'فليلك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'فلغربهما': [{'vocalized': u'فلغربهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'فشمالنا': [{'vocalized': u'فشمالنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'لجنوبها': [{'vocalized': u'لجنوبها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'لساعتنا': [{'vocalized': u'لساعتنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'فنعم': [{'vocalized': u'فنعم', 'procletic': u'ف-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'نعم', 'encletic': u'', 'type': u'حرف', 'original': u'نعم'},
 {'vocalized': u'فنعم', 'procletic': u'ف-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'نعم', 'encletic': u'', 'type': u'فعل', 'original': u'نعم'}],

 u'وجميعكما': [{'vocalized': u'وجميعكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعكما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'انبرى': [{'vocalized': u'انبرى', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'انبرى', 'encletic': u'', 'type': u'فعل', 'original': u'انبرى'}],

 u'فنفسكما': [{'vocalized': u'فنفسكما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'ليستا': [{'vocalized': u'ليستا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ليستا', 'encletic': u'', 'type': u'فعل', 'original': u'ليستا'}],

 u'فغروب': [{'vocalized': u'فغروب', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'أوبنفسي': [{'vocalized': u'أوبنفسي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أوبنفسي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'وذويي': [{'vocalized': u'وذويي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'وذويي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'أوفوقي': [{'vocalized': u'أوفوقي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'أوفوقي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'كغربها': [{'vocalized': u'كغربها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'أفمثلها': [{'vocalized': u'أفمثلها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'وذويك': [{'vocalized': u'وذويك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'أوبنفسك': [{'vocalized': u'أوبنفسك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'أوأناهم': [{'vocalized': u'أوأناهم', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'أوبعضها': [{'vocalized': u'أوبعضها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'وذويه': [{'vocalized': u'وذويه', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'أوبنفسه': [{'vocalized': u'أوبنفسه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'فلما': [{'vocalized': u'فلما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'لما', 'encletic': u'', 'type': u'اسم', 'original': u'لما'},
 {'vocalized': u'فلما', 'procletic': u'ف-', 'tags': u'حرف;حرف جزم;عطف', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'},
 {'vocalized': u'فلما', 'procletic': u'ف-', 'tags': u'حرف;ظرف;عطف', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'}],

 u'فلأيتهما': [{'vocalized': u'فلأيتهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'ألتحت': [{'vocalized': u'ألتحت', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'أوأجمعه': [{'vocalized': u'أوأجمعه', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلعامتها': [{'vocalized': u'أفلعامتها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'وكعينكن': [{'vocalized': u'وكعينكن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فكنفسكما': [{'vocalized': u'فكنفسكما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'وكعينكم': [{'vocalized': u'وكعينكم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أوأنا': [{'vocalized': u'أوأنا', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'أوأنا', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'ولديهن': [{'vocalized': u'ولديهن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدى'}],

 u'ر': [{'vocalized': u'ر', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ر', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ر'}],

 u'فأجمعكم': [{'vocalized': u'فأجمعكم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فأجمعكن': [{'vocalized': u'فأجمعكن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفكنحوهم': [{'vocalized': u'أفكنحوهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أفكنحوهن': [{'vocalized': u'أفكنحوهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'ولكأننا': [{'vocalized': u'ولكأننا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'لجميعهما': [{'vocalized': u'لجميعهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أبغيرك': [{'vocalized': u'أبغيرك', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'وكليلكما': [{'vocalized': u'وكليلكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'أبغيره': [{'vocalized': u'أبغيره', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'فلحظتنا': [{'vocalized': u'فلحظتنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'أبغيري': [{'vocalized': u'أبغيري', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أبغيري', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'ولبعضها': [{'vocalized': u'ولبعضها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'أولأولئكم': [{'vocalized': u'أولأولئكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'وأقلهما': [{'vocalized': u'وأقلهما', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'ولديها': [{'vocalized': u'ولديها', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدى'}],

 u'أووراء': [{'vocalized': u'أووراء', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'لأسفلهن': [{'vocalized': u'لأسفلهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفكنحوها': [{'vocalized': u'أفكنحوها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'غربه': [{'vocalized': u'غربه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'وغربهما': [{'vocalized': u'وغربهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'مازلن': [{'vocalized': u'مازلن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلن', 'encletic': u'', 'type': u'فعل', 'original': u'مازلن'}],

 u'وحي': [{'vocalized': u'وحي', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'حي', 'encletic': u'', 'type': u'اسم فعل', 'original': u'حي'}],

 u'وحم': [{'vocalized': u'وحم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حم', 'encletic': u'', 'type': u'اسم', 'original': u'حم'}],

 u'كوقتك': [{'vocalized': u'كوقتك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'ولبعضهن': [{'vocalized': u'ولبعضهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أكغيركما': [{'vocalized': u'أكغيركما', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'أفكنفسها': [{'vocalized': u'أفكنفسها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'وبغيرهما': [{'vocalized': u'وبغيرهما', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'أوتحتكن': [{'vocalized': u'أوتحتكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'أفمثلهن': [{'vocalized': u'أفمثلهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'كغربهن': [{'vocalized': u'كغربهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'كغربهم': [{'vocalized': u'كغربهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'أفمثلهم': [{'vocalized': u'أفمثلهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'فبنحوكن': [{'vocalized': u'فبنحوكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'فكأنكم': [{'vocalized': u'فكأنكم', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنكم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'فكأنكن': [{'vocalized': u'فكأنكن', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأنكن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'فبنحوكم': [{'vocalized': u'فبنحوكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'فوقتهما': [{'vocalized': u'فوقتهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'فكأعليهما': [{'vocalized': u'فكأعليهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فلأيكن': [{'vocalized': u'فلأيكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'فلأيكم': [{'vocalized': u'فلأيكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'أوتحتكم': [{'vocalized': u'أوتحتكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلعامتهم': [{'vocalized': u'أفلعامتهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلعامتهن': [{'vocalized': u'أفلعامتهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'أعامتهن': [{'vocalized': u'أعامتهن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'ولعمركما': [{'vocalized': u'ولعمركما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لعمر'}],

 u'وبأبيهما': [{'vocalized': u'وبأبيهما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'لابنهن': [{'vocalized': u'لابنهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'لابنهم': [{'vocalized': u'لابنهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'أفوق': [{'vocalized': u'أفوق', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'وكأبيهما': [{'vocalized': u'وكأبيهما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'فكوقت': [{'vocalized': u'فكوقت', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'فلساعتها': [{'vocalized': u'فلساعتها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'فضمنكما': [{'vocalized': u'فضمنكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ضمن'}],

 u'أفبنفسكن': [{'vocalized': u'أفبنفسكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'وكمثلها': [{'vocalized': u'وكمثلها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'ألعلي': [{'vocalized': u'ألعلي', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'ألعلي', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'ألعلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'ألعلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'ألعلى': [{'vocalized': u'ألعلى', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'ألعله': [{'vocalized': u'ألعله', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لعل'}],

 u'فكشرقنا': [{'vocalized': u'فكشرقنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'ألعلك': [{'vocalized': u'ألعلك', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لعل'}],

 u'فلساعتهم': [{'vocalized': u'فلساعتهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'أقلي': [{'vocalized': u'أقلي', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'أقلي', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'فأثناءهم': [{'vocalized': u'فأثناءهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'أكجميعكم': [{'vocalized': u'أكجميعكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعكم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'أكجميعكن': [{'vocalized': u'أكجميعكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعكن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'أقلك': [{'vocalized': u'أقلك', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'أقله': [{'vocalized': u'أقله', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'وكمثلهن': [{'vocalized': u'وكمثلهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'وكمثلهم': [{'vocalized': u'وكمثلهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'فمافتئتما': [{'vocalized': u'فمافتئتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتما', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتما'},
 {'vocalized': u'فمافتئتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتما', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتما'}],

 u'أولازالا': [{'vocalized': u'أولازالا', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالا'}],

 u'أبنفسهن': [{'vocalized': u'أبنفسهن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'فيمينه': [{'vocalized': u'فيمينه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'أوكبعضهن': [{'vocalized': u'أوكبعضهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'فيمينك': [{'vocalized': u'فيمينك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'أوأجمع': [{'vocalized': u'أوأجمع', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'بأجمع': [{'vocalized': u'بأجمع', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'فيميني': [{'vocalized': u'فيميني', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'فيميني', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'فكتلك': [{'vocalized': u'فكتلك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'أوكجميع': [{'vocalized': u'أوكجميع', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميع', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكعامتكما': [{'vocalized': u'أفكعامتكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'بأثناء': [{'vocalized': u'بأثناء', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'فللحظتهما': [{'vocalized': u'فللحظتهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلخلفنا': [{'vocalized': u'أفلخلفنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'أولعننا': [{'vocalized': u'أولعننا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'أبكلي': [{'vocalized': u'أبكلي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'وغربك': [{'vocalized': u'وغربك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'وبضعكما': [{'vocalized': u'وبضعكما', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بضع'}],

 u'أبكلك': [{'vocalized': u'أبكلك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلك', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'والتي': [{'vocalized': u'والتي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'أبكله': [{'vocalized': u'أبكله', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكله', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'فبأكثركم': [{'vocalized': u'فبأكثركم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فبأكثركن': [{'vocalized': u'فبأكثركن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'بأيتها': [{'vocalized': u'بأيتها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'فكهي': [{'vocalized': u'فكهي', 'procletic': u'ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'للحظة': [{'vocalized': u'للحظة', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'لوراءها': [{'vocalized': u'لوراءها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'ولعينكن': [{'vocalized': u'ولعينكن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'ولعينكم': [{'vocalized': u'ولعينكم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'كغروبي': [{'vocalized': u'كغروبي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'كغروبي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'ألفوقهن': [{'vocalized': u'ألفوقهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'كغروبه': [{'vocalized': u'كغروبه', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'ألفوقهم': [{'vocalized': u'ألفوقهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'كغروبك': [{'vocalized': u'كغروبك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'وتجاهكما': [{'vocalized': u'وتجاهكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تجاه'}],

 u'ولإنكن': [{'vocalized': u'ولإنكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'وليلها': [{'vocalized': u'وليلها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'ولإنكم': [{'vocalized': u'ولإنكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'أولكأنهما': [{'vocalized': u'أولكأنهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'أينما': [{'vocalized': u'أينما', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'أينما', 'encletic': u'', 'type': u'اسم', 'original': u'أينما'}],

 u'وأناك': [{'vocalized': u'وأناك', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'لفوق': [{'vocalized': u'لفوق', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'لأعلى': [{'vocalized': u'لأعلى', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'لأعلي': [{'vocalized': u'لأعلي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'لأعلي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبشطركن': [{'vocalized': u'فبشطركن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'فبشطركم': [{'vocalized': u'فبشطركم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'فحينهما': [{'vocalized': u'فحينهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حين'}],

 u'ولإن': [{'vocalized': u'ولإن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'ولإن', 'procletic': u'و-ل-', 'tags': u'حرف;المشبهة بليس;مجرور;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'أبشبهنا': [{'vocalized': u'أبشبهنا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'أولديهم': [{'vocalized': u'أولديهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدى'}],

 u'وليلهم': [{'vocalized': u'وليلهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'شمالهن': [{'vocalized': u'شمالهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'شمالهم': [{'vocalized': u'شمالهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'وليلهن': [{'vocalized': u'وليلهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'وبأسفلكما': [{'vocalized': u'وبأسفلكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أكمثلك': [{'vocalized': u'أكمثلك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أكمثله': [{'vocalized': u'أكمثله', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'وكفيي': [{'vocalized': u'وكفيي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وكفيي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'}],

 u'فبخلفها': [{'vocalized': u'فبخلفها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'وكفيك': [{'vocalized': u'وكفيك', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'}],

 u'وكفيه': [{'vocalized': u'وكفيه', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'}],

 u'فإليه': [{'vocalized': u'فإليه', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'أوكذي': [{'vocalized': u'أوكذي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فكلنا': [{'vocalized': u'فكلنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلنا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'فإليك': [{'vocalized': u'فإليك', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليك'},
 {'vocalized': u'فإليك', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'وبأخيي': [{'vocalized': u'وبأخيي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'وبأخيي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'أولغيرهما': [{'vocalized': u'أولغيرهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيرهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'أوبحسبك': [{'vocalized': u'أوبحسبك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبحسبه': [{'vocalized': u'أوبحسبه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'فلمثلها': [{'vocalized': u'فلمثلها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'وكاد': [{'vocalized': u'وكاد', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'كاد', 'encletic': u'', 'type': u'فعل', 'original': u'كاد'}],

 u'أوبحسبي': [{'vocalized': u'أوبحسبي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أوبحسبي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أبيكن': [{'vocalized': u'أبيكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'وبأخيه': [{'vocalized': u'وبأخيه', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'أفبحسبهما': [{'vocalized': u'أفبحسبهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'فكوقتكم': [{'vocalized': u'فكوقتكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'فلأثناءك': [{'vocalized': u'فلأثناءك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'أولأولاء': [{'vocalized': u'أولأولاء', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'أوبكليكما': [{'vocalized': u'أوبكليكما', 'procletic': u'أ-و-ب-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'فبعامتكما': [{'vocalized': u'فبعامتكما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'فلحظة': [{'vocalized': u'فلحظة', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'ن': [{'vocalized': u'ن', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ن', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ن'}],

 u'فلذين': [{'vocalized': u'فلذين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'ولشطرنا': [{'vocalized': u'ولشطرنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'كحسبهن': [{'vocalized': u'كحسبهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'وشمالكما': [{'vocalized': u'وشمالكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'للذي': [{'vocalized': u'للذي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'أفلتحت': [{'vocalized': u'أفلتحت', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'أولطالما': [{'vocalized': u'أولطالما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'أفلعلهن': [{'vocalized': u'أفلعلهن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لعل'}],

 u'بكلهما': [{'vocalized': u'بكلهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلهما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'بذاته': [{'vocalized': u'بذاته', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'بذاتي': [{'vocalized': u'بذاتي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'بذاتي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'ألذلكما': [{'vocalized': u'ألذلكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'غيرك': [{'vocalized': u'غيرك', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'غيره': [{'vocalized': u'غيره', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'غيري': [{'vocalized': u'غيري', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'غيري', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أفبتلك': [{'vocalized': u'أفبتلك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'وهكذا': [{'vocalized': u'وهكذا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هكذا', 'encletic': u'', 'type': u'اسم', 'original': u'هكذا'}],

 u'أففيهن': [{'vocalized': u'أففيهن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'وكان': [{'vocalized': u'وكان', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'كان', 'encletic': u'', 'type': u'فعل', 'original': u'كان'}],

 u'كمثلكن': [{'vocalized': u'كمثلكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'فلمثلهن': [{'vocalized': u'فلمثلهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'فلمثلهم': [{'vocalized': u'فلمثلهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'كمثلكم': [{'vocalized': u'كمثلكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'ولعنكما': [{'vocalized': u'ولعنكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'ألنفسها': [{'vocalized': u'ألنفسها', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أوغير': [{'vocalized': u'أوغير', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وآض': [{'vocalized': u'وآض', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'آض', 'encletic': u'', 'type': u'فعل', 'original': u'آض'}],

 u'أويمينكما': [{'vocalized': u'أويمينكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'وراءنا': [{'vocalized': u'وراءنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'أفبمثلها': [{'vocalized': u'أفبمثلها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'ولدنكما': [{'vocalized': u'ولدنكما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدن'}],

 u'خلفك': [{'vocalized': u'خلفك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'فلليلنا': [{'vocalized': u'فلليلنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'وشطرهما': [{'vocalized': u'وشطرهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'أكمثلهم': [{'vocalized': u'أكمثلهم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أكمثلهن': [{'vocalized': u'أكمثلهن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'فمعاذكم': [{'vocalized': u'فمعاذكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-كم', 'type': u'اسم', 'original': u'معاذ'}],

 u'فمعاذكن': [{'vocalized': u'فمعاذكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-كن', 'type': u'اسم', 'original': u'معاذ'}],

 u'خلفي': [{'vocalized': u'خلفي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فعامته': [{'vocalized': u'فعامته', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'فعندك': [{'vocalized': u'فعندك', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عند'}],

 u'وجميعهما': [{'vocalized': u'وجميعهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعهما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'وجميعنا': [{'vocalized': u'وجميعنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعنا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'أكأجمعهما': [{'vocalized': u'أكأجمعهما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوكعامتها': [{'vocalized': u'أوكعامتها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'فعامتي': [{'vocalized': u'فعامتي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فعامتي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فبخلفهن': [{'vocalized': u'فبخلفهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أففيكن': [{'vocalized': u'أففيكن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'فلأقلها': [{'vocalized': u'فلأقلها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'أففيكم': [{'vocalized': u'أففيكم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'أفلغيرهما': [{'vocalized': u'أفلغيرهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيرهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'أولنفسه': [{'vocalized': u'أولنفسه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'أمام': [{'vocalized': u'أمام', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'وسويهما': [{'vocalized': u'وسويهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'ولليلي': [{'vocalized': u'ولليلي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'ولليلي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'فمثلهما': [{'vocalized': u'فمثلهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'أوأناهن': [{'vocalized': u'أوأناهن', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'فلأقلهن': [{'vocalized': u'فلأقلهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'فلأقلهم': [{'vocalized': u'فلأقلهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'أكشبهكن': [{'vocalized': u'أكشبهكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أكشبهكم': [{'vocalized': u'أكشبهكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'أأجمعكن': [{'vocalized': u'أأجمعكن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أبأجمعك': [{'vocalized': u'أبأجمعك', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أأجمعكم': [{'vocalized': u'أأجمعكم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أبأجمعه': [{'vocalized': u'أبأجمعه', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'فإزاء': [{'vocalized': u'فإزاء', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'إزاء', 'encletic': u'', 'type': u'اسم', 'original': u'إزاء'}],

 u'أولوراءكم': [{'vocalized': u'أولوراءكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'وهاهنا': [{'vocalized': u'وهاهنا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاهنا', 'encletic': u'', 'type': u'اسم', 'original': u'هاهنا'}],

 u'وبيني': [{'vocalized': u'وبيني', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بين'},
 {'vocalized': u'وبيني', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بين'}],

 u'ومعكن': [{'vocalized': u'ومعكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'أولمثلكم': [{'vocalized': u'أولمثلكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أولمثلكن': [{'vocalized': u'أولمثلكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'ومعكم': [{'vocalized': u'ومعكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'ألأمامكم': [{'vocalized': u'ألأمامكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'وبزمانكما': [{'vocalized': u'وبزمانكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'أولازالت': [{'vocalized': u'أولازالت', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'}],

 u'أفبمثلهم': [{'vocalized': u'أفبمثلهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفبمثلهن': [{'vocalized': u'أفبمثلهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'ولأمامه': [{'vocalized': u'ولأمامه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'أولنفسي': [{'vocalized': u'أولنفسي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'ولأخيهما': [{'vocalized': u'ولأخيهما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'أكمثلها': [{'vocalized': u'أكمثلها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'أعامة': [{'vocalized': u'أعامة', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'فبأخيهما': [{'vocalized': u'فبأخيهما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'وكساعتنا': [{'vocalized': u'وكساعتنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'وكلكما': [{'vocalized': u'وكلكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلكما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'أكذينك': [{'vocalized': u'أكذينك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'أوكعامتهم': [{'vocalized': u'أوكعامتهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أوكعامتهن': [{'vocalized': u'أوكعامتهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فلسويهن': [{'vocalized': u'فلسويهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'أفبحسبك': [{'vocalized': u'أفبحسبك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'وحيثما': [{'vocalized': u'وحيثما', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'حيثما', 'encletic': u'', 'type': u'اسم', 'original': u'حيثما'}],

 u'فابنهن': [{'vocalized': u'فابنهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'أفبحسبه': [{'vocalized': u'أفبحسبه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'شتان': [{'vocalized': u'شتان', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'شتان', 'encletic': u'', 'type': u'اسم فعل', 'original': u'شتان'}],

 u'فيهما': [{'vocalized': u'فيهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيهما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'فلأثناءها': [{'vocalized': u'فلأثناءها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'لأكثرها': [{'vocalized': u'لأكثرها', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكهم': [{'vocalized': u'فكهم', 'procletic': u'ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'إنها': [{'vocalized': u'إنها', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'فكهو': [{'vocalized': u'فكهو', 'procletic': u'ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'ممن': [{'vocalized': u'ممن', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'ممن', 'encletic': u'', 'type': u'اسم', 'original': u'ممن'}],

 u'ألفيكن': [{'vocalized': u'ألفيكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'أفنحوك': [{'vocalized': u'أفنحوك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'كأسفله': [{'vocalized': u'كأسفله', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكالذي': [{'vocalized': u'فكالذي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'أفنحوه': [{'vocalized': u'أفنحوه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'ولدنكم': [{'vocalized': u'ولدنكم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدن'}],

 u'حرى': [{'vocalized': u'حرى', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'حرى', 'encletic': u'', 'type': u'فعل', 'original': u'حرى'}],

 u'أفنحوي': [{'vocalized': u'أفنحوي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أفنحوي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'كأسفلي': [{'vocalized': u'كأسفلي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'كأسفلي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفكلما': [{'vocalized': u'أفكلما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام', 'stem': u'كلما', 'encletic': u'', 'type': u'اسم', 'original': u'كلما'}],

 u'فبغروبكم': [{'vocalized': u'فبغروبكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'أوبعينك': [{'vocalized': u'أوبعينك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'منكم': [{'vocalized': u'منكم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'وكنحوكن': [{'vocalized': u'وكنحوكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'أويميني': [{'vocalized': u'أويميني', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'أويميني', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'وكنحوكم': [{'vocalized': u'وكنحوكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'منكن': [{'vocalized': u'منكن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'ولذويها': [{'vocalized': u'ولذويها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفكعامتكن': [{'vocalized': u'أفكعامتكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أفكعامتكم': [{'vocalized': u'أفكعامتكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'ولديهم': [{'vocalized': u'ولديهم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدى'}],

 u'فأجمعكما': [{'vocalized': u'فأجمعكما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'كأعليه': [{'vocalized': u'كأعليه', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'أولشمالي': [{'vocalized': u'أولشمالي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'أولشمالي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'وغيركن': [{'vocalized': u'وغيركن', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'وغيركم': [{'vocalized': u'وغيركم', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'فلجنوبكما': [{'vocalized': u'فلجنوبكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'أولشمالك': [{'vocalized': u'أولشمالك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'فلأمامكما': [{'vocalized': u'فلأمامكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'وراءه': [{'vocalized': u'وراءه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'ولذويهم': [{'vocalized': u'ولذويهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولذويهن': [{'vocalized': u'ولذويهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبضعكم': [{'vocalized': u'وبضعكم', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بضع'}],

 u'أفأولئك': [{'vocalized': u'أفأولئك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'أولستن': [{'vocalized': u'أولستن', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لستن', 'encletic': u'', 'type': u'فعل', 'original': u'لستن'}],

 u'فابنها': [{'vocalized': u'فابنها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'أولستم': [{'vocalized': u'أولستم', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لستم', 'encletic': u'', 'type': u'فعل', 'original': u'لستم'}],

 u'ولأيكما': [{'vocalized': u'ولأيكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'وبجنوبهن': [{'vocalized': u'وبجنوبهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلأثناءهم': [{'vocalized': u'فلأثناءهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'لأكثرهم': [{'vocalized': u'لأكثرهم', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'لأكثرهن': [{'vocalized': u'لأكثرهن', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلأثناءهن': [{'vocalized': u'فلأثناءهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'أكعينكم': [{'vocalized': u'أكعينكم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'إنهم': [{'vocalized': u'إنهم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'إنهن': [{'vocalized': u'إنهن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'أكعينكن': [{'vocalized': u'أكعينكن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'مما': [{'vocalized': u'مما', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'مما', 'encletic': u'', 'type': u'اسم', 'original': u'مما'}],

 u'عنده': [{'vocalized': u'عنده', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عند'}],

 u'غيرهما': [{'vocalized': u'غيرهما', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'عندك': [{'vocalized': u'عندك', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عند'}],

 u'فحماهما': [{'vocalized': u'فحماهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حما'}],

 u'لأمامنا': [{'vocalized': u'لأمامنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'وبأني': [{'vocalized': u'وبأني', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وبأني', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'كلك': [{'vocalized': u'كلك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلك', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'وككلتا': [{'vocalized': u'وككلتا', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'باللذين': [{'vocalized': u'باللذين', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'وبأنك': [{'vocalized': u'وبأنك', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'أولكلهم': [{'vocalized': u'أولكلهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أولكلهن': [{'vocalized': u'أولكلهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'وبأنه': [{'vocalized': u'وبأنه', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'فلإليكم': [{'vocalized': u'فلإليكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'فلإليكن': [{'vocalized': u'فلإليكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'أكحسبه': [{'vocalized': u'أكحسبه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أقلكم': [{'vocalized': u'أقلكم', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'أفكسوى': [{'vocalized': u'أفكسوى', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أفكسوي': [{'vocalized': u'أفكسوي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أفكسوي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'أقلكن': [{'vocalized': u'أقلكن', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'نفسها': [{'vocalized': u'نفسها', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'كهم': [{'vocalized': u'كهم', 'procletic': u'ك-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أكحسبي': [{'vocalized': u'أكحسبي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أكحسبي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'كهن': [{'vocalized': u'كهن', 'procletic': u'ك-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أفيهن': [{'vocalized': u'أفيهن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'فكأجمعك': [{'vocalized': u'فكأجمعك', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفيهم': [{'vocalized': u'أفيهم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'فكأجمعه': [{'vocalized': u'فكأجمعه', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'لذويهما': [{'vocalized': u'لذويهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكأجمعي': [{'vocalized': u'فكأجمعي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فكأجمعي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'بيد': [{'vocalized': u'بيد', 'procletic': u'', 'tags': u'اسم;استثناء', 'stem': u'بيد', 'encletic': u'', 'type': u'اسم', 'original': u'بيد'}],

 u'وكذاتنا': [{'vocalized': u'وكذاتنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'وبمثل': [{'vocalized': u'وبمثل', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'لعننا': [{'vocalized': u'لعننا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'فكمثلهما': [{'vocalized': u'فكمثلهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'نفسهن': [{'vocalized': u'نفسهن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أكجميعكما': [{'vocalized': u'أكجميعكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعكما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'نفسهم': [{'vocalized': u'نفسهم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'بفيكما': [{'vocalized': u'بفيكما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'}],

 u'لسوي': [{'vocalized': u'لسوي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'لسوي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'لسوى': [{'vocalized': u'لسوى', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'بين': [{'vocalized': u'بين', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'بين', 'encletic': u'', 'type': u'اسم', 'original': u'بين'}],

 u'فساعتنا': [{'vocalized': u'فساعتنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'وجميعهم': [{'vocalized': u'وجميعهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعهم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'لسوف': [{'vocalized': u'لسوف', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'سوف', 'encletic': u'', 'type': u'حرف', 'original': u'سوف'}],

 u'فيمينكما': [{'vocalized': u'فيمينكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'فجنوبكن': [{'vocalized': u'فجنوبكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'خلفهما': [{'vocalized': u'خلفهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'أومعكم': [{'vocalized': u'أومعكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'أومعكن': [{'vocalized': u'أومعكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'بعامتها': [{'vocalized': u'بعامتها', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'أوشمال': [{'vocalized': u'أوشمال', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'ولازال': [{'vocalized': u'ولازال', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازال', 'encletic': u'', 'type': u'فعل', 'original': u'لازال'}],

 u'ولأنشأ': [{'vocalized': u'ولأنشأ', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنشأ', 'encletic': u'', 'type': u'فعل', 'original': u'أنشأ'}],

 u'فبأكثرك': [{'vocalized': u'فبأكثرك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'ألعامتهم': [{'vocalized': u'ألعامتهم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أففوقنا': [{'vocalized': u'أففوقنا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'فبأكثره': [{'vocalized': u'فبأكثره', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'فبأكثري': [{'vocalized': u'فبأكثري', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'فبأكثري', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'كعيننا': [{'vocalized': u'كعيننا', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'فضمنها': [{'vocalized': u'فضمنها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ضمن'}],

 u'لتحول': [{'vocalized': u'لتحول', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'تحول', 'encletic': u'', 'type': u'فعل', 'original': u'تحول'}],

 u'أولكلها': [{'vocalized': u'أولكلها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'وكأخينا': [{'vocalized': u'وكأخينا', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'وكغيرنا': [{'vocalized': u'وكغيرنا', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فماانفككتن': [{'vocalized': u'فماانفككتن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتن', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتن'}],

 u'ولزمانكم': [{'vocalized': u'ولزمانكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'منكما': [{'vocalized': u'منكما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'ولزمانكن': [{'vocalized': u'ولزمانكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'ألنفسهما': [{'vocalized': u'ألنفسهما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'أفبذينك': [{'vocalized': u'أفبذينك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'تلقاءي': [{'vocalized': u'تلقاءي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'تلقاءي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'تلقاءه': [{'vocalized': u'تلقاءه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبأيتها': [{'vocalized': u'وبأيتها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'تلقاءك': [{'vocalized': u'تلقاءك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبذوي': [{'vocalized': u'فبذوي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفأناهم': [{'vocalized': u'أفأناهم', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'أفأناهن': [{'vocalized': u'أفأناهن', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'وحسبها': [{'vocalized': u'وحسبها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'وسبحان': [{'vocalized': u'وسبحان', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'سبحان', 'encletic': u'', 'type': u'اسم', 'original': u'سبحان'}],

 u'أثناءي': [{'vocalized': u'أثناءي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'أثناءي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'أولوراءك': [{'vocalized': u'أولوراءك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'أفعامته': [{'vocalized': u'أفعامته', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'أولوراءه': [{'vocalized': u'أولوراءه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'أولوراءي': [{'vocalized': u'أولوراءي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'أولوراءي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'أثناءك': [{'vocalized': u'أثناءك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'فنحوكما': [{'vocalized': u'فنحوكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فلحسب': [{'vocalized': u'فلحسب', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أثناءه': [{'vocalized': u'أثناءه', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'فبوقتكما': [{'vocalized': u'فبوقتكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'فلهناك': [{'vocalized': u'فلهناك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أفأناها': [{'vocalized': u'أفأناها', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'كغيركما': [{'vocalized': u'كغيركما', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'ولأسفلكم': [{'vocalized': u'ولأسفلكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوبضعك': [{'vocalized': u'أوبضعك', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بضع'}],

 u'وحسبهن': [{'vocalized': u'وحسبهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'وحسبهم': [{'vocalized': u'وحسبهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفعامتك': [{'vocalized': u'أفعامتك', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'ولأسفلكن': [{'vocalized': u'ولأسفلكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبأولئكم': [{'vocalized': u'وبأولئكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'فأخاكما': [{'vocalized': u'فأخاكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخا'}],

 u'وكليلهما': [{'vocalized': u'وكليلهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'وأبيهما': [{'vocalized': u'وأبيهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'ألعليه': [{'vocalized': u'ألعليه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'وبينهما': [{'vocalized': u'وبينهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بين'}],

 u'لدنكن': [{'vocalized': u'لدنكن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدن'}],

 u'لدنكم': [{'vocalized': u'لدنكم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدن'}],

 u'لشطرنا': [{'vocalized': u'لشطرنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'تجاه': [{'vocalized': u'تجاه', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'تجاه', 'encletic': u'', 'type': u'اسم', 'original': u'تجاه'}],

 u'فعندكما': [{'vocalized': u'فعندكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عند'}],

 u'لديكم': [{'vocalized': u'لديكم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدى'}],

 u'وبأيتهم': [{'vocalized': u'وبأيتهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'وتانك': [{'vocalized': u'وتانك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'وبأيتهن': [{'vocalized': u'وبأيتهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'أبأولالك': [{'vocalized': u'أبأولالك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'وبشهرك': [{'vocalized': u'وبشهرك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'أولغير': [{'vocalized': u'أولغير', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغير', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وكأننا': [{'vocalized': u'وكأننا', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأننا', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'فكغيركما': [{'vocalized': u'فكغيركما', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فمادمنا': [{'vocalized': u'فمادمنا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمنا', 'encletic': u'', 'type': u'فعل', 'original': u'مادمنا'}],

 u'فغداة': [{'vocalized': u'فغداة', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'غداة', 'encletic': u'', 'type': u'اسم', 'original': u'غداة'}],

 u'فمعاذك': [{'vocalized': u'فمعاذك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ك', 'type': u'اسم', 'original': u'معاذ'}],

 u'فكفيهن': [{'vocalized': u'فكفيهن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'}],

 u'فكفيهم': [{'vocalized': u'فكفيهم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'}],

 u'وحواليكم': [{'vocalized': u'وحواليكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حوالى'}],

 u'بلحظتكما': [{'vocalized': u'بلحظتكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'فسوي': [{'vocalized': u'فسوي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'فسوي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'ألفي': [{'vocalized': u'ألفي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'فبأخينا': [{'vocalized': u'فبأخينا', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'أفلإليهن': [{'vocalized': u'أفلإليهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'ألمثلهم': [{'vocalized': u'ألمثلهم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'ألمثلهن': [{'vocalized': u'ألمثلهن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'وكنفسهما': [{'vocalized': u'وكنفسهما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'بعامتهن': [{'vocalized': u'بعامتهن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'ولكنكما': [{'vocalized': u'ولكنكما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنكما', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لكن'}],

 u'بمثله': [{'vocalized': u'بمثله', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'ذويهما': [{'vocalized': u'ذويهما', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولبعضهم': [{'vocalized': u'ولبعضهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'بمثلك': [{'vocalized': u'بمثلك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أببعضها': [{'vocalized': u'أببعضها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'ألعني': [{'vocalized': u'ألعني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'ألعني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'فمعاذي': [{'vocalized': u'فمعاذي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ي', 'type': u'اسم', 'original': u'معاذ'},
 {'vocalized': u'فمعاذي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-ي', 'type': u'اسم', 'original': u'معاذ'}],

 u'بمثلي': [{'vocalized': u'بمثلي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'بمثلي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أوبشبهكن': [{'vocalized': u'أوبشبهكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أوبشبهكم': [{'vocalized': u'أوبشبهكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'ألمثلها': [{'vocalized': u'ألمثلها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'وبوقتها': [{'vocalized': u'وبوقتها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'ولغربكما': [{'vocalized': u'ولغربكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'أولتحتها': [{'vocalized': u'أولتحتها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'أببعضهم': [{'vocalized': u'أببعضهم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أببعضهن': [{'vocalized': u'أببعضهن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'كلكما': [{'vocalized': u'كلكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلكما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'وخلالي': [{'vocalized': u'وخلالي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلال'},
 {'vocalized': u'وخلالي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلال'}],

 u'فجنوبنا': [{'vocalized': u'فجنوبنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'بنفسنا': [{'vocalized': u'بنفسنا', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'فأنكما': [{'vocalized': u'فأنكما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'وبوقتكما': [{'vocalized': u'وبوقتكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'أفوقك': [{'vocalized': u'أفوقك', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'أوأناها': [{'vocalized': u'أوأناها', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'وبساعتهما': [{'vocalized': u'وبساعتهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوبسويكم': [{'vocalized': u'أوبسويكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'فكفيها': [{'vocalized': u'فكفيها', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'}],

 u'أوبسويكن': [{'vocalized': u'أوبسويكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أفوقي': [{'vocalized': u'أفوقي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'أفوقي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'أفبعضهن': [{'vocalized': u'أفبعضهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفبعضهم': [{'vocalized': u'أفبعضهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'وشبه': [{'vocalized': u'وشبه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'فحماهم': [{'vocalized': u'فحماهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حما'}],

 u'فحماهن': [{'vocalized': u'فحماهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حما'}],

 u'ألعينهم': [{'vocalized': u'ألعينهم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'ألعينهن': [{'vocalized': u'ألعينهن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'أوبضعكما': [{'vocalized': u'أوبضعكما', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بضع'}],

 u'أخونا': [{'vocalized': u'أخونا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخو'}],

 u'وعنهما': [{'vocalized': u'وعنهما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'فبجميعنا': [{'vocalized': u'فبجميعنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعنا', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وللذين': [{'vocalized': u'وللذين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'},
 {'vocalized': u'وللذين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'فعما': [{'vocalized': u'فعما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر مكفوف;عطف', 'stem': u'عما', 'encletic': u'', 'type': u'حرف', 'original': u'عما'}],

 u'شبهنا': [{'vocalized': u'شبهنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'فبات': [{'vocalized': u'فبات', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'بات', 'encletic': u'', 'type': u'فعل', 'original': u'بات'}],

 u'يمينه': [{'vocalized': u'يمينه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'أولشبههن': [{'vocalized': u'أولشبههن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبههن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أولشبههم': [{'vocalized': u'أولشبههم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبههم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'لأولاء': [{'vocalized': u'لأولاء', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'ولشرقي': [{'vocalized': u'ولشرقي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'ولشرقي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'فأننا': [{'vocalized': u'فأننا', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'حواليكما': [{'vocalized': u'حواليكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حوالى'}],

 u'وطالما': [{'vocalized': u'وطالما', 'procletic': u'و-', 'tags': u'فعل;فعل جامد;عطف', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'كليكما': [{'vocalized': u'كليكما', 'procletic': u'', 'tags': u'حرف;توكيد', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أفهما': [{'vocalized': u'أفهما', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'أولشبهها': [{'vocalized': u'أولشبهها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'حميك': [{'vocalized': u'حميك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'أفببعضنا': [{'vocalized': u'أفببعضنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'فأخوه': [{'vocalized': u'فأخوه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخو'}],

 u'فكزمان': [{'vocalized': u'فكزمان', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'أوراءكم': [{'vocalized': u'أوراءكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'ألحسبهما': [{'vocalized': u'ألحسبهما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أفبعضها': [{'vocalized': u'أفبعضها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'وكأعليك': [{'vocalized': u'وكأعليك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'فحماها': [{'vocalized': u'فحماها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حما'}],

 u'ألعينها': [{'vocalized': u'ألعينها', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فوراءها': [{'vocalized': u'فوراءها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'فأخوي': [{'vocalized': u'فأخوي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخو'},
 {'vocalized': u'فأخوي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخو'}],

 u'وحماكن': [{'vocalized': u'وحماكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حما'}],

 u'كتلقاءكما': [{'vocalized': u'كتلقاءكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وأيان': [{'vocalized': u'وأيان', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'},
 {'vocalized': u'وأيان', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'},
 {'vocalized': u'وأيان', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'}],

 u'عليكم': [{'vocalized': u'عليكم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'لابنكما': [{'vocalized': u'لابنكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'وتجاهكن': [{'vocalized': u'وتجاهكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تجاه'}],

 u'فلعليهما': [{'vocalized': u'فلعليهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'وتجاهكم': [{'vocalized': u'وتجاهكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تجاه'}],

 u'وبأجمعكما': [{'vocalized': u'وبأجمعكما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فتجاهها': [{'vocalized': u'فتجاهها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تجاه'}],

 u'أووراءها': [{'vocalized': u'أووراءها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'عنه': [{'vocalized': u'عنه', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'مادمت': [{'vocalized': u'مادمت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'},
 {'vocalized': u'مادمت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'},
 {'vocalized': u'مادمت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'}],

 u'فمثلهم': [{'vocalized': u'فمثلهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'فمثلهن': [{'vocalized': u'فمثلهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'بأولئك': [{'vocalized': u'بأولئك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'أوليمين': [{'vocalized': u'أوليمين', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'أفلوراءهم': [{'vocalized': u'أفلوراءهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'أفلوراءهن': [{'vocalized': u'أفلوراءهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'الألى': [{'vocalized': u'الألى', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'لأيتي': [{'vocalized': u'لأيتي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'لأيتي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'فلأيتها': [{'vocalized': u'فلأيتها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'بضعهن': [{'vocalized': u'بضعهن', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بضع'}],

 u'بضعهم': [{'vocalized': u'بضعهم', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بضع'}],

 u'لأيتك': [{'vocalized': u'لأيتك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'لأيته': [{'vocalized': u'لأيته', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'وبابنكما': [{'vocalized': u'وبابنكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'عينكم': [{'vocalized': u'عينكم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'عينكن': [{'vocalized': u'عينكن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فخلف': [{'vocalized': u'فخلف', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلف', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'أفلوراءها': [{'vocalized': u'أفلوراءها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'أفلشمالكما': [{'vocalized': u'أفلشمالكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'فلأيتهم': [{'vocalized': u'فلأيتهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'فلأيتهن': [{'vocalized': u'فلأيتهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'ولأمامكم': [{'vocalized': u'ولأمامكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'وكساعتها': [{'vocalized': u'وكساعتها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلتلكما': [{'vocalized': u'فلتلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'ولفيكم': [{'vocalized': u'ولفيكم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'أشمالهم': [{'vocalized': u'أشمالهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'وأثناء': [{'vocalized': u'وأثناء', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكإن': [{'vocalized': u'وكإن', 'procletic': u'و-ك-', 'tags': u'حرف;المشبهة بليس;مجرور;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'وحموه': [{'vocalized': u'وحموه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمو'}],

 u'أوبه': [{'vocalized': u'أوبه', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'به', 'encletic': u'', 'type': u'ضمير', 'original': u'به'}],

 u'وبمثلكما': [{'vocalized': u'وبمثلكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'ألتينك': [{'vocalized': u'ألتينك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'ولكأنكما': [{'vocalized': u'ولكأنكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'فلذلكما': [{'vocalized': u'فلذلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'أشمالهن': [{'vocalized': u'أشمالهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'أووراءهم': [{'vocalized': u'أووراءهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'فتجاههن': [{'vocalized': u'فتجاههن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تجاه'}],

 u'فتجاههم': [{'vocalized': u'فتجاههم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تجاه'}],

 u'أوبي': [{'vocalized': u'أوبي', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بي', 'encletic': u'', 'type': u'ضمير', 'original': u'بي'}],

 u'وكوقتكما': [{'vocalized': u'وكوقتكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'كأخي': [{'vocalized': u'كأخي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'فعامة': [{'vocalized': u'فعامة', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'وبذلكما': [{'vocalized': u'وبذلكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'لجنبهما': [{'vocalized': u'لجنبهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'أفخلفك': [{'vocalized': u'أفخلفك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'وحاشانا': [{'vocalized': u'وحاشانا', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'حاشا'}],

 u'فمثلها': [{'vocalized': u'فمثلها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'فكغروبك': [{'vocalized': u'فكغروبك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'فأخوها': [{'vocalized': u'فأخوها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخو'}],

 u'فكغروبه': [{'vocalized': u'فكغروبه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'أولذلكما': [{'vocalized': u'أولذلكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'فكغروبي': [{'vocalized': u'فكغروبي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'فكغروبي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'فكجنوبهن': [{'vocalized': u'فكجنوبهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فكجنوبهم': [{'vocalized': u'فكجنوبهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وحينك': [{'vocalized': u'وحينك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حين'}],

 u'فبلحظته': [{'vocalized': u'فبلحظته', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'بشطركن': [{'vocalized': u'بشطركن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'بشطركم': [{'vocalized': u'بشطركم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'ولشطرهما': [{'vocalized': u'ولشطرهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'فبلحظتك': [{'vocalized': u'فبلحظتك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبأيكن': [{'vocalized': u'فبأيكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'فبأيكم': [{'vocalized': u'فبأيكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'فلليلهم': [{'vocalized': u'فلليلهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'فبلحظتي': [{'vocalized': u'فبلحظتي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'فبلحظتي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلليلهن': [{'vocalized': u'فلليلهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'فكهذي': [{'vocalized': u'فكهذي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'أوبحسبهما': [{'vocalized': u'أوبحسبهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'وكليلنا': [{'vocalized': u'وكليلنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'أفلسويهما': [{'vocalized': u'أفلسويهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فلعين': [{'vocalized': u'فلعين', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعين', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'فكهذه': [{'vocalized': u'فكهذه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'وحموي': [{'vocalized': u'وحموي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمو'},
 {'vocalized': u'وحموي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمو'}],

 u'أفكحسبهما': [{'vocalized': u'أفكحسبهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أفوقها': [{'vocalized': u'أفوقها', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'وحماهما': [{'vocalized': u'وحماهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حما'}],

 u'فكأكثركن': [{'vocalized': u'فكأكثركن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكأكثركم': [{'vocalized': u'فكأكثركم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فأيكما': [{'vocalized': u'فأيكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'لذويه': [{'vocalized': u'لذويه', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفبنفسها': [{'vocalized': u'أفبنفسها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلعليكما': [{'vocalized': u'أفلعليكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'لذويك': [{'vocalized': u'لذويك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'أوكشبه': [{'vocalized': u'أوكشبه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'ففقط': [{'vocalized': u'ففقط', 'procletic': u'ف-', 'tags': u'حرف;;عطف', 'stem': u'فقط', 'encletic': u'', 'type': u'حرف', 'original': u'فقط'}],

 u'وحمي': [{'vocalized': u'وحمي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'وحمو': [{'vocalized': u'وحمو', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حمو', 'encletic': u'', 'type': u'اسم', 'original': u'حمو'}],

 u'أفكعامتي': [{'vocalized': u'أفكعامتي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفكعامتي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فلهاتي': [{'vocalized': u'فلهاتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'أفكعامته': [{'vocalized': u'أفكعامته', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'فلهاته': [{'vocalized': u'فلهاته', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'فكهذا': [{'vocalized': u'فكهذا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'أفوقهم': [{'vocalized': u'أفوقهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'وتحتها': [{'vocalized': u'وتحتها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'فكذينك': [{'vocalized': u'فكذينك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'فأخوهم': [{'vocalized': u'فأخوهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخو'}],

 u'أفكلي': [{'vocalized': u'أفكلي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'فأخوهن': [{'vocalized': u'فأخوهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخو'}],

 u'كأننا': [{'vocalized': u'كأننا', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأننا', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'وبسوي': [{'vocalized': u'وبسوي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'وبسوي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'وبسوى': [{'vocalized': u'وبسوى', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'ولأناكم': [{'vocalized': u'ولأناكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'ولأناكن': [{'vocalized': u'ولأناكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'أبشبههما': [{'vocalized': u'أبشبههما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'كأخينا': [{'vocalized': u'كأخينا', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'فلليلها': [{'vocalized': u'فلليلها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'أفحسبكما': [{'vocalized': u'أفحسبكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'فبكلهم': [{'vocalized': u'فبكلهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلهم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'فبكلهن': [{'vocalized': u'فبكلهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلهن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'وكهاذين': [{'vocalized': u'وكهاذين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أفبأجمعي': [{'vocalized': u'أفبأجمعي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفبأجمعي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'مثلهما': [{'vocalized': u'مثلهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'أفبأجمعه': [{'vocalized': u'أفبأجمعه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفبأجمعك': [{'vocalized': u'أفبأجمعك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفي': [{'vocalized': u'أفي', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'أولهن': [{'vocalized': u'أولهن', 'procletic': u'أ-و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'},
 {'vocalized': u'أولهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أولهم': [{'vocalized': u'أولهم', 'procletic': u'أ-و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'},
 {'vocalized': u'أولهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أولهي': [{'vocalized': u'أولهي', 'procletic': u'أ-و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'},
 {'vocalized': u'أولهي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'أولهو': [{'vocalized': u'أولهو', 'procletic': u'أ-و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'},
 {'vocalized': u'أولهو', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'فشمالهن': [{'vocalized': u'فشمالهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'فشمالهم': [{'vocalized': u'فشمالهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'وقتها': [{'vocalized': u'وقتها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'كهاته': [{'vocalized': u'كهاته', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'كهاتي': [{'vocalized': u'كهاتي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'وكزمان': [{'vocalized': u'وكزمان', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'أكثرك': [{'vocalized': u'أكثرك', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولعينهن': [{'vocalized': u'ولعينهن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'لفيهما': [{'vocalized': u'لفيهما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'فلازلن': [{'vocalized': u'فلازلن', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلن'}],

 u'أفكنحوه': [{'vocalized': u'أفكنحوه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'بعض': [{'vocalized': u'بعض', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'فبشطرها': [{'vocalized': u'فبشطرها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'فأناهما': [{'vocalized': u'فأناهما', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'أفلديكن': [{'vocalized': u'أفلديكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدى'}],

 u'وشهرهما': [{'vocalized': u'وشهرهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'فلتحتهما': [{'vocalized': u'فلتحتهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'أفكنحوي': [{'vocalized': u'أفكنحوي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أفكنحوي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'وبشهر': [{'vocalized': u'وبشهر', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'وقتهم': [{'vocalized': u'وقتهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'وقتهن': [{'vocalized': u'وقتهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'فكأعليك': [{'vocalized': u'فكأعليك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولعينها': [{'vocalized': u'ولعينها', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'وبهناك': [{'vocalized': u'وبهناك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'وكحسبهما': [{'vocalized': u'وكحسبهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأثناءهما': [{'vocalized': u'وكأثناءهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'أولجميعكم': [{'vocalized': u'أولجميعكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فبشطرهن': [{'vocalized': u'فبشطرهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'فبشطرهم': [{'vocalized': u'فبشطرهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'أولجميعكن': [{'vocalized': u'أولجميعكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'ولجميع': [{'vocalized': u'ولجميع', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميع', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميع', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميع', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'أفعليه': [{'vocalized': u'أفعليه', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'أكنحوكما': [{'vocalized': u'أكنحوكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'أفإنكما': [{'vocalized': u'أفإنكما', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'فبكلها': [{'vocalized': u'فبكلها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلها', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'ولحظتهن': [{'vocalized': u'ولحظتهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'بحسبه': [{'vocalized': u'بحسبه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'بحسبي': [{'vocalized': u'بحسبي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'بحسبي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'فلشبهكن': [{'vocalized': u'فلشبهكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلجميعك': [{'vocalized': u'أفلجميعك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أولها': [{'vocalized': u'أولها', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لها', 'encletic': u'', 'type': u'ضمير', 'original': u'لها'}],

 u'أفلجميعه': [{'vocalized': u'أفلجميعه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلجميعي': [{'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'وبأثناءهم': [{'vocalized': u'وبأثناءهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'فشمالها': [{'vocalized': u'فشمالها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'فبنحوهما': [{'vocalized': u'فبنحوهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'حولهن': [{'vocalized': u'حولهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حول'}],

 u'فعلي': [{'vocalized': u'فعلي', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'فعلي', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'أبنحونا': [{'vocalized': u'أبنحونا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'ولبات': [{'vocalized': u'ولبات', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'بات', 'encletic': u'', 'type': u'فعل', 'original': u'بات'}],

 u'أوخلفهما': [{'vocalized': u'أوخلفهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'فلساعتهن': [{'vocalized': u'فلساعتهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أبيهم': [{'vocalized': u'أبيهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'كمثلها': [{'vocalized': u'كمثلها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'أبيهن': [{'vocalized': u'أبيهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'أولازلن': [{'vocalized': u'أولازلن', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلن'}],

 u'بأبيهما': [{'vocalized': u'بأبيهما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'أيتكن': [{'vocalized': u'أيتكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'فحوالينا': [{'vocalized': u'فحوالينا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حوالى'}],

 u'فغرب': [{'vocalized': u'فغرب', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'فكعينهن': [{'vocalized': u'فكعينهن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'وبأجمعهما': [{'vocalized': u'وبأجمعهما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولنفسنا': [{'vocalized': u'ولنفسنا', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'د': [{'vocalized': u'د', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'د', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'د'}],

 u'وعندهما': [{'vocalized': u'وعندهما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عند'}],

 u'فلعامتهما': [{'vocalized': u'فلعامتهما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'فكمثلكما': [{'vocalized': u'فكمثلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'بأسفلي': [{'vocalized': u'بأسفلي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'بأسفلي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'أولفيكما': [{'vocalized': u'أولفيكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'ضمننا': [{'vocalized': u'ضمننا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ضمن'}],

 u'كغربك': [{'vocalized': u'كغربك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'عندهما': [{'vocalized': u'عندهما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عند'}],

 u'وببعضكما': [{'vocalized': u'وببعضكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبنفسنا': [{'vocalized': u'أوبنفسنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'فبفي': [{'vocalized': u'فبفي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'}],

 u'ألعليكما': [{'vocalized': u'ألعليكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'أولوراء': [{'vocalized': u'أولوراء', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'وأعليها': [{'vocalized': u'وأعليها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'أفبأجمعنا': [{'vocalized': u'أفبأجمعنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'أذلك': [{'vocalized': u'أذلك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'أكغيرنا': [{'vocalized': u'أكغيرنا', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أفأمامي': [{'vocalized': u'أفأمامي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'أفأمامي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'أفغيري': [{'vocalized': u'أفغيري', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفغيري', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'كمثلهن': [{'vocalized': u'كمثلهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'فلمثلكن': [{'vocalized': u'فلمثلكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'فلمثلكم': [{'vocalized': u'فلمثلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'كمثلهم': [{'vocalized': u'كمثلهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفأمامك': [{'vocalized': u'أفأمامك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'أفغيرك': [{'vocalized': u'أفغيرك', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'كغربي': [{'vocalized': u'كغربي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'كغربي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'أفأمامه': [{'vocalized': u'أفأمامه', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'أفغيره': [{'vocalized': u'أفغيره', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أفلحسبه': [{'vocalized': u'أفلحسبه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلحسبك': [{'vocalized': u'أفلحسبك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'أبهاذين': [{'vocalized': u'أبهاذين', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أفلحسبي': [{'vocalized': u'أفلحسبي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أفلحسبي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أفمثلهما': [{'vocalized': u'أفمثلهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلهؤلاء': [{'vocalized': u'أفلهؤلاء', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'كأكثرهما': [{'vocalized': u'كأكثرهما', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'وإياها': [{'vocalized': u'وإياها', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياها', 'encletic': u'', 'type': u'ضمير', 'original': u'إياها'}],

 u'وكسويهما': [{'vocalized': u'وكسويهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فوراءهما': [{'vocalized': u'فوراءهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'فخلاهم': [{'vocalized': u'فخلاهم', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'خلا'}],

 u'فخلاهن': [{'vocalized': u'فخلاهن', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'خلا'}],

 u'أكشبهكما': [{'vocalized': u'أكشبهكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'فأنه': [{'vocalized': u'فأنه', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'لشرقي': [{'vocalized': u'لشرقي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'لشرقي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'فأنك': [{'vocalized': u'فأنك', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'فشبههم': [{'vocalized': u'فشبههم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'فأني': [{'vocalized': u'فأني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فأني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'فأنى': [{'vocalized': u'فأنى', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أنى', 'encletic': u'', 'type': u'اسم', 'original': u'أنى'},
 {'vocalized': u'فأنى', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أنى', 'encletic': u'', 'type': u'اسم', 'original': u'أنى'}],

 u'فخلاها': [{'vocalized': u'فخلاها', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'خلا'}],

 u'بزمانكن': [{'vocalized': u'بزمانكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'لغير': [{'vocalized': u'لغير', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغير', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'بدونكما': [{'vocalized': u'بدونكما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بدون'}],

 u'فأنا': [{'vocalized': u'فأنا', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'فأنا', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'فشبهها': [{'vocalized': u'فشبهها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'بشهرهما': [{'vocalized': u'بشهرهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'أولإنها': [{'vocalized': u'أولإنها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'فأنت': [{'vocalized': u'فأنت', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'فأنت', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'فلزمانكما': [{'vocalized': u'فلزمانكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'لديكما': [{'vocalized': u'لديكما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدى'}],

 u'فلحميك': [{'vocalized': u'فلحميك', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'فلحميه': [{'vocalized': u'فلحميه', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'أفبأجمعكما': [{'vocalized': u'أفبأجمعكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبسويكن': [{'vocalized': u'وبسويكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'وبسويكم': [{'vocalized': u'وبسويكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'وبكلكما': [{'vocalized': u'وبكلكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلكما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'وكاللاتي': [{'vocalized': u'وكاللاتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'فكالألى': [{'vocalized': u'فكالألى', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'أفلخلفكما': [{'vocalized': u'أفلخلفكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'فكمثلي': [{'vocalized': u'فكمثلي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فكمثلي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'فكمثله': [{'vocalized': u'فكمثله', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'فكمثلك': [{'vocalized': u'فكمثلك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أكبعض': [{'vocalized': u'أكبعض', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'ولتلقاء': [{'vocalized': u'ولتلقاء', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أبعضكما': [{'vocalized': u'أبعضكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أولنفسها': [{'vocalized': u'أولنفسها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلوراءهما': [{'vocalized': u'أفلوراءهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'أكأجمعكما': [{'vocalized': u'أكأجمعكما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'والذين': [{'vocalized': u'والذين', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'فكغيرك': [{'vocalized': u'فكغيرك', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'أفلهو': [{'vocalized': u'أفلهو', 'procletic': u'أ-ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'},
 {'vocalized': u'أفلهو', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'فكغيره': [{'vocalized': u'فكغيره', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'كأبيي': [{'vocalized': u'كأبيي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'كأبيي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'غربك': [{'vocalized': u'غربك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'أفلهم': [{'vocalized': u'أفلهم', 'procletic': u'أ-ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'},
 {'vocalized': u'أفلهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'كأبيه': [{'vocalized': u'كأبيه', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'فكغيري': [{'vocalized': u'فكغيري', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فكغيري', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'فكأبيهما': [{'vocalized': u'فكأبيهما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'فحسبكم': [{'vocalized': u'فحسبكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'فحسبكن': [{'vocalized': u'فحسبكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'حاشاها': [{'vocalized': u'حاشاها', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'حاشا'}],

 u'لابنها': [{'vocalized': u'لابنها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'وبزمان': [{'vocalized': u'وبزمان', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'فقام': [{'vocalized': u'فقام', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'قام', 'encletic': u'', 'type': u'فعل', 'original': u'قام'}],

 u'ولشرقكما': [{'vocalized': u'ولشرقكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'أطالما': [{'vocalized': u'أطالما', 'procletic': u'أ-', 'tags': u'فعل;فعل جامد;استفهام', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'أفلخلفهم': [{'vocalized': u'أفلخلفهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'أولخلفهما': [{'vocalized': u'أولخلفهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'فبشهركن': [{'vocalized': u'فبشهركن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'فبشهركم': [{'vocalized': u'فبشهركم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'أفنفسهما': [{'vocalized': u'أفنفسهما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'أبكلنا': [{'vocalized': u'أبكلنا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلنا', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'حاشاهم': [{'vocalized': u'حاشاهم', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'حاشا'}],

 u'حاشاهن': [{'vocalized': u'حاشاهن', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'حاشا'}],

 u'وبتلقاءنا': [{'vocalized': u'وبتلقاءنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكعامتكن': [{'vocalized': u'وكعامتكن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'فليتهما': [{'vocalized': u'فليتهما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-هما', 'type': u'حرف', 'original': u'ليت'}],

 u'أفوراءكم': [{'vocalized': u'أفوراءكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'كشهرنا': [{'vocalized': u'كشهرنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'وفاكما': [{'vocalized': u'وفاكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فا'}],

 u'فلإن': [{'vocalized': u'فلإن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'فلإن', 'procletic': u'ف-ل-', 'tags': u'حرف;المشبهة بليس;مجرور;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'لوراءهن': [{'vocalized': u'لوراءهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'وكأيه': [{'vocalized': u'وكأيه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'وكأين': [{'vocalized': u'وكأين', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'كأين', 'encletic': u'', 'type': u'اسم', 'original': u'كأين'},
 {'vocalized': u'وكأين', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'كأين', 'encletic': u'', 'type': u'اسم', 'original': u'كأين'}],

 u'أولخلفكما': [{'vocalized': u'أولخلفكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'وأثناءهما': [{'vocalized': u'وأثناءهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكأيي': [{'vocalized': u'وكأيي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وكأيي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'فغيركم': [{'vocalized': u'فغيركم', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أإنكما': [{'vocalized': u'أإنكما', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'لأنكن': [{'vocalized': u'لأنكن', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'لأنكم': [{'vocalized': u'لأنكم', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'أولنفسهن': [{'vocalized': u'أولنفسهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'وكذاتكما': [{'vocalized': u'وكذاتكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'أولنفسهم': [{'vocalized': u'أولنفسهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'فبجميعهما': [{'vocalized': u'فبجميعهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعهما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلكأنهما': [{'vocalized': u'أفلكأنهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'أنتم': [{'vocalized': u'أنتم', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'فلعينها': [{'vocalized': u'فلعينها', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'أفأنتما': [{'vocalized': u'أفأنتما', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'فحوالي': [{'vocalized': u'فحوالي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حوالى'},
 {'vocalized': u'فحوالي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حوالى'}],

 u'فهذان': [{'vocalized': u'فهذان', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذان', 'encletic': u'', 'type': u'اسم', 'original': u'هذان'}],

 u'أفلها': [{'vocalized': u'أفلها', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لها', 'encletic': u'', 'type': u'ضمير', 'original': u'لها'}],

 u'أخوهما': [{'vocalized': u'أخوهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخو'}],

 u'وشرق': [{'vocalized': u'وشرق', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'ونفسها': [{'vocalized': u'ونفسها', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أناهما': [{'vocalized': u'أناهما', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'وهذه': [{'vocalized': u'وهذه', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'حوالي': [{'vocalized': u'حوالي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حوالى'},
 {'vocalized': u'حوالي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حوالى'}],

 u'ألعامتكم': [{'vocalized': u'ألعامتكم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'وهذي': [{'vocalized': u'وهذي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'وكشهركم': [{'vocalized': u'وكشهركم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'ألعامتكن': [{'vocalized': u'ألعامتكن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'حوالى': [{'vocalized': u'حوالى', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'حوالى', 'encletic': u'', 'type': u'اسم', 'original': u'حوالى'}],

 u'فحما': [{'vocalized': u'فحما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حما', 'encletic': u'', 'type': u'اسم', 'original': u'حما'}],

 u'أومعها': [{'vocalized': u'أومعها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'ولوراءكما': [{'vocalized': u'ولوراءكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'أوأناك': [{'vocalized': u'أوأناك', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'وحبذا': [{'vocalized': u'وحبذا', 'procletic': u'و-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'حبذا', 'encletic': u'', 'type': u'فعل', 'original': u'حبذا'}],

 u'أوأناه': [{'vocalized': u'أوأناه', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'لأيتهما': [{'vocalized': u'لأيتهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'فغربكم': [{'vocalized': u'فغربكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'وكنحوها': [{'vocalized': u'وكنحوها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'سوف': [{'vocalized': u'سوف', 'procletic': u'', 'tags': u'حرف;حرف استقبال', 'stem': u'سوف', 'encletic': u'', 'type': u'حرف', 'original': u'سوف'}],

 u'فبغروبها': [{'vocalized': u'فبغروبها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'فلإليهم': [{'vocalized': u'فلإليهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'فلإليهن': [{'vocalized': u'فلإليهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'وبتين': [{'vocalized': u'وبتين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'فكجنوبكما': [{'vocalized': u'فكجنوبكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبذات': [{'vocalized': u'فبذات', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'فإن': [{'vocalized': u'فإن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'فإن', 'procletic': u'ف-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'فإن', 'procletic': u'ف-', 'tags': u'حرف;حرف جزم;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'فإن', 'procletic': u'ف-', 'tags': u'حرف;حرف شرط;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'فإي': [{'vocalized': u'فإي', 'procletic': u'ف-', 'tags': u'حرف;حرف جواب;عطف', 'stem': u'إي', 'encletic': u'', 'type': u'حرف', 'original': u'إي'}],

 u'أفيكن': [{'vocalized': u'أفيكن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'أكأننا': [{'vocalized': u'أكأننا', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'أفيكم': [{'vocalized': u'أفيكم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'فإذ': [{'vocalized': u'فإذ', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'إذ', 'encletic': u'', 'type': u'اسم', 'original': u'إذ'},
 {'vocalized': u'فإذ', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'إذ', 'encletic': u'', 'type': u'اسم', 'original': u'إذ'}],

 u'وكنحوهن': [{'vocalized': u'وكنحوهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'أوهذا': [{'vocalized': u'أوهذا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'أفحسبنا': [{'vocalized': u'أفحسبنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'وكنحوهم': [{'vocalized': u'وكنحوهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'فبغروبهم': [{'vocalized': u'فبغروبهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'فبغروبهن': [{'vocalized': u'فبغروبهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'فلإليها': [{'vocalized': u'فلإليها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'فكشبهه': [{'vocalized': u'فكشبهه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'بعدئذ': [{'vocalized': u'بعدئذ', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'بعدئذ', 'encletic': u'', 'type': u'اسم', 'original': u'بعدئذ'}],

 u'فكشبهك': [{'vocalized': u'فكشبهك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أفشمال': [{'vocalized': u'أفشمال', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'نفسكم': [{'vocalized': u'نفسكم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'فكشبهي': [{'vocalized': u'فكشبهي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فكشبهي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'ونفسهم': [{'vocalized': u'ونفسهم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'فحمو': [{'vocalized': u'فحمو', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حمو', 'encletic': u'', 'type': u'اسم', 'original': u'حمو'}],

 u'وللحظة': [{'vocalized': u'وللحظة', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'فحمي': [{'vocalized': u'فحمي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'وهذا': [{'vocalized': u'وهذا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'فشمالكن': [{'vocalized': u'فشمالكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'فشرقكما': [{'vocalized': u'فشرقكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'وكنفسهم': [{'vocalized': u'وكنفسهم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'أبأولئكم': [{'vocalized': u'أبأولئكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'وكنفسهن': [{'vocalized': u'وكنفسهن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أومعهم': [{'vocalized': u'أومعهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'أومعهن': [{'vocalized': u'أومعهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'لمنهما': [{'vocalized': u'لمنهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'ولعينكما': [{'vocalized': u'ولعينكما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'أفكأجمعكما': [{'vocalized': u'أفكأجمعكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوكجميعي': [{'vocalized': u'أوكجميعي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'فلدنهما': [{'vocalized': u'فلدنهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدن'}],

 u'فحولك': [{'vocalized': u'فحولك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حول'}],

 u'ذووكم': [{'vocalized': u'ذووكم', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوو'}],

 u'ذووكن': [{'vocalized': u'ذووكن', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوو'}],

 u'فكذين': [{'vocalized': u'فكذين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'أوجميعهن': [{'vocalized': u'أوجميعهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعهن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'أوجميعهم': [{'vocalized': u'أوجميعهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعهم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'باللواتي': [{'vocalized': u'باللواتي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'ولزمانهم': [{'vocalized': u'ولزمانهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'فلغربها': [{'vocalized': u'فلغربها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'ولزمانهن': [{'vocalized': u'ولزمانهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'فمابرحوا': [{'vocalized': u'فمابرحوا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحوا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحوا'}],

 u'وفاهما': [{'vocalized': u'وفاهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فا'}],

 u'فلازالتا': [{'vocalized': u'فلازالتا', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالتا'}],

 u'فلحار': [{'vocalized': u'فلحار', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'حار', 'encletic': u'', 'type': u'فعل', 'original': u'حار'}],

 u'وككلي': [{'vocalized': u'وككلي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'هذين': [{'vocalized': u'هذين', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'أفأناكن': [{'vocalized': u'أفأناكن', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'وكذاتهم': [{'vocalized': u'وكذاتهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'فلشبهه': [{'vocalized': u'فلشبهه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'بأسفل': [{'vocalized': u'بأسفل', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'أولذواتي': [{'vocalized': u'أولذواتي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'فلشبهك': [{'vocalized': u'فلشبهك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'فلشبهي': [{'vocalized': u'فلشبهي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'بنفسك': [{'vocalized': u'بنفسك', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'وأجمعكما': [{'vocalized': u'وأجمعكما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وعداها': [{'vocalized': u'وعداها', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'عدا'}],

 u'بنفسه': [{'vocalized': u'بنفسه', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'بنفسي': [{'vocalized': u'بنفسي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'بنفسي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أبحسبنا': [{'vocalized': u'أبحسبنا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'فلبعضك': [{'vocalized': u'فلبعضك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فلبعضه': [{'vocalized': u'فلبعضه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'وحسبكم': [{'vocalized': u'وحسبكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أوكذواتي': [{'vocalized': u'أوكذواتي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'فلبعضي': [{'vocalized': u'فلبعضي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فبأسفلكما': [{'vocalized': u'فبأسفلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفكذانك': [{'vocalized': u'أفكذانك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أوسوى': [{'vocalized': u'أوسوى', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أنفسكما': [{'vocalized': u'أنفسكما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'أوسوي': [{'vocalized': u'أوسوي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أوسوي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'ذيت': [{'vocalized': u'ذيت', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'ذيت', 'encletic': u'', 'type': u'اسم', 'original': u'ذيت'}],

 u'كهناك': [{'vocalized': u'كهناك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أوجميعها': [{'vocalized': u'أوجميعها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعها', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'ولعامتنا': [{'vocalized': u'ولعامتنا', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلشمالكم': [{'vocalized': u'أفلشمالكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'فلغربهن': [{'vocalized': u'فلغربهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'ولزمانها': [{'vocalized': u'ولزمانها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'فلغربهم': [{'vocalized': u'فلغربهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'قلما': [{'vocalized': u'قلما', 'procletic': u'', 'tags': u'فعل;فعل جامد', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'أفبهؤلاء': [{'vocalized': u'أفبهؤلاء', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'ألذاك': [{'vocalized': u'ألذاك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'أولازال': [{'vocalized': u'أولازال', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازال', 'encletic': u'', 'type': u'فعل', 'original': u'لازال'}],

 u'فمازلتما': [{'vocalized': u'فمازلتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتما'},
 {'vocalized': u'فمازلتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتما'}],

 u'أفلعامتكم': [{'vocalized': u'أفلعامتكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أحسبنا': [{'vocalized': u'أحسبنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلعامتكن': [{'vocalized': u'أفلعامتكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أوبضعهن': [{'vocalized': u'أوبضعهن', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بضع'}],

 u'لتلقاءهما': [{'vocalized': u'لتلقاءهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبنحوها': [{'vocalized': u'فبنحوها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'فلأعليك': [{'vocalized': u'فلأعليك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولذينك': [{'vocalized': u'ولذينك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'فلازلنا': [{'vocalized': u'فلازلنا', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'لازلنا'}],

 u'فلأيها': [{'vocalized': u'فلأيها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'أبسويها': [{'vocalized': u'أبسويها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'وكعينهن': [{'vocalized': u'وكعينهن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'وحيننا': [{'vocalized': u'وحيننا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حين'}],

 u'فبشبه': [{'vocalized': u'فبشبه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'أيان': [{'vocalized': u'أيان', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'},
 {'vocalized': u'أيان', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'},
 {'vocalized': u'أيان', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'}],

 u'وبوقتنا': [{'vocalized': u'وبوقتنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'حاشاهما': [{'vocalized': u'حاشاهما', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'حاشا'}],

 u'وكذين': [{'vocalized': u'وكذين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'شمالها': [{'vocalized': u'شمالها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'أوبعامتهن': [{'vocalized': u'أوبعامتهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'أوبعامتهم': [{'vocalized': u'أوبعامتهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أبسويهم': [{'vocalized': u'أبسويهم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أبسويهن': [{'vocalized': u'أبسويهن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'وكعينها': [{'vocalized': u'وكعينها', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فبأكثرهما': [{'vocalized': u'فبأكثرهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولشمالكن': [{'vocalized': u'ولشمالكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'لأسفلكن': [{'vocalized': u'لأسفلكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'لأسفلكم': [{'vocalized': u'لأسفلكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'فلغربي': [{'vocalized': u'فلغربي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'فلغربي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'وكزمانكن': [{'vocalized': u'وكزمانكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'أوبعامتها': [{'vocalized': u'أوبعامتها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'وإياهن': [{'vocalized': u'وإياهن', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياهن', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهن'}],

 u'أبغيركما': [{'vocalized': u'أبغيركما', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'وبهما': [{'vocalized': u'وبهما', 'procletic': u'و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'وفوقكن': [{'vocalized': u'وفوقكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'وكهؤلاء': [{'vocalized': u'وكهؤلاء', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'يمينها': [{'vocalized': u'يمينها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'وكأولئك': [{'vocalized': u'وكأولئك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'بشطرهما': [{'vocalized': u'بشطرهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'فلتبدل': [{'vocalized': u'فلتبدل', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'تبدل', 'encletic': u'', 'type': u'فعل', 'original': u'تبدل'}],

 u'فبنحوهن': [{'vocalized': u'فبنحوهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'فوقكم': [{'vocalized': u'فوقكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'فبنحوهم': [{'vocalized': u'فبنحوهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'فبأجمعه': [{'vocalized': u'فبأجمعه', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلأيهن': [{'vocalized': u'فلأيهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'فلأيهم': [{'vocalized': u'فلأيهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'أكأولالك': [{'vocalized': u'أكأولالك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فبحمي': [{'vocalized': u'فبحمي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'فبجنوب': [{'vocalized': u'فبجنوب', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبأسفلكن': [{'vocalized': u'فبأسفلكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وخلفي': [{'vocalized': u'وخلفي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فكأجمعهما': [{'vocalized': u'فكأجمعهما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأناه': [{'vocalized': u'وأناه', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'أنحونا': [{'vocalized': u'أنحونا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'لابنكن': [{'vocalized': u'لابنكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'لابنكم': [{'vocalized': u'لابنكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'أكعامتكن': [{'vocalized': u'أكعامتكن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أكعامتكم': [{'vocalized': u'أكعامتكم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أنفسهن': [{'vocalized': u'أنفسهن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'لمثلهن': [{'vocalized': u'لمثلهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'فلعسى': [{'vocalized': u'فلعسى', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'عسى', 'encletic': u'', 'type': u'فعل', 'original': u'عسى'}],

 u'أفلأنتما': [{'vocalized': u'أفلأنتما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'وبأيكم': [{'vocalized': u'وبأيكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'وبأيكن': [{'vocalized': u'وبأيكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'فبما': [{'vocalized': u'فبما', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بما', 'encletic': u'', 'type': u'اسم', 'original': u'بما'}],

 u'ولشطر': [{'vocalized': u'ولشطر', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'وأسفلهم': [{'vocalized': u'وأسفلهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'ألفوقها': [{'vocalized': u'ألفوقها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'ولأثناءنا': [{'vocalized': u'ولأثناءنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'أكجميعها': [{'vocalized': u'أكجميعها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعها', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'وكليلي': [{'vocalized': u'وكليلي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'وكليلي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'ذين': [{'vocalized': u'ذين', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'فبمن': [{'vocalized': u'فبمن', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بمن', 'encletic': u'', 'type': u'اسم', 'original': u'بمن'},
 {'vocalized': u'فبمن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'وغيري': [{'vocalized': u'وغيري', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'وغيري', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أفلذين': [{'vocalized': u'أفلذين', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'أيكما': [{'vocalized': u'أيكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'ولحظة': [{'vocalized': u'ولحظة', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'أكجميعهم': [{'vocalized': u'أكجميعهم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعهم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'وغيرك': [{'vocalized': u'وغيرك', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'أكجميعهن': [{'vocalized': u'أكجميعهن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعهن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'وغيره': [{'vocalized': u'وغيره', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'وكلحظتهما': [{'vocalized': u'وكلحظتهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'وكأبيها': [{'vocalized': u'وكأبيها', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'فلشبههما': [{'vocalized': u'فلشبههما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبههما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'أوكحسبهم': [{'vocalized': u'أوكحسبهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فليلهم': [{'vocalized': u'فليلهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'فماداما': [{'vocalized': u'فماداما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماداما', 'encletic': u'', 'type': u'فعل', 'original': u'ماداما'}],

 u'أكمثلي': [{'vocalized': u'أكمثلي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أكمثلي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلازالوا': [{'vocalized': u'أفلازالوا', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالوا'}],

 u'مادامتا': [{'vocalized': u'مادامتا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادامتا', 'encletic': u'', 'type': u'فعل', 'original': u'مادامتا'}],

 u'ومازالوا': [{'vocalized': u'ومازالوا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالوا'}],

 u'فلوراءنا': [{'vocalized': u'فلوراءنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'وعليك': [{'vocalized': u'وعليك', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'عليك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'عليك'},
 {'vocalized': u'وعليك', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'شهركن': [{'vocalized': u'شهركن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'وعليه': [{'vocalized': u'وعليه', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'لأعليهم': [{'vocalized': u'لأعليهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'لأعليهن': [{'vocalized': u'لأعليهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'أوبذينك': [{'vocalized': u'أوبذينك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'وكلنا': [{'vocalized': u'وكلنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلنا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'ولأمامها': [{'vocalized': u'ولأمامها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'أفيميني': [{'vocalized': u'أفيميني', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'أفيميني', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'لمننا': [{'vocalized': u'لمننا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'وذويهم': [{'vocalized': u'وذويهم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'وذويهن': [{'vocalized': u'وذويهن', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'مافتئ': [{'vocalized': u'مافتئ', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئ', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئ'}],

 u'كزمانهم': [{'vocalized': u'كزمانهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'لأخيي': [{'vocalized': u'لأخيي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'لأخيي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'كزمانهن': [{'vocalized': u'كزمانهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'فمثلكم': [{'vocalized': u'فمثلكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فمثلكن': [{'vocalized': u'فمثلكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'لأخيه': [{'vocalized': u'لأخيه', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'لأخيك': [{'vocalized': u'لأخيك', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'ألغيركم': [{'vocalized': u'ألغيركم', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيركم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'ألغيركن': [{'vocalized': u'ألغيركن', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيركن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'أولجميع': [{'vocalized': u'أولجميع', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميع', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميع', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميع', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'أعيني': [{'vocalized': u'أعيني', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أعيني', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وأناي': [{'vocalized': u'وأناي', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'وأناي', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'فلذوي': [{'vocalized': u'فلذوي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'أعينك': [{'vocalized': u'أعينك', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'فلكأن': [{'vocalized': u'فلكأن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'فلتحتي': [{'vocalized': u'فلتحتي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'فلتحتي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلذواتي': [{'vocalized': u'أفلذواتي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'فلعينه': [{'vocalized': u'فلعينه', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'كشبهكما': [{'vocalized': u'كشبهكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'فلعيني': [{'vocalized': u'فلعيني', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعيني', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعيني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعيني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'كحميهما': [{'vocalized': u'كحميهما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'فلتحته': [{'vocalized': u'فلتحته', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلأجمعكن': [{'vocalized': u'أفلأجمعكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلأجمعكم': [{'vocalized': u'أفلأجمعكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولفيكما': [{'vocalized': u'ولفيكما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'ولأعليهما': [{'vocalized': u'ولأعليهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبتلقاءهما': [{'vocalized': u'فبتلقاءهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'بعدها': [{'vocalized': u'بعدها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعد'}],

 u'فلأوشك': [{'vocalized': u'فلأوشك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أوشك', 'encletic': u'', 'type': u'فعل', 'original': u'أوشك'}],

 u'فلأيتكم': [{'vocalized': u'فلأيتكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'فلأيتكن': [{'vocalized': u'فلأيتكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'بزماني': [{'vocalized': u'بزماني', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'بزماني', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'لأعليها': [{'vocalized': u'لأعليها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولأجمع': [{'vocalized': u'ولأجمع', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمع', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولأمامهم': [{'vocalized': u'ولأمامهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'بزمانك': [{'vocalized': u'بزمانك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'ولأمامهن': [{'vocalized': u'ولأمامهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'بزمانه': [{'vocalized': u'بزمانه', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'لذي': [{'vocalized': u'لذي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'وذويها': [{'vocalized': u'وذويها', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولغروبكما': [{'vocalized': u'ولغروبكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'فكجنوبكن': [{'vocalized': u'فكجنوبكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فكجنوبكم': [{'vocalized': u'فكجنوبكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوبشبه': [{'vocalized': u'أوبشبه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'ذووكما': [{'vocalized': u'ذووكما', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوو'}],

 u'ولأناهن': [{'vocalized': u'ولأناهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'ألمنهن': [{'vocalized': u'ألمنهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'وعينهن': [{'vocalized': u'وعينهن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'أولالك': [{'vocalized': u'أولالك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'وكشبه': [{'vocalized': u'وكشبه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'وكأبيهن': [{'vocalized': u'وكأبيهن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'أفلسوينا': [{'vocalized': u'أفلسوينا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'بشطرهن': [{'vocalized': u'بشطرهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'بشطرهم': [{'vocalized': u'بشطرهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'فكأثناءكما': [{'vocalized': u'فكأثناءكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'لأنتم': [{'vocalized': u'لأنتم', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'لأنتن': [{'vocalized': u'لأنتن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'لهاتين': [{'vocalized': u'لهاتين', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'ألمنهم': [{'vocalized': u'ألمنهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فببعضهم': [{'vocalized': u'فببعضهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أبعامتهما': [{'vocalized': u'أبعامتهما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'وجعل': [{'vocalized': u'وجعل', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'جعل', 'encletic': u'', 'type': u'فعل', 'original': u'جعل'}],

 u'أفلازالتا': [{'vocalized': u'أفلازالتا', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالتا'}],

 u'أوبعيننا': [{'vocalized': u'أوبعيننا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'فكعامتكم': [{'vocalized': u'فكعامتكم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'فكعامتكن': [{'vocalized': u'فكعامتكن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'وغربكن': [{'vocalized': u'وغربكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'غيركما': [{'vocalized': u'غيركما', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'ألكما': [{'vocalized': u'ألكما', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'لكما', 'encletic': u'', 'type': u'ضمير', 'original': u'لكما'}],

 u'فلكنهما': [{'vocalized': u'فلكنهما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنهما', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لكن'}],

 u'لبعض': [{'vocalized': u'لبعض', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعض', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'فألا': [{'vocalized': u'فألا', 'procletic': u'ف-', 'tags': u'حرف;حرف عرض;عطف', 'stem': u'ألا', 'encletic': u'', 'type': u'حرف', 'original': u'ألا'}],

 u'وأقلنا': [{'vocalized': u'وأقلنا', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'لزمانكما': [{'vocalized': u'لزمانكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'فنفسكن': [{'vocalized': u'فنفسكن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'فلأعلى': [{'vocalized': u'فلأعلى', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'أفكعينكما': [{'vocalized': u'أفكعينكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فنفسكم': [{'vocalized': u'فنفسكم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'أفوقكم': [{'vocalized': u'أفوقكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'فكساعتها': [{'vocalized': u'فكساعتها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'فخلالنا': [{'vocalized': u'فخلالنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلال'}],

 u'ولأناها': [{'vocalized': u'ولأناها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'أبضعي': [{'vocalized': u'أبضعي', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'},
 {'vocalized': u'أبضعي', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'}],

 u'فأخوكم': [{'vocalized': u'فأخوكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخو'}],

 u'فأخوكن': [{'vocalized': u'فأخوكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخو'}],

 u'وتينك': [{'vocalized': u'وتينك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'وعينها': [{'vocalized': u'وعينها', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'أوكنفسي': [{'vocalized': u'أوكنفسي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أوكنفسي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أولدينا': [{'vocalized': u'أولدينا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدى'}],

 u'أوكنفسك': [{'vocalized': u'أوكنفسك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'بشطرها': [{'vocalized': u'بشطرها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'ليسوا': [{'vocalized': u'ليسوا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ليسوا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسوا'}],

 u'أوكنفسه': [{'vocalized': u'أوكنفسه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'ومعها': [{'vocalized': u'ومعها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'فأبدا': [{'vocalized': u'فأبدا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أبدا', 'encletic': u'', 'type': u'اسم', 'original': u'أبدا'}],

 u'فمازلن': [{'vocalized': u'فمازلن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلن', 'encletic': u'', 'type': u'فعل', 'original': u'مازلن'}],

 u'كجنب': [{'vocalized': u'كجنب', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'ولأسفلنا': [{'vocalized': u'ولأسفلنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوبعامتهما': [{'vocalized': u'أوبعامتهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلمن': [{'vocalized': u'أفلمن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'أفلمن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'وشرقها': [{'vocalized': u'وشرقها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'وليستا': [{'vocalized': u'وليستا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليستا', 'encletic': u'', 'type': u'فعل', 'original': u'ليستا'}],

 u'وكأكثركما': [{'vocalized': u'وكأكثركما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'أكمثلكن': [{'vocalized': u'أكمثلكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'وكتلك': [{'vocalized': u'وكتلك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'فغروبه': [{'vocalized': u'فغروبه', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'أولإلينا': [{'vocalized': u'أولإلينا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'أفشبهي': [{'vocalized': u'أفشبهي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفشبهي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'أفشبهه': [{'vocalized': u'أفشبهه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'ألشبهكما': [{'vocalized': u'ألشبهكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'أفشبهك': [{'vocalized': u'أفشبهك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أففيهم': [{'vocalized': u'أففيهم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'كشطركن': [{'vocalized': u'كشطركن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'أبيكم': [{'vocalized': u'أبيكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'أولنحوهما': [{'vocalized': u'أولنحوهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'كشطركم': [{'vocalized': u'كشطركم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'أأجمعها': [{'vocalized': u'أأجمعها', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'أشبههم': [{'vocalized': u'أشبههم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'أأمامنا': [{'vocalized': u'أأمامنا', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'بليل': [{'vocalized': u'بليل', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'أشبههن': [{'vocalized': u'أشبههن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أوشمالكم': [{'vocalized': u'أوشمالكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'أوشمالكن': [{'vocalized': u'أوشمالكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'فبتلقاءنا': [{'vocalized': u'فبتلقاءنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ق': [{'vocalized': u'ق', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ق', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ق'}],

 u'فلجنبك': [{'vocalized': u'فلجنبك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'فكأكثرهن': [{'vocalized': u'فكأكثرهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكأكثرهم': [{'vocalized': u'فكأكثرهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلأقلكن': [{'vocalized': u'فلأقلكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'أففيها': [{'vocalized': u'أففيها', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'فلأقلكم': [{'vocalized': u'فلأقلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'ألأمامهم': [{'vocalized': u'ألأمامهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'ألأمامهن': [{'vocalized': u'ألأمامهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'أأجمعهن': [{'vocalized': u'أأجمعهن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفشمالي': [{'vocalized': u'أفشمالي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'أفشمالي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'أليس': [{'vocalized': u'أليس', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'ليس', 'encletic': u'', 'type': u'فعل', 'original': u'ليس'}],

 u'أأجمعهم': [{'vocalized': u'أأجمعهم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفشماله': [{'vocalized': u'أفشماله', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'أبوكن': [{'vocalized': u'أبوكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبو'}],

 u'أشبهها': [{'vocalized': u'أشبهها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'أفشمالك': [{'vocalized': u'أفشمالك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'لأعليك': [{'vocalized': u'لأعليك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'بذلكما': [{'vocalized': u'بذلكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'وجميعي': [{'vocalized': u'وجميعي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'ومعهن': [{'vocalized': u'ومعهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'فمازلت': [{'vocalized': u'فمازلت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'},
 {'vocalized': u'فمازلت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'},
 {'vocalized': u'فمازلت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'}],

 u'ومعهم': [{'vocalized': u'ومعهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'وجميعك': [{'vocalized': u'وجميعك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعك', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أوكأولئك': [{'vocalized': u'أوكأولئك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'وجميعه': [{'vocalized': u'وجميعه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعه', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'وشرقهن': [{'vocalized': u'وشرقهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'أفلما': [{'vocalized': u'أفلما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'اسم', 'original': u'لما'},
 {'vocalized': u'أفلما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جزم;عطف;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'},
 {'vocalized': u'أفلما', 'procletic': u'أ-ف-', 'tags': u'حرف;ظرف;عطف;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'}],

 u'وشرقهم': [{'vocalized': u'وشرقهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'أكهن': [{'vocalized': u'أكهن', 'procletic': u'أ-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'فأناك': [{'vocalized': u'فأناك', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'فأناه': [{'vocalized': u'فأناه', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'أكعينهم': [{'vocalized': u'أكعينهم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'ولعامتي': [{'vocalized': u'ولعامتي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'وكجميعك': [{'vocalized': u'وكجميعك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعك', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'وكجميعه': [{'vocalized': u'وكجميعه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعه', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'وكجميعي': [{'vocalized': u'وكجميعي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'ولعامتك': [{'vocalized': u'ولعامتك', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'أجميعكما': [{'vocalized': u'أجميعكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعكما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'ولعامته': [{'vocalized': u'ولعامته', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامته', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'فابنكم': [{'vocalized': u'فابنكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'وبعامتكم': [{'vocalized': u'وبعامتكم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'وبعامتكن': [{'vocalized': u'وبعامتكن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'فابنكن': [{'vocalized': u'فابنكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'أوهذان': [{'vocalized': u'أوهذان', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هذان', 'encletic': u'', 'type': u'اسم', 'original': u'هذان'}],

 u'وكنحوهما': [{'vocalized': u'وكنحوهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'وكلا': [{'vocalized': u'وكلا', 'procletic': u'و-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'},
 {'vocalized': u'وكلا', 'procletic': u'و-', 'tags': u'حرف;حرف ردع;عطف', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'}],

 u'ذوينا': [{'vocalized': u'ذوينا', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'فبوقتهن': [{'vocalized': u'فبوقتهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'ألفيهن': [{'vocalized': u'ألفيهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'ألفيهم': [{'vocalized': u'ألفيهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'فاكما': [{'vocalized': u'فاكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فا'}],

 u'وعامتهما': [{'vocalized': u'وعامتهما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'لوراءك': [{'vocalized': u'لوراءك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'وكأخيهم': [{'vocalized': u'وكأخيهم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'فبوقتهم': [{'vocalized': u'فبوقتهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'أفبعامتكن': [{'vocalized': u'أفبعامتكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'ألفيها': [{'vocalized': u'ألفيها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'لمنهن': [{'vocalized': u'لمنهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'ولكأني': [{'vocalized': u'ولكأني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'ولكأني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'للذين': [{'vocalized': u'للذين', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'},
 {'vocalized': u'للذين', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'ولكأنك': [{'vocalized': u'ولكأنك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'ولكأنه': [{'vocalized': u'ولكأنه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'زمانكما': [{'vocalized': u'زمانكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'فكحميك': [{'vocalized': u'فكحميك', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'أكعينها': [{'vocalized': u'أكعينها', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'لعامتنا': [{'vocalized': u'لعامتنا', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'فكحميه': [{'vocalized': u'فكحميه', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'فكحميي': [{'vocalized': u'فكحميي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'فكحميي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'فلسويك': [{'vocalized': u'فلسويك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فلسويه': [{'vocalized': u'فلسويه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'وكلي': [{'vocalized': u'وكلي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'لشهرهما': [{'vocalized': u'لشهرهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'خلفنا': [{'vocalized': u'خلفنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'وكلك': [{'vocalized': u'وكلك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلك', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'فحواليك': [{'vocalized': u'فحواليك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حوالى'}],

 u'وكله': [{'vocalized': u'وكله', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكله', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'لأكثركم': [{'vocalized': u'لأكثركم', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'لأكثركن': [{'vocalized': u'لأكثركن', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكذوي': [{'vocalized': u'فكذوي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'أكذلك': [{'vocalized': u'أكذلك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'},
 {'vocalized': u'أكذلك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'كذلك', 'encletic': u'', 'type': u'اسم', 'original': u'كذلك'}],

 u'لأيتها': [{'vocalized': u'لأيتها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'أكعينه': [{'vocalized': u'أكعينه', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أولإنهما': [{'vocalized': u'أولإنهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'وكنفسكما': [{'vocalized': u'وكنفسكما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'أكعينك': [{'vocalized': u'أكعينك', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أولأمامكن': [{'vocalized': u'أولأمامكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'كنحوي': [{'vocalized': u'كنحوي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'أفبسويهم': [{'vocalized': u'أفبسويهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أفبسويهن': [{'vocalized': u'أفبسويهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'وبشهرهما': [{'vocalized': u'وبشهرهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'لأسفلكما': [{'vocalized': u'لأسفلكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أكعيني': [{'vocalized': u'أكعيني', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أكعيني', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'كنحوك': [{'vocalized': u'كنحوك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'أخوكما': [{'vocalized': u'أخوكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخو'}],

 u'بشهركن': [{'vocalized': u'بشهركن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'بشهركم': [{'vocalized': u'بشهركم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'ولليلهما': [{'vocalized': u'ولليلهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'أوبنفس': [{'vocalized': u'أوبنفس', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فوقتهن': [{'vocalized': u'فوقتهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'ومابرحن': [{'vocalized': u'ومابرحن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحن', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحن'}],

 u'وكخلفكم': [{'vocalized': u'وكخلفكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'وكخلفكن': [{'vocalized': u'وكخلفكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'أفهؤلاء': [{'vocalized': u'أفهؤلاء', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'أووراءي': [{'vocalized': u'أووراءي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'أووراءي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'أفبشبهها': [{'vocalized': u'أفبشبهها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'سبحاننا': [{'vocalized': u'سبحاننا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سبحان'}],

 u'كأيته': [{'vocalized': u'كأيته', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'فمثلي': [{'vocalized': u'فمثلي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فمثلي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'ولعمرهما': [{'vocalized': u'ولعمرهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لعمر'}],

 u'فليتنا': [{'vocalized': u'فليتنا', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-نا', 'type': u'حرف', 'original': u'ليت'}],

 u'فمثلك': [{'vocalized': u'فمثلك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'كعين': [{'vocalized': u'كعين', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'فمثله': [{'vocalized': u'فمثله', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'وكأخيكما': [{'vocalized': u'وكأخيكما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'ومابرحا': [{'vocalized': u'ومابرحا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحا'}],

 u'ولشهركما': [{'vocalized': u'ولشهركما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'أفبشبههن': [{'vocalized': u'أفبشبههن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفبشبههم': [{'vocalized': u'أفبشبههم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'ولفيي': [{'vocalized': u'ولفيي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'ولفيي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'ولدنهم': [{'vocalized': u'ولدنهم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدن'}],

 u'ولدنهن': [{'vocalized': u'ولدنهن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدن'}],

 u'أوبتلكما': [{'vocalized': u'أوبتلكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'لأيتهم': [{'vocalized': u'لأيتهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'فغربهما': [{'vocalized': u'فغربهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'كنفسكم': [{'vocalized': u'كنفسكم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'كنفسكن': [{'vocalized': u'كنفسكن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'بمثلكما': [{'vocalized': u'بمثلكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أفكغير': [{'vocalized': u'أفكغير', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'بليلكن': [{'vocalized': u'بليلكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'ولوقته': [{'vocalized': u'ولوقته', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'أكعينهما': [{'vocalized': u'أكعينهما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'أفبسويها': [{'vocalized': u'أفبسويها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أغيركما': [{'vocalized': u'أغيركما', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'ولوقتك': [{'vocalized': u'ولوقتك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'فككلتا': [{'vocalized': u'فككلتا', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'وأبيكن': [{'vocalized': u'وأبيكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'فأخاها': [{'vocalized': u'فأخاها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخا'}],

 u'وكمثله': [{'vocalized': u'وكمثله', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'وأبيكم': [{'vocalized': u'وأبيكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'ولغروبها': [{'vocalized': u'ولغروبها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'وكمثلك': [{'vocalized': u'وكمثلك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'فأينا': [{'vocalized': u'فأينا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'وكمثلي': [{'vocalized': u'وكمثلي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'وكمثلي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'وعلينا': [{'vocalized': u'وعلينا', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'بذاتك': [{'vocalized': u'بذاتك', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'وللواتي': [{'vocalized': u'وللواتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'ولأيتكما': [{'vocalized': u'ولأيتكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'فهؤلاء': [{'vocalized': u'فهؤلاء', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'فبحسبك': [{'vocalized': u'فبحسبك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فلحسبها': [{'vocalized': u'فلحسبها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'وبهاته': [{'vocalized': u'وبهاته', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'فبحسبه': [{'vocalized': u'فبحسبه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'وبهاتي': [{'vocalized': u'وبهاتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'ث': [{'vocalized': u'ث', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ث', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ث'}],

 u'فبحسبي': [{'vocalized': u'فبحسبي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'فبحسبي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أولسويهم': [{'vocalized': u'أولسويهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أولسويهن': [{'vocalized': u'أولسويهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'وكذلك': [{'vocalized': u'وكذلك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'},
 {'vocalized': u'وكذلك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'كذلك', 'encletic': u'', 'type': u'اسم', 'original': u'كذلك'}],

 u'ومازالا': [{'vocalized': u'ومازالا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازالا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالا'}],

 u'فحواليها': [{'vocalized': u'فحواليها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حوالى'}],

 u'فسبحانهما': [{'vocalized': u'فسبحانهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سبحان'}],

 u'وبذاتكن': [{'vocalized': u'وبذاتكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أفعينكن': [{'vocalized': u'أفعينكن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'أفعينكم': [{'vocalized': u'أفعينكم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'وإنما': [{'vocalized': u'وإنما', 'procletic': u'و-', 'tags': u'حرف;كافة ومكفوفة;عطف', 'stem': u'إنما', 'encletic': u'', 'type': u'حرف', 'original': u'إنما'}],

 u'فلحسبهن': [{'vocalized': u'فلحسبهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'فلحسبهم': [{'vocalized': u'فلحسبهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فشمالكم': [{'vocalized': u'فشمالكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'وعداه': [{'vocalized': u'وعداه', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'عدا'}],

 u'أولسويها': [{'vocalized': u'أولسويها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'وعداك': [{'vocalized': u'وعداك', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'عدا'}],

 u'وككلك': [{'vocalized': u'وككلك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلك', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'لحميهما': [{'vocalized': u'لحميهما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'أفلبعضه': [{'vocalized': u'أفلبعضه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'فبابني': [{'vocalized': u'فبابني', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'فبابني', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'فبأجمعنا': [{'vocalized': u'فبأجمعنا', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'لابن': [{'vocalized': u'لابن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'فبابنه': [{'vocalized': u'فبابنه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'أونحوكن': [{'vocalized': u'أونحوكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلبعضي': [{'vocalized': u'أفلبعضي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فأخاهن': [{'vocalized': u'فأخاهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخا'}],

 u'فأخاهم': [{'vocalized': u'فأخاهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخا'}],

 u'ولغروبهن': [{'vocalized': u'ولغروبهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'ولغروبهم': [{'vocalized': u'ولغروبهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'بينما': [{'vocalized': u'بينما', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'بينما', 'encletic': u'', 'type': u'اسم', 'original': u'بينما'}],

 u'فبجنبنا': [{'vocalized': u'فبجنبنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'وبشرقهن': [{'vocalized': u'وبشرقهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'ولكلتا': [{'vocalized': u'ولكلتا', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'},
 {'vocalized': u'ولكلتا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'ولازلنا': [{'vocalized': u'ولازلنا', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'لازلنا'}],

 u'فمنهما': [{'vocalized': u'فمنهما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'فبغربهما': [{'vocalized': u'فبغربهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'أوبسويهم': [{'vocalized': u'أوبسويهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوبسويهن': [{'vocalized': u'أوبسويهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'فبابنكن': [{'vocalized': u'فبابنكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'أفيك': [{'vocalized': u'أفيك', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'فبابنكم': [{'vocalized': u'فبابنكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'فبالتي': [{'vocalized': u'فبالتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'أفيه': [{'vocalized': u'أفيه', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'وللحظتهما': [{'vocalized': u'وللحظتهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفيي': [{'vocalized': u'أفيي', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'أفيي', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'فحميهما': [{'vocalized': u'فحميهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'وليل': [{'vocalized': u'وليل', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'كليلكم': [{'vocalized': u'كليلكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'كليلكن': [{'vocalized': u'كليلكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'فبعينه': [{'vocalized': u'فبعينه', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'فبعينك': [{'vocalized': u'فبعينك', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'فبأسفلكم': [{'vocalized': u'فبأسفلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبعينهما': [{'vocalized': u'وبعينهما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فتلكما': [{'vocalized': u'فتلكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'فبعيني': [{'vocalized': u'فبعيني', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فبعيني', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'فكزمانكما': [{'vocalized': u'فكزمانكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'وبأيتنا': [{'vocalized': u'وبأيتنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'ولليلكم': [{'vocalized': u'ولليلكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'ومعي': [{'vocalized': u'ومعي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'ومعي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'فبكل': [{'vocalized': u'فبكل', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكل', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'فبكم': [{'vocalized': u'فبكم', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بكم', 'encletic': u'', 'type': u'اسم', 'original': u'بكم'},
 {'vocalized': u'فبكم', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بكم', 'encletic': u'', 'type': u'ضمير', 'original': u'بكم'}],

 u'ومعه': [{'vocalized': u'ومعه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'ومعك': [{'vocalized': u'ومعك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'أهاذين': [{'vocalized': u'أهاذين', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'ولحميك': [{'vocalized': u'ولحميك', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'أفإن': [{'vocalized': u'أفإن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'وكأجمع': [{'vocalized': u'وكأجمع', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'كعامتكما': [{'vocalized': u'كعامتكما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'ولخلفك': [{'vocalized': u'ولخلفك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'أفعليهم': [{'vocalized': u'أفعليهم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'فحاشا': [{'vocalized': u'فحاشا', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف', 'stem': u'حاشا', 'encletic': u'', 'type': u'فعل', 'original': u'حاشا'}],

 u'أفلقلما': [{'vocalized': u'أفلقلما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'بكن': [{'vocalized': u'بكن', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'بكن', 'encletic': u'', 'type': u'ضمير', 'original': u'بكن'}],

 u'وألا': [{'vocalized': u'وألا', 'procletic': u'و-', 'tags': u'حرف;حرف عرض;عطف', 'stem': u'ألا', 'encletic': u'', 'type': u'حرف', 'original': u'ألا'}],

 u'أوبسويها': [{'vocalized': u'أوبسويها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'ولوقت': [{'vocalized': u'ولوقت', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'وليت': [{'vocalized': u'وليت', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'ليت', 'encletic': u'', 'type': u'حرف', 'original': u'ليت'}],

 u'أفلمثلنا': [{'vocalized': u'أفلمثلنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'أوفوقنا': [{'vocalized': u'أوفوقنا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'أفلشمال': [{'vocalized': u'أفلشمال', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'أقلكما': [{'vocalized': u'أقلكما', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'بعضهم': [{'vocalized': u'بعضهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'بعضهن': [{'vocalized': u'بعضهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفبعضكن': [{'vocalized': u'أفبعضكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفبعضكم': [{'vocalized': u'أفبعضكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أولمن': [{'vocalized': u'أولمن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'أولمن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'فحماكم': [{'vocalized': u'فحماكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حما'}],

 u'فانبرى': [{'vocalized': u'فانبرى', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'انبرى', 'encletic': u'', 'type': u'فعل', 'original': u'انبرى'}],

 u'فحماكن': [{'vocalized': u'فحماكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حما'}],

 u'وأجمع': [{'vocalized': u'وأجمع', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلحسبهما': [{'vocalized': u'أفلحسبهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'زمانكن': [{'vocalized': u'زمانكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'بأسفله': [{'vocalized': u'بأسفله', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'مابرحتم': [{'vocalized': u'مابرحتم', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحتم', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتم'}],

 u'فقد': [{'vocalized': u'فقد', 'procletic': u'ف-', 'tags': u'حرف;حرف تحقيق/ توقع;عطف', 'stem': u'قد', 'encletic': u'', 'type': u'حرف', 'original': u'قد'}],

 u'وبشرقها': [{'vocalized': u'وبشرقها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'وكخلفي': [{'vocalized': u'وكخلفي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وكخلفي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فبليلكن': [{'vocalized': u'فبليلكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'ولات': [{'vocalized': u'ولات', 'procletic': u'و-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'لات', 'encletic': u'', 'type': u'حرف', 'original': u'لات'}],

 u'وكخلفك': [{'vocalized': u'وكخلفك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'وكخلفه': [{'vocalized': u'وكخلفه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'وخلفكما': [{'vocalized': u'وخلفكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'ولازالا': [{'vocalized': u'ولازالا', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالا'}],

 u'أفعنكما': [{'vocalized': u'أفعنكما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'ولزماني': [{'vocalized': u'ولزماني', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'ولزماني', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'لحظتهم': [{'vocalized': u'لحظتهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'أولتحتكن': [{'vocalized': u'أولتحتكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'وكالذي': [{'vocalized': u'وكالذي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'أوهي': [{'vocalized': u'أوهي', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'بجنبهما': [{'vocalized': u'بجنبهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'ولازالت': [{'vocalized': u'ولازالت', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'},
 {'vocalized': u'ولازالت', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'}],

 u'وليمينكن': [{'vocalized': u'وليمينكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'وليمينكم': [{'vocalized': u'وليمينكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'أفلأناها': [{'vocalized': u'أفلأناها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'مساء': [{'vocalized': u'مساء', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'مساء', 'encletic': u'', 'type': u'اسم', 'original': u'مساء'}],

 u'أأناهم': [{'vocalized': u'أأناهم', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'أأناهن': [{'vocalized': u'أأناهن', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'فلتحت': [{'vocalized': u'فلتحت', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'أكحسبكم': [{'vocalized': u'أكحسبكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أكحسبكن': [{'vocalized': u'أكحسبكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'ولأيتك': [{'vocalized': u'ولأيتك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'فأثناءنا': [{'vocalized': u'فأثناءنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولشطركما': [{'vocalized': u'ولشطركما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'بعضها': [{'vocalized': u'بعضها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'أولمع': [{'vocalized': u'أولمع', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'أفلبعضكما': [{'vocalized': u'أفلبعضكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أولما': [{'vocalized': u'أولما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'اسم', 'original': u'لما'},
 {'vocalized': u'أولما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جزم;عطف;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'},
 {'vocalized': u'أولما', 'procletic': u'أ-و-', 'tags': u'حرف;ظرف;عطف;استفهام', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'}],

 u'أوكعيننا': [{'vocalized': u'أوكعيننا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'فكوقتك': [{'vocalized': u'فكوقتك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'ما': [{'vocalized': u'ما', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'ما', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'ما', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'ما', 'procletic': u'', 'tags': u'حرف;المشبهة بليس', 'stem': u'ما', 'encletic': u'', 'type': u'حرف', 'original': u'ما'}],

 u'وكذا': [{'vocalized': u'وكذا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'وكذا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'وكذا', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'كذا', 'encletic': u'', 'type': u'اسم', 'original': u'كذا'}],

 u'وإذ': [{'vocalized': u'وإذ', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'إذ', 'encletic': u'', 'type': u'اسم', 'original': u'إذ'},
 {'vocalized': u'وإذ', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'إذ', 'encletic': u'', 'type': u'اسم', 'original': u'إذ'}],

 u'فكحمينا': [{'vocalized': u'فكحمينا', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'وزمان': [{'vocalized': u'وزمان', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'لساعة': [{'vocalized': u'لساعة', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'لازلتما': [{'vocalized': u'لازلتما', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'},
 {'vocalized': u'لازلتما', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'}],

 u'خلفه': [{'vocalized': u'خلفه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'ابنكم': [{'vocalized': u'ابنكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'ابنكن': [{'vocalized': u'ابنكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'فخلالهما': [{'vocalized': u'فخلالهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلال'}],

 u'لتلقاءهم': [{'vocalized': u'لتلقاءهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'لتلقاءهن': [{'vocalized': u'لتلقاءهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبحسبهما': [{'vocalized': u'وبحسبهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'ألإلي': [{'vocalized': u'ألإلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'ألإلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'ألإلى': [{'vocalized': u'ألإلى', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'أوبحسب': [{'vocalized': u'أوبحسب', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبعامتكن': [{'vocalized': u'أوبعامتكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'بهاتين': [{'vocalized': u'بهاتين', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'أوبعامتكم': [{'vocalized': u'أوبعامتكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أولخلفي': [{'vocalized': u'أولخلفي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'أولخلفي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'أولخلفه': [{'vocalized': u'أولخلفه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'لازال': [{'vocalized': u'لازال', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازال', 'encletic': u'', 'type': u'فعل', 'original': u'لازال'}],

 u'فلعنكما': [{'vocalized': u'فلعنكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'أفسويهما': [{'vocalized': u'أفسويهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'ألكأنكما': [{'vocalized': u'ألكأنكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'فأخذ': [{'vocalized': u'فأخذ', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أخذ', 'encletic': u'', 'type': u'فعل', 'original': u'أخذ'}],

 u'أبسويكم': [{'vocalized': u'أبسويكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أبسويكن': [{'vocalized': u'أبسويكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'وشهرهن': [{'vocalized': u'وشهرهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'وبئس': [{'vocalized': u'وبئس', 'procletic': u'و-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'بئس', 'encletic': u'', 'type': u'فعل', 'original': u'بئس'}],

 u'وعننا': [{'vocalized': u'وعننا', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'فلأقبل': [{'vocalized': u'فلأقبل', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أقبل', 'encletic': u'', 'type': u'فعل', 'original': u'أقبل'}],

 u'وكذه': [{'vocalized': u'وكذه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'ويومئذ': [{'vocalized': u'ويومئذ', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'يومئذ', 'encletic': u'', 'type': u'اسم', 'original': u'يومئذ'}],

 u'فبجنبهما': [{'vocalized': u'فبجنبهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'أفلإننا': [{'vocalized': u'أفلإننا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'وكذي': [{'vocalized': u'وكذي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'مذ': [{'vocalized': u'مذ', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'مذ', 'encletic': u'', 'type': u'حرف', 'original': u'مذ'},
 {'vocalized': u'مذ', 'procletic': u'', 'tags': u'حرف;ظرف زمان', 'stem': u'مذ', 'encletic': u'', 'type': u'حرف', 'original': u'مذ'}],

 u'وإن': [{'vocalized': u'وإن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'وإن', 'procletic': u'و-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'وإن', 'procletic': u'و-', 'tags': u'حرف;حرف جزم;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'وإن', 'procletic': u'و-', 'tags': u'حرف;حرف شرط;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'وأخوكما': [{'vocalized': u'وأخوكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخو'}],

 u'لتلقاءها': [{'vocalized': u'لتلقاءها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فعامتك': [{'vocalized': u'فعامتك', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'أوكعامتك': [{'vocalized': u'أوكعامتك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'ولدنه': [{'vocalized': u'ولدنه', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدن'}],

 u'ليله': [{'vocalized': u'ليله', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'فوراءكما': [{'vocalized': u'فوراءكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'أولخلفك': [{'vocalized': u'أولخلفك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'أولتلك': [{'vocalized': u'أولتلك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'بهاذين': [{'vocalized': u'بهاذين', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'وانبرى': [{'vocalized': u'وانبرى', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'انبرى', 'encletic': u'', 'type': u'فعل', 'original': u'انبرى'}],

 u'واللائي': [{'vocalized': u'واللائي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'ونفسك': [{'vocalized': u'ونفسك', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'ونفسه': [{'vocalized': u'ونفسه', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'فكبعضها': [{'vocalized': u'فكبعضها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'ونفسي': [{'vocalized': u'ونفسي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ونفسي', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أنهما': [{'vocalized': u'أنهما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'أكعامتهن': [{'vocalized': u'أكعامتهن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلأمامكم': [{'vocalized': u'أفلأمامكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'أفلأمامكن': [{'vocalized': u'أفلأمامكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'أنحوي': [{'vocalized': u'أنحوي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أنحوي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'وبأيهم': [{'vocalized': u'وبأيهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'وبأيهن': [{'vocalized': u'وبأيهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'أجميعنا': [{'vocalized': u'أجميعنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعنا', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'أنحوك': [{'vocalized': u'أنحوك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'من': [{'vocalized': u'من', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'من', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'من', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'من', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'فكبعضهن': [{'vocalized': u'فكبعضهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'فكبعضهم': [{'vocalized': u'فكبعضهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'ولأثناءكما': [{'vocalized': u'ولأثناءكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'أكهذه': [{'vocalized': u'أكهذه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'أكعامتها': [{'vocalized': u'أكعامتها', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'أفتحتهما': [{'vocalized': u'أفتحتهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'وبأيها': [{'vocalized': u'وبأيها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'وبحسبنا': [{'vocalized': u'وبحسبنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأنهن': [{'vocalized': u'وكأنهن', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنهن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'ورب': [{'vocalized': u'ورب', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'رب', 'encletic': u'', 'type': u'حرف', 'original': u'رب'}],

 u'وبأثناءه': [{'vocalized': u'وبأثناءه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلأعلينا': [{'vocalized': u'فلأعلينا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'وبأثناءك': [{'vocalized': u'وبأثناءك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفببعضكما': [{'vocalized': u'أفببعضكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'وبأثناءي': [{'vocalized': u'وبأثناءي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'وبأثناءي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'لكلي': [{'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'لكننا': [{'vocalized': u'لكننا', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكننا', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لكن'}],

 u'لكله': [{'vocalized': u'لكله', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكله', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكله', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكله', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'جنبكما': [{'vocalized': u'جنبكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'لكلك': [{'vocalized': u'لكلك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلك', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'ولكلكن': [{'vocalized': u'ولكلكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'بنحوها': [{'vocalized': u'بنحوها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'ولكلكم': [{'vocalized': u'ولكلكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أولجميعها': [{'vocalized': u'أولجميعها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'فكأبيي': [{'vocalized': u'فكأبيي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'فكأبيي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'فبكلكم': [{'vocalized': u'فبكلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'فبكلكن': [{'vocalized': u'فبكلكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلكن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'فأبانا': [{'vocalized': u'فأبانا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبا'}],

 u'أوعليها': [{'vocalized': u'أوعليها', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'وبتلقاءهما': [{'vocalized': u'وبتلقاءهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'والآن': [{'vocalized': u'والآن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'الآن', 'encletic': u'', 'type': u'اسم', 'original': u'الآن'}],

 u'فكأبيه': [{'vocalized': u'فكأبيه', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'أعنهما': [{'vocalized': u'أعنهما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'فلأبيي': [{'vocalized': u'فلأبيي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'فلأبيي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'أبمثلكما': [{'vocalized': u'أبمثلكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أولكل': [{'vocalized': u'أولكل', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكل', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكل', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكل', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'كذاتهما': [{'vocalized': u'كذاتهما', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'أوخلفهم': [{'vocalized': u'أوخلفهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'فحسبهما': [{'vocalized': u'فحسبهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'فلا': [{'vocalized': u'فلا', 'procletic': u'ف-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'فلا', 'procletic': u'ف-', 'tags': u'حرف;نافية للجنس;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'فلا', 'procletic': u'ف-', 'tags': u'حرف;ناهية;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'فلا', 'procletic': u'ف-', 'tags': u'حرف;نافية;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'}],

 u'فلنفس': [{'vocalized': u'فلنفس', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفس', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فساعة': [{'vocalized': u'فساعة', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'وراءهما': [{'vocalized': u'وراءهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'بعدهم': [{'vocalized': u'بعدهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعد'}],

 u'بعدهن': [{'vocalized': u'بعدهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعد'}],

 u'ي': [{'vocalized': u'ي', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ي', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ي'}],

 u'وقتكم': [{'vocalized': u'وقتكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'وقتكن': [{'vocalized': u'وقتكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'فلن': [{'vocalized': u'فلن', 'procletic': u'ف-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لن', 'encletic': u'', 'type': u'حرف', 'original': u'لن'}],

 u'كغيركن': [{'vocalized': u'كغيركن', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'كغيركم': [{'vocalized': u'كغيركم', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'فلم': [{'vocalized': u'فلم', 'procletic': u'ف-', 'tags': u'حرف;حرف جزم;عطف', 'stem': u'لم', 'encletic': u'', 'type': u'حرف', 'original': u'لم'}],

 u'لغروبكم': [{'vocalized': u'لغروبكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'فلك': [{'vocalized': u'فلك', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لك', 'encletic': u'', 'type': u'ضمير', 'original': u'لك'}],

 u'لغروبكن': [{'vocalized': u'لغروبكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'ألعامتهما': [{'vocalized': u'ألعامتهما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'بدونهما': [{'vocalized': u'بدونهما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بدون'}],

 u'فلي': [{'vocalized': u'فلي', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لي', 'encletic': u'', 'type': u'ضمير', 'original': u'لي'}],

 u'فلو': [{'vocalized': u'فلو', 'procletic': u'ف-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لو', 'encletic': u'', 'type': u'حرف', 'original': u'لو'}],

 u'بنحوهن': [{'vocalized': u'بنحوهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'بنحوهم': [{'vocalized': u'بنحوهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'وبفينا': [{'vocalized': u'وبفينا', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'}],

 u'أولجميعهم': [{'vocalized': u'أولجميعهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أولجميعهن': [{'vocalized': u'أولجميعهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'أوعليهن': [{'vocalized': u'أوعليهن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'وباللائي': [{'vocalized': u'وباللائي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'أوعليهم': [{'vocalized': u'أوعليهم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'فلازلتما': [{'vocalized': u'فلازلتما', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'},
 {'vocalized': u'فلازلتما', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'}],

 u'لعينه': [{'vocalized': u'لعينه', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أخيكما': [{'vocalized': u'أخيكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'لحظتكم': [{'vocalized': u'لحظتكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'لجنوبهما': [{'vocalized': u'لجنوبهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفلإليها': [{'vocalized': u'أفلإليها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'فبعضهما': [{'vocalized': u'فبعضهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'فلنحوي': [{'vocalized': u'فلنحوي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'أبأجمعي': [{'vocalized': u'أبأجمعي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أبأجمعي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلوراءهما': [{'vocalized': u'فلوراءهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'فلنحوك': [{'vocalized': u'فلنحوك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'فلنحوه': [{'vocalized': u'فلنحوه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'فلصار': [{'vocalized': u'فلصار', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'صار', 'encletic': u'', 'type': u'فعل', 'original': u'صار'}],

 u'لكأنما': [{'vocalized': u'لكأنما', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'عنها': [{'vocalized': u'عنها', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'أيتهن': [{'vocalized': u'أيتهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'أيتهم': [{'vocalized': u'أيتهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'كأجمعكما': [{'vocalized': u'كأجمعكما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'طفق': [{'vocalized': u'طفق', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'طفق', 'encletic': u'', 'type': u'فعل', 'original': u'طفق'}],

 u'وشمالها': [{'vocalized': u'وشمالها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'أولمنهما': [{'vocalized': u'أولمنهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'فلأمام': [{'vocalized': u'فلأمام', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'بات': [{'vocalized': u'بات', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'بات', 'encletic': u'', 'type': u'فعل', 'original': u'بات'}],

 u'فبأبيهما': [{'vocalized': u'فبأبيهما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'أفلديهم': [{'vocalized': u'أفلديهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدى'}],

 u'عنهم': [{'vocalized': u'عنهم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'لكأنك': [{'vocalized': u'لكأنك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'أفلديهن': [{'vocalized': u'أفلديهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدى'}],

 u'وكلحظتك': [{'vocalized': u'وكلحظتك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'لكأنه': [{'vocalized': u'لكأنه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'أيتها': [{'vocalized': u'أيتها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'فلحظتكما': [{'vocalized': u'فلحظتكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبغربك': [{'vocalized': u'وبغربك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'لكأني': [{'vocalized': u'لكأني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'لكأني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'وكلحظتي': [{'vocalized': u'وكلحظتي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'وكلحظتي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبغربه': [{'vocalized': u'وبغربه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'بتلكما': [{'vocalized': u'بتلكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'وبشهرهن': [{'vocalized': u'وبشهرهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'ألعامة': [{'vocalized': u'ألعامة', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامة', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'ماانفكوا': [{'vocalized': u'ماانفكوا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفكوا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكوا'}],

 u'ولجنبهم': [{'vocalized': u'ولجنبهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'ولجنبهن': [{'vocalized': u'ولجنبهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'فأخيكما': [{'vocalized': u'فأخيكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'فتحتهن': [{'vocalized': u'فتحتهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'ألأناكما': [{'vocalized': u'ألأناكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'وذويهما': [{'vocalized': u'وذويهما', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكجنب': [{'vocalized': u'وكجنب', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'أفلإنهما': [{'vocalized': u'أفلإنهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'وكشرقهما': [{'vocalized': u'وكشرقهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'فكليهما': [{'vocalized': u'فكليهما', 'procletic': u'ف-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'أفلفي': [{'vocalized': u'أفلفي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'أفإنا': [{'vocalized': u'أفإنا', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'كخلفهن': [{'vocalized': u'كخلفهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أوبنحوي': [{'vocalized': u'أوبنحوي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أوبنحوي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'كاللواتي': [{'vocalized': u'كاللواتي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'فأبوها': [{'vocalized': u'فأبوها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبو'}],

 u'وبينه': [{'vocalized': u'وبينه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بين'}],

 u'فغيرهما': [{'vocalized': u'فغيرهما', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فبساعتكما': [{'vocalized': u'فبساعتكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'كجنوبكن': [{'vocalized': u'كجنوبكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكجميع': [{'vocalized': u'وكجميع', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميع', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'كجنوبكم': [{'vocalized': u'كجنوبكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوشمالهم': [{'vocalized': u'أوشمالهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'أوشمالهن': [{'vocalized': u'أوشمالهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'لوقتنا': [{'vocalized': u'لوقتنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'وبساعتي': [{'vocalized': u'وبساعتي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'وبساعتي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'ألأمامكن': [{'vocalized': u'ألأمامكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'فلات': [{'vocalized': u'فلات', 'procletic': u'ف-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'لات', 'encletic': u'', 'type': u'حرف', 'original': u'لات'}],

 u'ألمنها': [{'vocalized': u'ألمنها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'ليت': [{'vocalized': u'ليت', 'procletic': u'', 'tags': u'حرف;إن و أخواتها', 'stem': u'ليت', 'encletic': u'', 'type': u'حرف', 'original': u'ليت'}],

 u'كشطرهن': [{'vocalized': u'كشطرهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'وبساعتك': [{'vocalized': u'وبساعتك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'كشطرهم': [{'vocalized': u'كشطرهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'فحسبه': [{'vocalized': u'فحسبه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'فحسبما': [{'vocalized': u'فحسبما', 'procletic': u'ف-', 'tags': u'اسم;جار ومجرور;عطف', 'stem': u'حسبما', 'encletic': u'', 'type': u'اسم', 'original': u'حسبما'}],

 u'لمنكما': [{'vocalized': u'لمنكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'وبابننا': [{'vocalized': u'وبابننا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'أوشمالها': [{'vocalized': u'أوشمالها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'فلان': [{'vocalized': u'فلان', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'فلان', 'encletic': u'', 'type': u'اسم', 'original': u'فلان'}],

 u'ليل': [{'vocalized': u'ليل', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'فغروبنا': [{'vocalized': u'فغروبنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'فبينهما': [{'vocalized': u'فبينهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بين'}],

 u'أكثركما': [{'vocalized': u'أكثركما', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'كشطرها': [{'vocalized': u'كشطرها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'فلتحتكم': [{'vocalized': u'فلتحتكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'فلنفسه': [{'vocalized': u'فلنفسه', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'فلأنتما': [{'vocalized': u'فلأنتما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'ألكلهما': [{'vocalized': u'ألكلهما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'حماه': [{'vocalized': u'حماه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حما'}],

 u'أفإنه': [{'vocalized': u'أفإنه', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'وكحسبك': [{'vocalized': u'وكحسبك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'أفإنك': [{'vocalized': u'أفإنك', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'لعلكم': [{'vocalized': u'لعلكم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لعل'}],

 u'وكأثناءه': [{'vocalized': u'وكأثناءه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلنفسك': [{'vocalized': u'فلنفسك', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'وكحسبي': [{'vocalized': u'وكحسبي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'وكحسبي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أفإني': [{'vocalized': u'أفإني', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'أفإني', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'وشرقكم': [{'vocalized': u'وشرقكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'أولأجمعنا': [{'vocalized': u'أولأجمعنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'كتلقاءي': [{'vocalized': u'كتلقاءي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'كتلقاءي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبأعليكما': [{'vocalized': u'وبأعليكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'كتلقاءه': [{'vocalized': u'كتلقاءه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'كتلقاءك': [{'vocalized': u'كتلقاءك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفلشبههن': [{'vocalized': u'أفلشبههن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبههن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلشبههم': [{'vocalized': u'أفلشبههم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبههم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'أفبعيننا': [{'vocalized': u'أفبعيننا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'وبعامتهم': [{'vocalized': u'وبعامتهم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'وبعامتهن': [{'vocalized': u'وبعامتهن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فكجميعهن': [{'vocalized': u'فكجميعهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعهن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فكجميعهم': [{'vocalized': u'فكجميعهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعهم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلنفسي': [{'vocalized': u'فلنفسي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'فكاللذين': [{'vocalized': u'فكاللذين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'س': [{'vocalized': u'س', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'س', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'س'}],

 u'فبغربي': [{'vocalized': u'فبغربي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'فبغربي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'وبغربهما': [{'vocalized': u'وبغربهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'فبغربه': [{'vocalized': u'فبغربه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'وابن': [{'vocalized': u'وابن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'أفلشبهها': [{'vocalized': u'أفلشبهها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'فصباح': [{'vocalized': u'فصباح', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'صباح', 'encletic': u'', 'type': u'اسم', 'original': u'صباح'}],

 u'أشبهكم': [{'vocalized': u'أشبهكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'أشبهكن': [{'vocalized': u'أشبهكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'وعندكن': [{'vocalized': u'وعندكن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عند'}],

 u'أوكشبهنا': [{'vocalized': u'أوكشبهنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'وبعامتها': [{'vocalized': u'وبعامتها', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'فكجميعها': [{'vocalized': u'فكجميعها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعها', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'حيننا': [{'vocalized': u'حيننا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حين'}],

 u'ألعامتك': [{'vocalized': u'ألعامتك', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'وكذات': [{'vocalized': u'وكذات', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'ألعامته': [{'vocalized': u'ألعامته', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامته', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'وبشبهنا': [{'vocalized': u'وبشبهنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'ألعامتي': [{'vocalized': u'ألعامتي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'كهؤلاء': [{'vocalized': u'كهؤلاء', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'أوفيكما': [{'vocalized': u'أوفيكما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'وظل': [{'vocalized': u'وظل', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ظل', 'encletic': u'', 'type': u'فعل', 'original': u'ظل'}],

 u'وتحول': [{'vocalized': u'وتحول', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'تحول', 'encletic': u'', 'type': u'فعل', 'original': u'تحول'}],

 u'أفكغيرنا': [{'vocalized': u'أفكغيرنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أفكأنهما': [{'vocalized': u'أفكأنهما', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'لابنك': [{'vocalized': u'لابنك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'أولمثل': [{'vocalized': u'أولمثل', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثل', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'لابنه': [{'vocalized': u'لابنه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'لابني': [{'vocalized': u'لابني', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'لابني', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'فمافتئتا': [{'vocalized': u'فمافتئتا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتا'}],

 u'فكبعضكن': [{'vocalized': u'فكبعضكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفجميعهم': [{'vocalized': u'أفجميعهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعهم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلحظتي': [{'vocalized': u'فلحظتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'فلحظتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفبحسبي': [{'vocalized': u'أفبحسبي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أفبحسبي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أفبنحوها': [{'vocalized': u'أفبنحوها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'لأثناءنا': [{'vocalized': u'لأثناءنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'ووراءكما': [{'vocalized': u'ووراءكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'وكشهرهن': [{'vocalized': u'وكشهرهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'وكشهرهم': [{'vocalized': u'وكشهرهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'لذات': [{'vocalized': u'لذات', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'فإنهما': [{'vocalized': u'فإنهما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'أبأولاء': [{'vocalized': u'أبأولاء', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'وكأيكما': [{'vocalized': u'وكأيكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'أفكسوينا': [{'vocalized': u'أفكسوينا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'لوراءهما': [{'vocalized': u'لوراءهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'ولغيركما': [{'vocalized': u'ولغيركما', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيركما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فابنهم': [{'vocalized': u'فابنهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'فلاستحال': [{'vocalized': u'فلاستحال', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'استحال', 'encletic': u'', 'type': u'فعل', 'original': u'استحال'}],

 u'كأسفلهم': [{'vocalized': u'كأسفلهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكنحوهما': [{'vocalized': u'فكنحوهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'ولكننا': [{'vocalized': u'ولكننا', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكننا', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لكن'}],

 u'لجعل': [{'vocalized': u'لجعل', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'جعل', 'encletic': u'', 'type': u'فعل', 'original': u'جعل'}],

 u'أكشبههما': [{'vocalized': u'أكشبههما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'أفكأنما': [{'vocalized': u'أفكأنما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف تشبيه;عطف;استفهام', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'وإليكما': [{'vocalized': u'وإليكما', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليكما', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكما'},
 {'vocalized': u'وإليكما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'وكأقلنا': [{'vocalized': u'وكأقلنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'ونفسكم': [{'vocalized': u'ونفسكم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'فلأنشأ': [{'vocalized': u'فلأنشأ', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنشأ', 'encletic': u'', 'type': u'فعل', 'original': u'أنشأ'}],

 u'ونفسكن': [{'vocalized': u'ونفسكن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'فبأقلكن': [{'vocalized': u'فبأقلكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'فبأقلكم': [{'vocalized': u'فبأقلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'وكشهرها': [{'vocalized': u'وكشهرها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'كجنبي': [{'vocalized': u'كجنبي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'كجنبي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'وكنفسكم': [{'vocalized': u'وكنفسكم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'وكنفسكن': [{'vocalized': u'وكنفسكن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أوكذينك': [{'vocalized': u'أوكذينك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'لذاك': [{'vocalized': u'لذاك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'كجنبك': [{'vocalized': u'كجنبك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'ولشهري': [{'vocalized': u'ولشهري', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'ولشهري', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'بغروبي': [{'vocalized': u'بغروبي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'بغروبي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'وضمنه': [{'vocalized': u'وضمنه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ضمن'}],

 u'فلغربكن': [{'vocalized': u'فلغربكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'وخلالنا': [{'vocalized': u'وخلالنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلال'}],

 u'وضمنك': [{'vocalized': u'وضمنك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ضمن'}],

 u'بغروبك': [{'vocalized': u'بغروبك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'ولشهرك': [{'vocalized': u'ولشهرك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'فكهن': [{'vocalized': u'فكهن', 'procletic': u'ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'بغروبه': [{'vocalized': u'بغروبه', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'ولشهره': [{'vocalized': u'ولشهره', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'وضمني': [{'vocalized': u'وضمني', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ضمن'},
 {'vocalized': u'وضمني', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ضمن'}],

 u'ويكأننا': [{'vocalized': u'ويكأننا', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-نا', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'وأسفلكن': [{'vocalized': u'وأسفلكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وأسفلكم': [{'vocalized': u'وأسفلكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'وإيانا': [{'vocalized': u'وإيانا', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إيانا', 'encletic': u'', 'type': u'ضمير', 'original': u'إيانا'}],

 u'ذووهم': [{'vocalized': u'ذووهم', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوو'}],

 u'ذووهن': [{'vocalized': u'ذووهن', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوو'}],

 u'فلأولئك': [{'vocalized': u'فلأولئك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'ولأولالك': [{'vocalized': u'ولأولالك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فسبحاننا': [{'vocalized': u'فسبحاننا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سبحان'}],

 u'أوجميعكن': [{'vocalized': u'أوجميعكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعكن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'وعندك': [{'vocalized': u'وعندك', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عند'}],

 u'فمادام': [{'vocalized': u'فمادام', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادام', 'encletic': u'', 'type': u'فعل', 'original': u'مادام'}],

 u'أوجميعكم': [{'vocalized': u'أوجميعكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعكم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلتلك': [{'vocalized': u'فلتلك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'لانبرى': [{'vocalized': u'لانبرى', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'انبرى', 'encletic': u'', 'type': u'فعل', 'original': u'انبرى'}],

 u'أولعامتكن': [{'vocalized': u'أولعامتكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أولعامتكم': [{'vocalized': u'أولعامتكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'إياك': [{'vocalized': u'إياك', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياك', 'encletic': u'', 'type': u'ضمير', 'original': u'إياك'},
 {'vocalized': u'إياك', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياك', 'encletic': u'', 'type': u'ضمير', 'original': u'إياك'}],

 u'وكذاك': [{'vocalized': u'وكذاك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'ألوراء': [{'vocalized': u'ألوراء', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'أجميع': [{'vocalized': u'أجميع', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميع', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'وحماهم': [{'vocalized': u'وحماهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حما'}],

 u'وغربهم': [{'vocalized': u'وغربهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'بهناك': [{'vocalized': u'بهناك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'عيني': [{'vocalized': u'عيني', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'عيني', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وكأجمعكم': [{'vocalized': u'وكأجمعكم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألإليهما': [{'vocalized': u'ألإليهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'وشبهنا': [{'vocalized': u'وشبهنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'ألفيكم': [{'vocalized': u'ألفيكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'أفليمينكن': [{'vocalized': u'أفليمينكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'فإياهما': [{'vocalized': u'فإياهما', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياهما', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهما'}],

 u'لمثلنا': [{'vocalized': u'لمثلنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'بأخيك': [{'vocalized': u'بأخيك', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'بأخيه': [{'vocalized': u'بأخيه', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'وشمالهن': [{'vocalized': u'وشمالهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'بأخيي': [{'vocalized': u'بأخيي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'بأخيي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'وبشطركما': [{'vocalized': u'وبشطركما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'فلشهرك': [{'vocalized': u'فلشهرك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'ألبعضي': [{'vocalized': u'ألبعضي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'جنوبكما': [{'vocalized': u'جنوبكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'ذووها': [{'vocalized': u'ذووها', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوو'}],

 u'فكسويكن': [{'vocalized': u'فكسويكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'فكسويكم': [{'vocalized': u'فكسويكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'ألبعضك': [{'vocalized': u'ألبعضك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'ألبعضه': [{'vocalized': u'ألبعضه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'لأمامكن': [{'vocalized': u'لأمامكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'حيثما': [{'vocalized': u'حيثما', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'حيثما', 'encletic': u'', 'type': u'اسم', 'original': u'حيثما'}],

 u'وكأيكن': [{'vocalized': u'وكأيكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'لأمامكم': [{'vocalized': u'لأمامكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'أفكأجمعكن': [{'vocalized': u'أفكأجمعكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'لإليهما': [{'vocalized': u'لإليهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'أبذلكما': [{'vocalized': u'أبذلكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'وبعامتهما': [{'vocalized': u'وبعامتهما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'فمافتئت': [{'vocalized': u'فمافتئت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'فمافتئت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'فمافتئت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'فمافتئت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'}],

 u'فلمثل': [{'vocalized': u'فلمثل', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثل', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'زمانهما': [{'vocalized': u'زمانهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'فلغرب': [{'vocalized': u'فلغرب', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'فبابنهن': [{'vocalized': u'فبابنهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'فكتلقاءكم': [{'vocalized': u'فكتلقاءكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فكتلقاءكن': [{'vocalized': u'فكتلقاءكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبابنهم': [{'vocalized': u'فبابنهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'كأكثر': [{'vocalized': u'كأكثر', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'أكهاذين': [{'vocalized': u'أكهاذين', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'وأسفلهما': [{'vocalized': u'وأسفلهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'لعيننا': [{'vocalized': u'لعيننا', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعيننا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'أولعلكن': [{'vocalized': u'أولعلكن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لعل'}],

 u'كليلهم': [{'vocalized': u'كليلهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'كليلهن': [{'vocalized': u'كليلهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'أولعلكم': [{'vocalized': u'أولعلكم', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لعل'}],

 u'فالألى': [{'vocalized': u'فالألى', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'فبها': [{'vocalized': u'فبها', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بها', 'encletic': u'', 'type': u'ضمير', 'original': u'بها'}],

 u'فبأسفلهن': [{'vocalized': u'فبأسفلهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'هاتان': [{'vocalized': u'هاتان', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هاتان', 'encletic': u'', 'type': u'اسم', 'original': u'هاتان'}],

 u'وغروبهم': [{'vocalized': u'وغروبهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'وغروبهن': [{'vocalized': u'وغروبهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'فبسوينا': [{'vocalized': u'فبسوينا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'وذوونا': [{'vocalized': u'وذوونا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوو'}],

 u'فبمثلهما': [{'vocalized': u'فبمثلهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فبغروبكن': [{'vocalized': u'فبغروبكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'لديهما': [{'vocalized': u'لديهما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدى'}],

 u'وكذوي': [{'vocalized': u'وكذوي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'كأيتنا': [{'vocalized': u'كأيتنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'فبهن': [{'vocalized': u'فبهن', 'procletic': u'ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أولشمالهما': [{'vocalized': u'أولشمالهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'ولأبينا': [{'vocalized': u'ولأبينا', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'وبأيتي': [{'vocalized': u'وبأيتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'وبأيتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'وذووهما': [{'vocalized': u'وذووهما', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوو'}],

 u'فبهي': [{'vocalized': u'فبهي', 'procletic': u'ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'أفلذلك': [{'vocalized': u'أفلذلك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'فبهو': [{'vocalized': u'فبهو', 'procletic': u'ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'وبشبهه': [{'vocalized': u'وبشبهه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'لفينا': [{'vocalized': u'لفينا', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفينا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'فمافتئن': [{'vocalized': u'فمافتئن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئن', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئن'}],

 u'وبشبهك': [{'vocalized': u'وبشبهك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أكهما': [{'vocalized': u'أكهما', 'procletic': u'أ-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'بأقلكما': [{'vocalized': u'بأقلكما', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'وبشبهي': [{'vocalized': u'وبشبهي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'وبشبهي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'وبذاتي': [{'vocalized': u'وبذاتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'وبذاتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'فكخلفهن': [{'vocalized': u'فكخلفهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'فبأجمعي': [{'vocalized': u'فبأجمعي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فبأجمعي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'بتلقاء': [{'vocalized': u'بتلقاء', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبذاتك': [{'vocalized': u'وبذاتك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'فأبو': [{'vocalized': u'فأبو', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أبو', 'encletic': u'', 'type': u'اسم', 'original': u'أبو'}],

 u'وبذاته': [{'vocalized': u'وبذاته', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'فبابنها': [{'vocalized': u'فبابنها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'جنوبهم': [{'vocalized': u'جنوبهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وليمينها': [{'vocalized': u'وليمينها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'فلأبيكما': [{'vocalized': u'فلأبيكما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'وذاتنا': [{'vocalized': u'وذاتنا', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'ألكأنهما': [{'vocalized': u'ألكأنهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'وقلما': [{'vocalized': u'وقلما', 'procletic': u'و-', 'tags': u'فعل;فعل جامد;عطف', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'وكحميك': [{'vocalized': u'وكحميك', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'أكحسبها': [{'vocalized': u'أكحسبها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'وكليله': [{'vocalized': u'وكليله', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'لليلها': [{'vocalized': u'لليلها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'أولفي': [{'vocalized': u'أولفي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'بعضكم': [{'vocalized': u'بعضكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'كهما': [{'vocalized': u'كهما', 'procletic': u'ك-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'بعضكن': [{'vocalized': u'بعضكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'وكفيهما': [{'vocalized': u'وكفيهما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'}],

 u'أفعامتكن': [{'vocalized': u'أفعامتكن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'فحبذا': [{'vocalized': u'فحبذا', 'procletic': u'ف-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'حبذا', 'encletic': u'', 'type': u'فعل', 'original': u'حبذا'}],

 u'أوبشبهكما': [{'vocalized': u'أوبشبهكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'فللتيا': [{'vocalized': u'فللتيا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'أفكهاذين': [{'vocalized': u'أفكهاذين', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أولكلتا': [{'vocalized': u'أولكلتا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'},
 {'vocalized': u'أولكلتا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفلنحوهما': [{'vocalized': u'أفلنحوهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'أوخلفها': [{'vocalized': u'أوخلفها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'لذينك': [{'vocalized': u'لذينك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'وكذاته': [{'vocalized': u'وكذاته', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'وكذاتك': [{'vocalized': u'وكذاتك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'وللحظتها': [{'vocalized': u'وللحظتها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'وكذاتي': [{'vocalized': u'وكذاتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'وكذاتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'بعينهما': [{'vocalized': u'بعينهما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'كتلك': [{'vocalized': u'كتلك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'بأجمعي': [{'vocalized': u'بأجمعي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'بأجمعي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلجنوبي': [{'vocalized': u'فلجنوبي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'فلجنوبي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'فللتين': [{'vocalized': u'فللتين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'وعندئذ': [{'vocalized': u'وعندئذ', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'عندئذ', 'encletic': u'', 'type': u'اسم', 'original': u'عندئذ'}],

 u'بأجمعك': [{'vocalized': u'بأجمعك', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلجنوبك': [{'vocalized': u'فلجنوبك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'بأجمعه': [{'vocalized': u'بأجمعه', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'فمادامت': [{'vocalized': u'فمادامت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادامت', 'encletic': u'', 'type': u'فعل', 'original': u'مادامت'}],

 u'فلجنوبه': [{'vocalized': u'فلجنوبه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'حموكن': [{'vocalized': u'حموكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمو'}],

 u'فكغيرنا': [{'vocalized': u'فكغيرنا', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أوببعضكم': [{'vocalized': u'أوببعضكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'فحميهم': [{'vocalized': u'فحميهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'فحميهن': [{'vocalized': u'فحميهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'أوببعضكن': [{'vocalized': u'أوببعضكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'ألفيهما': [{'vocalized': u'ألفيهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'وللحظتهم': [{'vocalized': u'وللحظتهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فمازلتم': [{'vocalized': u'فمازلتم', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتم'}],

 u'أكأنكما': [{'vocalized': u'أكأنكما', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'أفلنا': [{'vocalized': u'أفلنا', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لنا', 'encletic': u'', 'type': u'ضمير', 'original': u'لنا'}],

 u'أفليمين': [{'vocalized': u'أفليمين', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'ولأن': [{'vocalized': u'ولأن', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'ولأن', 'procletic': u'و-ل-', 'tags': u'حرف;حرف نصب;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'ولأن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'أأناكم': [{'vocalized': u'أأناكم', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'أأناكن': [{'vocalized': u'أأناكن', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'ولأي': [{'vocalized': u'ولأي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'ولأي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'أكحسبهم': [{'vocalized': u'أكحسبهم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أكحسبهن': [{'vocalized': u'أكحسبهن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'ولأمامي': [{'vocalized': u'ولأمامي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'ولأمامي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'لليلهم': [{'vocalized': u'لليلهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'وعينك': [{'vocalized': u'وعينك', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'لليلهن': [{'vocalized': u'لليلهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'أفبعضكما': [{'vocalized': u'أفبعضكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'وعينه': [{'vocalized': u'وعينه', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'الألاء': [{'vocalized': u'الألاء', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'وعيني': [{'vocalized': u'وعيني', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'وعيني', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'فحينئذ': [{'vocalized': u'فحينئذ', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'حينئذ', 'encletic': u'', 'type': u'اسم', 'original': u'حينئذ'}],

 u'كبعضكن': [{'vocalized': u'كبعضكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'كبعضكم': [{'vocalized': u'كبعضكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلأجمعها': [{'vocalized': u'أفلأجمعها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكخلفكن': [{'vocalized': u'فكخلفكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'فأيان': [{'vocalized': u'فأيان', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'},
 {'vocalized': u'فأيان', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'},
 {'vocalized': u'فأيان', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أيان', 'encletic': u'', 'type': u'اسم', 'original': u'أيان'}],

 u'للاتي': [{'vocalized': u'للاتي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'لأعليكم': [{'vocalized': u'لأعليكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'لأعليكن': [{'vocalized': u'لأعليكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولذاته': [{'vocalized': u'ولذاته', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'بشهركما': [{'vocalized': u'بشهركما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'بجميعهم': [{'vocalized': u'بجميعهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعهم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'بجميعهن': [{'vocalized': u'بجميعهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعهن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فكغربك': [{'vocalized': u'فكغربك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'وذويكم': [{'vocalized': u'وذويكم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'وذويكن': [{'vocalized': u'وذويكن', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'ألأمامها': [{'vocalized': u'ألأمامها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'ولأناهم': [{'vocalized': u'ولأناهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'كزمانكم': [{'vocalized': u'كزمانكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'مافتئتما': [{'vocalized': u'مافتئتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئتما', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتما'},
 {'vocalized': u'مافتئتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئتما', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتما'}],

 u'وبأقلي': [{'vocalized': u'وبأقلي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'وبأقلي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'فكهاته': [{'vocalized': u'فكهاته', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'وضمنهم': [{'vocalized': u'وضمنهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ضمن'}],

 u'فكهاتي': [{'vocalized': u'فكهاتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'فأعلينا': [{'vocalized': u'فأعلينا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'وبأقلك': [{'vocalized': u'وبأقلك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'ألغيرهم': [{'vocalized': u'ألغيرهم', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيرهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'ألغيرهن': [{'vocalized': u'ألغيرهن', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيرهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'لازلت': [{'vocalized': u'لازلت', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'لازلت', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'لازلت', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'}],

 u'وحمونا': [{'vocalized': u'وحمونا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمو'}],

 u'كفي': [{'vocalized': u'كفي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'}],

 u'فبغيركن': [{'vocalized': u'فبغيركن', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'فبغيركم': [{'vocalized': u'فبغيركم', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'لأناهما': [{'vocalized': u'لأناهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'فلدينا': [{'vocalized': u'فلدينا', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدى'}],

 u'وكذلكما': [{'vocalized': u'وكذلكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'فنحوكم': [{'vocalized': u'فنحوكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'فنحوكن': [{'vocalized': u'فنحوكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'كزمانها': [{'vocalized': u'كزمانها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'ألغيرها': [{'vocalized': u'ألغيرها', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيرها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'فجميعي': [{'vocalized': u'فجميعي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلأجمعهن': [{'vocalized': u'أفلأجمعهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلأجمعهم': [{'vocalized': u'أفلأجمعهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فجميعك': [{'vocalized': u'فجميعك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعك', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'كحسبنا': [{'vocalized': u'كحسبنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'فجميعه': [{'vocalized': u'فجميعه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعه', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلعلنا': [{'vocalized': u'أفلعلنا', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لعل'}],

 u'كفيك': [{'vocalized': u'كفيك', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'}],

 u'كفيه': [{'vocalized': u'كفيه', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'}],

 u'بجنوبهن': [{'vocalized': u'بجنوبهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلسويكما': [{'vocalized': u'فلسويكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'كفيي': [{'vocalized': u'كفيي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'كفيي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'}],

 u'بجميعها': [{'vocalized': u'بجميعها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعها', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكتلكما': [{'vocalized': u'أفكتلكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'وثنا': [{'vocalized': u'وثنا', 'procletic': u'و-', 'tags': u'فعل;اختصار;عطف', 'stem': u'ثنا', 'encletic': u'', 'type': u'فعل', 'original': u'ثنا'}],

 u'بحميهن': [{'vocalized': u'بحميهن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'بحميهم': [{'vocalized': u'بحميهم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'فنفسها': [{'vocalized': u'فنفسها', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'نحوهما': [{'vocalized': u'نحوهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'أبنفسنا': [{'vocalized': u'أبنفسنا', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'لشطرهن': [{'vocalized': u'لشطرهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'لشطرهم': [{'vocalized': u'لشطرهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'فبأخيهم': [{'vocalized': u'فبأخيهم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'فبأخيهن': [{'vocalized': u'فبأخيهن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'أجمعهم': [{'vocalized': u'أجمعهم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أجمعهن': [{'vocalized': u'أجمعهن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'زماننا': [{'vocalized': u'زماننا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'أفثمة': [{'vocalized': u'أفثمة', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ثمة', 'encletic': u'', 'type': u'اسم', 'original': u'ثمة'}],

 u'كجنوبهما': [{'vocalized': u'كجنوبهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبغربنا': [{'vocalized': u'فبغربنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'ألخلفهم': [{'vocalized': u'ألخلفهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'وعينكن': [{'vocalized': u'وعينكن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'لإنهما': [{'vocalized': u'لإنهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'وعينكم': [{'vocalized': u'وعينكم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'ففاه': [{'vocalized': u'ففاه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فا'}],

 u'كذي': [{'vocalized': u'كذي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فشبهكما': [{'vocalized': u'فشبهكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'ففاي': [{'vocalized': u'ففاي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فا'},
 {'vocalized': u'ففاي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فا'}],

 u'أفعليها': [{'vocalized': u'أفعليها', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'كذه': [{'vocalized': u'كذه', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'لذاتي': [{'vocalized': u'لذاتي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'لذاتي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'فأول': [{'vocalized': u'فأول', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أول', 'encletic': u'', 'type': u'اسم', 'original': u'أول'}],

 u'أولأنانا': [{'vocalized': u'أولأنانا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'فأوه': [{'vocalized': u'فأوه', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أوه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أوه'}],

 u'فإياهم': [{'vocalized': u'فإياهم', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياهم', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهم'}],

 u'فإياهن': [{'vocalized': u'فإياهن', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياهن', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهن'}],

 u'لذاتك': [{'vocalized': u'لذاتك', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'لشهركما': [{'vocalized': u'لشهركما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'أفلفيها': [{'vocalized': u'أفلفيها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'فبعد': [{'vocalized': u'فبعد', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بعد', 'encletic': u'', 'type': u'اسم', 'original': u'بعد'}],

 u'عندي': [{'vocalized': u'عندي', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عند'},
 {'vocalized': u'عندي', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عند'}],

 u'فلذلك': [{'vocalized': u'فلذلك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'كعامة': [{'vocalized': u'كعامة', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'لئلا': [{'vocalized': u'لئلا', 'procletic': u'', 'tags': u'حرف;حرف نصب', 'stem': u'لئلا', 'encletic': u'', 'type': u'حرف', 'original': u'لئلا'}],

 u'كذا': [{'vocalized': u'كذا', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'كذا', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'كذا', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'كذا', 'encletic': u'', 'type': u'اسم', 'original': u'كذا'}],

 u'أتحته': [{'vocalized': u'أتحته', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'أتحتك': [{'vocalized': u'أتحتك', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'وأبدا': [{'vocalized': u'وأبدا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أبدا', 'encletic': u'', 'type': u'اسم', 'original': u'أبدا'}],

 u'فأخي': [{'vocalized': u'فأخي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'أولتلكم': [{'vocalized': u'أولتلكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أتحتي': [{'vocalized': u'أتحتي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'أتحتي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'فإياها': [{'vocalized': u'فإياها', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياها', 'encletic': u'', 'type': u'ضمير', 'original': u'إياها'}],

 u'بحميها': [{'vocalized': u'بحميها', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'فلخلفهما': [{'vocalized': u'فلخلفهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'ففيك': [{'vocalized': u'ففيك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيك', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'فنفسهن': [{'vocalized': u'فنفسهن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'ففيم': [{'vocalized': u'ففيم', 'procletic': u'ف-', 'tags': u'حرف;حرف استفهام;عطف', 'stem': u'فيم', 'encletic': u'', 'type': u'حرف', 'original': u'فيم'}],

 u'ففيه': [{'vocalized': u'ففيه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيه', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'لشطرها': [{'vocalized': u'لشطرها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'ففيي': [{'vocalized': u'ففيي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيي', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'ففيي', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'وكغروبي': [{'vocalized': u'وكغروبي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'وكغروبي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'ألازالوا': [{'vocalized': u'ألازالوا', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالوا'}],

 u'فبأخيها': [{'vocalized': u'فبأخيها', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'ولتلقاءهما': [{'vocalized': u'ولتلقاءهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ألخلفها': [{'vocalized': u'ألخلفها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'أوكغير': [{'vocalized': u'أوكغير', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'أومثلكما': [{'vocalized': u'أومثلكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'ولغربها': [{'vocalized': u'ولغربها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'فلحظتك': [{'vocalized': u'فلحظتك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'ألشبهنا': [{'vocalized': u'ألشبهنا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'فعنهن': [{'vocalized': u'فعنهن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'عنهن': [{'vocalized': u'عنهن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'فأمسى': [{'vocalized': u'فأمسى', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'أمسى', 'encletic': u'', 'type': u'فعل', 'original': u'أمسى'}],

 u'وراءك': [{'vocalized': u'وراءك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'وراءك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وراءك'},
 {'vocalized': u'وراءك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'وراءك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وراءك'},
 {'vocalized': u'وراءك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'ومنهم': [{'vocalized': u'ومنهم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فلهب': [{'vocalized': u'فلهب', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'هب', 'encletic': u'', 'type': u'فعل', 'original': u'هب'}],

 u'ومنهن': [{'vocalized': u'ومنهن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'فبأعليها': [{'vocalized': u'فبأعليها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'كبعضي': [{'vocalized': u'كبعضي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'كبعضي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فلأعليكما': [{'vocalized': u'فلأعليكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فأناكما': [{'vocalized': u'فأناكما', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'كبعضه': [{'vocalized': u'كبعضه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'أوذلكما': [{'vocalized': u'أوذلكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'بأبيهن': [{'vocalized': u'بأبيهن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'أفبنحوكما': [{'vocalized': u'أفبنحوكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'كبعضك': [{'vocalized': u'كبعضك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'بأبيهم': [{'vocalized': u'بأبيهم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'أفتحته': [{'vocalized': u'أفتحته', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'ووقتك': [{'vocalized': u'ووقتك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'أفتحتك': [{'vocalized': u'أفتحتك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'واللذين': [{'vocalized': u'واللذين', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'كبعضهما': [{'vocalized': u'كبعضهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'ووقتي': [{'vocalized': u'ووقتي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'ووقتي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'ألأنتن': [{'vocalized': u'ألأنتن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'أفتحتي': [{'vocalized': u'أفتحتي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'أفتحتي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'ألأنتم': [{'vocalized': u'ألأنتم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'وبزمانك': [{'vocalized': u'وبزمانك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'فبأعليهم': [{'vocalized': u'فبأعليهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبأعليهن': [{'vocalized': u'فبأعليهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'تارة': [{'vocalized': u'تارة', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'تارة', 'encletic': u'', 'type': u'اسم', 'original': u'تارة'}],

 u'أوكنحونا': [{'vocalized': u'أوكنحونا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'وبزماني': [{'vocalized': u'وبزماني', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'وبزماني', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'بأبيها': [{'vocalized': u'بأبيها', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'فلعمرنا': [{'vocalized': u'فلعمرنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لعمر'}],

 u'أوبهاتين': [{'vocalized': u'أوبهاتين', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'وبأخي': [{'vocalized': u'وبأخي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'وبغروبنا': [{'vocalized': u'وبغروبنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'مازلتما': [{'vocalized': u'مازلتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتما'},
 {'vocalized': u'مازلتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتما'}],

 u'فلفيهما': [{'vocalized': u'فلفيهما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'ولأجمعكما': [{'vocalized': u'ولأجمعكما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفهاتي': [{'vocalized': u'أفهاتي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'مثله': [{'vocalized': u'مثله', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'فحاشاكما': [{'vocalized': u'فحاشاكما', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'حاشا'}],

 u'بغربك': [{'vocalized': u'بغربك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'أفأنا': [{'vocalized': u'أفأنا', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'أفأنا', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'أفهاته': [{'vocalized': u'أفهاته', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'بذين': [{'vocalized': u'بذين', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'فعينكما': [{'vocalized': u'فعينكما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'ليتهما': [{'vocalized': u'ليتهما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-هما', 'type': u'حرف', 'original': u'ليت'}],

 u'ومنها': [{'vocalized': u'ومنها', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'فكابننا': [{'vocalized': u'فكابننا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'فلكلكما': [{'vocalized': u'فلكلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'هاذين': [{'vocalized': u'هاذين', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'ألعامتها': [{'vocalized': u'ألعامتها', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'ليتكن': [{'vocalized': u'ليتكن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-كن', 'type': u'حرف', 'original': u'ليت'}],

 u'أفلشمالك': [{'vocalized': u'أفلشمالك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'لسنا': [{'vocalized': u'لسنا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لسنا', 'encletic': u'', 'type': u'فعل', 'original': u'لسنا'}],

 u'ولبعض': [{'vocalized': u'ولبعض', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعض', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'فبحميهن': [{'vocalized': u'فبحميهن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'فبحميهم': [{'vocalized': u'فبحميهم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'بعامة': [{'vocalized': u'بعامة', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'فبعدنا': [{'vocalized': u'فبعدنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعد'}],

 u'فبجنوبهم': [{'vocalized': u'فبجنوبهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفلعامتهما': [{'vocalized': u'أفلعامتهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'فكشبهها': [{'vocalized': u'فكشبهها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'فكأولئكم': [{'vocalized': u'فكأولئكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'وهناك': [{'vocalized': u'وهناك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'حموهما': [{'vocalized': u'حموهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمو'}],

 u'لكلكم': [{'vocalized': u'لكلكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أنفسهما': [{'vocalized': u'أنفسهما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'أبمثل': [{'vocalized': u'أبمثل', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'لكلكن': [{'vocalized': u'لكلكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'وكأكثرهم': [{'vocalized': u'وكأكثرهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'وكأكثرهن': [{'vocalized': u'وكأكثرهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فضمنهن': [{'vocalized': u'فضمنهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ضمن'}],

 u'لإنها': [{'vocalized': u'لإنها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'لئن': [{'vocalized': u'لئن', 'procletic': u'', 'tags': u'حرف;حرف شرط', 'stem': u'لئن', 'encletic': u'', 'type': u'حرف', 'original': u'لئن'}],

 u'لجنب': [{'vocalized': u'لجنب', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'أفكأنكن': [{'vocalized': u'أفكأنكن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'أفعنها': [{'vocalized': u'أفعنها', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'بجميعكما': [{'vocalized': u'بجميعكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعكما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكأنكم': [{'vocalized': u'أفكأنكم', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'وكلحظتكما': [{'vocalized': u'وكلحظتكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'فثم': [{'vocalized': u'فثم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'},
 {'vocalized': u'فثم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'}],

 u'فكشبههم': [{'vocalized': u'فكشبههم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'فضمنكم': [{'vocalized': u'فضمنكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ضمن'}],

 u'فكشبههن': [{'vocalized': u'فكشبههن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'وأباهما': [{'vocalized': u'وأباهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبا'}],

 u'كهو': [{'vocalized': u'كهو', 'procletic': u'ك-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'وكأكثرها': [{'vocalized': u'وكأكثرها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'لإنهم': [{'vocalized': u'لإنهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'أولعنكما': [{'vocalized': u'أولعنكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'لإنهن': [{'vocalized': u'لإنهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'ولساعتنا': [{'vocalized': u'ولساعتنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفلسويه': [{'vocalized': u'أفلسويه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أفعنهن': [{'vocalized': u'أفعنهن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أفعنهم': [{'vocalized': u'أفعنهم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'وكخلفهما': [{'vocalized': u'وكخلفهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'فعدا': [{'vocalized': u'فعدا', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف', 'stem': u'عدا', 'encletic': u'', 'type': u'فعل', 'original': u'عدا'}],

 u'كأبيكن': [{'vocalized': u'كأبيكن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'فشرقكم': [{'vocalized': u'فشرقكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'أكحسبك': [{'vocalized': u'أكحسبك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فوقنا': [{'vocalized': u'فوقنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'وراء': [{'vocalized': u'وراء', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'لعلهما': [{'vocalized': u'لعلهما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لعل'}],

 u'وبكلتا': [{'vocalized': u'وبكلتا', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'فلوقتهن': [{'vocalized': u'فلوقتهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'فبجنوبها': [{'vocalized': u'فبجنوبها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'ومكانكم': [{'vocalized': u'ومكانكم', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانكم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكم'}],

 u'ومكانكن': [{'vocalized': u'ومكانكن', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانكن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكن'}],

 u'وليتكما': [{'vocalized': u'وليتكما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-كما', 'type': u'حرف', 'original': u'ليت'}],

 u'فكزماننا': [{'vocalized': u'فكزماننا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'وبجنوبها': [{'vocalized': u'وبجنوبها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'فليمينهما': [{'vocalized': u'فليمينهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'فكأية': [{'vocalized': u'فكأية', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'فلأنها': [{'vocalized': u'فلأنها', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'فإياي': [{'vocalized': u'فإياي', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياي', 'encletic': u'', 'type': u'ضمير', 'original': u'إياي'}],

 u'أوكبعضهم': [{'vocalized': u'أوكبعضهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'فلتين': [{'vocalized': u'فلتين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'فلشماله': [{'vocalized': u'فلشماله', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'فإياك': [{'vocalized': u'فإياك', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياك', 'encletic': u'', 'type': u'ضمير', 'original': u'إياك'},
 {'vocalized': u'فإياك', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياك', 'encletic': u'', 'type': u'ضمير', 'original': u'إياك'}],

 u'بشهرهن': [{'vocalized': u'بشهرهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'بشهرهم': [{'vocalized': u'بشهرهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'فإياه': [{'vocalized': u'فإياه', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياه', 'encletic': u'', 'type': u'ضمير', 'original': u'إياه'}],

 u'وإنكم': [{'vocalized': u'وإنكم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'وإنكن': [{'vocalized': u'وإنكن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'فبلحظتكم': [{'vocalized': u'فبلحظتكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلمثلكما': [{'vocalized': u'أفلمثلكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'فبلحظتكن': [{'vocalized': u'فبلحظتكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'كأخيهم': [{'vocalized': u'كأخيهم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'كأخيهن': [{'vocalized': u'كأخيهن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'فلشمالك': [{'vocalized': u'فلشمالك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'فلأنهن': [{'vocalized': u'فلأنهن', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'فلأنهم': [{'vocalized': u'فلأنهم', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'ألذانك': [{'vocalized': u'ألذانك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'وحماها': [{'vocalized': u'وحماها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حما'}],

 u'أوكبعضها': [{'vocalized': u'أوكبعضها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'فبغربها': [{'vocalized': u'فبغربها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'بشهرها': [{'vocalized': u'بشهرها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'ألمنهما': [{'vocalized': u'ألمنهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'فحميكما': [{'vocalized': u'فحميكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'ولمعكما': [{'vocalized': u'ولمعكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'وكلاهما': [{'vocalized': u'وكلاهما', 'procletic': u'و-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كلاهما', 'encletic': u'', 'type': u'حرف', 'original': u'كلاهما'}],

 u'فبخلفهم': [{'vocalized': u'فبخلفهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'كأخيها': [{'vocalized': u'كأخيها', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'وللحظتكما': [{'vocalized': u'وللحظتكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبنفسهما': [{'vocalized': u'فبنفسهما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'وعليهما': [{'vocalized': u'وعليهما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'فكابنهما': [{'vocalized': u'فكابنهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'فكحسبكما': [{'vocalized': u'فكحسبكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'فلشمالي': [{'vocalized': u'فلشمالي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'فلشمالي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'أبجميعنا': [{'vocalized': u'أبجميعنا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعنا', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وشهركما': [{'vocalized': u'وشهركما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'أفبكليهما': [{'vocalized': u'أفبكليهما', 'procletic': u'أ-ف-ب-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'ولدنكن': [{'vocalized': u'ولدنكن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدن'}],

 u'أوبأجمعنا': [{'vocalized': u'أوبأجمعنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'بجنوبهما': [{'vocalized': u'بجنوبهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'لأيتكم': [{'vocalized': u'لأيتكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'لأيتكن': [{'vocalized': u'لأيتكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'وأبيي': [{'vocalized': u'وأبيي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'وأبيي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'أبحسبكما': [{'vocalized': u'أبحسبكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'فبينكما': [{'vocalized': u'فبينكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بين'}],

 u'أذانك': [{'vocalized': u'أذانك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'ماداموا': [{'vocalized': u'ماداموا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماداموا', 'encletic': u'', 'type': u'فعل', 'original': u'ماداموا'}],

 u'أشمالها': [{'vocalized': u'أشمالها', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'أبأجمعكما': [{'vocalized': u'أبأجمعكما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألحسب': [{'vocalized': u'ألحسب', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'وأبيهن': [{'vocalized': u'وأبيهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'وأبيهم': [{'vocalized': u'وأبيهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'غيرنا': [{'vocalized': u'غيرنا', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أفبنفسهن': [{'vocalized': u'أفبنفسهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أفبنفسهم': [{'vocalized': u'أفبنفسهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'وأب': [{'vocalized': u'وأب', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أب', 'encletic': u'', 'type': u'اسم', 'original': u'أب'}],

 u'وأخ': [{'vocalized': u'وأخ', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخ', 'encletic': u'', 'type': u'اسم', 'original': u'أخ'}],

 u'ولعلكم': [{'vocalized': u'ولعلكم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لعل'}],

 u'ولعلكن': [{'vocalized': u'ولعلكن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لعل'}],

 u'وعامتنا': [{'vocalized': u'وعامتنا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أولسويكم': [{'vocalized': u'أولسويكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'ألإنه': [{'vocalized': u'ألإنه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'أولسويكن': [{'vocalized': u'أولسويكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'ألإنك': [{'vocalized': u'ألإنك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'فبضعي': [{'vocalized': u'فبضعي', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'},
 {'vocalized': u'فبضعي', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'}],

 u'أنتما': [{'vocalized': u'أنتما', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'ألإني': [{'vocalized': u'ألإني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'ألإني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'أفلهاته': [{'vocalized': u'أفلهاته', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'لوما': [{'vocalized': u'لوما', 'procletic': u'', 'tags': u'حرف;الحروف(حروف)', 'stem': u'لوما', 'encletic': u'', 'type': u'حرف', 'original': u'لوما'}],

 u'وبعدهما': [{'vocalized': u'وبعدهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعد'}],

 u'أفلهاتي': [{'vocalized': u'أفلهاتي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'فكحميكما': [{'vocalized': u'فكحميكما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'ألإنا': [{'vocalized': u'ألإنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'يمينك': [{'vocalized': u'يمينك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'وإياك': [{'vocalized': u'وإياك', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياك', 'encletic': u'', 'type': u'ضمير', 'original': u'إياك'},
 {'vocalized': u'وإياك', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياك', 'encletic': u'', 'type': u'ضمير', 'original': u'إياك'}],

 u'أجمعكم': [{'vocalized': u'أجمعكم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'يميني': [{'vocalized': u'يميني', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'يميني', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'أولتحت': [{'vocalized': u'أولتحت', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'بلحظتكم': [{'vocalized': u'بلحظتكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'أوعامتهما': [{'vocalized': u'أوعامتهما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'بلحظتكن': [{'vocalized': u'بلحظتكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'كشطره': [{'vocalized': u'كشطره', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'أوشماله': [{'vocalized': u'أوشماله', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'كشطرك': [{'vocalized': u'كشطرك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'وماانفكا': [{'vocalized': u'وماانفكا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكا'}],

 u'أوشمالك': [{'vocalized': u'أوشمالك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'ألمني': [{'vocalized': u'ألمني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'ألمني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'كشطري': [{'vocalized': u'كشطري', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'كشطري', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'أوشمالي': [{'vocalized': u'أوشمالي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'أوشمالي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'كأقلهما': [{'vocalized': u'كأقلهما', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'بماذا': [{'vocalized': u'بماذا', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'بماذا', 'encletic': u'', 'type': u'اسم', 'original': u'بماذا'}],

 u'معاذك': [{'vocalized': u'معاذك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-ك', 'type': u'اسم', 'original': u'معاذ'}],

 u'وحيني': [{'vocalized': u'وحيني', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حين'},
 {'vocalized': u'وحيني', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حين'}],

 u'فكساعة': [{'vocalized': u'فكساعة', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفيها': [{'vocalized': u'أفيها', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'أفكليهما': [{'vocalized': u'أفكليهما', 'procletic': u'أ-ف-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'وحينه': [{'vocalized': u'وحينه', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حين'}],

 u'فكعينهما': [{'vocalized': u'فكعينهما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فأخاكن': [{'vocalized': u'فأخاكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخا'}],

 u'وأبيها': [{'vocalized': u'وأبيها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'فأخاكم': [{'vocalized': u'فأخاكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخا'}],

 u'وكأسفلها': [{'vocalized': u'وكأسفلها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'وأف': [{'vocalized': u'وأف', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أف', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أف'},
 {'vocalized': u'وأف', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أف', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أف'}],

 u'وأن': [{'vocalized': u'وأن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وأن', 'procletic': u'و-', 'tags': u'حرف;حرف نصب;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'وأي': [{'vocalized': u'وأي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وأي', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وأي', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وأي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'وإليه': [{'vocalized': u'وإليه', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'وإليك': [{'vocalized': u'وإليك', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليك'},
 {'vocalized': u'وإليك', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'حم': [{'vocalized': u'حم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'حم', 'encletic': u'', 'type': u'اسم', 'original': u'حم'}],

 u'كلها': [{'vocalized': u'كلها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلها', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'فوراءكن': [{'vocalized': u'فوراءكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'حي': [{'vocalized': u'حي', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'حي', 'encletic': u'', 'type': u'اسم فعل', 'original': u'حي'}],

 u'أمعهم': [{'vocalized': u'أمعهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'فلشبهكم': [{'vocalized': u'فلشبهكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'حسبي': [{'vocalized': u'حسبي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'حسبي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أمعهن': [{'vocalized': u'أمعهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'بأسفلك': [{'vocalized': u'بأسفلك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'حسبك': [{'vocalized': u'حسبك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فبأقلها': [{'vocalized': u'فبأقلها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'بنا': [{'vocalized': u'بنا', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'بنا', 'encletic': u'', 'type': u'ضمير', 'original': u'بنا'}],

 u'حسبه': [{'vocalized': u'حسبه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أوككلنا': [{'vocalized': u'أوككلنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'ؤ': [{'vocalized': u'ؤ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ؤ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ؤ'}],

 u'بكلنا': [{'vocalized': u'بكلنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلنا', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'ألذي': [{'vocalized': u'ألذي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فلارتد': [{'vocalized': u'فلارتد', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'ارتد', 'encletic': u'', 'type': u'فعل', 'original': u'ارتد'}],

 u'أولحسبكما': [{'vocalized': u'أولحسبكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'وأبيه': [{'vocalized': u'وأبيه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'فماانفكت': [{'vocalized': u'فماانفكت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكت'}],

 u'وأبيك': [{'vocalized': u'وأبيك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'وبشبهكما': [{'vocalized': u'وبشبهكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'وحرى': [{'vocalized': u'وحرى', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'حرى', 'encletic': u'', 'type': u'فعل', 'original': u'حرى'}],

 u'فماانفكا': [{'vocalized': u'فماانفكا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكا'}],

 u'لكليهما': [{'vocalized': u'لكليهما', 'procletic': u'ل-', 'tags': u'حرف;توكيد;مجرور', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'ولنحوهما': [{'vocalized': u'ولنحوهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'أفبأولاء': [{'vocalized': u'أفبأولاء', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'ولهاته': [{'vocalized': u'ولهاته', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'شهره': [{'vocalized': u'شهره', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'خلاكما': [{'vocalized': u'خلاكما', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'خلا'}],

 u'وككليهما': [{'vocalized': u'وككليهما', 'procletic': u'و-ك-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'ولهاتي': [{'vocalized': u'ولهاتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'ولإليها': [{'vocalized': u'ولإليها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'كلهم': [{'vocalized': u'كلهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلهم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'كلهن': [{'vocalized': u'كلهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلهن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أونفسي': [{'vocalized': u'أونفسي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أونفسي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أونفسه': [{'vocalized': u'أونفسه', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'شهرك': [{'vocalized': u'شهرك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'أونفسك': [{'vocalized': u'أونفسك', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'ألنفس': [{'vocalized': u'ألنفس', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفس', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أمعها': [{'vocalized': u'أمعها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'وكشبهك': [{'vocalized': u'وكشبهك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'وأخا': [{'vocalized': u'وأخا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخا', 'encletic': u'', 'type': u'اسم', 'original': u'أخا'}],

 u'وكشبهه': [{'vocalized': u'وكشبهه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'ووقت': [{'vocalized': u'ووقت', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'وكشبهي': [{'vocalized': u'وكشبهي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'وكشبهي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'فبأقلهن': [{'vocalized': u'فبأقلهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'فبأقلهم': [{'vocalized': u'فبأقلهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'ألحسبكما': [{'vocalized': u'ألحسبكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'فكسويهن': [{'vocalized': u'فكسويهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'فكسويهم': [{'vocalized': u'فكسويهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أنانا': [{'vocalized': u'أنانا', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'كأعلى': [{'vocalized': u'كأعلى', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'لغروبكما': [{'vocalized': u'لغروبكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'فلنا': [{'vocalized': u'فلنا', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لنا', 'encletic': u'', 'type': u'ضمير', 'original': u'لنا'}],

 u'وشطرنا': [{'vocalized': u'وشطرنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'أنهن': [{'vocalized': u'أنهن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'وأسفلهن': [{'vocalized': u'وأسفلهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'فجميعها': [{'vocalized': u'فجميعها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعها', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'أنهم': [{'vocalized': u'أنهم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'كشرقك': [{'vocalized': u'كشرقك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'ولصار': [{'vocalized': u'ولصار', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'صار', 'encletic': u'', 'type': u'فعل', 'original': u'صار'}],

 u'لذه': [{'vocalized': u'لذه', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'حولكن': [{'vocalized': u'حولكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حول'}],

 u'وحماي': [{'vocalized': u'وحماي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حما'},
 {'vocalized': u'وحماي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حما'}],

 u'ألجميعنا': [{'vocalized': u'ألجميعنا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعنا', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'هاهنا': [{'vocalized': u'هاهنا', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هاهنا', 'encletic': u'', 'type': u'اسم', 'original': u'هاهنا'}],

 u'فشرقي': [{'vocalized': u'فشرقي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'فشرقي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'فحي': [{'vocalized': u'فحي', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'حي', 'encletic': u'', 'type': u'اسم فعل', 'original': u'حي'}],

 u'ولانبرى': [{'vocalized': u'ولانبرى', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'انبرى', 'encletic': u'', 'type': u'فعل', 'original': u'انبرى'}],

 u'جنبهما': [{'vocalized': u'جنبهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'أومعكما': [{'vocalized': u'أومعكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'ألعامتهن': [{'vocalized': u'ألعامتهن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فحم': [{'vocalized': u'فحم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حم', 'encletic': u'', 'type': u'اسم', 'original': u'حم'}],

 u'فكأخيهما': [{'vocalized': u'فكأخيهما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'وغربكم': [{'vocalized': u'وغربكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'لذا': [{'vocalized': u'لذا', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'لذا', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'ولفوقكن': [{'vocalized': u'ولفوقكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'وحماه': [{'vocalized': u'وحماه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حما'}],

 u'لذاتنا': [{'vocalized': u'لذاتنا', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'فكساعتكما': [{'vocalized': u'فكساعتكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكسويها': [{'vocalized': u'فكسويها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أكهي': [{'vocalized': u'أكهي', 'procletic': u'أ-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'أكهو': [{'vocalized': u'أكهو', 'procletic': u'أ-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'أوله': [{'vocalized': u'أوله', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'له', 'encletic': u'', 'type': u'ضمير', 'original': u'له'}],

 u'أكهم': [{'vocalized': u'أكهم', 'procletic': u'أ-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أنكما': [{'vocalized': u'أنكما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'وأخي': [{'vocalized': u'وأخي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'هيت': [{'vocalized': u'هيت', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'هيت', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هيت'}],

 u'لشبهكما': [{'vocalized': u'لشبهكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'هيا': [{'vocalized': u'هيا', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'هيا', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هيا'},
 {'vocalized': u'هيا', 'procletic': u'', 'tags': u'حرف;حرف نداء', 'stem': u'هيا', 'encletic': u'', 'type': u'حرف', 'original': u'هيا'}],

 u'لمثلهما': [{'vocalized': u'لمثلهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'أنها': [{'vocalized': u'أنها', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'فجميعهن': [{'vocalized': u'فجميعهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعهن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فلأمامكن': [{'vocalized': u'فلأمامكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'فماانفككتم': [{'vocalized': u'فماانفككتم', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتم', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتم'}],

 u'فلأمامكم': [{'vocalized': u'فلأمامكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'بابني': [{'vocalized': u'بابني', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'بابني', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'بابنه': [{'vocalized': u'بابنه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'فكذات': [{'vocalized': u'فكذات', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'أبذي': [{'vocalized': u'أبذي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'بابنك': [{'vocalized': u'بابنك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'فلذويها': [{'vocalized': u'فلذويها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكنفس': [{'vocalized': u'فكنفس', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'لتلقاءكم': [{'vocalized': u'لتلقاءكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفعليكم': [{'vocalized': u'أفعليكم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'لتلقاءكن': [{'vocalized': u'لتلقاءكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولفيك': [{'vocalized': u'ولفيك', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'ابنهم': [{'vocalized': u'ابنهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'ولفيه': [{'vocalized': u'ولفيه', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'ابنهن': [{'vocalized': u'ابنهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'وبتي': [{'vocalized': u'وبتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'وبأخيكما': [{'vocalized': u'وبأخيكما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'وأضحى': [{'vocalized': u'وأضحى', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'أضحى', 'encletic': u'', 'type': u'فعل', 'original': u'أضحى'}],

 u'فعليكما': [{'vocalized': u'فعليكما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'أولعامتها': [{'vocalized': u'أولعامتها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'وبشرقهم': [{'vocalized': u'وبشرقهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'وبته': [{'vocalized': u'وبته', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'أفلوراءنا': [{'vocalized': u'أفلوراءنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'شرقها': [{'vocalized': u'شرقها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'فبعامتها': [{'vocalized': u'فبعامتها', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'ولرجع': [{'vocalized': u'ولرجع', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'رجع', 'encletic': u'', 'type': u'فعل', 'original': u'رجع'}],

 u'أفلعليهما': [{'vocalized': u'أفلعليهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'فبفيهما': [{'vocalized': u'فبفيهما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'}],

 u'ودونك': [{'vocalized': u'ودونك', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'دونك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'دونك'}],

 u'أولعامتهن': [{'vocalized': u'أولعامتهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'أولعامتهم': [{'vocalized': u'أولعامتهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'وخلفه': [{'vocalized': u'وخلفه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'فبعامتهن': [{'vocalized': u'فبعامتهن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فبعامتهم': [{'vocalized': u'فبعامتهم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'بأعليكما': [{'vocalized': u'بأعليكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'وللحظتكم': [{'vocalized': u'وللحظتكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فكذاك': [{'vocalized': u'فكذاك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'فلأجمعكما': [{'vocalized': u'فلأجمعكما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'يمينهما': [{'vocalized': u'يمينهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'لديه': [{'vocalized': u'لديه', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدى'}],

 u'لغربهما': [{'vocalized': u'لغربهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'فلذويهم': [{'vocalized': u'فلذويهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'لديك': [{'vocalized': u'لديك', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدى'}],

 u'فلذويهن': [{'vocalized': u'فلذويهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'ففوقكن': [{'vocalized': u'ففوقكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'ففوقكم': [{'vocalized': u'ففوقكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'وأيضا': [{'vocalized': u'وأيضا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'أيضا', 'encletic': u'', 'type': u'اسم', 'original': u'أيضا'}],

 u'ولوراءهما': [{'vocalized': u'ولوراءهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'فكأين': [{'vocalized': u'فكأين', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'كأين', 'encletic': u'', 'type': u'اسم', 'original': u'كأين'},
 {'vocalized': u'فكأين', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'كأين', 'encletic': u'', 'type': u'اسم', 'original': u'كأين'}],

 u'ابنها': [{'vocalized': u'ابنها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'وأمس': [{'vocalized': u'وأمس', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أمس', 'encletic': u'', 'type': u'اسم', 'original': u'أمس'}],

 u'فكنفسهم': [{'vocalized': u'فكنفسهم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'فكنفسهن': [{'vocalized': u'فكنفسهن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلنفسهما': [{'vocalized': u'أفلنفسهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'ألطالما': [{'vocalized': u'ألطالما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'بأن': [{'vocalized': u'بأن', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'بأن', 'procletic': u'ب-', 'tags': u'حرف;حرف نصب;مجرور', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'أسفلنا': [{'vocalized': u'أسفلنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'بأي': [{'vocalized': u'بأي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'بأي', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'فثنا': [{'vocalized': u'فثنا', 'procletic': u'ف-', 'tags': u'فعل;اختصار;عطف', 'stem': u'ثنا', 'encletic': u'', 'type': u'فعل', 'original': u'ثنا'}],

 u'فغدا': [{'vocalized': u'فغدا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'غدا', 'encletic': u'', 'type': u'اسم', 'original': u'غدا'},
 {'vocalized': u'فغدا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'غدا', 'encletic': u'', 'type': u'فعل', 'original': u'غدا'}],

 u'وبعامة': [{'vocalized': u'وبعامة', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أفمن': [{'vocalized': u'أفمن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم موصول;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'أفمن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'فلأيتكما': [{'vocalized': u'فلأيتكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'فحموكما': [{'vocalized': u'فحموكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمو'}],

 u'أفلمنهما': [{'vocalized': u'أفلمنهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'لكليكما': [{'vocalized': u'لكليكما', 'procletic': u'ل-', 'tags': u'حرف;توكيد;مجرور', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'هنا': [{'vocalized': u'هنا', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هنا', 'encletic': u'', 'type': u'اسم', 'original': u'هنا'}],

 u'وإنا': [{'vocalized': u'وإنا', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'فكلحظتهن': [{'vocalized': u'فكلحظتهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلك': [{'vocalized': u'أفلك', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لك', 'encletic': u'', 'type': u'ضمير', 'original': u'لك'}],

 u'أفجميعها': [{'vocalized': u'أفجميعها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعها', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلم': [{'vocalized': u'أفلم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جزم;عطف;استفهام', 'stem': u'لم', 'encletic': u'', 'type': u'حرف', 'original': u'لم'}],

 u'أفلن': [{'vocalized': u'أفلن', 'procletic': u'أ-ف-', 'tags': u'حرف;الحروف(حروف);عطف;استفهام', 'stem': u'لن', 'encletic': u'', 'type': u'حرف', 'original': u'لن'}],

 u'أفله': [{'vocalized': u'أفله', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'له', 'encletic': u'', 'type': u'ضمير', 'original': u'له'}],

 u'أفلو': [{'vocalized': u'أفلو', 'procletic': u'أ-ف-', 'tags': u'حرف;الحروف(حروف);عطف;استفهام', 'stem': u'لو', 'encletic': u'', 'type': u'حرف', 'original': u'لو'}],

 u'فبالذي': [{'vocalized': u'فبالذي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'بضعنا': [{'vocalized': u'بضعنا', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بضع'}],

 u'فذلكم': [{'vocalized': u'فذلكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'وفاهن': [{'vocalized': u'وفاهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فا'}],

 u'فذلكن': [{'vocalized': u'فذلكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أمامك': [{'vocalized': u'أمامك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'أمامك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أمامك'},
 {'vocalized': u'أمامك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'وخلفك': [{'vocalized': u'وخلفك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'أمامه': [{'vocalized': u'أمامه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'أمامي': [{'vocalized': u'أمامي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'أمامي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'فأخاهما': [{'vocalized': u'فأخاهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخا'}],

 u'وإنه': [{'vocalized': u'وإنه', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'وإنك': [{'vocalized': u'وإنك', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'أفجميعهن': [{'vocalized': u'أفجميعهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعهن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فكبعضكم': [{'vocalized': u'فكبعضكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلا': [{'vocalized': u'أفلا', 'procletic': u'أ-ف-', 'tags': u'حرف;المشبهة بليس;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'أفلا', 'procletic': u'أ-ف-', 'tags': u'حرف;نافية للجنس;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'أفلا', 'procletic': u'أ-ف-', 'tags': u'حرف;ناهية;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'أفلا', 'procletic': u'أ-ف-', 'tags': u'حرف;نافية;عطف;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'}],

 u'وكحميكن': [{'vocalized': u'وكحميكن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'وكحميكم': [{'vocalized': u'وكحميكم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'كشهرهما': [{'vocalized': u'كشهرهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'وإني': [{'vocalized': u'وإني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'وإني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'فلليلكما': [{'vocalized': u'فلليلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'فكنفسها': [{'vocalized': u'فكنفسها', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'وحولنا': [{'vocalized': u'وحولنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حول'}],

 u'فتحتكن': [{'vocalized': u'فتحتكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'فتحتكم': [{'vocalized': u'فتحتكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'ألفيكما': [{'vocalized': u'ألفيكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'وأما': [{'vocalized': u'وأما', 'procletic': u'و-', 'tags': u'حرف;حرف شرط وتفصيل وتوكيد;عطف', 'stem': u'أما', 'encletic': u'', 'type': u'حرف', 'original': u'أما'},
 {'vocalized': u'وأما', 'procletic': u'و-', 'tags': u'حرف;حرف عرض;عطف', 'stem': u'أما', 'encletic': u'', 'type': u'حرف', 'original': u'أما'}],

 u'بنفسكما': [{'vocalized': u'بنفسكما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'لساعتكما': [{'vocalized': u'لساعتكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفنفسك': [{'vocalized': u'أفنفسك', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'فنحوها': [{'vocalized': u'فنحوها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'أفنفسه': [{'vocalized': u'أفنفسه', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'أفنفسي': [{'vocalized': u'أفنفسي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفنفسي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'ألبعضها': [{'vocalized': u'ألبعضها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'فوقهما': [{'vocalized': u'فوقهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'كبعضهن': [{'vocalized': u'كبعضهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'كبعضهم': [{'vocalized': u'كبعضهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'فكخلفهم': [{'vocalized': u'فكخلفهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'أوغيرك': [{'vocalized': u'أوغيرك', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'ولساعتكما': [{'vocalized': u'ولساعتكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوغيره': [{'vocalized': u'أوغيره', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'ألازالتا': [{'vocalized': u'ألازالتا', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالتا'}],

 u'أوغيري': [{'vocalized': u'أوغيري', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أوغيري', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'للائي': [{'vocalized': u'للائي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'بجميعكم': [{'vocalized': u'بجميعكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعكم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'بجميعكن': [{'vocalized': u'بجميعكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعكن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'ألخلفك': [{'vocalized': u'ألخلفك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'لكأنها': [{'vocalized': u'لكأنها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'وعنكن': [{'vocalized': u'وعنكن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'أفأناهما': [{'vocalized': u'أفأناهما', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'فكغيرهما': [{'vocalized': u'فكغيرهما', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'أوكجميعكما': [{'vocalized': u'أوكجميعكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'فبغيرها': [{'vocalized': u'فبغيرها', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'ألخلفه': [{'vocalized': u'ألخلفه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'فكخلفه': [{'vocalized': u'فكخلفه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'وكلحظتكم': [{'vocalized': u'وكلحظتكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبأجمعكما': [{'vocalized': u'فبأجمعكما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكنفسكن': [{'vocalized': u'أكنفسكن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'وكلحظتكن': [{'vocalized': u'وكلحظتكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'لكأنهن': [{'vocalized': u'لكأنهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'لكأنهم': [{'vocalized': u'لكأنهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'كلهما': [{'vocalized': u'كلهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلهما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'وككلكما': [{'vocalized': u'وككلكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلكما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فبشرقكما': [{'vocalized': u'فبشرقكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'فبغيرهن': [{'vocalized': u'فبغيرهن', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أولمنهن': [{'vocalized': u'أولمنهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'فبغيرهم': [{'vocalized': u'فبغيرهم', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'وراءي': [{'vocalized': u'وراءي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'وراءي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'فلعينكما': [{'vocalized': u'فلعينكما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'شطرنا': [{'vocalized': u'شطرنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'فببعضنا': [{'vocalized': u'فببعضنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'فنحوهم': [{'vocalized': u'فنحوهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'فنحوهن': [{'vocalized': u'فنحوهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'ألبعضهم': [{'vocalized': u'ألبعضهم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'ألبعضهن': [{'vocalized': u'ألبعضهن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'وقت': [{'vocalized': u'وقت', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'كبعضها': [{'vocalized': u'كبعضها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'بأكثركما': [{'vocalized': u'بأكثركما', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'أوبأولاء': [{'vocalized': u'أوبأولاء', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'فماذا': [{'vocalized': u'فماذا', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'ماذا', 'encletic': u'', 'type': u'اسم', 'original': u'ماذا'}],

 u'بأسفلكن': [{'vocalized': u'بأسفلكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'بأسفلكم': [{'vocalized': u'بأسفلكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'بغروبنا': [{'vocalized': u'بغروبنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'أفلشبه': [{'vocalized': u'أفلشبه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'فلابنهما': [{'vocalized': u'فلابنهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'وببعض': [{'vocalized': u'وببعض', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'حواليهما': [{'vocalized': u'حواليهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حوالى'}],

 u'ولجنوبكن': [{'vocalized': u'ولجنوبكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'ثم': [{'vocalized': u'ثم', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'},
 {'vocalized': u'ثم', 'procletic': u'', 'tags': u'حرف;حرف عطف منفصل', 'stem': u'ثم', 'encletic': u'', 'type': u'حرف', 'original': u'ثم'},
 {'vocalized': u'ثم', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'}],

 u'وأينا': [{'vocalized': u'وأينا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'ولأولئك': [{'vocalized': u'ولأولئك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'وبغربكما': [{'vocalized': u'وبغربكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'بحميكن': [{'vocalized': u'بحميكن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'بحميكم': [{'vocalized': u'بحميكم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'ضمنكم': [{'vocalized': u'ضمنكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ضمن'}],

 u'أفلنفسنا': [{'vocalized': u'أفلنفسنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'لشطركن': [{'vocalized': u'لشطركن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'لشطركم': [{'vocalized': u'لشطركم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'أفلسنا': [{'vocalized': u'أفلسنا', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لسنا', 'encletic': u'', 'type': u'فعل', 'original': u'لسنا'}],

 u'حمينا': [{'vocalized': u'حمينا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'فبأخيكم': [{'vocalized': u'فبأخيكم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'فبأخيكن': [{'vocalized': u'فبأخيكن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'فعداها': [{'vocalized': u'فعداها', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'عدا'}],

 u'فكذاتي': [{'vocalized': u'فكذاتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'فكذاتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'أجمعكن': [{'vocalized': u'أجمعكن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألخلفكن': [{'vocalized': u'ألخلفكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'أفبضعهن': [{'vocalized': u'أفبضعهن', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بضع'}],

 u'ألخلفكم': [{'vocalized': u'ألخلفكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'فكذاتك': [{'vocalized': u'فكذاتك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'ولازلت': [{'vocalized': u'ولازلت', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'ولازلت', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'ولازلت', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'}],

 u'فكذاته': [{'vocalized': u'فكذاته', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'أفعليكما': [{'vocalized': u'أفعليكما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'وكليلكم': [{'vocalized': u'وكليلكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'فجميع': [{'vocalized': u'فجميع', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميع', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'فعداهن': [{'vocalized': u'فعداهن', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'عدا'}],

 u'فعداهم': [{'vocalized': u'فعداهم', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'عدا'}],

 u'فكشرقي': [{'vocalized': u'فكشرقي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'فكشرقي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'فلخلفكم': [{'vocalized': u'فلخلفكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'فلخلفكن': [{'vocalized': u'فلخلفكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'وكليلكن': [{'vocalized': u'وكليلكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'فكشرقه': [{'vocalized': u'فكشرقه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'فبين': [{'vocalized': u'فبين', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'بين', 'encletic': u'', 'type': u'اسم', 'original': u'بين'}],

 u'بأثناءكما': [{'vocalized': u'بأثناءكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'سويكما': [{'vocalized': u'سويكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ولجميعي': [{'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'للتي': [{'vocalized': u'للتي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'أولذلك': [{'vocalized': u'أولذلك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'ولجميعه': [{'vocalized': u'ولجميعه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعه', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أفعليكن': [{'vocalized': u'أفعليكن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'ألسويكما': [{'vocalized': u'ألسويكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ولجميعك': [{'vocalized': u'ولجميعك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعك', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أأجمعي': [{'vocalized': u'أأجمعي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أأجمعي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'أشبهكما': [{'vocalized': u'أشبهكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'وأخينا': [{'vocalized': u'وأخينا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'أوجميع': [{'vocalized': u'أوجميع', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميع', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'ولفوقي': [{'vocalized': u'ولفوقي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'ولفوقي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'وكشرق': [{'vocalized': u'وكشرق', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'ولكيلا': [{'vocalized': u'ولكيلا', 'procletic': u'و-', 'tags': u'حرف;حرف تعليل;عطف', 'stem': u'لكيلا', 'encletic': u'', 'type': u'حرف', 'original': u'لكيلا'}],

 u'وكشطركن': [{'vocalized': u'وكشطركن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'وكشطركم': [{'vocalized': u'وكشطركم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'لعلهن': [{'vocalized': u'لعلهن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لعل'}],

 u'لعلهم': [{'vocalized': u'لعلهم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لعل'}],

 u'ولغيرهما': [{'vocalized': u'ولغيرهما', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيرهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'ولكأنهما': [{'vocalized': u'ولكأنهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'فكفيي': [{'vocalized': u'فكفيي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فكفيي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'}],

 u'فكفيه': [{'vocalized': u'فكفيه', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'}],

 u'كخلفكم': [{'vocalized': u'كخلفكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'فكفيك': [{'vocalized': u'فكفيك', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'}],

 u'كخلفكن': [{'vocalized': u'كخلفكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'أوخلفكن': [{'vocalized': u'أوخلفكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'فلدننا': [{'vocalized': u'فلدننا', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدن'}],

 u'فبعين': [{'vocalized': u'فبعين', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'أوبسويهما': [{'vocalized': u'أوبسويهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'أفمنكن': [{'vocalized': u'أفمنكن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'إنهما': [{'vocalized': u'إنهما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'أفمنكم': [{'vocalized': u'أفمنكم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'إزاء': [{'vocalized': u'إزاء', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'إزاء', 'encletic': u'', 'type': u'اسم', 'original': u'إزاء'}],

 u'لنا': [{'vocalized': u'لنا', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'لنا', 'encletic': u'', 'type': u'ضمير', 'original': u'لنا'}],

 u'فبهنالك': [{'vocalized': u'فبهنالك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'وكجميعها': [{'vocalized': u'وكجميعها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعها', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'ومافتئوا': [{'vocalized': u'ومافتئوا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئوا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئوا'}],

 u'أوبكما': [{'vocalized': u'أوبكما', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بكما', 'encletic': u'', 'type': u'ضمير', 'original': u'بكما'}],

 u'فإياكم': [{'vocalized': u'فإياكم', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياكم', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكم'}],

 u'فذلكما': [{'vocalized': u'فذلكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'وبجميعهما': [{'vocalized': u'وبجميعهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعهما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'فبأسفلهما': [{'vocalized': u'فبأسفلهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'فلمنكما': [{'vocalized': u'فلمنكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'فلوراءي': [{'vocalized': u'فلوراءي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'فلوراءي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'وشمالنا': [{'vocalized': u'وشمالنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'وإليهما': [{'vocalized': u'وإليهما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'فلوراءك': [{'vocalized': u'فلوراءك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'فلأن': [{'vocalized': u'فلأن', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فلأن', 'procletic': u'ف-ل-', 'tags': u'حرف;حرف نصب;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فلأن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'ومثلنا': [{'vocalized': u'ومثلنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'أكنفسهما': [{'vocalized': u'أكنفسهما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'وبخلفها': [{'vocalized': u'وبخلفها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'ذاتك': [{'vocalized': u'ذاتك', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'فلأي': [{'vocalized': u'فلأي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فلأي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'أفأمام': [{'vocalized': u'أفأمام', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'ذاته': [{'vocalized': u'ذاته', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'أوببعضكما': [{'vocalized': u'أوببعضكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'لكلهما': [{'vocalized': u'لكلهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'فعداكما': [{'vocalized': u'فعداكما', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'عدا'}],

 u'أوعليك': [{'vocalized': u'أوعليك', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'فأباك': [{'vocalized': u'فأباك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبا'}],

 u'أوعليه': [{'vocalized': u'أوعليه', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'فأباه': [{'vocalized': u'فأباه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبا'}],

 u'أمن': [{'vocalized': u'أمن', 'procletic': u'أ-', 'tags': u'اسم;اسم موصول;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'أمن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'وكأجمعكن': [{'vocalized': u'وكأجمعكن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'فبدونكن': [{'vocalized': u'فبدونكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بدون'}],

 u'فبدونكم': [{'vocalized': u'فبدونكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بدون'}],

 u'وبلحظتنا': [{'vocalized': u'وبلحظتنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلكأننا': [{'vocalized': u'فلكأننا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'لأبينا': [{'vocalized': u'لأبينا', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'فلفيكم': [{'vocalized': u'فلفيكم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'فكجميعكن': [{'vocalized': u'فكجميعكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعكن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'فكجميعكم': [{'vocalized': u'فكجميعكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعكم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلفيكن': [{'vocalized': u'فلفيكن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'ولأقلها': [{'vocalized': u'ولأقلها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'فأيهما': [{'vocalized': u'فأيهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'أفكجميعهم': [{'vocalized': u'أفكجميعهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكجميعهن': [{'vocalized': u'أفكجميعهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلشبهكن': [{'vocalized': u'أفلشبهكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلشبهكم': [{'vocalized': u'أفلشبهكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'وبذانك': [{'vocalized': u'وبذانك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'كعامتهن': [{'vocalized': u'كعامتهن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'وكيفما': [{'vocalized': u'وكيفما', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'كيفما', 'encletic': u'', 'type': u'اسم', 'original': u'كيفما'}],

 u'فبليلهما': [{'vocalized': u'فبليلهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'أمثل': [{'vocalized': u'أمثل', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'أفكجميعها': [{'vocalized': u'أفكجميعها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'وفوق': [{'vocalized': u'وفوق', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'فبذويه': [{'vocalized': u'فبذويه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'تلقاءكم': [{'vocalized': u'تلقاءكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبذويك': [{'vocalized': u'فبذويك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'وعندهن': [{'vocalized': u'وعندهن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عند'}],

 u'وعندهم': [{'vocalized': u'وعندهم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عند'}],

 u'ألتلكم': [{'vocalized': u'ألتلكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أما': [{'vocalized': u'أما', 'procletic': u'', 'tags': u'حرف;حرف شرط وتفصيل وتوكيد', 'stem': u'أما', 'encletic': u'', 'type': u'حرف', 'original': u'أما'},
 {'vocalized': u'أما', 'procletic': u'', 'tags': u'حرف;حرف عرض', 'stem': u'أما', 'encletic': u'', 'type': u'حرف', 'original': u'أما'}],

 u'فمازال': [{'vocalized': u'فمازال', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازال', 'encletic': u'', 'type': u'فعل', 'original': u'مازال'}],

 u'ولازالوا': [{'vocalized': u'ولازالوا', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالوا'}],

 u'أمد': [{'vocalized': u'أمد', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'أمد', 'encletic': u'', 'type': u'اسم', 'original': u'أمد'}],

 u'أفحسبهما': [{'vocalized': u'أفحسبهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'وبذاتهما': [{'vocalized': u'وبذاتهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'اللواتي': [{'vocalized': u'اللواتي', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'أمس': [{'vocalized': u'أمس', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'أمس', 'encletic': u'', 'type': u'اسم', 'original': u'أمس'}],

 u'كنحونا': [{'vocalized': u'كنحونا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحونا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أمع': [{'vocalized': u'أمع', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'أولمعه': [{'vocalized': u'أولمعه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'أفلأولالك': [{'vocalized': u'أفلأولالك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'كغروبكم': [{'vocalized': u'كغروبكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'فأنتما': [{'vocalized': u'فأنتما', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'أفلازلتن': [{'vocalized': u'أفلازلتن', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتن'}],

 u'أولإليه': [{'vocalized': u'أولإليه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'وليته': [{'vocalized': u'وليته', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ه', 'type': u'حرف', 'original': u'ليت'}],

 u'وليتك': [{'vocalized': u'وليتك', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ك', 'type': u'حرف', 'original': u'ليت'}],

 u'أوتحتهن': [{'vocalized': u'أوتحتهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'فلوراءه': [{'vocalized': u'فلوراءه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'غير': [{'vocalized': u'غير', 'procletic': u'', 'tags': u'اسم;استثناء', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وليتي': [{'vocalized': u'وليتي', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ي', 'type': u'حرف', 'original': u'ليت'},
 {'vocalized': u'وليتي', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ي', 'type': u'حرف', 'original': u'ليت'}],

 u'أفكأنها': [{'vocalized': u'أفكأنها', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'فبجنبكما': [{'vocalized': u'فبجنبكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'وللحظتك': [{'vocalized': u'وللحظتك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'كليلكما': [{'vocalized': u'كليلكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'أوخلفكما': [{'vocalized': u'أوخلفكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'أوكبعضكم': [{'vocalized': u'أوكبعضكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أوكبعضكن': [{'vocalized': u'أوكبعضكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'فاللواتي': [{'vocalized': u'فاللواتي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'وإنهم': [{'vocalized': u'وإنهم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'أولست': [{'vocalized': u'أولست', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'أولست', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'أولست', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'}],

 u'وإنهن': [{'vocalized': u'وإنهن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'لعلها': [{'vocalized': u'لعلها', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لعل'}],

 u'أكنحو': [{'vocalized': u'أكنحو', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'وبنحوي': [{'vocalized': u'وبنحوي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'أفكأنهن': [{'vocalized': u'أفكأنهن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'أفكأنهم': [{'vocalized': u'أفكأنهم', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'وبنحوك': [{'vocalized': u'وبنحوك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'تحتي': [{'vocalized': u'تحتي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'تحتي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'فلأنكن': [{'vocalized': u'فلأنكن', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'فلأنكم': [{'vocalized': u'فلأنكم', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'ولجنوبي': [{'vocalized': u'ولجنوبي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'ولجنوبي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'بعيننا': [{'vocalized': u'بعيننا', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'ذاتي': [{'vocalized': u'ذاتي', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'ذاتي', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'عامة': [{'vocalized': u'عامة', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'تحته': [{'vocalized': u'تحته', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'وإنها': [{'vocalized': u'وإنها', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'وبأعليهما': [{'vocalized': u'وبأعليهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فلأقل': [{'vocalized': u'فلأقل', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'إليكن': [{'vocalized': u'إليكن', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'إليكن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكن'},
 {'vocalized': u'إليكن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'إليكم': [{'vocalized': u'إليكم', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'إليكم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكم'},
 {'vocalized': u'إليكم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'وكأسفلنا': [{'vocalized': u'وكأسفلنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبجنوبكن': [{'vocalized': u'وبجنوبكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'وبجنوبكم': [{'vocalized': u'وبجنوبكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفبنفسهما': [{'vocalized': u'أفبنفسهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'كأعلي': [{'vocalized': u'كأعلي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'كأعلي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'أوتحتها': [{'vocalized': u'أوتحتها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'فلإنهما': [{'vocalized': u'فلإنهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'بتلكم': [{'vocalized': u'بتلكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'وكغربكن': [{'vocalized': u'وكغربكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'وكغربكم': [{'vocalized': u'وكغربكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'فكتلكم': [{'vocalized': u'فكتلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أفنحن': [{'vocalized': u'أفنحن', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'أفنحو': [{'vocalized': u'أفنحو', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'وبشبههما': [{'vocalized': u'وبشبههما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'أويمينه': [{'vocalized': u'أويمينه', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'وكليلهم': [{'vocalized': u'وكليلهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'أفبكلها': [{'vocalized': u'أفبكلها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'بكلي': [{'vocalized': u'بكلي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'فكأثناء': [{'vocalized': u'فكأثناء', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'أكلتا': [{'vocalized': u'أكلتا', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفتحتكما': [{'vocalized': u'أفتحتكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'بكلك': [{'vocalized': u'بكلك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلك', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'فعلق': [{'vocalized': u'فعلق', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'علق', 'encletic': u'', 'type': u'فعل', 'original': u'علق'}],

 u'بكله': [{'vocalized': u'بكله', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكله', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'ومابرحت': [{'vocalized': u'ومابرحت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'ومابرحت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'ومابرحت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'ومابرحت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'}],

 u'وحواليكن': [{'vocalized': u'وحواليكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حوالى'}],

 u'أويمينك': [{'vocalized': u'أويمينك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'أكتينك': [{'vocalized': u'أكتينك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'ولعلهن': [{'vocalized': u'ولعلهن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لعل'}],

 u'أفبذلكن': [{'vocalized': u'أفبذلكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'فأباي': [{'vocalized': u'فأباي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبا'},
 {'vocalized': u'فأباي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبا'}],

 u'أفبذلكم': [{'vocalized': u'أفبذلكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'أولنحوي': [{'vocalized': u'أولنحوي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أولنحوي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'وبأعلينا': [{'vocalized': u'وبأعلينا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'ط': [{'vocalized': u'ط', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ط', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ط'}],

 u'أولنحوك': [{'vocalized': u'أولنحوك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'بلحظتها': [{'vocalized': u'بلحظتها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'أولنحوه': [{'vocalized': u'أولنحوه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'أولنفس': [{'vocalized': u'أولنفس', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفس', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'وأمسى': [{'vocalized': u'وأمسى', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'أمسى', 'encletic': u'', 'type': u'فعل', 'original': u'أمسى'}],

 u'كأخيكم': [{'vocalized': u'كأخيكم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'كأخيكن': [{'vocalized': u'كأخيكن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'نحوهم': [{'vocalized': u'نحوهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'وكحميهما': [{'vocalized': u'وكحميهما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'أبنفسه': [{'vocalized': u'أبنفسه', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'نحوهن': [{'vocalized': u'نحوهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'كغير': [{'vocalized': u'كغير', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'أوبحسبهم': [{'vocalized': u'أوبحسبهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبحسبهن': [{'vocalized': u'أوبحسبهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'إياكم': [{'vocalized': u'إياكم', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياكم', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكم'}],

 u'إياكن': [{'vocalized': u'إياكن', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياكن', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكن'}],

 u'فكأيتكم': [{'vocalized': u'فكأيتكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'ألكلي': [{'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'وحميكما': [{'vocalized': u'وحميكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'وأقل': [{'vocalized': u'وأقل', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'ألكله': [{'vocalized': u'ألكله', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكله', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكله', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكله', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'بلحظتهن': [{'vocalized': u'بلحظتهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفبمثل': [{'vocalized': u'أفبمثل', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'ولأجمعنا': [{'vocalized': u'ولأجمعنا', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'أومعه': [{'vocalized': u'أومعه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'أومعك': [{'vocalized': u'أومعك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'كعامتنا': [{'vocalized': u'كعامتنا', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'كابنكن': [{'vocalized': u'كابنكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'كابنكم': [{'vocalized': u'كابنكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'أومعي': [{'vocalized': u'أومعي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'أومعي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'وكجنبه': [{'vocalized': u'وكجنبه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'أفبكلهن': [{'vocalized': u'أفبكلهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أفبكلهم': [{'vocalized': u'أفبكلهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أشمالكن': [{'vocalized': u'أشمالكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'وكجنبك': [{'vocalized': u'وكجنبك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'وفوقنا': [{'vocalized': u'وفوقنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'لتين': [{'vocalized': u'لتين', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'أبمثلهما': [{'vocalized': u'أبمثلهما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فسويهم': [{'vocalized': u'فسويهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'لكنه': [{'vocalized': u'لكنه', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنه', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لكن'}],

 u'فسويهن': [{'vocalized': u'فسويهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'أومعهما': [{'vocalized': u'أومعهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'لكنك': [{'vocalized': u'لكنك', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنك', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لكن'}],

 u'آها': [{'vocalized': u'آها', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'آها', 'encletic': u'', 'type': u'اسم فعل', 'original': u'آها'}],

 u'أوكتلك': [{'vocalized': u'أوكتلك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'لأمامهن': [{'vocalized': u'لأمامهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'لكني': [{'vocalized': u'لكني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكني', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكني', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'}],

 u'فكتلقاءهم': [{'vocalized': u'فكتلقاءهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فكتلقاءهن': [{'vocalized': u'فكتلقاءهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'كغرب': [{'vocalized': u'كغرب', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'أفمثل': [{'vocalized': u'أفمثل', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'شرقهن': [{'vocalized': u'شرقهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'أفكأنكما': [{'vocalized': u'أفكأنكما', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'وبأبي': [{'vocalized': u'وبأبي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'ولأيتكم': [{'vocalized': u'ولأيتكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'ألسويكم': [{'vocalized': u'ألسويكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'ألسويكن': [{'vocalized': u'ألسويكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'كجميعي': [{'vocalized': u'كجميعي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'ولكان': [{'vocalized': u'ولكان', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كان', 'encletic': u'', 'type': u'فعل', 'original': u'كان'}],

 u'كجميعك': [{'vocalized': u'كجميعك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعك', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أولمننا': [{'vocalized': u'أولمننا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'ولسويك': [{'vocalized': u'ولسويك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'كجميعه': [{'vocalized': u'كجميعه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعه', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'بأكثره': [{'vocalized': u'بأكثره', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'أولعلهن': [{'vocalized': u'أولعلهن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لعل'}],

 u'أولعلهم': [{'vocalized': u'أولعلهم', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لعل'}],

 u'ذواتي': [{'vocalized': u'ذواتي', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'بأكثري': [{'vocalized': u'بأكثري', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'بأكثري', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'أولتحتهن': [{'vocalized': u'أولتحتهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'فساء': [{'vocalized': u'فساء', 'procletic': u'ف-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'ساء', 'encletic': u'', 'type': u'فعل', 'original': u'ساء'}],

 u'أبمثلنا': [{'vocalized': u'أبمثلنا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'فمابرحتما': [{'vocalized': u'فمابرحتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتما', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتما'},
 {'vocalized': u'فمابرحتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتما', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتما'}],

 u'ولسويه': [{'vocalized': u'ولسويه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'ولكاد': [{'vocalized': u'ولكاد', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كاد', 'encletic': u'', 'type': u'فعل', 'original': u'كاد'}],

 u'كأثناءكما': [{'vocalized': u'كأثناءكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'لغربكن': [{'vocalized': u'لغربكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'فكخلفهما': [{'vocalized': u'فكخلفهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'أولعلها': [{'vocalized': u'أولعلها', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لعل'}],

 u'ذواتا': [{'vocalized': u'ذواتا', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذواتا', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتا'}],

 u'فسويها': [{'vocalized': u'فسويها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أفليميننا': [{'vocalized': u'أفليميننا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'لشرقكما': [{'vocalized': u'لشرقكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'ولأننا': [{'vocalized': u'ولأننا', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'لأمامها': [{'vocalized': u'لأمامها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'فغيرك': [{'vocalized': u'فغيرك', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'ولشرقكن': [{'vocalized': u'ولشرقكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'ولشرقكم': [{'vocalized': u'ولشرقكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'فكتلقاءها': [{'vocalized': u'فكتلقاءها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فغيره': [{'vocalized': u'فغيره', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'وكفي': [{'vocalized': u'وكفي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'}],

 u'فغيري': [{'vocalized': u'فغيري', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فغيري', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أبذين': [{'vocalized': u'أبذين', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'ولسنا': [{'vocalized': u'ولسنا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لسنا', 'encletic': u'', 'type': u'فعل', 'original': u'لسنا'}],

 u'فبطآن': [{'vocalized': u'فبطآن', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بطآن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بطآن'}],

 u'ولحمي': [{'vocalized': u'ولحمي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'ولعمرها': [{'vocalized': u'ولعمرها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لعمر'}],

 u'أوببعضها': [{'vocalized': u'أوببعضها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'هذا': [{'vocalized': u'هذا', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'فلمننا': [{'vocalized': u'فلمننا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'أفعامتهم': [{'vocalized': u'أفعامتهم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أفعامتهن': [{'vocalized': u'أفعامتهن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فذاتكن': [{'vocalized': u'فذاتكن', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'فذاتكم': [{'vocalized': u'فذاتكم', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'أوتحتهم': [{'vocalized': u'أوتحتهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'أفكهاتين': [{'vocalized': u'أفكهاتين', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'أفلعنكم': [{'vocalized': u'أفلعنكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'يمينكما': [{'vocalized': u'يمينكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'فجنوبي': [{'vocalized': u'فجنوبي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'فجنوبي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'فذاته': [{'vocalized': u'فذاته', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'فبذويكم': [{'vocalized': u'فبذويكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'فذاتك': [{'vocalized': u'فذاتك', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'فبذويكن': [{'vocalized': u'فبذويكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'أبنفسكما': [{'vocalized': u'أبنفسكما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'فذاتي': [{'vocalized': u'فذاتي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'فذاتي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'فذوونا': [{'vocalized': u'فذوونا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوو'}],

 u'بعضهما': [{'vocalized': u'بعضهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'أمثلكن': [{'vocalized': u'أمثلكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'أمثلكم': [{'vocalized': u'أمثلكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فحسبك': [{'vocalized': u'فحسبك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فكحسبي': [{'vocalized': u'فكحسبي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'فكحسبي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أفمنه': [{'vocalized': u'أفمنه', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'فيي': [{'vocalized': u'فيي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيي', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'فيي', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'فكأينا': [{'vocalized': u'فكأينا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'أفمنك': [{'vocalized': u'أفمنك', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'أولعليكن': [{'vocalized': u'أولعليكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'فكحسبك': [{'vocalized': u'فكحسبك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فيك': [{'vocalized': u'فيك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيك', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'أوكمثلكم': [{'vocalized': u'أوكمثلكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فكحسبه': [{'vocalized': u'فكحسبه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أوكمثلكن': [{'vocalized': u'أوكمثلكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'فحميكم': [{'vocalized': u'فحميكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'فحميكن': [{'vocalized': u'فحميكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'فليتك': [{'vocalized': u'فليتك', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ك', 'type': u'حرف', 'original': u'ليت'}],

 u'ولعمرهم': [{'vocalized': u'ولعمرهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لعمر'}],

 u'أولعامته': [{'vocalized': u'أولعامته', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامته', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'هذي': [{'vocalized': u'هذي', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'ولعمرهن': [{'vocalized': u'ولعمرهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لعمر'}],

 u'أوببعضهم': [{'vocalized': u'أوببعضهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'فليتي': [{'vocalized': u'فليتي', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ي', 'type': u'حرف', 'original': u'ليت'},
 {'vocalized': u'فليتي', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ي', 'type': u'حرف', 'original': u'ليت'}],

 u'هذه': [{'vocalized': u'هذه', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'وللحظتكن': [{'vocalized': u'وللحظتكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'وتلقاءي': [{'vocalized': u'وتلقاءي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'وتلقاءي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وسويه': [{'vocalized': u'وسويه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلغيره': [{'vocalized': u'أفلغيره', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيره', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'وسويك': [{'vocalized': u'وسويك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فبذويكما': [{'vocalized': u'فبذويكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفلغيرك': [{'vocalized': u'أفلغيرك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيرك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'فكأقلنا': [{'vocalized': u'فكأقلنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'ولدى': [{'vocalized': u'ولدى', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'لدى', 'encletic': u'', 'type': u'اسم', 'original': u'لدى'}],

 u'أفلغيري': [{'vocalized': u'أفلغيري', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيري', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيري', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيري', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'ولدي': [{'vocalized': u'ولدي', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'},
 {'vocalized': u'ولدي', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'}],

 u'لمعنا': [{'vocalized': u'لمعنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'بساعتكم': [{'vocalized': u'بساعتكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فليتكما': [{'vocalized': u'فليتكما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-كما', 'type': u'حرف', 'original': u'ليت'}],

 u'أمهما': [{'vocalized': u'أمهما', 'procletic': u'أ-', 'tags': u'اسم;اسم الشرط;استفهام', 'stem': u'مهما', 'encletic': u'', 'type': u'اسم', 'original': u'مهما'}],

 u'ومنذ': [{'vocalized': u'ومنذ', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'منذ', 'encletic': u'', 'type': u'حرف', 'original': u'منذ'},
 {'vocalized': u'ومنذ', 'procletic': u'و-', 'tags': u'حرف;ظرف زمان;عطف', 'stem': u'منذ', 'encletic': u'', 'type': u'حرف', 'original': u'منذ'}],

 u'أولأمامكما': [{'vocalized': u'أولأمامكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'وبأولالك': [{'vocalized': u'وبأولالك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'كأقلكما': [{'vocalized': u'كأقلكما', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'وأسفلي': [{'vocalized': u'وأسفلي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'وأسفلي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'وحواليهم': [{'vocalized': u'وحواليهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حوالى'}],

 u'فبخلفك': [{'vocalized': u'فبخلفك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'فأثناءه': [{'vocalized': u'فأثناءه', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفذلكما': [{'vocalized': u'أفذلكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'ألوراءها': [{'vocalized': u'ألوراءها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'بحسبهما': [{'vocalized': u'بحسبهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'ألعلكم': [{'vocalized': u'ألعلكم', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لعل'}],

 u'فأسفل': [{'vocalized': u'فأسفل', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'ألعلكن': [{'vocalized': u'ألعلكن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لعل'}],

 u'ألست': [{'vocalized': u'ألست', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'ألست', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'ألست', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'}],

 u'فأيي': [{'vocalized': u'فأيي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فأيي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'فأثناءي': [{'vocalized': u'فأثناءي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'فأثناءي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'لأقلهما': [{'vocalized': u'لأقلهما', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'وتحتي': [{'vocalized': u'وتحتي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'وتحتي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'وكتلقاء': [{'vocalized': u'وكتلقاء', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فأيك': [{'vocalized': u'فأيك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'فأين': [{'vocalized': u'فأين', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'},
 {'vocalized': u'فأين', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'},
 {'vocalized': u'فأين', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'}],

 u'فأيه': [{'vocalized': u'فأيه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'وأناهن': [{'vocalized': u'وأناهن', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'ألوراءهم': [{'vocalized': u'ألوراءهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'لليلهما': [{'vocalized': u'لليلهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'فكفيكم': [{'vocalized': u'فكفيكم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'}],

 u'بابننا': [{'vocalized': u'بابننا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'جنوبنا': [{'vocalized': u'جنوبنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'لحسبنا': [{'vocalized': u'لحسبنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'أفإليكم': [{'vocalized': u'أفإليكم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'أوإننا': [{'vocalized': u'أوإننا', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'كحسبي': [{'vocalized': u'كحسبي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'كحسبي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أفنفسها': [{'vocalized': u'أفنفسها', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'كحسبك': [{'vocalized': u'كحسبك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'كحسبه': [{'vocalized': u'كحسبه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'ففوق': [{'vocalized': u'ففوق', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'كليهما': [{'vocalized': u'كليهما', 'procletic': u'', 'tags': u'حرف;توكيد', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'فمادمتم': [{'vocalized': u'فمادمتم', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتم', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتم'}],

 u'ومنه': [{'vocalized': u'ومنه', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'ومنك': [{'vocalized': u'ومنك', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'وبسويهن': [{'vocalized': u'وبسويهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'وبسويهم': [{'vocalized': u'وبسويهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'وجير': [{'vocalized': u'وجير', 'procletic': u'و-', 'tags': u'حرف;حرف جواب;عطف', 'stem': u'جير', 'encletic': u'', 'type': u'حرف', 'original': u'جير'}],

 u'وكاللائي': [{'vocalized': u'وكاللائي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'ومني': [{'vocalized': u'ومني', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'ومني', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'ألشمالهن': [{'vocalized': u'ألشمالهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'فأبوكما': [{'vocalized': u'فأبوكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبو'}],

 u'ولوراءكم': [{'vocalized': u'ولوراءكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'فبحسب': [{'vocalized': u'فبحسب', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'وحسبما': [{'vocalized': u'وحسبما', 'procletic': u'و-', 'tags': u'اسم;جار ومجرور;عطف', 'stem': u'حسبما', 'encletic': u'', 'type': u'اسم', 'original': u'حسبما'}],

 u'لأنها': [{'vocalized': u'لأنها', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'فلكلنا': [{'vocalized': u'فلكلنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلنا', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'ونفسكما': [{'vocalized': u'ونفسكما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'ففاكم': [{'vocalized': u'ففاكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فا'}],

 u'ولوراءكن': [{'vocalized': u'ولوراءكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'ففاكن': [{'vocalized': u'ففاكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فا'}],

 u'أفلكل': [{'vocalized': u'أفلكل', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكل', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكل', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكل', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'أفلكم': [{'vocalized': u'أفلكم', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لكم', 'encletic': u'', 'type': u'ضمير', 'original': u'لكم'}],

 u'أفلكن': [{'vocalized': u'أفلكن', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لكن', 'encletic': u'', 'type': u'ضمير', 'original': u'لكن'}],

 u'فحسبهم': [{'vocalized': u'فحسبهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فحسبهن': [{'vocalized': u'فحسبهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'أفخلفكم': [{'vocalized': u'أفخلفكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'أغيركم': [{'vocalized': u'أغيركم', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'وكغروبنا': [{'vocalized': u'وكغروبنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'أفلازلتما': [{'vocalized': u'أفلازلتما', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'},
 {'vocalized': u'أفلازلتما', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'}],

 u'وكتين': [{'vocalized': u'وكتين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'لعليهما': [{'vocalized': u'لعليهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'أفلإليك': [{'vocalized': u'أفلإليك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'أفوقه': [{'vocalized': u'أفوقه', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'وكأيتهم': [{'vocalized': u'وكأيتهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'وتحت': [{'vocalized': u'وتحت', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلحسبنا': [{'vocalized': u'أفلحسبنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'فكلحظة': [{'vocalized': u'فكلحظة', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'وحمينا': [{'vocalized': u'وحمينا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'فمعاذنا': [{'vocalized': u'فمعاذنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-نا', 'type': u'اسم', 'original': u'معاذ'}],

 u'فحسبها': [{'vocalized': u'فحسبها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'فكأقلكما': [{'vocalized': u'فكأقلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'لفوقي': [{'vocalized': u'لفوقي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'لفوقي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'أفبذي': [{'vocalized': u'أفبذي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'لخلفنا': [{'vocalized': u'لخلفنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'أفلنحوكما': [{'vocalized': u'أفلنحوكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'تلقاءكن': [{'vocalized': u'تلقاءكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أولأمامكم': [{'vocalized': u'أولأمامكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'ولفوقك': [{'vocalized': u'ولفوقك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'لأنهن': [{'vocalized': u'لأنهن', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'لأنهم': [{'vocalized': u'لأنهم', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'ولفوقه': [{'vocalized': u'ولفوقه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'أفإلى': [{'vocalized': u'أفإلى', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'أفإلي': [{'vocalized': u'أفإلي', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'أفإلي', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'كأنهما': [{'vocalized': u'كأنهما', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنهما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'أوكبعضه': [{'vocalized': u'أوكبعضه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'وزماننا': [{'vocalized': u'وزماننا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'وللتي': [{'vocalized': u'وللتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'لشطرك': [{'vocalized': u'لشطرك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'لفوقك': [{'vocalized': u'لفوقك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'لشطره': [{'vocalized': u'لشطره', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'فلجنبنا': [{'vocalized': u'فلجنبنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'لشطري': [{'vocalized': u'لشطري', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'لشطري', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'فكتلقاءكما': [{'vocalized': u'فكتلقاءكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فلذويكما': [{'vocalized': u'فلذويكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكيف': [{'vocalized': u'وكيف', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'كيف', 'encletic': u'', 'type': u'اسم', 'original': u'كيف'}],

 u'فلأعليكن': [{'vocalized': u'فلأعليكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبشهرها': [{'vocalized': u'فبشهرها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'لحظتكن': [{'vocalized': u'لحظتكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'وماداموا': [{'vocalized': u'وماداموا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماداموا', 'encletic': u'', 'type': u'فعل', 'original': u'ماداموا'}],

 u'سويه': [{'vocalized': u'سويه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'سويك': [{'vocalized': u'سويك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'وعندما': [{'vocalized': u'وعندما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'عندما', 'encletic': u'', 'type': u'اسم', 'original': u'عندما'}],

 u'فبذويي': [{'vocalized': u'فبذويي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'فبذويي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'أعينكن': [{'vocalized': u'أعينكن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'أعينكم': [{'vocalized': u'أعينكم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'كغربكما': [{'vocalized': u'كغربكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'فلسنا': [{'vocalized': u'فلسنا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لسنا', 'encletic': u'', 'type': u'فعل', 'original': u'لسنا'}],

 u'وفيه': [{'vocalized': u'وفيه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيه', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'وفيم': [{'vocalized': u'وفيم', 'procletic': u'و-', 'tags': u'حرف;حرف استفهام;عطف', 'stem': u'فيم', 'encletic': u'', 'type': u'حرف', 'original': u'فيم'}],

 u'وفيك': [{'vocalized': u'وفيك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيك', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'فبشهرهن': [{'vocalized': u'فبشهرهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'فبشهرهم': [{'vocalized': u'فبشهرهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'فكوقتكن': [{'vocalized': u'فكوقتكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'وفيي': [{'vocalized': u'وفيي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيي', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'وفيي', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'لزمانكن': [{'vocalized': u'لزمانكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'ووقتهما': [{'vocalized': u'ووقتهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'حاشاه': [{'vocalized': u'حاشاه', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'حاشا'}],

 u'حاشاك': [{'vocalized': u'حاشاك', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'حاشا'}],

 u'وعليكما': [{'vocalized': u'وعليكما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'حاشاي': [{'vocalized': u'حاشاي', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'حاشا'},
 {'vocalized': u'حاشاي', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'حاشا'}],

 u'لشمالي': [{'vocalized': u'لشمالي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'لشمالي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'أفلكلكن': [{'vocalized': u'أفلكلكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أفلكلكم': [{'vocalized': u'أفلكلكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'لشمالك': [{'vocalized': u'لشمالك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'فمثل': [{'vocalized': u'فمثل', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'أغير': [{'vocalized': u'أغير', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'لشماله': [{'vocalized': u'لشماله', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'أكأنكم': [{'vocalized': u'أكأنكم', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'فبينه': [{'vocalized': u'فبينه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بين'}],

 u'أكل': [{'vocalized': u'أكل', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكل', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'فبيني': [{'vocalized': u'فبيني', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بين'},
 {'vocalized': u'فبيني', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بين'}],

 u'وكيت': [{'vocalized': u'وكيت', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'كيت', 'encletic': u'', 'type': u'اسم', 'original': u'كيت'}],

 u'أكمثل': [{'vocalized': u'أكمثل', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'بلا': [{'vocalized': u'بلا', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'بلا', 'encletic': u'', 'type': u'حرف', 'original': u'بلا'}],

 u'فلزمانه': [{'vocalized': u'فلزمانه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'فبذواتي': [{'vocalized': u'فبذواتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'وحمانا': [{'vocalized': u'وحمانا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حما'}],

 u'كشبههم': [{'vocalized': u'كشبههم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'كشبههن': [{'vocalized': u'كشبههن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'هنالك': [{'vocalized': u'هنالك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فلأسفلهن': [{'vocalized': u'فلأسفلهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'فلأسفلهم': [{'vocalized': u'فلأسفلهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'حوله': [{'vocalized': u'حوله', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حول'}],

 u'وكأكثركم': [{'vocalized': u'وكأكثركم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'وكأكثركن': [{'vocalized': u'وكأكثركن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلشطره': [{'vocalized': u'فلشطره', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'أولمعكما': [{'vocalized': u'أولمعكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'أونحوهما': [{'vocalized': u'أونحوهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'فلشطري': [{'vocalized': u'فلشطري', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'فلشطري', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'ولخلفهما': [{'vocalized': u'ولخلفهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'وبأسفلك': [{'vocalized': u'وبأسفلك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'فأيتهن': [{'vocalized': u'فأيتهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'فأيتهم': [{'vocalized': u'فأيتهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'مهما': [{'vocalized': u'مهما', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'مهما', 'encletic': u'', 'type': u'اسم', 'original': u'مهما'}],

 u'لكلهن': [{'vocalized': u'لكلهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'وبتلك': [{'vocalized': u'وبتلك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'أوكأولالك': [{'vocalized': u'أوكأولالك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'كاللتين': [{'vocalized': u'كاللتين', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'أفبضعكم': [{'vocalized': u'أفبضعكم', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بضع'}],

 u'وكذويكما': [{'vocalized': u'وكذويكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفبضعكن': [{'vocalized': u'أفبضعكن', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بضع'}],

 u'وآنفا': [{'vocalized': u'وآنفا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آنفا', 'encletic': u'', 'type': u'اسم', 'original': u'آنفا'}],

 u'أفبغيرنا': [{'vocalized': u'أفبغيرنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فأيتها': [{'vocalized': u'فأيتها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'وغربنا': [{'vocalized': u'وغربنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'لمعهما': [{'vocalized': u'لمعهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'كتلقاءكم': [{'vocalized': u'كتلقاءكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'لكلها': [{'vocalized': u'لكلها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلها', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'فحموهما': [{'vocalized': u'فحموهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمو'}],

 u'لإنكم': [{'vocalized': u'لإنكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'أفلعلكما': [{'vocalized': u'أفلعلكما', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لعل'}],

 u'لإنكن': [{'vocalized': u'لإنكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'ولعنهما': [{'vocalized': u'ولعنهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'أفلجميعكن': [{'vocalized': u'أفلجميعكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلجميعكم': [{'vocalized': u'أفلجميعكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'بله': [{'vocalized': u'بله', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'بله', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بله'}],

 u'أفلعليكم': [{'vocalized': u'أفلعليكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'فشرقهم': [{'vocalized': u'فشرقهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'فشرقهن': [{'vocalized': u'فشرقهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'كشبهها': [{'vocalized': u'كشبهها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'فلأسفلها': [{'vocalized': u'فلأسفلها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'بلى': [{'vocalized': u'بلى', 'procletic': u'', 'tags': u'حرف;حرف جواب', 'stem': u'بلى', 'encletic': u'', 'type': u'حرف', 'original': u'بلى'}],

 u'كغروبكن': [{'vocalized': u'كغروبكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'فكأيتي': [{'vocalized': u'فكأيتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'فكأيتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'لقد': [{'vocalized': u'لقد', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'قد', 'encletic': u'', 'type': u'حرف', 'original': u'قد'}],

 u'وكسويكن': [{'vocalized': u'وكسويكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'ذوا': [{'vocalized': u'ذوا', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذوا', 'encletic': u'', 'type': u'اسم', 'original': u'ذوا'}],

 u'وكسويكم': [{'vocalized': u'وكسويكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'وكشهر': [{'vocalized': u'وكشهر', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'أولحسبهما': [{'vocalized': u'أولحسبهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أفليسوا': [{'vocalized': u'أفليسوا', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليسوا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسوا'}],

 u'ولأيتهن': [{'vocalized': u'ولأيتهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'وأجمعهما': [{'vocalized': u'وأجمعهما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'لدي': [{'vocalized': u'لدي', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'},
 {'vocalized': u'لدي', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'}],

 u'لدى': [{'vocalized': u'لدى', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'لدى', 'encletic': u'', 'type': u'اسم', 'original': u'لدى'}],

 u'أوفيها': [{'vocalized': u'أوفيها', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'أوأناكما': [{'vocalized': u'أوأناكما', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'أفلمثل': [{'vocalized': u'أفلمثل', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثل', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'فأناهم': [{'vocalized': u'فأناهم', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'لدن': [{'vocalized': u'لدن', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'لدن', 'encletic': u'', 'type': u'اسم', 'original': u'لدن'}],

 u'أفبضع': [{'vocalized': u'أفبضع', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام', 'stem': u'بضع', 'encletic': u'', 'type': u'اسم', 'original': u'بضع'}],

 u'وكفيهم': [{'vocalized': u'وكفيهم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'}],

 u'وكفيهن': [{'vocalized': u'وكفيهن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'}],

 u'أفمنهن': [{'vocalized': u'أفمنهن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'أفمنهم': [{'vocalized': u'أفمنهم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فبتلقاءكما': [{'vocalized': u'فبتلقاءكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فلحمينا': [{'vocalized': u'فلحمينا', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'فسوى': [{'vocalized': u'فسوى', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'فسوى', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'لأولالك': [{'vocalized': u'لأولالك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فجنبكن': [{'vocalized': u'فجنبكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'أوفيهن': [{'vocalized': u'أوفيهن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'أوفيهم': [{'vocalized': u'أوفيهم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'ولكنه': [{'vocalized': u'ولكنه', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنه', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لكن'}],

 u'فسوف': [{'vocalized': u'فسوف', 'procletic': u'ف-', 'tags': u'حرف;حرف استقبال;عطف', 'stem': u'سوف', 'encletic': u'', 'type': u'حرف', 'original': u'سوف'}],

 u'ولكنك': [{'vocalized': u'ولكنك', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنك', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لكن'}],

 u'أوكمثلكما': [{'vocalized': u'أوكمثلكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أأمامهما': [{'vocalized': u'أأمامهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'وكفيها': [{'vocalized': u'وكفيها', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'}],

 u'أفمنها': [{'vocalized': u'أفمنها', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'أيمينكما': [{'vocalized': u'أيمينكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'فلدي': [{'vocalized': u'فلدي', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'},
 {'vocalized': u'فلدي', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'}],

 u'فلدى': [{'vocalized': u'فلدى', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'لدى', 'encletic': u'', 'type': u'اسم', 'original': u'لدى'}],

 u'وحواليها': [{'vocalized': u'وحواليها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حوالى'}],

 u'فلدن': [{'vocalized': u'فلدن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'لدن', 'encletic': u'', 'type': u'اسم', 'original': u'لدن'}],

 u'أوحسبنا': [{'vocalized': u'أوحسبنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'وبشرقي': [{'vocalized': u'وبشرقي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'وبشرقي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'ولجنبي': [{'vocalized': u'ولجنبي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'ولجنبي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'فكشبهكما': [{'vocalized': u'فكشبهكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'أبذينك': [{'vocalized': u'أبذينك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'أفكنحوكما': [{'vocalized': u'أفكنحوكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'أوبجميعنا': [{'vocalized': u'أوبجميعنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وبشرقه': [{'vocalized': u'وبشرقه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'اللذين': [{'vocalized': u'اللذين', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'آنذاك': [{'vocalized': u'آنذاك', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'آنذاك', 'encletic': u'', 'type': u'اسم', 'original': u'آنذاك'}],

 u'ذوي': [{'vocalized': u'ذوي', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'قبل': [{'vocalized': u'قبل', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'قبل', 'encletic': u'', 'type': u'اسم', 'original': u'قبل'}],

 u'تجاهي': [{'vocalized': u'تجاهي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تجاه'},
 {'vocalized': u'تجاهي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تجاه'}],

 u'فبدونهن': [{'vocalized': u'فبدونهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بدون'}],

 u'فبدونهم': [{'vocalized': u'فبدونهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بدون'}],

 u'وبنحوهن': [{'vocalized': u'وبنحوهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'تجاهك': [{'vocalized': u'تجاهك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تجاه'}],

 u'وذا': [{'vocalized': u'وذا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'وذا', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'وذا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'تجاهه': [{'vocalized': u'تجاهه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تجاه'}],

 u'أفكجميعكم': [{'vocalized': u'أفكجميعكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فأخيه': [{'vocalized': u'فأخيه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'أفكجميعكن': [{'vocalized': u'أفكجميعكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'فأخيك': [{'vocalized': u'فأخيك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'أولسنا': [{'vocalized': u'أولسنا', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لسنا', 'encletic': u'', 'type': u'فعل', 'original': u'لسنا'}],

 u'فلفيهم': [{'vocalized': u'فلفيهم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'فأخيي': [{'vocalized': u'فأخيي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'فأخيي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'ولخلفي': [{'vocalized': u'ولخلفي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'وحواليهما': [{'vocalized': u'وحواليهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حوالى'}],

 u'هكذا': [{'vocalized': u'هكذا', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هكذا', 'encletic': u'', 'type': u'اسم', 'original': u'هكذا'}],

 u'وللألى': [{'vocalized': u'وللألى', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'فعامتكم': [{'vocalized': u'فعامتكم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'ولخلفه': [{'vocalized': u'ولخلفه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'فلأكثرهما': [{'vocalized': u'فلأكثرهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'أجميعي': [{'vocalized': u'أجميعي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أوشمالهما': [{'vocalized': u'أوشمالهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'مابرحتن': [{'vocalized': u'مابرحتن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحتن', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتن'}],

 u'أجميعك': [{'vocalized': u'أجميعك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعك', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'كشطرهما': [{'vocalized': u'كشطرهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'وبحسبه': [{'vocalized': u'وبحسبه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أجميعه': [{'vocalized': u'أجميعه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعه', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أومني': [{'vocalized': u'أومني', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'أومني', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'أوكسويكم': [{'vocalized': u'أوكسويكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكسويكن': [{'vocalized': u'أوكسويكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أومنك': [{'vocalized': u'أومنك', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'تلقاءهن': [{'vocalized': u'تلقاءهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أومنه': [{'vocalized': u'أومنه', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'تلقاءهم': [{'vocalized': u'تلقاءهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'واستحال': [{'vocalized': u'واستحال', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'استحال', 'encletic': u'', 'type': u'فعل', 'original': u'استحال'}],

 u'هب': [{'vocalized': u'هب', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'هب', 'encletic': u'', 'type': u'فعل', 'original': u'هب'}],

 u'وكشطري': [{'vocalized': u'وكشطري', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'وكشطري', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'وكشطره': [{'vocalized': u'وكشطره', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'وكشطرك': [{'vocalized': u'وكشطرك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'وذي': [{'vocalized': u'وذي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'},
 {'vocalized': u'وذي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'وذو': [{'vocalized': u'وذو', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'ذو', 'encletic': u'', 'type': u'اسم', 'original': u'ذو'}],

 u'ماانفكت': [{'vocalized': u'ماانفكت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفكت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكت'}],

 u'فبدونها': [{'vocalized': u'فبدونها', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بدون'}],

 u'أكنحوهما': [{'vocalized': u'أكنحوهما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'وبنحوها': [{'vocalized': u'وبنحوها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'بأعلينا': [{'vocalized': u'بأعلينا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'وذه': [{'vocalized': u'وذه', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'وكأكثرهما': [{'vocalized': u'وكأكثرهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'جنبي': [{'vocalized': u'جنبي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'جنبي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'كنفسكما': [{'vocalized': u'كنفسكما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'ألعينكم': [{'vocalized': u'ألعينكم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'وكبعضكن': [{'vocalized': u'وكبعضكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'جنبه': [{'vocalized': u'جنبه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'وكبعضكم': [{'vocalized': u'وكبعضكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'كتلكم': [{'vocalized': u'كتلكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'ألعينكن': [{'vocalized': u'ألعينكن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'بشرقهن': [{'vocalized': u'بشرقهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'بشرقهم': [{'vocalized': u'بشرقهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'وكجنبكم': [{'vocalized': u'وكجنبكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'أفبمثلهما': [{'vocalized': u'أفبمثلهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'وكجنبكن': [{'vocalized': u'وكجنبكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'جنبكن': [{'vocalized': u'جنبكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'جنبكم': [{'vocalized': u'جنبكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'أمعكم': [{'vocalized': u'أمعكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'فلشبههم': [{'vocalized': u'فلشبههم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبههم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'فلشبههن': [{'vocalized': u'فلشبههن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبههن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أمعكن': [{'vocalized': u'أمعكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'ولأبيها': [{'vocalized': u'ولأبيها', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'كخ': [{'vocalized': u'كخ', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'كخ', 'encletic': u'', 'type': u'اسم فعل', 'original': u'كخ'}],

 u'وكجنوبي': [{'vocalized': u'وكجنوبي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'وكجنوبي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'فوراءك': [{'vocalized': u'فوراءك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'وكجنوبه': [{'vocalized': u'وكجنوبه', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'فوراءه': [{'vocalized': u'فوراءه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'وكجنوبك': [{'vocalized': u'وكجنوبك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'فكما': [{'vocalized': u'فكما', 'procletic': u'ف-', 'tags': u'حرف;حرف تشبيه;عطف', 'stem': u'كما', 'encletic': u'', 'type': u'حرف', 'original': u'كما'}],

 u'فكأخيكما': [{'vocalized': u'فكأخيكما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'ألنفسه': [{'vocalized': u'ألنفسه', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'سويكم': [{'vocalized': u'سويكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'سويكن': [{'vocalized': u'سويكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'فباللاتي': [{'vocalized': u'فباللاتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'لحظتهن': [{'vocalized': u'لحظتهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبأنهما': [{'vocalized': u'وبأنهما', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'ولأبيهم': [{'vocalized': u'ولأبيهم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'ألتحتكما': [{'vocalized': u'ألتحتكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'كم': [{'vocalized': u'كم', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'كم', 'encletic': u'', 'type': u'اسم', 'original': u'كم'},
 {'vocalized': u'كم', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'كم', 'encletic': u'', 'type': u'اسم', 'original': u'كم'}],

 u'كل': [{'vocalized': u'كل', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كل', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'فكليلهن': [{'vocalized': u'فكليلهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'بخلفنا': [{'vocalized': u'بخلفنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'وهذان': [{'vocalized': u'وهذان', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذان', 'encletic': u'', 'type': u'اسم', 'original': u'هذان'}],

 u'مابرحوا': [{'vocalized': u'مابرحوا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحوا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحوا'}],

 u'أولتحتك': [{'vocalized': u'أولتحتك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'كلكم': [{'vocalized': u'كلكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلكم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'كلكن': [{'vocalized': u'كلكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلكن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أليمينكما': [{'vocalized': u'أليمينكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'بشرقها': [{'vocalized': u'بشرقها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'وكأقلهما': [{'vocalized': u'وكأقلهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'كتلكما': [{'vocalized': u'كتلكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'فلدنكما': [{'vocalized': u'فلدنكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدن'}],

 u'نفسنا': [{'vocalized': u'نفسنا', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'فلشبهها': [{'vocalized': u'فلشبهها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'مابرحتا': [{'vocalized': u'مابرحتا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحتا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتا'}],

 u'أفلفوق': [{'vocalized': u'أفلفوق', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'فجميعكم': [{'vocalized': u'فجميعكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعكم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فجميعكن': [{'vocalized': u'فجميعكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعكن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'ولذا': [{'vocalized': u'ولذا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'ولذا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'مادمن': [{'vocalized': u'مادمن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمن', 'encletic': u'', 'type': u'فعل', 'original': u'مادمن'}],

 u'ومثلكما': [{'vocalized': u'ومثلكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'قام': [{'vocalized': u'قام', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'قام', 'encletic': u'', 'type': u'فعل', 'original': u'قام'}],

 u'فشطرنا': [{'vocalized': u'فشطرنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'وأعليهما': [{'vocalized': u'وأعليهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'أفكهو': [{'vocalized': u'أفكهو', 'procletic': u'أ-ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'ومازلن': [{'vocalized': u'ومازلن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلن', 'encletic': u'', 'type': u'فعل', 'original': u'مازلن'}],

 u'أنكن': [{'vocalized': u'أنكن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'أنكم': [{'vocalized': u'أنكم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'كجنبهم': [{'vocalized': u'كجنبهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'وبساعتكم': [{'vocalized': u'وبساعتكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'بتلقاءكم': [{'vocalized': u'بتلقاءكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفذين': [{'vocalized': u'أفذين', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'بتلقاءكن': [{'vocalized': u'بتلقاءكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وببعضها': [{'vocalized': u'وببعضها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'فكاللواتي': [{'vocalized': u'فكاللواتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'أفكشبهكما': [{'vocalized': u'أفكشبهكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'أعامتنا': [{'vocalized': u'أعامتنا', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'ومازلت': [{'vocalized': u'ومازلت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'},
 {'vocalized': u'ومازلت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'},
 {'vocalized': u'ومازلت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'}],

 u'أوكسويهما': [{'vocalized': u'أوكسويهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فبوقتنا': [{'vocalized': u'فبوقتنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'أوسويكما': [{'vocalized': u'أوسويكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'وبنحوه': [{'vocalized': u'وبنحوه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'بأعليهما': [{'vocalized': u'بأعليهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'وأولاء': [{'vocalized': u'وأولاء', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'فكمثلنا': [{'vocalized': u'فكمثلنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'وكلتا': [{'vocalized': u'وكلتا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'وكابنكن': [{'vocalized': u'وكابنكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'ولذي': [{'vocalized': u'ولذي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'وكابنكم': [{'vocalized': u'وكابنكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'أولعل': [{'vocalized': u'أولعل', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام', 'stem': u'لعل', 'encletic': u'', 'type': u'حرف', 'original': u'لعل'}],

 u'أولعن': [{'vocalized': u'أولعن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'فلقد': [{'vocalized': u'فلقد', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'قد', 'encletic': u'', 'type': u'حرف', 'original': u'قد'}],

 u'ولذه': [{'vocalized': u'ولذه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'ألأجمع': [{'vocalized': u'ألأجمع', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمع', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولإنكما': [{'vocalized': u'ولإنكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'شبههما': [{'vocalized': u'شبههما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فلجميعكم': [{'vocalized': u'فلجميعكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلجميعكن': [{'vocalized': u'فلجميعكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'أككل': [{'vocalized': u'أككل', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككل', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'أبتلكم': [{'vocalized': u'أبتلكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'خلاها': [{'vocalized': u'خلاها', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'خلا'}],

 u'عليكن': [{'vocalized': u'عليكن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'لأسفلهما': [{'vocalized': u'لأسفلهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبسوينا': [{'vocalized': u'وبسوينا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'فسويكم': [{'vocalized': u'فسويكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'فسويكن': [{'vocalized': u'فسويكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلتحتها': [{'vocalized': u'أفلتحتها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'بإن': [{'vocalized': u'بإن', 'procletic': u'ب-', 'tags': u'حرف;المشبهة بليس;مجرور', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'أفككل': [{'vocalized': u'أفككل', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككل', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'فلفوقي': [{'vocalized': u'فلفوقي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'فلفوقي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'ولشرقها': [{'vocalized': u'ولشرقها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'أولإنكما': [{'vocalized': u'أولإنكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'أوبغيركم': [{'vocalized': u'أوبغيركم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أوكتلكم': [{'vocalized': u'أوكتلكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أوبغيركن': [{'vocalized': u'أوبغيركن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'ب': [{'vocalized': u'ب', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ب', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ب'}],

 u'ولأعليك': [{'vocalized': u'ولأعليك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'فآنذاك': [{'vocalized': u'فآنذاك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آنذاك', 'encletic': u'', 'type': u'اسم', 'original': u'آنذاك'}],

 u'أولفينا': [{'vocalized': u'أولفينا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'ألسويهم': [{'vocalized': u'ألسويهم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'ألسويهن': [{'vocalized': u'ألسويهن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'بجنبي': [{'vocalized': u'بجنبي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'بجنبي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'فلابنك': [{'vocalized': u'فلابنك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'كليلها': [{'vocalized': u'كليلها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'وذات': [{'vocalized': u'وذات', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'فلابنه': [{'vocalized': u'فلابنه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'فذويكن': [{'vocalized': u'فذويكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'أوخلفنا': [{'vocalized': u'أوخلفنا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'وإلا': [{'vocalized': u'وإلا', 'procletic': u'و-', 'tags': u'حرف;حرف استثناء;عطف', 'stem': u'إلا', 'encletic': u'', 'type': u'حرف', 'original': u'إلا'},
 {'vocalized': u'وإلا', 'procletic': u'و-', 'tags': u'حرف;حرف استثناء;عطف', 'stem': u'إلا', 'encletic': u'', 'type': u'حرف', 'original': u'إلا'}],

 u'فذويكم': [{'vocalized': u'فذويكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'لغربها': [{'vocalized': u'لغربها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'فبذانك': [{'vocalized': u'فبذانك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'ألسويها': [{'vocalized': u'ألسويها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'وحسبكما': [{'vocalized': u'وحسبكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'فلنحوهما': [{'vocalized': u'فلنحوهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'وإلى': [{'vocalized': u'وإلى', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'فلشمالهن': [{'vocalized': u'فلشمالهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'وكأبينا': [{'vocalized': u'وكأبينا', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'وإلي': [{'vocalized': u'وإلي', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'وإلي', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'لغربهن': [{'vocalized': u'لغربهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'بابن': [{'vocalized': u'بابن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'فبخلفكم': [{'vocalized': u'فبخلفكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'خلاهم': [{'vocalized': u'خلاهم', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'خلا'}],

 u'خلاهن': [{'vocalized': u'خلاهن', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'خلا'}],

 u'أكذانك': [{'vocalized': u'أكذانك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أبهناك': [{'vocalized': u'أبهناك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أفلتحتهن': [{'vocalized': u'أفلتحتهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلتحتهم': [{'vocalized': u'أفلتحتهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'لغيرنا': [{'vocalized': u'لغيرنا', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيرنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'ولشرقهن': [{'vocalized': u'ولشرقهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'ولشرقهم': [{'vocalized': u'ولشرقهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'كسويكن': [{'vocalized': u'كسويكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'كسويكم': [{'vocalized': u'كسويكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'وأكثر': [{'vocalized': u'وأكثر', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'شمال': [{'vocalized': u'شمال', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'فآض': [{'vocalized': u'فآض', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'آض', 'encletic': u'', 'type': u'فعل', 'original': u'آض'}],

 u'وزمانكما': [{'vocalized': u'وزمانكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'شماله': [{'vocalized': u'شماله', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'فأصلا': [{'vocalized': u'فأصلا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أصلا', 'encletic': u'', 'type': u'اسم', 'original': u'أصلا'}],

 u'أوقلما': [{'vocalized': u'أوقلما', 'procletic': u'أ-و-', 'tags': u'فعل;فعل جامد;عطف;استفهام', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'أفشمالكم': [{'vocalized': u'أفشمالكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'أفشمالكن': [{'vocalized': u'أفشمالكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'فأكثرهم': [{'vocalized': u'فأكثرهم', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فذاتهن': [{'vocalized': u'فذاتهن', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'فذاتهم': [{'vocalized': u'فذاتهم', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'فأكثرهن': [{'vocalized': u'فأكثرهن', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكغربها': [{'vocalized': u'فكغربها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'أكليهما': [{'vocalized': u'أكليهما', 'procletic': u'أ-', 'tags': u'حرف;توكيد;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'أفلعنهن': [{'vocalized': u'أفلعنهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أفلعنهم': [{'vocalized': u'أفلعنهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'أوبذلكم': [{'vocalized': u'أوبذلكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'أوكمثلها': [{'vocalized': u'أوكمثلها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'أوبذلكن': [{'vocalized': u'أوبذلكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أمثلها': [{'vocalized': u'أمثلها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'فلعمر': [{'vocalized': u'فلعمر', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'لعمر', 'encletic': u'', 'type': u'اسم', 'original': u'لعمر'}],

 u'كسويهما': [{'vocalized': u'كسويهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'وضمننا': [{'vocalized': u'وضمننا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ضمن'}],

 u'فتلكم': [{'vocalized': u'فتلكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'فلتلكم': [{'vocalized': u'فلتلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'وأول': [{'vocalized': u'وأول', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أول', 'encletic': u'', 'type': u'اسم', 'original': u'أول'}],

 u'فذاتها': [{'vocalized': u'فذاتها', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'فأكثرها': [{'vocalized': u'فأكثرها', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكغربهن': [{'vocalized': u'فكغربهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'فكغربهم': [{'vocalized': u'فكغربهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'أفلعنها': [{'vocalized': u'أفلعنها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'أوكمثلهم': [{'vocalized': u'أوكمثلهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلفوقك': [{'vocalized': u'أفلفوقك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'أوكمثلهن': [{'vocalized': u'أوكمثلهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'أمثلهن': [{'vocalized': u'أمثلهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلفوقه': [{'vocalized': u'أفلفوقه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'أمثلهم': [{'vocalized': u'أمثلهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'فلحسبكما': [{'vocalized': u'فلحسبكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبأولئكم': [{'vocalized': u'أوبأولئكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'فكلحظتكم': [{'vocalized': u'فكلحظتكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفبذانك': [{'vocalized': u'أفبذانك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أمما': [{'vocalized': u'أمما', 'procletic': u'أ-', 'tags': u'اسم;اسم الاستفهام;استفهام', 'stem': u'مما', 'encletic': u'', 'type': u'اسم', 'original': u'مما'}],

 u'ألعننا': [{'vocalized': u'ألعننا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'ألوراءكما': [{'vocalized': u'ألوراءكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'أكلما': [{'vocalized': u'أكلما', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام', 'stem': u'كلما', 'encletic': u'', 'type': u'اسم', 'original': u'كلما'}],

 u'وأسفله': [{'vocalized': u'وأسفله', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'اللذان': [{'vocalized': u'اللذان', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللذان', 'encletic': u'', 'type': u'اسم', 'original': u'اللذان'}],

 u'تحتكن': [{'vocalized': u'تحتكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'تحتكم': [{'vocalized': u'تحتكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'ولعمركم': [{'vocalized': u'ولعمركم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لعمر'}],

 u'فعنكم': [{'vocalized': u'فعنكم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'فعنكن': [{'vocalized': u'فعنكن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'ولعمركن': [{'vocalized': u'ولعمركن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لعمر'}],

 u'ولأخينا': [{'vocalized': u'ولأخينا', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'وغرب': [{'vocalized': u'وغرب', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'كذاتكم': [{'vocalized': u'كذاتكم', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'كذاتكن': [{'vocalized': u'كذاتكن', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أوكهناك': [{'vocalized': u'أوكهناك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'فسويك': [{'vocalized': u'فسويك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فسويه': [{'vocalized': u'فسويه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أوعينهم': [{'vocalized': u'أوعينهم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أوعينهن': [{'vocalized': u'أوعينهن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'وساعتنا': [{'vocalized': u'وساعتنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكسويكما': [{'vocalized': u'فكسويكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ووقتهن': [{'vocalized': u'ووقتهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'ووقتهم': [{'vocalized': u'ووقتهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'بأسفلها': [{'vocalized': u'بأسفلها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'أكحسبكما': [{'vocalized': u'أكحسبكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'جميعكما': [{'vocalized': u'جميعكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعكما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'وكشرقكن': [{'vocalized': u'وكشرقكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'فبزمانها': [{'vocalized': u'فبزمانها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'فبذويها': [{'vocalized': u'فبذويها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكشرقكم': [{'vocalized': u'وكشرقكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'فآنفا': [{'vocalized': u'فآنفا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آنفا', 'encletic': u'', 'type': u'اسم', 'original': u'آنفا'}],

 u'غربنا': [{'vocalized': u'غربنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'أففوقها': [{'vocalized': u'أففوقها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'ولسويكن': [{'vocalized': u'ولسويكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أعينهما': [{'vocalized': u'أعينهما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فبغربكما': [{'vocalized': u'فبغربكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'ولسويكم': [{'vocalized': u'ولسويكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'وأيا': [{'vocalized': u'وأيا', 'procletic': u'و-', 'tags': u'حرف;حرف نداء;عطف', 'stem': u'أيا', 'encletic': u'', 'type': u'حرف', 'original': u'أيا'}],

 u'أوبعضهما': [{'vocalized': u'أوبعضهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلديهما': [{'vocalized': u'أفلديهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدى'}],

 u'بخلفه': [{'vocalized': u'بخلفه', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'فمازالتا': [{'vocalized': u'فمازالتا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالتا'}],

 u'وبأسفل': [{'vocalized': u'وبأسفل', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'فبذويهم': [{'vocalized': u'فبذويهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلذاتكما': [{'vocalized': u'فلذاتكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'فبذويهن': [{'vocalized': u'فبذويهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'فشرقنا': [{'vocalized': u'فشرقنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'أوشمالكما': [{'vocalized': u'أوشمالكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'وحينهما': [{'vocalized': u'وحينهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حين'}],

 u'فبعضي': [{'vocalized': u'فبعضي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فبعضي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'لكأنكم': [{'vocalized': u'لكأنكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'فبعضه': [{'vocalized': u'فبعضه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'وكلحظتهن': [{'vocalized': u'وكلحظتهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبعضك': [{'vocalized': u'فبعضك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'ولأثناءكم': [{'vocalized': u'ولأثناءكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولأثناءكن': [{'vocalized': u'ولأثناءكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلأمامنا': [{'vocalized': u'فلأمامنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'وبغروبك': [{'vocalized': u'وبغروبك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'أوعينها': [{'vocalized': u'أوعينها', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فحولهما': [{'vocalized': u'فحولهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حول'}],

 u'ألبعضكم': [{'vocalized': u'ألبعضكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'ألبعضكن': [{'vocalized': u'ألبعضكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'غروبهما': [{'vocalized': u'غروبهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'ووقتها': [{'vocalized': u'ووقتها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'ونحوكما': [{'vocalized': u'ونحوكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'وأولالك': [{'vocalized': u'وأولالك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'بأسفلهم': [{'vocalized': u'بأسفلهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبغروبه': [{'vocalized': u'وبغروبه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'أفبشبهه': [{'vocalized': u'أفبشبهه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'أوبهما': [{'vocalized': u'أوبهما', 'procletic': u'أ-و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'أفبشبهك': [{'vocalized': u'أفبشبهك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'وكشطرهم': [{'vocalized': u'وكشطرهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'بحسبنا': [{'vocalized': u'بحسبنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'فكغربهما': [{'vocalized': u'فكغربهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'فهب': [{'vocalized': u'فهب', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'هب', 'encletic': u'', 'type': u'فعل', 'original': u'هب'}],

 u'أفبشبهي': [{'vocalized': u'أفبشبهي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفبشبهي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'ولشبههن': [{'vocalized': u'ولشبههن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبههن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'شهرنا': [{'vocalized': u'شهرنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'وبغروبي': [{'vocalized': u'وبغروبي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'وبغروبي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'أوعامتكم': [{'vocalized': u'أوعامتكم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أوعامتكن': [{'vocalized': u'أوعامتكن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أفنحوهن': [{'vocalized': u'أفنحوهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'أفنحوهم': [{'vocalized': u'أفنحوهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'ووراءه': [{'vocalized': u'ووراءه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'أوأنتما': [{'vocalized': u'أوأنتما', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'ووراءي': [{'vocalized': u'ووراءي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'ووراءي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'كحميكن': [{'vocalized': u'كحميكن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'وكحسبنا': [{'vocalized': u'وكحسبنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'أوكعامته': [{'vocalized': u'أوكعامته', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'أيتهما': [{'vocalized': u'أيتهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'أقلهما': [{'vocalized': u'أقلهما', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'فلخلفها': [{'vocalized': u'فلخلفها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'أوكعامتي': [{'vocalized': u'أوكعامتي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أوكعامتي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'وضمنكن': [{'vocalized': u'وضمنكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ضمن'}],

 u'وكأثناءنا': [{'vocalized': u'وكأثناءنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفنحوها': [{'vocalized': u'أفنحوها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'بذلكم': [{'vocalized': u'بذلكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'بذلكن': [{'vocalized': u'بذلكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'فلمعكن': [{'vocalized': u'فلمعكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'فلمعكم': [{'vocalized': u'فلمعكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'فعداكن': [{'vocalized': u'فعداكن', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'عدا'}],

 u'فعداكم': [{'vocalized': u'فعداكم', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'عدا'}],

 u'فلشرقهما': [{'vocalized': u'فلشرقهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'وتلقاءكم': [{'vocalized': u'وتلقاءكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فلخلفهم': [{'vocalized': u'فلخلفهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'فلخلفهن': [{'vocalized': u'فلخلفهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'وتلقاءكن': [{'vocalized': u'وتلقاءكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أكعين': [{'vocalized': u'أكعين', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'فلغيري': [{'vocalized': u'فلغيري', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيري', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيري', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيري', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أففوقهم': [{'vocalized': u'أففوقهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'وكشطرها': [{'vocalized': u'وكشطرها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'فلغيرك': [{'vocalized': u'فلغيرك', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيرك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'فلغيره': [{'vocalized': u'فلغيره', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيره', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'ولشبهها': [{'vocalized': u'ولشبهها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'أففوقهن': [{'vocalized': u'أففوقهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'ليميننا': [{'vocalized': u'ليميننا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'ولعلهم': [{'vocalized': u'ولعلهم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لعل'}],

 u'لذين': [{'vocalized': u'لذين', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'ألإليكن': [{'vocalized': u'ألإليكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'نحوها': [{'vocalized': u'نحوها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'لنحونا': [{'vocalized': u'لنحونا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحونا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أهو': [{'vocalized': u'أهو', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'أإننا': [{'vocalized': u'أإننا', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'أهي': [{'vocalized': u'أهي', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'أوبكلتا': [{'vocalized': u'أوبكلتا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'ولنحوي': [{'vocalized': u'ولنحوي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'ولأولاء': [{'vocalized': u'ولأولاء', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'وكذويهما': [{'vocalized': u'وكذويهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'ألإليكم': [{'vocalized': u'ألإليكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'أفلكلها': [{'vocalized': u'أفلكلها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'ولنحوك': [{'vocalized': u'ولنحوك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'أهن': [{'vocalized': u'أهن', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أوغيرنا': [{'vocalized': u'أوغيرنا', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'بضعها': [{'vocalized': u'بضعها', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بضع'}],

 u'أفبعيني': [{'vocalized': u'أفبعيني', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفبعيني', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'أفبنحونا': [{'vocalized': u'أفبنحونا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'كاللائي': [{'vocalized': u'كاللائي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'لزمانه': [{'vocalized': u'لزمانه', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'أوبحسبها': [{'vocalized': u'أوبحسبها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'لزمانك': [{'vocalized': u'لزمانك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'أفبعينه': [{'vocalized': u'أفبعينه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أوبكلهم': [{'vocalized': u'أوبكلهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أوبكلهن': [{'vocalized': u'أوبكلهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'لرجع': [{'vocalized': u'لرجع', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'رجع', 'encletic': u'', 'type': u'فعل', 'original': u'رجع'}],

 u'وبذينك': [{'vocalized': u'وبذينك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'فآنئذ': [{'vocalized': u'فآنئذ', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آنئذ', 'encletic': u'', 'type': u'اسم', 'original': u'آنئذ'}],

 u'فلذويي': [{'vocalized': u'فلذويي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'فلذويي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبعدهم': [{'vocalized': u'وبعدهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعد'}],

 u'فلمنهما': [{'vocalized': u'فلمنهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'أولفوقي': [{'vocalized': u'أولفوقي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'أولفوقي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'فلذويك': [{'vocalized': u'فلذويك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'أولفوقه': [{'vocalized': u'أولفوقه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'فلذويه': [{'vocalized': u'فلذويه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'أعينهن': [{'vocalized': u'أعينهن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'أعينهم': [{'vocalized': u'أعينهم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'لوراءنا': [{'vocalized': u'لوراءنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'أذي': [{'vocalized': u'أذي', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'أوبكلها': [{'vocalized': u'أوبكلها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'كلتا': [{'vocalized': u'كلتا', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'وبدوننا': [{'vocalized': u'وبدوننا', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بدون'}],

 u'وبعدها': [{'vocalized': u'وبعدها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعد'}],

 u'أفهاذين': [{'vocalized': u'أفهاذين', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أوعيني': [{'vocalized': u'أوعيني', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أوعيني', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'فكعيني': [{'vocalized': u'فكعيني', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فكعيني', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'أفلازلنا': [{'vocalized': u'أفلازلنا', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'لازلنا'}],

 u'فلعامتهن': [{'vocalized': u'فلعامتهن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'ألازلن': [{'vocalized': u'ألازلن', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلن'}],

 u'أولمعنا': [{'vocalized': u'أولمعنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'ساء': [{'vocalized': u'ساء', 'procletic': u'', 'tags': u'فعل;المدح والذم', 'stem': u'ساء', 'encletic': u'', 'type': u'فعل', 'original': u'ساء'}],

 u'وأثناءنا': [{'vocalized': u'وأثناءنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'أوعينك': [{'vocalized': u'أوعينك', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أعينها': [{'vocalized': u'أعينها', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'وفلان': [{'vocalized': u'وفلان', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'فلان', 'encletic': u'', 'type': u'اسم', 'original': u'فلان'}],

 u'أوعينه': [{'vocalized': u'أوعينه', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أبضعكم': [{'vocalized': u'أبضعكم', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بضع'}],

 u'فلساعتكما': [{'vocalized': u'فلساعتكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'لطالما': [{'vocalized': u'لطالما', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'أوبك': [{'vocalized': u'أوبك', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بك', 'encletic': u'', 'type': u'ضمير', 'original': u'بك'}],

 u'فبابنهما': [{'vocalized': u'فبابنهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'فشهرنا': [{'vocalized': u'فشهرنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'فلكلهم': [{'vocalized': u'فلكلهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'فآه': [{'vocalized': u'فآه', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'آه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'آه'}],

 u'أفلكلهن': [{'vocalized': u'أفلكلهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أفلكلهم': [{'vocalized': u'أفلكلهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'ألمعي': [{'vocalized': u'ألمعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'ألمعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'فلشهرنا': [{'vocalized': u'فلشهرنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'وبأثناءكما': [{'vocalized': u'وبأثناءكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'فضحوة': [{'vocalized': u'فضحوة', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'ضحوة', 'encletic': u'', 'type': u'اسم', 'original': u'ضحوة'}],

 u'ألمعك': [{'vocalized': u'ألمعك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'أككلنا': [{'vocalized': u'أككلنا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلنا', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'ألمعه': [{'vocalized': u'ألمعه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'وحميها': [{'vocalized': u'وحميها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'أفبنفسي': [{'vocalized': u'أفبنفسي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفبنفسي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلعليهن': [{'vocalized': u'أفلعليهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'كلما': [{'vocalized': u'كلما', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'كلما', 'encletic': u'', 'type': u'اسم', 'original': u'كلما'}],

 u'أنفسكم': [{'vocalized': u'أنفسكم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلعليهم': [{'vocalized': u'أفلعليهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'فلعلكن': [{'vocalized': u'فلعلكن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لعل'}],

 u'فلعلكم': [{'vocalized': u'فلعلكم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لعل'}],

 u'كتلقاءها': [{'vocalized': u'كتلقاءها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فضمن': [{'vocalized': u'فضمن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'ضمن', 'encletic': u'', 'type': u'اسم', 'original': u'ضمن'}],

 u'وتلقاءهما': [{'vocalized': u'وتلقاءهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'بساعة': [{'vocalized': u'بساعة', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلأسفلكن': [{'vocalized': u'فلأسفلكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوكحسب': [{'vocalized': u'أوكحسب', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أوكنحو': [{'vocalized': u'أوكنحو', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فكعينه': [{'vocalized': u'فكعينه', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'لجنبهم': [{'vocalized': u'لجنبهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'أفلجميعها': [{'vocalized': u'أفلجميعها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'لجنبهن': [{'vocalized': u'لجنبهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'وعداكم': [{'vocalized': u'وعداكم', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'عدا'}],

 u'وعداكن': [{'vocalized': u'وعداكن', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'عدا'}],

 u'كزمانك': [{'vocalized': u'كزمانك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'ولراح': [{'vocalized': u'ولراح', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'راح', 'encletic': u'', 'type': u'فعل', 'original': u'راح'}],

 u'لنحن': [{'vocalized': u'لنحن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'كشبهكم': [{'vocalized': u'كشبهكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'غربهما': [{'vocalized': u'غربهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'كشبهكن': [{'vocalized': u'كشبهكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'كزماني': [{'vocalized': u'كزماني', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'كزماني', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'ألأناها': [{'vocalized': u'ألأناها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'أبنفسي': [{'vocalized': u'أبنفسي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أبنفسي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أبغيرنا': [{'vocalized': u'أبغيرنا', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'وكزمانها': [{'vocalized': u'وكزمانها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'أفبضعها': [{'vocalized': u'أفبضعها', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بضع'}],

 u'أوكنحوكما': [{'vocalized': u'أوكنحوكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فأيتكم': [{'vocalized': u'فأيتكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'أفخلفي': [{'vocalized': u'أفخلفي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'أفخلفي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'ولعلها': [{'vocalized': u'ولعلها', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لعل'}],

 u'وأبوي': [{'vocalized': u'وأبوي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبو'},
 {'vocalized': u'وأبوي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبو'}],

 u'فكأبيكن': [{'vocalized': u'فكأبيكن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'فكأبيكم': [{'vocalized': u'فكأبيكم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'وأبوه': [{'vocalized': u'وأبوه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبو'}],

 u'كشهرهن': [{'vocalized': u'كشهرهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'حينكما': [{'vocalized': u'حينكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حين'}],

 u'وكغيرهما': [{'vocalized': u'وكغيرهما', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'وكزمانهن': [{'vocalized': u'وكزمانهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'أوأمامهما': [{'vocalized': u'أوأمامهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'وكزمانهم': [{'vocalized': u'وكزمانهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'أخيهم': [{'vocalized': u'أخيهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'أسفله': [{'vocalized': u'أسفله', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'غروبكما': [{'vocalized': u'غروبكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'أولإنكم': [{'vocalized': u'أولإنكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'أولإنكن': [{'vocalized': u'أولإنكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'أفلعليها': [{'vocalized': u'أفلعليها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'فكغربي': [{'vocalized': u'فكغربي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'فكغربي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'كتلقاءهم': [{'vocalized': u'كتلقاءهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'كتلقاءهن': [{'vocalized': u'كتلقاءهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أسفلك': [{'vocalized': u'أسفلك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكتي': [{'vocalized': u'فكتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'أفلجميعهن': [{'vocalized': u'أفلجميعهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'لجنبها': [{'vocalized': u'لجنبها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'أفلجميعهم': [{'vocalized': u'أفلجميعهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أوهاهنا': [{'vocalized': u'أوهاهنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاهنا', 'encletic': u'', 'type': u'اسم', 'original': u'هاهنا'}],

 u'فكته': [{'vocalized': u'فكته', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'وبأخيهما': [{'vocalized': u'وبأخيهما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'أعليكم': [{'vocalized': u'أعليكم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'أعليكن': [{'vocalized': u'أعليكن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'لغدا': [{'vocalized': u'لغدا', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'غدا', 'encletic': u'', 'type': u'فعل', 'original': u'غدا'}],

 u'أفلمعها': [{'vocalized': u'أفلمعها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'كغروبهن': [{'vocalized': u'كغروبهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'فلأنا': [{'vocalized': u'فلأنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'فلأنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'كغروبهم': [{'vocalized': u'كغروبهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'إليها': [{'vocalized': u'إليها', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'بلحظتهم': [{'vocalized': u'بلحظتهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'لحيث': [{'vocalized': u'لحيث', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'كوقتنا': [{'vocalized': u'كوقتنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'أفيمينك': [{'vocalized': u'أفيمينك', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'أشبههما': [{'vocalized': u'أشبههما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'ولعليكم': [{'vocalized': u'ولعليكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'ولعليكن': [{'vocalized': u'ولعليكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'ولشهرهن': [{'vocalized': u'ولشهرهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'كلحظتهن': [{'vocalized': u'كلحظتهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'ولشهرهم': [{'vocalized': u'ولشهرهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'لتلقاء': [{'vocalized': u'لتلقاء', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبجنوبنا': [{'vocalized': u'وبجنوبنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفيمينه': [{'vocalized': u'أفيمينه', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'فبأنهما': [{'vocalized': u'فبأنهما', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'أولكأننا': [{'vocalized': u'أولكأننا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'ألكلك': [{'vocalized': u'ألكلك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلك', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'عدانا': [{'vocalized': u'عدانا', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'عدا'}],

 u'أوخلفكم': [{'vocalized': u'أوخلفكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'أفبنا': [{'vocalized': u'أفبنا', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بنا', 'encletic': u'', 'type': u'ضمير', 'original': u'بنا'}],

 u'ولشهرها': [{'vocalized': u'ولشهرها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'وفوقكما': [{'vocalized': u'وفوقكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'ألفوقك': [{'vocalized': u'ألفوقك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'لأبيهن': [{'vocalized': u'لأبيهن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'كأقلنا': [{'vocalized': u'كأقلنا', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'فجنبي': [{'vocalized': u'فجنبي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'فجنبي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'فجنبه': [{'vocalized': u'فجنبه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'فجنبك': [{'vocalized': u'فجنبك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'بفيكم': [{'vocalized': u'بفيكم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'}],

 u'فلأني': [{'vocalized': u'فلأني', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فلأني', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'أوليمينها': [{'vocalized': u'أوليمينها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'أفلمعهم': [{'vocalized': u'أفلمعهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'أفلمعهن': [{'vocalized': u'أفلمعهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'فكهما': [{'vocalized': u'فكهما', 'procletic': u'ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'فلأنه': [{'vocalized': u'فلأنه', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'إليهن': [{'vocalized': u'إليهن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'إليهم': [{'vocalized': u'إليهم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'أكمن': [{'vocalized': u'أكمن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم موصول;مجرور;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'أفلهنالك': [{'vocalized': u'أفلهنالك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'أإليك': [{'vocalized': u'أإليك', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'فراح': [{'vocalized': u'فراح', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'راح', 'encletic': u'', 'type': u'فعل', 'original': u'راح'}],

 u'أإليه': [{'vocalized': u'أإليه', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'أفبعامة': [{'vocalized': u'أفبعامة', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'حوالينا': [{'vocalized': u'حوالينا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حوالى'}],

 u'فمعكن': [{'vocalized': u'فمعكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'فمعكم': [{'vocalized': u'فمعكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'وأنت': [{'vocalized': u'وأنت', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'وأنت', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'وكغربهن': [{'vocalized': u'وكغربهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'وساعة': [{'vocalized': u'وساعة', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'أثناءنا': [{'vocalized': u'أثناءنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكغربهم': [{'vocalized': u'وكغربهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'لاسيما': [{'vocalized': u'لاسيما', 'procletic': u'', 'tags': u'حرف;استثناء', 'stem': u'لاسيما', 'encletic': u'', 'type': u'حرف', 'original': u'لاسيما'}],

 u'كابنها': [{'vocalized': u'كابنها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'بأعليك': [{'vocalized': u'بأعليك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'أولفوقنا': [{'vocalized': u'أولفوقنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'فأجمع': [{'vocalized': u'فأجمع', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'أشمالكم': [{'vocalized': u'أشمالكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'ولفوق': [{'vocalized': u'ولفوق', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'ولأسفلك': [{'vocalized': u'ولأسفلك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولأسفله': [{'vocalized': u'ولأسفله', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوكعامتكما': [{'vocalized': u'أوكعامتكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'وحولكما': [{'vocalized': u'وحولكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حول'}],

 u'وبأنكما': [{'vocalized': u'وبأنكما', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'فلليلهما': [{'vocalized': u'فلليلهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'إياها': [{'vocalized': u'إياها', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياها', 'encletic': u'', 'type': u'ضمير', 'original': u'إياها'}],

 u'أوبحسبكم': [{'vocalized': u'أوبحسبكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبحسبكن': [{'vocalized': u'أوبحسبكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'أفكهؤلاء': [{'vocalized': u'أفكهؤلاء', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'إليكما': [{'vocalized': u'إليكما', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'إليكما', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكما'},
 {'vocalized': u'إليكما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'بغيرنا': [{'vocalized': u'بغيرنا', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'نحوكم': [{'vocalized': u'نحوكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'نحوكن': [{'vocalized': u'نحوكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'أخيكن': [{'vocalized': u'أخيكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'أخيكم': [{'vocalized': u'أخيكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'لبات': [{'vocalized': u'لبات', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'بات', 'encletic': u'', 'type': u'فعل', 'original': u'بات'}],

 u'فبأينا': [{'vocalized': u'فبأينا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'إياهن': [{'vocalized': u'إياهن', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياهن', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهن'}],

 u'وأنك': [{'vocalized': u'وأنك', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'وأنه': [{'vocalized': u'وأنه', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'وأنى': [{'vocalized': u'وأنى', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أنى', 'encletic': u'', 'type': u'اسم', 'original': u'أنى'},
 {'vocalized': u'وأنى', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أنى', 'encletic': u'', 'type': u'اسم', 'original': u'أنى'}],

 u'وأني': [{'vocalized': u'وأني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وأني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'أبنا': [{'vocalized': u'أبنا', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'بنا', 'encletic': u'', 'type': u'ضمير', 'original': u'بنا'}],

 u'وكغربها': [{'vocalized': u'وكغربها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'وكجنبي': [{'vocalized': u'وكجنبي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'وكجنبي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'لساعتك': [{'vocalized': u'لساعتك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'وشمالي': [{'vocalized': u'وشمالي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'وشمالي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'كابنهن': [{'vocalized': u'كابنهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'كابنهم': [{'vocalized': u'كابنهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'وشماله': [{'vocalized': u'وشماله', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'لما': [{'vocalized': u'لما', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'لما', 'encletic': u'', 'type': u'اسم', 'original': u'لما'},
 {'vocalized': u'لما', 'procletic': u'', 'tags': u'حرف;حرف جزم', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'},
 {'vocalized': u'لما', 'procletic': u'', 'tags': u'حرف;ظرف', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'}],

 u'أفبكلكن': [{'vocalized': u'أفبكلكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أفبكلكم': [{'vocalized': u'أفبكلكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'لغروبها': [{'vocalized': u'لغروبها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'بغرب': [{'vocalized': u'بغرب', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'ولكلهن': [{'vocalized': u'ولكلهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'ولكلهم': [{'vocalized': u'ولكلهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'فبأعليه': [{'vocalized': u'فبأعليه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'فوقك': [{'vocalized': u'فوقك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'أكلها': [{'vocalized': u'أكلها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلها', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'أبنفس': [{'vocalized': u'أبنفس', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أولأجمعكما': [{'vocalized': u'أولأجمعكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ومازلتن': [{'vocalized': u'ومازلتن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتن'}],

 u'ومازلتم': [{'vocalized': u'ومازلتم', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتم'}],

 u'أولهاذين': [{'vocalized': u'أولهاذين', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'بلحظتك': [{'vocalized': u'بلحظتك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلأمامها': [{'vocalized': u'أفلأمامها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'فبشهرهما': [{'vocalized': u'فبشهرهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'أفلأولئك': [{'vocalized': u'أفلأولئك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'بحسبكما': [{'vocalized': u'بحسبكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'ولابني': [{'vocalized': u'ولابني', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'ولابني', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'ولابنك': [{'vocalized': u'ولابنك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'فكغروبكم': [{'vocalized': u'فكغروبكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'كغيرها': [{'vocalized': u'كغيرها', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'ولابنه': [{'vocalized': u'ولابنه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'لذويي': [{'vocalized': u'لذويي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'لذويي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'ألأولالك': [{'vocalized': u'ألأولالك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فكتينك': [{'vocalized': u'فكتينك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'أفغيركم': [{'vocalized': u'أفغيركم', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'فكفيكما': [{'vocalized': u'فكفيكما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'}],

 u'فلأيهما': [{'vocalized': u'فلأيهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'أبنحوهما': [{'vocalized': u'أبنحوهما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلأمامهن': [{'vocalized': u'أفلأمامهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'وأننا': [{'vocalized': u'وأننا', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'أولشمالهن': [{'vocalized': u'أولشمالهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'أولشمالهم': [{'vocalized': u'أولشمالهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'تلقاءكما': [{'vocalized': u'تلقاءكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'بعدكم': [{'vocalized': u'بعدكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعد'}],

 u'بعدكن': [{'vocalized': u'بعدكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعد'}],

 u'شبه': [{'vocalized': u'شبه', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'فأبوكن': [{'vocalized': u'فأبوكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبو'}],

 u'فأبوكم': [{'vocalized': u'فأبوكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبو'}],

 u'لأمامهم': [{'vocalized': u'لأمامهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'كغيرهن': [{'vocalized': u'كغيرهن', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'كغيرهم': [{'vocalized': u'كغيرهم', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'لغروبهم': [{'vocalized': u'لغروبهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'وعنها': [{'vocalized': u'وعنها', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'لغروبهن': [{'vocalized': u'لغروبهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'لعلينا': [{'vocalized': u'لعلينا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'فكلاهما': [{'vocalized': u'فكلاهما', 'procletic': u'ف-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كلاهما', 'encletic': u'', 'type': u'حرف', 'original': u'كلاهما'}],

 u'بنحوكن': [{'vocalized': u'بنحوكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'ولكلها': [{'vocalized': u'ولكلها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلها', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'بنحوكم': [{'vocalized': u'بنحوكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'لفي': [{'vocalized': u'لفي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفي', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'أكلهن': [{'vocalized': u'أكلهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلهن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'فهذين': [{'vocalized': u'فهذين', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'لشمالكم': [{'vocalized': u'لشمالكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'أكلهم': [{'vocalized': u'أكلهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلهم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أوعليكن': [{'vocalized': u'أوعليكن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'أوعليكم': [{'vocalized': u'أوعليكم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'أليمين': [{'vocalized': u'أليمين', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'ولابنها': [{'vocalized': u'ولابنها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'وكجميعكن': [{'vocalized': u'وكجميعكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعكن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'فبسويهما': [{'vocalized': u'فبسويهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'ولتحتهم': [{'vocalized': u'ولتحتهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'فأمامها': [{'vocalized': u'فأمامها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'ولتحتهن': [{'vocalized': u'ولتحتهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'فككلهن': [{'vocalized': u'فككلهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلهن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'فككلهم': [{'vocalized': u'فككلهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلهم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أولخلفكن': [{'vocalized': u'أولخلفكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'أولخلفكم': [{'vocalized': u'أولخلفكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'فخلفكما': [{'vocalized': u'فخلفكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'فكنحونا': [{'vocalized': u'فكنحونا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحونا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'عنهما': [{'vocalized': u'عنهما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'أفكعين': [{'vocalized': u'أفكعين', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'وجنوبهم': [{'vocalized': u'وجنوبهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وجنوبهن': [{'vocalized': u'وجنوبهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'أولأنتما': [{'vocalized': u'أولأنتما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'ساعتكم': [{'vocalized': u'ساعتكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فككلها': [{'vocalized': u'فككلها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلها', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'وحواليه': [{'vocalized': u'وحواليه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حوالى'}],

 u'ولغربي': [{'vocalized': u'ولغربي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'ولغربي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'ولغربه': [{'vocalized': u'ولغربه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'فكأبي': [{'vocalized': u'فكأبي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'عنكم': [{'vocalized': u'عنكم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'عنكن': [{'vocalized': u'عنكن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'أفكعامتك': [{'vocalized': u'أفكعامتك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'ولأيتكن': [{'vocalized': u'ولأيتكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'فكعامتي': [{'vocalized': u'فكعامتي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فكعامتي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فكعامته': [{'vocalized': u'فكعامته', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'كنحوكما': [{'vocalized': u'كنحوكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فكعامتك': [{'vocalized': u'فكعامتك', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'فلغير': [{'vocalized': u'فلغير', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغير', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وبأجمعه': [{'vocalized': u'وبأجمعه', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبأجمعي': [{'vocalized': u'وبأجمعي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'وبأجمعي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولابنهن': [{'vocalized': u'ولابنهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'ولابنهم': [{'vocalized': u'ولابنهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'فتحت': [{'vocalized': u'فتحت', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'ولجنبكم': [{'vocalized': u'ولجنبكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'ولجنبكن': [{'vocalized': u'ولجنبكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'ولاستحال': [{'vocalized': u'ولاستحال', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'استحال', 'encletic': u'', 'type': u'فعل', 'original': u'استحال'}],

 u'أكأنه': [{'vocalized': u'أكأنه', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'أفوقهن': [{'vocalized': u'أفوقهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'أفلأناكما': [{'vocalized': u'أفلأناكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'أكأنك': [{'vocalized': u'أكأنك', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'وبغروبهن': [{'vocalized': u'وبغروبهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'فحينك': [{'vocalized': u'فحينك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حين'}],

 u'أكأني': [{'vocalized': u'أكأني', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'أكأني', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'ولتحتها': [{'vocalized': u'ولتحتها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'وهو': [{'vocalized': u'وهو', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'فليلنا': [{'vocalized': u'فليلنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'وبأجمعها': [{'vocalized': u'وبأجمعها', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'بساعتهم': [{'vocalized': u'بساعتهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكأيكما': [{'vocalized': u'فكأيكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'بساعتهن': [{'vocalized': u'بساعتهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'مازالتا': [{'vocalized': u'مازالتا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالتا'}],

 u'ألأجمعكما': [{'vocalized': u'ألأجمعكما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'لأثناءكما': [{'vocalized': u'لأثناءكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'لأجمعه': [{'vocalized': u'لأجمعه', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أبضع': [{'vocalized': u'أبضع', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام', 'stem': u'بضع', 'encletic': u'', 'type': u'اسم', 'original': u'بضع'}],

 u'فلفوقه': [{'vocalized': u'فلفوقه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'لأجمعك': [{'vocalized': u'لأجمعك', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولأناي': [{'vocalized': u'ولأناي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'ولأناي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'ومابرحتا': [{'vocalized': u'ومابرحتا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتا'}],

 u'وأباها': [{'vocalized': u'وأباها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبا'}],

 u'أوبعضكم': [{'vocalized': u'أوبعضكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبعضكن': [{'vocalized': u'أوبعضكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'ولأناه': [{'vocalized': u'ولأناه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'لأجمعي': [{'vocalized': u'لأجمعي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'بجنبنا': [{'vocalized': u'بجنبنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'أجل': [{'vocalized': u'أجل', 'procletic': u'', 'tags': u'حرف;حرف جواب', 'stem': u'أجل', 'encletic': u'', 'type': u'حرف', 'original': u'أجل'}],

 u'فبأخيك': [{'vocalized': u'فبأخيك', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'ألعلهم': [{'vocalized': u'ألعلهم', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لعل'}],

 u'وبضعهما': [{'vocalized': u'وبضعهما', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بضع'}],

 u'ألعلهن': [{'vocalized': u'ألعلهن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لعل'}],

 u'كجميعهن': [{'vocalized': u'كجميعهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعهن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'كجميعهم': [{'vocalized': u'كجميعهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعهم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلفوقك': [{'vocalized': u'فلفوقك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'وبأقلكما': [{'vocalized': u'وبأقلكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'فيومئذ': [{'vocalized': u'فيومئذ', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'يومئذ', 'encletic': u'', 'type': u'اسم', 'original': u'يومئذ'}],

 u'ومابرحتم': [{'vocalized': u'ومابرحتم', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتم', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتم'}],

 u'ومابرحتن': [{'vocalized': u'ومابرحتن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتن', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتن'}],

 u'نعم': [{'vocalized': u'نعم', 'procletic': u'', 'tags': u'حرف;الحروف(حروف)', 'stem': u'نعم', 'encletic': u'', 'type': u'حرف', 'original': u'نعم'},
 {'vocalized': u'نعم', 'procletic': u'', 'tags': u'فعل;المدح والذم', 'stem': u'نعم', 'encletic': u'', 'type': u'فعل', 'original': u'نعم'}],

 u'وأباهن': [{'vocalized': u'وأباهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبا'}],

 u'وأباهم': [{'vocalized': u'وأباهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبا'}],

 u'بأكثرك': [{'vocalized': u'بأكثرك', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفوقكن': [{'vocalized': u'أفوقكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'أبأجمعهن': [{'vocalized': u'أبأجمعهن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألعلها': [{'vocalized': u'ألعلها', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لعل'}],

 u'كمثله': [{'vocalized': u'كمثله', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'كجميعها': [{'vocalized': u'كجميعها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعها', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'لأنشأ': [{'vocalized': u'لأنشأ', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنشأ', 'encletic': u'', 'type': u'فعل', 'original': u'أنشأ'}],

 u'وحاشاها': [{'vocalized': u'وحاشاها', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'حاشا'}],

 u'فلكأنهم': [{'vocalized': u'فلكأنهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'فبأولالك': [{'vocalized': u'فبأولالك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'وبأجمعهن': [{'vocalized': u'وبأجمعهن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبلحظتهن': [{'vocalized': u'وبلحظتهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبأجمعهم': [{'vocalized': u'وبأجمعهم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'عندئذ': [{'vocalized': u'عندئذ', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'عندئذ', 'encletic': u'', 'type': u'اسم', 'original': u'عندئذ'}],

 u'ألشمالكم': [{'vocalized': u'ألشمالكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'بساعتها': [{'vocalized': u'بساعتها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'لكاد': [{'vocalized': u'لكاد', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كاد', 'encletic': u'', 'type': u'فعل', 'original': u'كاد'}],

 u'ويكأن': [{'vocalized': u'ويكأن', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'ويكأن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'لأيهما': [{'vocalized': u'لأيهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'لذوي': [{'vocalized': u'لذوي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبلحظتهم': [{'vocalized': u'وبلحظتهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'لي': [{'vocalized': u'لي', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'لي', 'encletic': u'', 'type': u'ضمير', 'original': u'لي'}],

 u'لو': [{'vocalized': u'لو', 'procletic': u'', 'tags': u'حرف;الحروف(حروف)', 'stem': u'لو', 'encletic': u'', 'type': u'حرف', 'original': u'لو'}],

 u'لن': [{'vocalized': u'لن', 'procletic': u'', 'tags': u'حرف;الحروف(حروف)', 'stem': u'لن', 'encletic': u'', 'type': u'حرف', 'original': u'لن'}],

 u'له': [{'vocalized': u'له', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'له', 'encletic': u'', 'type': u'ضمير', 'original': u'له'}],

 u'لم': [{'vocalized': u'لم', 'procletic': u'', 'tags': u'حرف;حرف جزم', 'stem': u'لم', 'encletic': u'', 'type': u'حرف', 'original': u'لم'}],

 u'لك': [{'vocalized': u'لك', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'لك', 'encletic': u'', 'type': u'ضمير', 'original': u'لك'}],

 u'ولخلفكما': [{'vocalized': u'ولخلفكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'لبعضهما': [{'vocalized': u'لبعضهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'أولأمامها': [{'vocalized': u'أولأمامها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'إما': [{'vocalized': u'إما', 'procletic': u'', 'tags': u'حرف;حرف تخيير وتفصيل', 'stem': u'إما', 'encletic': u'', 'type': u'حرف', 'original': u'إما'}],

 u'كعينهما': [{'vocalized': u'كعينهما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'بأجمعهم': [{'vocalized': u'بأجمعهم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ففاهم': [{'vocalized': u'ففاهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فا'}],

 u'ففاهن': [{'vocalized': u'ففاهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فا'}],

 u'أفسويكن': [{'vocalized': u'أفسويكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أفسويكم': [{'vocalized': u'أفسويكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'ألشبههما': [{'vocalized': u'ألشبههما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبههما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فلئلا': [{'vocalized': u'فلئلا', 'procletic': u'ف-', 'tags': u'حرف;حرف نصب;عطف', 'stem': u'لئلا', 'encletic': u'', 'type': u'حرف', 'original': u'لئلا'}],

 u'عامتنا': [{'vocalized': u'عامتنا', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أفخلفهم': [{'vocalized': u'أفخلفهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'أفخلفهن': [{'vocalized': u'أفخلفهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أولمعهما': [{'vocalized': u'أولمعهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'لفوقهم': [{'vocalized': u'لفوقهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'لفوقهن': [{'vocalized': u'لفوقهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'ولكله': [{'vocalized': u'ولكله', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكله', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكله', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكله', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'ولكلك': [{'vocalized': u'ولكلك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلك', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'فعنهما': [{'vocalized': u'فعنهما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'ولكلي': [{'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'ففاها': [{'vocalized': u'ففاها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فا'}],

 u'وبهؤلاء': [{'vocalized': u'وبهؤلاء', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'لدنك': [{'vocalized': u'لدنك', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدن'}],

 u'وانقلب': [{'vocalized': u'وانقلب', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'انقلب', 'encletic': u'', 'type': u'فعل', 'original': u'انقلب'}],

 u'أفخلفها': [{'vocalized': u'أفخلفها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'أفكبعضنا': [{'vocalized': u'أفكبعضنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبضعهم': [{'vocalized': u'أوبضعهم', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بضع'}],

 u'بزمانهما': [{'vocalized': u'بزمانهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'وكفيكما': [{'vocalized': u'وكفيكما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'}],

 u'ولجنوب': [{'vocalized': u'ولجنوب', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'لا': [{'vocalized': u'لا', 'procletic': u'', 'tags': u'حرف;المشبهة بليس', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'لا', 'procletic': u'', 'tags': u'حرف;نافية للجنس', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'لا', 'procletic': u'', 'tags': u'حرف;ناهية', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'لا', 'procletic': u'', 'tags': u'حرف;نافية', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'}],

 u'فلعلينا': [{'vocalized': u'فلعلينا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'لغربكم': [{'vocalized': u'لغربكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'أولأمامهن': [{'vocalized': u'أولأمامهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'أولأمامهم': [{'vocalized': u'أولأمامهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'أفنحوهما': [{'vocalized': u'أفنحوهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'أوبضعه': [{'vocalized': u'أوبضعه', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بضع'}],

 u'وخلاهم': [{'vocalized': u'وخلاهم', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'خلا'}],

 u'ففينا': [{'vocalized': u'ففينا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففينا', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'بأيته': [{'vocalized': u'بأيته', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'فكأكثر': [{'vocalized': u'فكأكثر', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'فابن': [{'vocalized': u'فابن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'فكنحوي': [{'vocalized': u'فكنحوي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'لذوينا': [{'vocalized': u'لذوينا', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'فتان': [{'vocalized': u'فتان', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تان', 'encletic': u'', 'type': u'اسم', 'original': u'تان'}],

 u'ولأثناءه': [{'vocalized': u'ولأثناءه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'أكذلكم': [{'vocalized': u'أكذلكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'فكنحوك': [{'vocalized': u'فكنحوك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'أكذلكن': [{'vocalized': u'أكذلكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'عوض': [{'vocalized': u'عوض', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'عوض', 'encletic': u'', 'type': u'اسم', 'original': u'عوض'}],

 u'فكنحوه': [{'vocalized': u'فكنحوه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'بأقلهما': [{'vocalized': u'بأقلهما', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'ووقتكن': [{'vocalized': u'ووقتكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'ووقتكم': [{'vocalized': u'ووقتكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'فبساعتي': [{'vocalized': u'فبساعتي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'فبساعتي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'يميننا': [{'vocalized': u'يميننا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'لأعليه': [{'vocalized': u'لأعليه', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'وكشرقهن': [{'vocalized': u'وكشرقهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'وكشرقهم': [{'vocalized': u'وكشرقهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'ولأثناءها': [{'vocalized': u'ولأثناءها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولشمالهم': [{'vocalized': u'ولشمالهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'شمالكما': [{'vocalized': u'شمالكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'أثم': [{'vocalized': u'أثم', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'}],

 u'وزمانهن': [{'vocalized': u'وزمانهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'أفتحتنا': [{'vocalized': u'أفتحتنا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'ككلكما': [{'vocalized': u'ككلكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلكما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فعيننا': [{'vocalized': u'فعيننا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'لدنه': [{'vocalized': u'لدنه', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدن'}],

 u'ولشمالهن': [{'vocalized': u'ولشمالهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'وكشرقها': [{'vocalized': u'وكشرقها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'ألغيركما': [{'vocalized': u'ألغيركما', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيركما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'ولأثناءهم': [{'vocalized': u'ولأثناءهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولأثناءهن': [{'vocalized': u'ولأثناءهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'وزمانهم': [{'vocalized': u'وزمانهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'فبزمانكن': [{'vocalized': u'فبزمانكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'ولذاتنا': [{'vocalized': u'ولذاتنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'عينهما': [{'vocalized': u'عينهما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فبزمانكم': [{'vocalized': u'فبزمانكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'فذواتي': [{'vocalized': u'فذواتي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'ولنحوكن': [{'vocalized': u'ولنحوكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'ولنحوكم': [{'vocalized': u'ولنحوكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'فبأولئك': [{'vocalized': u'فبأولئك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'فعندما': [{'vocalized': u'فعندما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'عندما', 'encletic': u'', 'type': u'اسم', 'original': u'عندما'}],

 u'فكتانك': [{'vocalized': u'فكتانك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'بأبي': [{'vocalized': u'بأبي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'فبساعته': [{'vocalized': u'فبساعته', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفكبعضكن': [{'vocalized': u'أفكبعضكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'كفيهن': [{'vocalized': u'كفيهن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'}],

 u'وبجنب': [{'vocalized': u'وبجنب', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'وأمامنا': [{'vocalized': u'وأمامنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'أولشمالنا': [{'vocalized': u'أولشمالنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'ولحظتي': [{'vocalized': u'ولحظتي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'ولحظتي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'ولحظته': [{'vocalized': u'ولحظته', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'أولتحتهما': [{'vocalized': u'أولتحتهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'ألفوقكما': [{'vocalized': u'ألفوقكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'ولحظتك': [{'vocalized': u'ولحظتك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'فكليلكم': [{'vocalized': u'فكليلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'لعامتك': [{'vocalized': u'لعامتك', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'فلغدا': [{'vocalized': u'فلغدا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'غدا', 'encletic': u'', 'type': u'فعل', 'original': u'غدا'}],

 u'أفكجميعكما': [{'vocalized': u'أفكجميعكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'لعامته': [{'vocalized': u'لعامته', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامته', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلمنها': [{'vocalized': u'أفلمنها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'وتلقاءها': [{'vocalized': u'وتلقاءها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'لعامتي': [{'vocalized': u'لعامتي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'أولهذا': [{'vocalized': u'أولهذا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'وبغروبها': [{'vocalized': u'وبغروبها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'ولشبهكم': [{'vocalized': u'ولشبهكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'أفكنفس': [{'vocalized': u'أفكنفس', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أأمامكما': [{'vocalized': u'أأمامكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'لأينا': [{'vocalized': u'لأينا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'وذوو': [{'vocalized': u'وذوو', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذوو', 'encletic': u'', 'type': u'اسم', 'original': u'ذوو'}],

 u'وذوي': [{'vocalized': u'وذوي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'أأمامك': [{'vocalized': u'أأمامك', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'وكغربكما': [{'vocalized': u'وكغربكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'ألإن': [{'vocalized': u'ألإن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'أونفسنا': [{'vocalized': u'أونفسنا', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أوعامتهم': [{'vocalized': u'أوعامتهم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'لخلفكما': [{'vocalized': u'لخلفكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'أوعامتهن': [{'vocalized': u'أوعامتهن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'معهن': [{'vocalized': u'معهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'معهم': [{'vocalized': u'معهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'تجاهها': [{'vocalized': u'تجاهها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تجاه'}],

 u'وكوقتكن': [{'vocalized': u'وكوقتكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'وكوقتكم': [{'vocalized': u'وكوقتكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'فلمعها': [{'vocalized': u'فلمعها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'ة': [{'vocalized': u'ة', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ة', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ة'}],

 u'أأمامه': [{'vocalized': u'أأمامه', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'جدا': [{'vocalized': u'جدا', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'جدا', 'encletic': u'', 'type': u'اسم', 'original': u'جدا'}],

 u'كحميهن': [{'vocalized': u'كحميهن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'أفإننا': [{'vocalized': u'أفإننا', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'كحميهم': [{'vocalized': u'كحميهم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'ليلكن': [{'vocalized': u'ليلكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'كالذي': [{'vocalized': u'كالذي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'وأباك': [{'vocalized': u'وأباك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبا'}],

 u'ليلكم': [{'vocalized': u'ليلكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'لستم': [{'vocalized': u'لستم', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لستم', 'encletic': u'', 'type': u'فعل', 'original': u'لستم'}],

 u'وأباه': [{'vocalized': u'وأباه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبا'}],

 u'لستن': [{'vocalized': u'لستن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لستن', 'encletic': u'', 'type': u'فعل', 'original': u'لستن'}],

 u'لعسى': [{'vocalized': u'لعسى', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'عسى', 'encletic': u'', 'type': u'فعل', 'original': u'عسى'}],

 u'أوعامتها': [{'vocalized': u'أوعامتها', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'وأباي': [{'vocalized': u'وأباي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبا'},
 {'vocalized': u'وأباي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبا'}],

 u'معها': [{'vocalized': u'معها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'حتى': [{'vocalized': u'حتى', 'procletic': u'', 'tags': u'حرف;تعليل', 'stem': u'حتى', 'encletic': u'', 'type': u'حرف', 'original': u'حتى'},
 {'vocalized': u'حتى', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'حتى', 'encletic': u'', 'type': u'حرف', 'original': u'حتى'}],

 u'فتين': [{'vocalized': u'فتين', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'تجاههم': [{'vocalized': u'تجاههم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تجاه'}],

 u'فلمعهن': [{'vocalized': u'فلمعهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'أيتك': [{'vocalized': u'أيتك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'فلمعهم': [{'vocalized': u'فلمعهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'كجميعهما': [{'vocalized': u'كجميعهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعهما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'كحميها': [{'vocalized': u'كحميها', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'أكثري': [{'vocalized': u'أكثري', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'أكثري', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفبعضهما': [{'vocalized': u'أفبعضهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'لعينهما': [{'vocalized': u'لعينهما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'ألإنكما': [{'vocalized': u'ألإنكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'فلساعتي': [{'vocalized': u'فلساعتي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'فلساعتي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'وتلقاءهم': [{'vocalized': u'وتلقاءهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفلمنهن': [{'vocalized': u'أفلمنهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'أفلمنهم': [{'vocalized': u'أفلمنهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'وتلقاءهن': [{'vocalized': u'وتلقاءهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فلساعتك': [{'vocalized': u'فلساعتك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'أكثره': [{'vocalized': u'أكثره', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'وذوا': [{'vocalized': u'وذوا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذوا', 'encletic': u'', 'type': u'اسم', 'original': u'ذوا'}],

 u'ولجنوبكما': [{'vocalized': u'ولجنوبكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكأجمعهما': [{'vocalized': u'وكأجمعهما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فتحتي': [{'vocalized': u'فتحتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'فتحتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'لوراء': [{'vocalized': u'لوراء', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'فتحته': [{'vocalized': u'فتحته', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'فتحتك': [{'vocalized': u'فتحتك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'مابرح': [{'vocalized': u'مابرح', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرح', 'encletic': u'', 'type': u'فعل', 'original': u'مابرح'}],

 u'فلأثناءهما': [{'vocalized': u'فلأثناءهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولشبهي': [{'vocalized': u'ولشبهي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'زمانك': [{'vocalized': u'زمانك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'وكسويهن': [{'vocalized': u'وكسويهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'ولعينهم': [{'vocalized': u'ولعينهم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'زمانه': [{'vocalized': u'زمانه', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'وكسويهم': [{'vocalized': u'وكسويهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'ولشبهك': [{'vocalized': u'ولشبهك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'زماني': [{'vocalized': u'زماني', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'زماني', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'ولشبهه': [{'vocalized': u'ولشبهه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'ولأبيهما': [{'vocalized': u'ولأبيهما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'جعل': [{'vocalized': u'جعل', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'جعل', 'encletic': u'', 'type': u'فعل', 'original': u'جعل'}],

 u'بغروبكما': [{'vocalized': u'بغروبكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'فمابرحتا': [{'vocalized': u'فمابرحتا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتا'}],

 u'ألأناي': [{'vocalized': u'ألأناي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'ألأناي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'فلأسفلك': [{'vocalized': u'فلأسفلك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'فأناكن': [{'vocalized': u'فأناكن', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'أوبسوى': [{'vocalized': u'أوبسوى', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أوبسوي': [{'vocalized': u'أوبسوي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أوبسوي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'فأناكم': [{'vocalized': u'فأناكم', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'أفكنحوك': [{'vocalized': u'أفكنحوك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'فلأسفلي': [{'vocalized': u'فلأسفلي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'فلأسفلي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'دون': [{'vocalized': u'دون', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'دون', 'encletic': u'', 'type': u'اسم', 'original': u'دون'}],

 u'فبعدهن': [{'vocalized': u'فبعدهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعد'}],

 u'فمابرحتم': [{'vocalized': u'فمابرحتم', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتم', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتم'}],

 u'أولهنالك': [{'vocalized': u'أولهنالك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'نفسهما': [{'vocalized': u'نفسهما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'ومادام': [{'vocalized': u'ومادام', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادام', 'encletic': u'', 'type': u'فعل', 'original': u'مادام'}],

 u'لشمالهما': [{'vocalized': u'لشمالهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'فجنبهن': [{'vocalized': u'فجنبهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'أوفيكن': [{'vocalized': u'أوفيكن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'أوفيكم': [{'vocalized': u'أوفيكم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'فجنبهم': [{'vocalized': u'فجنبهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'أخلفك': [{'vocalized': u'أخلفك', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'فبالألى': [{'vocalized': u'فبالألى', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'بليلهم': [{'vocalized': u'بليلهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'أفكأجمع': [{'vocalized': u'أفكأجمع', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'بدونكن': [{'vocalized': u'بدونكن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بدون'}],

 u'ألهاذين': [{'vocalized': u'ألهاذين', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'فلسويهما': [{'vocalized': u'فلسويهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فمافتئوا': [{'vocalized': u'فمافتئوا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئوا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئوا'}],

 u'وبجنبكم': [{'vocalized': u'وبجنبكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'وبزمانكن': [{'vocalized': u'وبزمانكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'وبأيته': [{'vocalized': u'وبأيته', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'فحواليهما': [{'vocalized': u'فحواليهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حوالى'}],

 u'فبأقلكما': [{'vocalized': u'فبأقلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'كأثناءنا': [{'vocalized': u'كأثناءنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكسويها': [{'vocalized': u'وكسويها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'فساعتي': [{'vocalized': u'فساعتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'فساعتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'ولئلا': [{'vocalized': u'ولئلا', 'procletic': u'و-', 'tags': u'حرف;حرف نصب;عطف', 'stem': u'لئلا', 'encletic': u'', 'type': u'حرف', 'original': u'لئلا'}],

 u'وبأكثرنا': [{'vocalized': u'وبأكثرنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'أبسويهما': [{'vocalized': u'أبسويهما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فساعتك': [{'vocalized': u'فساعتك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'وكهن': [{'vocalized': u'وكهن', 'procletic': u'و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'بذاتهم': [{'vocalized': u'بذاتهم', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'بذاتهن': [{'vocalized': u'بذاتهن', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'ولوراءهم': [{'vocalized': u'ولوراءهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'فكأيتها': [{'vocalized': u'فكأيتها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'أوكسويها': [{'vocalized': u'أوكسويها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'فبذاتنا': [{'vocalized': u'فبذاتنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'وباللواتي': [{'vocalized': u'وباللواتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'فبشبهكما': [{'vocalized': u'فبشبهكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'شبهه': [{'vocalized': u'شبهه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'وكهم': [{'vocalized': u'وكهم', 'procletic': u'و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'عيننا': [{'vocalized': u'عيننا', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'شبهك': [{'vocalized': u'شبهك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'وإذن': [{'vocalized': u'وإذن', 'procletic': u'و-', 'tags': u'حرف;حرف جواب;عطف', 'stem': u'إذن', 'encletic': u'', 'type': u'حرف', 'original': u'إذن'}],

 u'ولخلفهن': [{'vocalized': u'ولخلفهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أأجمعكما': [{'vocalized': u'أأجمعكما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'شبهي': [{'vocalized': u'شبهي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'شبهي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'وبنحوكن': [{'vocalized': u'وبنحوكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'وبنحوكم': [{'vocalized': u'وبنحوكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'ولجنب': [{'vocalized': u'ولجنب', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'غروبنا': [{'vocalized': u'غروبنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'أهذه': [{'vocalized': u'أهذه', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'ألمعهن': [{'vocalized': u'ألمعهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'أفبكما': [{'vocalized': u'أفبكما', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بكما', 'encletic': u'', 'type': u'ضمير', 'original': u'بكما'}],

 u'بليلهن': [{'vocalized': u'بليلهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'ولأعليها': [{'vocalized': u'ولأعليها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'أكأجمعهم': [{'vocalized': u'أكأجمعهم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'وشتان': [{'vocalized': u'وشتان', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'شتان', 'encletic': u'', 'type': u'اسم فعل', 'original': u'شتان'}],

 u'ولم': [{'vocalized': u'ولم', 'procletic': u'و-', 'tags': u'حرف;حرف جزم;عطف', 'stem': u'لم', 'encletic': u'', 'type': u'حرف', 'original': u'لم'}],

 u'فهاتين': [{'vocalized': u'فهاتين', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'فيكم': [{'vocalized': u'فيكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيكم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'فيكن': [{'vocalized': u'فيكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيكن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'وبعيننا': [{'vocalized': u'وبعيننا', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'أهذا': [{'vocalized': u'أهذا', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'ألمعها': [{'vocalized': u'ألمعها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'أوبضعي': [{'vocalized': u'أوبضعي', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'},
 {'vocalized': u'أوبضعي', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'}],

 u'وبأكثرهما': [{'vocalized': u'وبأكثرهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'أعن': [{'vocalized': u'أعن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'أفشبهكما': [{'vocalized': u'أفشبهكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'بجنوبكم': [{'vocalized': u'بجنوبكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'فمنك': [{'vocalized': u'فمنك', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'وكأجمعنا': [{'vocalized': u'وكأجمعنا', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'بذاتها': [{'vocalized': u'بذاتها', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'أمسى': [{'vocalized': u'أمسى', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'أمسى', 'encletic': u'', 'type': u'فعل', 'original': u'أمسى'}],

 u'أوكسويهم': [{'vocalized': u'أوكسويهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكسويهن': [{'vocalized': u'أوكسويهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'فكأيتهن': [{'vocalized': u'فكأيتهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'هم': [{'vocalized': u'هم', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أولك': [{'vocalized': u'أولك', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لك', 'encletic': u'', 'type': u'ضمير', 'original': u'لك'}],

 u'أسفلهما': [{'vocalized': u'أسفلهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أولم': [{'vocalized': u'أولم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جزم;عطف;استفهام', 'stem': u'لم', 'encletic': u'', 'type': u'حرف', 'original': u'لم'}],

 u'أوبهناك': [{'vocalized': u'أوبهناك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'وإذا': [{'vocalized': u'وإذا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'إذا', 'encletic': u'', 'type': u'اسم', 'original': u'إذا'},
 {'vocalized': u'وإذا', 'procletic': u'و-', 'tags': u'حرف;اسم شرط;عطف', 'stem': u'إذا', 'encletic': u'', 'type': u'حرف', 'original': u'إذا'}],

 u'أولن': [{'vocalized': u'أولن', 'procletic': u'أ-و-', 'tags': u'حرف;الحروف(حروف);عطف;استفهام', 'stem': u'لن', 'encletic': u'', 'type': u'حرف', 'original': u'لن'}],

 u'أفلمعكما': [{'vocalized': u'أفلمعكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'أولي': [{'vocalized': u'أولي', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لي', 'encletic': u'', 'type': u'ضمير', 'original': u'لي'}],

 u'وكتلقاءكم': [{'vocalized': u'وكتلقاءكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكتلقاءكن': [{'vocalized': u'وكتلقاءكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فعوض': [{'vocalized': u'فعوض', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'عوض', 'encletic': u'', 'type': u'اسم', 'original': u'عوض'}],

 u'إليهما': [{'vocalized': u'إليهما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'أعليهم': [{'vocalized': u'أعليهم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'بفيها': [{'vocalized': u'بفيها', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'}],

 u'أعليهن': [{'vocalized': u'أعليهن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'آض': [{'vocalized': u'آض', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'آض', 'encletic': u'', 'type': u'فعل', 'original': u'آض'}],

 u'أفعليك': [{'vocalized': u'أفعليك', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'فبهناك': [{'vocalized': u'فبهناك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'فكزمانها': [{'vocalized': u'فكزمانها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'فالذي': [{'vocalized': u'فالذي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'أوكذلكن': [{'vocalized': u'أوكذلكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أوكذلكم': [{'vocalized': u'أوكذلكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'أهاتين': [{'vocalized': u'أهاتين', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'ولعليهم': [{'vocalized': u'ولعليهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'ولعليهن': [{'vocalized': u'ولعليهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'فإننا': [{'vocalized': u'فإننا', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'هي': [{'vocalized': u'هي', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'بأقلها': [{'vocalized': u'بأقلها', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'فلغروبهم': [{'vocalized': u'فلغروبهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'ساعتهم': [{'vocalized': u'ساعتهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'لجميعكما': [{'vocalized': u'لجميعكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلكأننا': [{'vocalized': u'أفلكأننا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'ألأجمعنا': [{'vocalized': u'ألأجمعنا', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'فنحوي': [{'vocalized': u'فنحوي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'فنحوه': [{'vocalized': u'فنحوه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'ولعليها': [{'vocalized': u'ولعليها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'فكان': [{'vocalized': u'فكان', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'كان', 'encletic': u'', 'type': u'فعل', 'original': u'كان'}],

 u'فنحوك': [{'vocalized': u'فنحوك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'بحسبك': [{'vocalized': u'بحسبك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'خلالهما': [{'vocalized': u'خلالهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلال'}],

 u'بأقلهن': [{'vocalized': u'بأقلهن', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'كأيي': [{'vocalized': u'كأيي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'كأيي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'ألإننا': [{'vocalized': u'ألإننا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'فلغروبها': [{'vocalized': u'فلغروبها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'لشبهنا': [{'vocalized': u'لشبهنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'لأناه': [{'vocalized': u'لأناه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'كأيك': [{'vocalized': u'كأيك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'بأيتك': [{'vocalized': u'بأيتك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'كأين': [{'vocalized': u'كأين', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'كأين', 'encletic': u'', 'type': u'اسم', 'original': u'كأين'},
 {'vocalized': u'كأين', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'كأين', 'encletic': u'', 'type': u'اسم', 'original': u'كأين'}],

 u'كأيه': [{'vocalized': u'كأيه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'أخلفي': [{'vocalized': u'أخلفي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'أخلفي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فكأكثرهما': [{'vocalized': u'فكأكثرهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'فعينهما': [{'vocalized': u'فعينهما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فبعينكم': [{'vocalized': u'فبعينكم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'بفيهم': [{'vocalized': u'بفيهم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'}],

 u'ولكنهما': [{'vocalized': u'ولكنهما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنهما', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لكن'}],

 u'أعليها': [{'vocalized': u'أعليها', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'بفيهن': [{'vocalized': u'بفيهن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'}],

 u'فلزماننا': [{'vocalized': u'فلزماننا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'كفينا': [{'vocalized': u'كفينا', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'}],

 u'قط': [{'vocalized': u'قط', 'procletic': u'', 'tags': u'حرف;ظرف', 'stem': u'قط', 'encletic': u'', 'type': u'حرف', 'original': u'قط'}],

 u'فكزمانهم': [{'vocalized': u'فكزمانهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'أفلمعكم': [{'vocalized': u'أفلمعكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'أفلمعكن': [{'vocalized': u'أفلمعكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'فلأيي': [{'vocalized': u'فلأيي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فلأيي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'فلأيه': [{'vocalized': u'فلأيه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'فلأيك': [{'vocalized': u'فلأيك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'لسوينا': [{'vocalized': u'لسوينا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'ومازلتما': [{'vocalized': u'ومازلتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتما'},
 {'vocalized': u'ومازلتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتما'}],

 u'فمعهن': [{'vocalized': u'فمعهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'فمعهم': [{'vocalized': u'فمعهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'أفبتلكم': [{'vocalized': u'أفبتلكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'عليه': [{'vocalized': u'عليه', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'ألعنهن': [{'vocalized': u'ألعنهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أبيه': [{'vocalized': u'أبيه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'أبيك': [{'vocalized': u'أبيك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'ألعنهم': [{'vocalized': u'ألعنهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'حموك': [{'vocalized': u'حموك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمو'}],

 u'فعندئذ': [{'vocalized': u'فعندئذ', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'عندئذ', 'encletic': u'', 'type': u'اسم', 'original': u'عندئذ'}],

 u'فلغيرها': [{'vocalized': u'فلغيرها', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيرها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'وجنبكما': [{'vocalized': u'وجنبكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'فكذويها': [{'vocalized': u'فكذويها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'فحسبي': [{'vocalized': u'فحسبي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'فحسبي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'فبينما': [{'vocalized': u'فبينما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بينما', 'encletic': u'', 'type': u'اسم', 'original': u'بينما'}],

 u'مثل': [{'vocalized': u'مثل', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'فشماله': [{'vocalized': u'فشماله', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'أففوق': [{'vocalized': u'أففوق', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'وغروبكم': [{'vocalized': u'وغروبكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'أوكنحوي': [{'vocalized': u'أوكنحوي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أوكنحوي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'ولأكثرهن': [{'vocalized': u'ولأكثرهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولأكثرهم': [{'vocalized': u'ولأكثرهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكوقتكما': [{'vocalized': u'فكوقتكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'وبتينك': [{'vocalized': u'وبتينك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'فبساعتهم': [{'vocalized': u'فبساعتهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فسويكما': [{'vocalized': u'فسويكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكنحوه': [{'vocalized': u'أوكنحوه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'فلغيرهن': [{'vocalized': u'فلغيرهن', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيرهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'فكذويهم': [{'vocalized': u'فكذويهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكذويهن': [{'vocalized': u'فكذويهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلغيرهم': [{'vocalized': u'فلغيرهم', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيرهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'بأيتنا': [{'vocalized': u'بأيتنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'نحو': [{'vocalized': u'نحو', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحو', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'لبعضكن': [{'vocalized': u'لبعضكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'لبعضكم': [{'vocalized': u'لبعضكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'ولإلي': [{'vocalized': u'ولإلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'ولإلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'وكتانك': [{'vocalized': u'وكتانك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'أفلذانك': [{'vocalized': u'أفلذانك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'فكبعضي': [{'vocalized': u'فكبعضي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فكبعضي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'ولأكثرها': [{'vocalized': u'ولأكثرها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكبعضك': [{'vocalized': u'فكبعضك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فكبعضه': [{'vocalized': u'فكبعضه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'أليستا': [{'vocalized': u'أليستا', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'ليستا', 'encletic': u'', 'type': u'فعل', 'original': u'ليستا'}],

 u'ألنفسنا': [{'vocalized': u'ألنفسنا', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'فمعها': [{'vocalized': u'فمعها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'كحسب': [{'vocalized': u'كحسب', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'وأيه': [{'vocalized': u'وأيه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'وأين': [{'vocalized': u'وأين', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'},
 {'vocalized': u'وأين', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'},
 {'vocalized': u'وأين', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'}],

 u'فلعامتكما': [{'vocalized': u'فلعامتكما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'وأيك': [{'vocalized': u'وأيك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'فأيضا': [{'vocalized': u'فأيضا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'أيضا', 'encletic': u'', 'type': u'اسم', 'original': u'أيضا'}],

 u'وأيي': [{'vocalized': u'وأيي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وأيي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'وبأعليهن': [{'vocalized': u'وبأعليهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبشبهها': [{'vocalized': u'فبشبهها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلتحتكن': [{'vocalized': u'أفلتحتكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلتحتكم': [{'vocalized': u'أفلتحتكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'فليمينكما': [{'vocalized': u'فليمينكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'فلوقتهما': [{'vocalized': u'فلوقتهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'أوهناك': [{'vocalized': u'أوهناك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'وكأثناءي': [{'vocalized': u'وكأثناءي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'وكأثناءي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلشرقي': [{'vocalized': u'فلشرقي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'فلشرقي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'فبأبينا': [{'vocalized': u'فبأبينا', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'فكحسبهما': [{'vocalized': u'فكحسبهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'ولفوقهم': [{'vocalized': u'ولفوقهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'أبونا': [{'vocalized': u'أبونا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبو'}],

 u'فلشرقك': [{'vocalized': u'فلشرقك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'فلشرقه': [{'vocalized': u'فلشرقه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'فبضعنا': [{'vocalized': u'فبضعنا', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بضع'}],

 u'أفكهن': [{'vocalized': u'أفكهن', 'procletic': u'أ-ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أفكهم': [{'vocalized': u'أفكهم', 'procletic': u'أ-ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'لأمامي': [{'vocalized': u'لأمامي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'لأمامي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'ولأني': [{'vocalized': u'ولأني', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'ولأني', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'أفمني': [{'vocalized': u'أفمني', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'أفمني', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'ولأنه': [{'vocalized': u'ولأنه', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'أفكهي': [{'vocalized': u'أفكهي', 'procletic': u'أ-ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'فكشطرهما': [{'vocalized': u'فكشطرهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'وكجنوبكم': [{'vocalized': u'وكجنوبكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكجنوبكن': [{'vocalized': u'وكجنوبكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوبغيرهم': [{'vocalized': u'أوبغيرهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'وقام': [{'vocalized': u'وقام', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'قام', 'encletic': u'', 'type': u'فعل', 'original': u'قام'}],

 u'أوبغيرهن': [{'vocalized': u'أوبغيرهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'فبئس': [{'vocalized': u'فبئس', 'procletic': u'ف-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'بئس', 'encletic': u'', 'type': u'فعل', 'original': u'بئس'}],

 u'أفلعنكن': [{'vocalized': u'أفلعنكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'ألمنكما': [{'vocalized': u'ألمنكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'ولأنت': [{'vocalized': u'ولأنت', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'ولأنت', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'أولعامتك': [{'vocalized': u'أولعامتك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'ولأنا': [{'vocalized': u'ولأنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'ولأنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'كحميه': [{'vocalized': u'كحميه', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'أفأناك': [{'vocalized': u'أفأناك', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'كحميك': [{'vocalized': u'كحميك', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'فشبه': [{'vocalized': u'فشبه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'أوبغيرها': [{'vocalized': u'أوبغيرها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'وأعليه': [{'vocalized': u'وأعليه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'كحميي': [{'vocalized': u'كحميي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'كحميي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'أوبمثلكم': [{'vocalized': u'أوبمثلكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أوبمثلكن': [{'vocalized': u'أوبمثلكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'وأعليك': [{'vocalized': u'وأعليك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'ومثلهما': [{'vocalized': u'ومثلهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فبشبههم': [{'vocalized': u'فبشبههم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'فبشبههن': [{'vocalized': u'فبشبههن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلشماله': [{'vocalized': u'أفلشماله', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'أفلعنك': [{'vocalized': u'أفلعنك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'فكشهركن': [{'vocalized': u'فكشهركن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'فليته': [{'vocalized': u'فليته', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ه', 'type': u'حرف', 'original': u'ليت'}],

 u'خلاكم': [{'vocalized': u'خلاكم', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'خلا'}],

 u'خلاكن': [{'vocalized': u'خلاكن', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'خلا'}],

 u'أولعامتي': [{'vocalized': u'أولعامتي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'وبكلنا': [{'vocalized': u'وبكلنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلنا', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أولازلنا': [{'vocalized': u'أولازلنا', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'لازلنا'}],

 u'ولفوقها': [{'vocalized': u'ولفوقها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'هن': [{'vocalized': u'هن', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'فبكليكما': [{'vocalized': u'فبكليكما', 'procletic': u'ف-ب-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أفأناي': [{'vocalized': u'أفأناي', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'أفأناي', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'أوببعضهن': [{'vocalized': u'أوببعضهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'كذاتهم': [{'vocalized': u'كذاتهم', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'فبينهن': [{'vocalized': u'فبينهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بين'}],

 u'كذاتهن': [{'vocalized': u'كذاتهن', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'وبأقلها': [{'vocalized': u'وبأقلها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'أوبكليهما': [{'vocalized': u'أوبكليهما', 'procletic': u'أ-و-ب-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'لشرقكم': [{'vocalized': u'لشرقكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'كسويهن': [{'vocalized': u'كسويهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'كسويهم': [{'vocalized': u'كسويهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أفشمالهم': [{'vocalized': u'أفشمالهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'أخانا': [{'vocalized': u'أخانا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخا'}],

 u'أفشمالهن': [{'vocalized': u'أفشمالهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'وتلقاء': [{'vocalized': u'وتلقاء', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ككلهن': [{'vocalized': u'ككلهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلهن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'ككلهم': [{'vocalized': u'ككلهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلهم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'وبجميعها': [{'vocalized': u'وبجميعها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعها', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'فعنها': [{'vocalized': u'فعنها', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'أولعينهم': [{'vocalized': u'أولعينهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'فذويها': [{'vocalized': u'فذويها', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'أولعينهن': [{'vocalized': u'أولعينهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'فبأثناء': [{'vocalized': u'فبأثناء', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'فكحميهما': [{'vocalized': u'فكحميهما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'وآنئذ': [{'vocalized': u'وآنئذ', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آنئذ', 'encletic': u'', 'type': u'اسم', 'original': u'آنئذ'}],

 u'فأكثركم': [{'vocalized': u'فأكثركم', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فأكثركن': [{'vocalized': u'فأكثركن', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'أيتكم': [{'vocalized': u'أيتكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'وشطري': [{'vocalized': u'وشطري', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'وشطري', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'وشطره': [{'vocalized': u'وشطره', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'وشطرك': [{'vocalized': u'وشطرك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'فتلقاءي': [{'vocalized': u'فتلقاءي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'فتلقاءي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ألذلك': [{'vocalized': u'ألذلك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'فذويهن': [{'vocalized': u'فذويهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكذواتي': [{'vocalized': u'وكذواتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'أولعينها': [{'vocalized': u'أولعينها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فذويهم': [{'vocalized': u'فذويهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفكأولئكم': [{'vocalized': u'أفكأولئكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'فتلقاءه': [{'vocalized': u'فتلقاءه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'شمالهما': [{'vocalized': u'شمالهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'فكغربكن': [{'vocalized': u'فكغربكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'لأقلنا': [{'vocalized': u'لأقلنا', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'أوبنا': [{'vocalized': u'أوبنا', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بنا', 'encletic': u'', 'type': u'ضمير', 'original': u'بنا'}],

 u'فآمين': [{'vocalized': u'فآمين', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'آمين', 'encletic': u'', 'type': u'اسم فعل', 'original': u'آمين'}],

 u'ألمعهما': [{'vocalized': u'ألمعهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'بأعليه': [{'vocalized': u'بأعليه', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولسويكما': [{'vocalized': u'ولسويكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'أولعليهن': [{'vocalized': u'أولعليهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'كذاتها': [{'vocalized': u'كذاتها', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'حسبهم': [{'vocalized': u'حسبهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'وبأقلهن': [{'vocalized': u'وبأقلهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'وبأقلهم': [{'vocalized': u'وبأقلهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'كسويها': [{'vocalized': u'كسويها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'حسبهن': [{'vocalized': u'حسبهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'فلعمركم': [{'vocalized': u'فلعمركم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لعمر'}],

 u'ولأقلكن': [{'vocalized': u'ولأقلكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'ولأقلكم': [{'vocalized': u'ولأقلكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'أفلعينهما': [{'vocalized': u'أفلعينهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'بزمانكما': [{'vocalized': u'بزمانكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'ككلها': [{'vocalized': u'ككلها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلها', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'تحتهم': [{'vocalized': u'تحتهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'لليلكن': [{'vocalized': u'لليلكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'وبجميعهن': [{'vocalized': u'وبجميعهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعهن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'وبجميعهم': [{'vocalized': u'وبجميعهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعهم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أوسوينا': [{'vocalized': u'أوسوينا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'فحين': [{'vocalized': u'فحين', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'حين', 'encletic': u'', 'type': u'اسم', 'original': u'حين'}],

 u'كأثناء': [{'vocalized': u'كأثناء', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفبحسبكما': [{'vocalized': u'أفبحسبكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'وشبهي': [{'vocalized': u'وشبهي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'وشبهي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'لتحتنا': [{'vocalized': u'لتحتنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'وشبهه': [{'vocalized': u'وشبهه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'أخلفكن': [{'vocalized': u'أخلفكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'وشبهك': [{'vocalized': u'وشبهك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'بعينك': [{'vocalized': u'بعينك', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'لشرقكن': [{'vocalized': u'لشرقكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'بعينه': [{'vocalized': u'بعينه', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'فبعامة': [{'vocalized': u'فبعامة', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'بعيني': [{'vocalized': u'بعيني', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'بعيني', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'ومادمن': [{'vocalized': u'ومادمن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمن', 'encletic': u'', 'type': u'فعل', 'original': u'مادمن'}],

 u'فحولنا': [{'vocalized': u'فحولنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حول'}],

 u'أوليستا': [{'vocalized': u'أوليستا', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليستا', 'encletic': u'', 'type': u'فعل', 'original': u'ليستا'}],

 u'فكشهر': [{'vocalized': u'فكشهر', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'فكتلكما': [{'vocalized': u'فكتلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'لكأن': [{'vocalized': u'لكأن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'أفبعامتنا': [{'vocalized': u'أفبعامتنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'كأجمعكم': [{'vocalized': u'كأجمعكم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ج': [{'vocalized': u'ج', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ج', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ج'}],

 u'فكساعتهن': [{'vocalized': u'فكساعتهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوبعضهم': [{'vocalized': u'أوبعضهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبعضهن': [{'vocalized': u'أوبعضهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفكهذه': [{'vocalized': u'أفكهذه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'لعلكما': [{'vocalized': u'لعلكما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لعل'}],

 u'أبكليهما': [{'vocalized': u'أبكليهما', 'procletic': u'أ-ب-', 'tags': u'حرف;توكيد;مجرور;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'وكشرقكما': [{'vocalized': u'وكشرقكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'وجنوبكم': [{'vocalized': u'وجنوبكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وجنوبكن': [{'vocalized': u'وجنوبكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فأسفلهن': [{'vocalized': u'فأسفلهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبزمانهما': [{'vocalized': u'وبزمانهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'فأسفلهم': [{'vocalized': u'فأسفلهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'بشبههما': [{'vocalized': u'بشبههما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'وأباكن': [{'vocalized': u'وأباكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبا'}],

 u'وأباكم': [{'vocalized': u'وأباكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبا'}],

 u'أفكهذا': [{'vocalized': u'أفكهذا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'أوتينك': [{'vocalized': u'أوتينك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'كجنبكما': [{'vocalized': u'كجنبكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'أشمالك': [{'vocalized': u'أشمالك', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'فكساعتنا': [{'vocalized': u'فكساعتنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'أشماله': [{'vocalized': u'أشماله', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'فبأنك': [{'vocalized': u'فبأنك', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'كوقتكما': [{'vocalized': u'كوقتكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'أبأجمعكن': [{'vocalized': u'أبأجمعكن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أبأجمعكم': [{'vocalized': u'أبأجمعكم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فبنحوكما': [{'vocalized': u'فبنحوكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فحيث': [{'vocalized': u'فحيث', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'فلوقتي': [{'vocalized': u'فلوقتي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'فلوقتي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'فأبيكما': [{'vocalized': u'فأبيكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'وبسويها': [{'vocalized': u'وبسويها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'فلوقتك': [{'vocalized': u'فلوقتك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'أوعننا': [{'vocalized': u'أوعننا', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'وبأجمعكن': [{'vocalized': u'وبأجمعكن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلوقته': [{'vocalized': u'فلوقته', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'وبأجمعكم': [{'vocalized': u'وبأجمعكم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'بيننا': [{'vocalized': u'بيننا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بين'}],

 u'فمكانك': [{'vocalized': u'فمكانك', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانك'},
 {'vocalized': u'فمكانك', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانك'}],

 u'بأسفلهما': [{'vocalized': u'بأسفلهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'فبأيتي': [{'vocalized': u'فبأيتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'فبأيتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'وبأبينا': [{'vocalized': u'وبأبينا', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'فبأيته': [{'vocalized': u'فبأيته', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'فبأيتك': [{'vocalized': u'فبأيتك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'فلأثناءي': [{'vocalized': u'فلأثناءي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'فلأثناءي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'ألهذه': [{'vocalized': u'ألهذه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'ليلنا': [{'vocalized': u'ليلنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'مثلنا': [{'vocalized': u'مثلنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'وبحيث': [{'vocalized': u'وبحيث', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'بذويها': [{'vocalized': u'بذويها', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'كأنك': [{'vocalized': u'كأنك', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنك', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'فلأثناءه': [{'vocalized': u'فلأثناءه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'لعمركما': [{'vocalized': u'لعمركما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لعمر'}],

 u'بعدهما': [{'vocalized': u'بعدهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعد'}],

 u'كيت': [{'vocalized': u'كيت', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'كيت', 'encletic': u'', 'type': u'اسم', 'original': u'كيت'}],

 u'ألتحتهن': [{'vocalized': u'ألتحتهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'أفكجميعي': [{'vocalized': u'أفكجميعي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكجميعه': [{'vocalized': u'أفكجميعه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'وبوقتكن': [{'vocalized': u'وبوقتكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'ولمننا': [{'vocalized': u'ولمننا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'أفكجميعك': [{'vocalized': u'أفكجميعك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'فلنحن': [{'vocalized': u'فلنحن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'أفأجمعها': [{'vocalized': u'أفأجمعها', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألتحتهم': [{'vocalized': u'ألتحتهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'وأخاهم': [{'vocalized': u'وأخاهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخا'}],

 u'وأخاهن': [{'vocalized': u'وأخاهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخا'}],

 u'أفسويهن': [{'vocalized': u'أفسويهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'أفسويهم': [{'vocalized': u'أفسويهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلوراءك': [{'vocalized': u'أفلوراءك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'أفلوراءه': [{'vocalized': u'أفلوراءه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'كجميعكن': [{'vocalized': u'كجميعكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعكن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'كجميعكم': [{'vocalized': u'كجميعكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعكم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلوراءي': [{'vocalized': u'أفلوراءي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'أفلوراءي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'كيف': [{'vocalized': u'كيف', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'كيف', 'encletic': u'', 'type': u'اسم', 'original': u'كيف'}],

 u'ساعتهما': [{'vocalized': u'ساعتهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفأجمعهن': [{'vocalized': u'أفأجمعهن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبدونكما': [{'vocalized': u'وبدونكما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بدون'}],

 u'أفأجمعهم': [{'vocalized': u'أفأجمعهم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'شرقنا': [{'vocalized': u'شرقنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'وأخاها': [{'vocalized': u'وأخاها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخا'}],

 u'أفسويها': [{'vocalized': u'أفسويها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'وبينما': [{'vocalized': u'وبينما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بينما', 'encletic': u'', 'type': u'اسم', 'original': u'بينما'}],

 u'أوحسبكما': [{'vocalized': u'أوحسبكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'وأمامكم': [{'vocalized': u'وأمامكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'أوبذانك': [{'vocalized': u'أوبذانك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أليميننا': [{'vocalized': u'أليميننا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'ألهذا': [{'vocalized': u'ألهذا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'لمثلي': [{'vocalized': u'لمثلي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'فأجمعهما': [{'vocalized': u'فأجمعهما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'بذويهم': [{'vocalized': u'بذويهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'لمثلك': [{'vocalized': u'لمثلك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'بذويهن': [{'vocalized': u'بذويهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'لديكن': [{'vocalized': u'لديكن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدى'}],

 u'لمثله': [{'vocalized': u'لمثله', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثله', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'لحظتنا': [{'vocalized': u'لحظتنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'أولحسبنا': [{'vocalized': u'أولحسبنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'وكسويكما': [{'vocalized': u'وكسويكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ولشرقه': [{'vocalized': u'ولشرقه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'ولشرقك': [{'vocalized': u'ولشرقك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'ولجنبهما': [{'vocalized': u'ولجنبهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'كجنوبنا': [{'vocalized': u'كجنوبنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'فأخوك': [{'vocalized': u'فأخوك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخو'}],

 u'وبشهركما': [{'vocalized': u'وبشهركما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'وهذين': [{'vocalized': u'وهذين', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'أأنتم': [{'vocalized': u'أأنتم', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'أفيمينكما': [{'vocalized': u'أفيمينكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'وفقط': [{'vocalized': u'وفقط', 'procletic': u'و-', 'tags': u'حرف;;عطف', 'stem': u'فقط', 'encletic': u'', 'type': u'حرف', 'original': u'فقط'}],

 u'كذينك': [{'vocalized': u'كذينك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'بأننا': [{'vocalized': u'بأننا', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'أوبكلكم': [{'vocalized': u'أوبكلكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أوبكلكن': [{'vocalized': u'أوبكلكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'وضمنها': [{'vocalized': u'وضمنها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ضمن'}],

 u'فأسفله': [{'vocalized': u'فأسفله', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'فذينك': [{'vocalized': u'فذينك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'وبعدكن': [{'vocalized': u'وبعدكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعد'}],

 u'وبعدكم': [{'vocalized': u'وبعدكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعد'}],

 u'فلسوي': [{'vocalized': u'فلسوي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'فلسوي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'وكشهركما': [{'vocalized': u'وكشهركما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'لفوقكم': [{'vocalized': u'لفوقكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'كلحظتنا': [{'vocalized': u'كلحظتنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'فكغروبهم': [{'vocalized': u'فكغروبهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'فبشطر': [{'vocalized': u'فبشطر', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'لأثناءهما': [{'vocalized': u'لأثناءهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفلخلفي': [{'vocalized': u'أفلخلفي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'أفلخلفي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فبساعة': [{'vocalized': u'فبساعة', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفلخلفك': [{'vocalized': u'أفلخلفك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'أفلخلفه': [{'vocalized': u'أفلخلفه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'وضمنهما': [{'vocalized': u'وضمنهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ضمن'}],

 u'كجميع': [{'vocalized': u'كجميع', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميع', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'بأكثركم': [{'vocalized': u'بأكثركم', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'فبشهر': [{'vocalized': u'فبشهر', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'أوكغيرك': [{'vocalized': u'أوكغيرك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'أوكغيره': [{'vocalized': u'أوكغيره', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أوكغيري': [{'vocalized': u'أوكغيري', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أوكغيري', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'ذويكما': [{'vocalized': u'ذويكما', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلسوف': [{'vocalized': u'فلسوف', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'سوف', 'encletic': u'', 'type': u'حرف', 'original': u'سوف'}],

 u'وكأبيك': [{'vocalized': u'وكأبيك', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'فكأبيكما': [{'vocalized': u'فكأبيكما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'ولطالما': [{'vocalized': u'ولطالما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'أيهما': [{'vocalized': u'أيهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'لمثلها': [{'vocalized': u'لمثلها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'لجنوبه': [{'vocalized': u'لجنوبه', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلعلهن': [{'vocalized': u'فلعلهن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لعل'}],

 u'فلعلهم': [{'vocalized': u'فلعلهم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لعل'}],

 u'لجنوبك': [{'vocalized': u'لجنوبك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'استحال': [{'vocalized': u'استحال', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'استحال', 'encletic': u'', 'type': u'فعل', 'original': u'استحال'}],

 u'وبينكما': [{'vocalized': u'وبينكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بين'}],

 u'فلغروبهما': [{'vocalized': u'فلغروبهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'لجنوبي': [{'vocalized': u'لجنوبي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'لجنوبي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'فذواتا': [{'vocalized': u'فذواتا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذواتا', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتا'}],

 u'لجنبكم': [{'vocalized': u'لجنبكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'أكثرنا': [{'vocalized': u'أكثرنا', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'لجنبكن': [{'vocalized': u'لجنبكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'وأخوهن': [{'vocalized': u'وأخوهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخو'}],

 u'وكأبيي': [{'vocalized': u'وكأبيي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'وكأبيي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'وعداهن': [{'vocalized': u'وعداهن', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'عدا'}],

 u'وأخوهم': [{'vocalized': u'وأخوهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخو'}],

 u'لأخذ': [{'vocalized': u'لأخذ', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أخذ', 'encletic': u'', 'type': u'فعل', 'original': u'أخذ'}],

 u'ولمن': [{'vocalized': u'ولمن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'ولمن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'فكأبيها': [{'vocalized': u'فكأبيها', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'كيفما': [{'vocalized': u'كيفما', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'كيفما', 'encletic': u'', 'type': u'اسم', 'original': u'كيفما'}],

 u'فكحميها': [{'vocalized': u'فكحميها', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'أولفوقهما': [{'vocalized': u'أولفوقهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'أبهما': [{'vocalized': u'أبهما', 'procletic': u'أ-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'أفلوراءكما': [{'vocalized': u'أفلوراءكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'أولازلت': [{'vocalized': u'أولازلت', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'أولازلت', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'أولازلت', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'}],

 u'وبجنبي': [{'vocalized': u'وبجنبي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'وبجنبي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'وعاد': [{'vocalized': u'وعاد', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'عاد', 'encletic': u'', 'type': u'فعل', 'original': u'عاد'}],

 u'أبيها': [{'vocalized': u'أبيها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'أوبعين': [{'vocalized': u'أوبعين', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'وشمالهما': [{'vocalized': u'وشمالهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'فلعينهن': [{'vocalized': u'فلعينهن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'وأخوها': [{'vocalized': u'وأخوها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخو'}],

 u'فلعينهم': [{'vocalized': u'فلعينهم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'فكأيهما': [{'vocalized': u'فكأيهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'ولمع': [{'vocalized': u'ولمع', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'ولما': [{'vocalized': u'ولما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'لما', 'encletic': u'', 'type': u'اسم', 'original': u'لما'},
 {'vocalized': u'ولما', 'procletic': u'و-', 'tags': u'حرف;حرف جزم;عطف', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'},
 {'vocalized': u'ولما', 'procletic': u'و-', 'tags': u'حرف;ظرف;عطف', 'stem': u'لما', 'encletic': u'', 'type': u'حرف', 'original': u'لما'}],

 u'فبخلفنا': [{'vocalized': u'فبخلفنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'أإنهما': [{'vocalized': u'أإنهما', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'فكأبيهن': [{'vocalized': u'فكأبيهن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'فكأبيهم': [{'vocalized': u'فكأبيهم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'ولشبه': [{'vocalized': u'ولشبه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'أفإليكن': [{'vocalized': u'أفإليكن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'ولساعتهم': [{'vocalized': u'ولساعتهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوكنفسهما': [{'vocalized': u'أوكنفسهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'وكزمانكم': [{'vocalized': u'وكزمانكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'أوككل': [{'vocalized': u'أوككل', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككل', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'لإليه': [{'vocalized': u'لإليه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'أولإنهم': [{'vocalized': u'أولإنهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'أولإنهن': [{'vocalized': u'أولإنهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'أفلكأني': [{'vocalized': u'أفلكأني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'أفلكأني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'لمثلهم': [{'vocalized': u'لمثلهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفبه': [{'vocalized': u'أفبه', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'به', 'encletic': u'', 'type': u'ضمير', 'original': u'به'}],

 u'فلعلها': [{'vocalized': u'فلعلها', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لعل'}],

 u'وأسفلك': [{'vocalized': u'وأسفلك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفبك': [{'vocalized': u'أفبك', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بك', 'encletic': u'', 'type': u'ضمير', 'original': u'بك'}],

 u'أفلكأنك': [{'vocalized': u'أفلكأنك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'لذلكم': [{'vocalized': u'لذلكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'لذلكن': [{'vocalized': u'لذلكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أعامتك': [{'vocalized': u'أعامتك', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'أبذاك': [{'vocalized': u'أبذاك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'أفبي': [{'vocalized': u'أفبي', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بي', 'encletic': u'', 'type': u'ضمير', 'original': u'بي'}],

 u'أعامته': [{'vocalized': u'أعامته', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'أخيهما': [{'vocalized': u'أخيهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'وكليل': [{'vocalized': u'وكليل', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'بأخيها': [{'vocalized': u'بأخيها', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'وراءهن': [{'vocalized': u'وراءهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'وراءهم': [{'vocalized': u'وراءهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'فلأمامهن': [{'vocalized': u'فلأمامهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'فلأمامهم': [{'vocalized': u'فلأمامهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'وكأيها': [{'vocalized': u'وكأيها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'أولوراءنا': [{'vocalized': u'أولوراءنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'ففوقها': [{'vocalized': u'ففوقها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'فلسوينا': [{'vocalized': u'فلسوينا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'أففيه': [{'vocalized': u'أففيه', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'فغروبي': [{'vocalized': u'فغروبي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'فغروبي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'أففيك': [{'vocalized': u'أففيك', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'فغروبك': [{'vocalized': u'فغروبك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'أففيي': [{'vocalized': u'أففيي', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'أففيي', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'فأيا': [{'vocalized': u'فأيا', 'procletic': u'ف-', 'tags': u'حرف;حرف نداء;عطف', 'stem': u'أيا', 'encletic': u'', 'type': u'حرف', 'original': u'أيا'}],

 u'وبليله': [{'vocalized': u'وبليله', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'وبشرقكن': [{'vocalized': u'وبشرقكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'وبشرقكم': [{'vocalized': u'وبشرقكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'وخلاهما': [{'vocalized': u'وخلاهما', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'خلا'}],

 u'فاستحال': [{'vocalized': u'فاستحال', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'استحال', 'encletic': u'', 'type': u'فعل', 'original': u'استحال'}],

 u'بسوي': [{'vocalized': u'بسوي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'بسوي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'أبسويك': [{'vocalized': u'أبسويك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'لأبيهما': [{'vocalized': u'لأبيهما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'أبسويه': [{'vocalized': u'أبسويه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'وبليلك': [{'vocalized': u'وبليلك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'ولشطري': [{'vocalized': u'ولشطري', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'ولشطري', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'فبعامتكن': [{'vocalized': u'فبعامتكن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'فبعامتكم': [{'vocalized': u'فبعامتكم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'فكفيهما': [{'vocalized': u'فكفيهما', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'}],

 u'وكغير': [{'vocalized': u'وكغير', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وساء': [{'vocalized': u'وساء', 'procletic': u'و-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'ساء', 'encletic': u'', 'type': u'فعل', 'original': u'ساء'}],

 u'فكأسفلنا': [{'vocalized': u'فكأسفلنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولشطرك': [{'vocalized': u'ولشطرك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'معهما': [{'vocalized': u'معهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'ولشطره': [{'vocalized': u'ولشطره', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'أهاتان': [{'vocalized': u'أهاتان', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هاتان', 'encletic': u'', 'type': u'اسم', 'original': u'هاتان'}],

 u'كأيتك': [{'vocalized': u'كأيتك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'بأخيهم': [{'vocalized': u'بأخيهم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'بأخيهن': [{'vocalized': u'بأخيهن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'ونحن': [{'vocalized': u'ونحن', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'وأوه': [{'vocalized': u'وأوه', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أوه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أوه'}],

 u'ونحو': [{'vocalized': u'ونحو', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحو', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'مكانك': [{'vocalized': u'مكانك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'مكانك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانك'},
 {'vocalized': u'مكانك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'مكانك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانك'}],

 u'كأيتي': [{'vocalized': u'كأيتي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'كأيتي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'فكغرب': [{'vocalized': u'فكغرب', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'ألازال': [{'vocalized': u'ألازال', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازال', 'encletic': u'', 'type': u'فعل', 'original': u'لازال'}],

 u'ولذويه': [{'vocalized': u'ولذويه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلأمامها': [{'vocalized': u'فلأمامها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'ولذويك': [{'vocalized': u'ولذويك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلذويكم': [{'vocalized': u'فلذويكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكأيهن': [{'vocalized': u'وكأيهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'وكأيهم': [{'vocalized': u'وكأيهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'فلذويكن': [{'vocalized': u'فلذويكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'ففوقهن': [{'vocalized': u'ففوقهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'ولذويي': [{'vocalized': u'ولذويي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'ولذويي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'ماانفككنا': [{'vocalized': u'ماانفككنا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككنا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككنا'}],

 u'أولنحونا': [{'vocalized': u'أولنحونا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'فأثناءكما': [{'vocalized': u'فأثناءكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكحميها': [{'vocalized': u'وكحميها', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'ولجميعكن': [{'vocalized': u'ولجميعكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'ولجميعكم': [{'vocalized': u'ولجميعكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فشهره': [{'vocalized': u'فشهره', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'فشهري': [{'vocalized': u'فشهري', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'فشهري', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فبلحظتنا': [{'vocalized': u'فبلحظتنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'فكنفسكم': [{'vocalized': u'فكنفسكم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'فكنفسكن': [{'vocalized': u'فكنفسكن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'فلجميعكما': [{'vocalized': u'فلجميعكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'فحمونا': [{'vocalized': u'فحمونا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمو'}],

 u'فتحتها': [{'vocalized': u'فتحتها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'أفكمن': [{'vocalized': u'أفكمن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'فكوقتي': [{'vocalized': u'فكوقتي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'فكوقتي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'وأجمعنا': [{'vocalized': u'وأجمعنا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'ثمة': [{'vocalized': u'ثمة', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ثمة', 'encletic': u'', 'type': u'اسم', 'original': u'ثمة'}],

 u'فبأنكن': [{'vocalized': u'فبأنكن', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'فبأنكم': [{'vocalized': u'فبأنكم', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'كجميعكما': [{'vocalized': u'كجميعكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعكما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'فكوقته': [{'vocalized': u'فكوقته', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'ولوقتكما': [{'vocalized': u'ولوقتكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'مع': [{'vocalized': u'مع', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'وبعدئذ': [{'vocalized': u'وبعدئذ', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بعدئذ', 'encletic': u'', 'type': u'اسم', 'original': u'بعدئذ'}],

 u'عنكما': [{'vocalized': u'عنكما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'أوبضعهما': [{'vocalized': u'أوبضعهما', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بضع'}],

 u'أوبنحونا': [{'vocalized': u'أوبنحونا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أبنحوكما': [{'vocalized': u'أبنحوكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'أفبغيرهما': [{'vocalized': u'أفبغيرهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فلغروبكن': [{'vocalized': u'فلغروبكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'ليلك': [{'vocalized': u'ليلك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'ورويدك': [{'vocalized': u'ورويدك', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'رويدك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'رويدك'}],

 u'ذات': [{'vocalized': u'ذات', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'مه': [{'vocalized': u'مه', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'مه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مه'}],

 u'أفبغير': [{'vocalized': u'أفبغير', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'ليلي': [{'vocalized': u'ليلي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'ليلي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'وبجنبك': [{'vocalized': u'وبجنبك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'فلعمرك': [{'vocalized': u'فلعمرك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لعمر'}],

 u'فلبعضنا': [{'vocalized': u'فلبعضنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'فلعمره': [{'vocalized': u'فلعمره', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لعمر'}],

 u'فلعمري': [{'vocalized': u'فلعمري', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لعمر'},
 {'vocalized': u'فلعمري', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لعمر'}],

 u'ولعلك': [{'vocalized': u'ولعلك', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لعل'}],

 u'كجنبهما': [{'vocalized': u'كجنبهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'فكأبيك': [{'vocalized': u'فكأبيك', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'بدون': [{'vocalized': u'بدون', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'بدون', 'encletic': u'', 'type': u'اسم', 'original': u'بدون'}],

 u'لعيني': [{'vocalized': u'لعيني', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعيني', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعيني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعيني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وكحميهن': [{'vocalized': u'وكحميهن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'وكحميهم': [{'vocalized': u'وكحميهم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'أفكمثل': [{'vocalized': u'أفكمثل', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'أفجميعكن': [{'vocalized': u'أفجميعكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعكن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'أفجميعكم': [{'vocalized': u'أفجميعكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعكم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'لعينك': [{'vocalized': u'لعينك', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أفلشبههما': [{'vocalized': u'أفلشبههما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبههما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'أولشماله': [{'vocalized': u'أولشماله', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'ومثل': [{'vocalized': u'ومثل', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'أبعينهن': [{'vocalized': u'أبعينهن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'فتحتهم': [{'vocalized': u'فتحتهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'أوبعينه': [{'vocalized': u'أوبعينه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أكلكن': [{'vocalized': u'أكلكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلكن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أفكعامة': [{'vocalized': u'أفكعامة', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أكلكم': [{'vocalized': u'أكلكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلكم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'ولمثلها': [{'vocalized': u'ولمثلها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'أوبعيني': [{'vocalized': u'أوبعيني', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أوبعيني', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'ولأوشك': [{'vocalized': u'ولأوشك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أوشك', 'encletic': u'', 'type': u'فعل', 'original': u'أوشك'}],

 u'كشرقكم': [{'vocalized': u'كشرقكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'ألفوقكن': [{'vocalized': u'ألفوقكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'ولذويهما': [{'vocalized': u'ولذويهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أكأولاء': [{'vocalized': u'أكأولاء', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'ونعما': [{'vocalized': u'ونعما', 'procletic': u'و-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'نعما', 'encletic': u'', 'type': u'فعل', 'original': u'نعما'}],

 u'كنحوهما': [{'vocalized': u'كنحوهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'ومكانكما': [{'vocalized': u'ومكانكما', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانكما', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكما'}],

 u'وفينا': [{'vocalized': u'وفينا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفينا', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'كمثلهما': [{'vocalized': u'كمثلهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فبعضنا': [{'vocalized': u'فبعضنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'أمثلما': [{'vocalized': u'أمثلما', 'procletic': u'أ-', 'tags': u'اسم;جار ومجرور;استفهام', 'stem': u'مثلما', 'encletic': u'', 'type': u'اسم', 'original': u'مثلما'}],

 u'فلمثلكما': [{'vocalized': u'فلمثلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'فشبههن': [{'vocalized': u'فشبههن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أوكحسبنا': [{'vocalized': u'أوكحسبنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'فكأجمع': [{'vocalized': u'فكأجمع', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'وكأسفلهم': [{'vocalized': u'وكأسفلهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'وحواليكما': [{'vocalized': u'وحواليكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حوالى'}],

 u'أولتحتهم': [{'vocalized': u'أولتحتهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'فكغروب': [{'vocalized': u'فكغروب', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'أوأولئك': [{'vocalized': u'أوأولئك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'وكأخيك': [{'vocalized': u'وكأخيك', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'فبهاذين': [{'vocalized': u'فبهاذين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'فلشهره': [{'vocalized': u'فلشهره', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'فلشهري': [{'vocalized': u'فلشهري', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'فلشهري', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فأبوهن': [{'vocalized': u'فأبوهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبو'}],

 u'فأبوهم': [{'vocalized': u'فأبوهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبو'}],

 u'ولمثلهن': [{'vocalized': u'ولمثلهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'رويدك': [{'vocalized': u'رويدك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'رويدك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'رويدك'}],

 u'ولمثلهم': [{'vocalized': u'ولمثلهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أبغيرهما': [{'vocalized': u'أبغيرهما', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'كي': [{'vocalized': u'كي', 'procletic': u'', 'tags': u'حرف;تعليل', 'stem': u'كي', 'encletic': u'', 'type': u'حرف', 'original': u'كي'}],

 u'أوعليهما': [{'vocalized': u'أوعليهما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'فأنشأ': [{'vocalized': u'فأنشأ', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أنشأ', 'encletic': u'', 'type': u'فعل', 'original': u'أنشأ'}],

 u'أفتحت': [{'vocalized': u'أفتحت', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'أوبضعنا': [{'vocalized': u'أوبضعنا', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بضع'}],

 u'أوكهاتين': [{'vocalized': u'أوكهاتين', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'فكأولئك': [{'vocalized': u'فكأولئك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'لجميعكم': [{'vocalized': u'لجميعكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'لجميعكن': [{'vocalized': u'لجميعكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'لعلك': [{'vocalized': u'لعلك', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لعل'}],

 u'أفلستما': [{'vocalized': u'أفلستما', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لستما', 'encletic': u'', 'type': u'فعل', 'original': u'لستما'}],

 u'وبجنبه': [{'vocalized': u'وبجنبه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'وحاشاكما': [{'vocalized': u'وحاشاكما', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'حاشا'}],

 u'أفكأجمعكم': [{'vocalized': u'أفكأجمعكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوكمثلي': [{'vocalized': u'أوكمثلي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أوكمثلي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أوكمثله': [{'vocalized': u'أوكمثله', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'فبأيتكم': [{'vocalized': u'فبأيتكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'فبأيتكن': [{'vocalized': u'فبأيتكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'أوكمثلك': [{'vocalized': u'أوكمثلك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'وضمنكم': [{'vocalized': u'وضمنكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ضمن'}],

 u'لأخيها': [{'vocalized': u'لأخيها', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'أكشبهي': [{'vocalized': u'أكشبهي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أكشبهي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'أأنتن': [{'vocalized': u'أأنتن', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'جميع': [{'vocalized': u'جميع', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميع', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'ولتحتكم': [{'vocalized': u'ولتحتكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'أكشبهك': [{'vocalized': u'أكشبهك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'ولتحتكن': [{'vocalized': u'ولتحتكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'فككلكن': [{'vocalized': u'فككلكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلكن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أكشبهه': [{'vocalized': u'أكشبهه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'فككلكم': [{'vocalized': u'فككلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'فحسبكما': [{'vocalized': u'فحسبكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'مثلي': [{'vocalized': u'مثلي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'مثلي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أولخلفهن': [{'vocalized': u'أولخلفهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أولخلفهم': [{'vocalized': u'أولخلفهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'ومثلي': [{'vocalized': u'ومثلي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ومثلي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أفبهذه': [{'vocalized': u'أفبهذه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'مثلك': [{'vocalized': u'مثلك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'ليتكم': [{'vocalized': u'ليتكم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-كم', 'type': u'حرف', 'original': u'ليت'}],

 u'وبعضنا': [{'vocalized': u'وبعضنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'وفاك': [{'vocalized': u'وفاك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فا'}],

 u'لكأنهما': [{'vocalized': u'لكأنهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'وفاه': [{'vocalized': u'وفاه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فا'}],

 u'ألوراءكم': [{'vocalized': u'ألوراءكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'وفاي': [{'vocalized': u'وفاي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فا'},
 {'vocalized': u'وفاي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فا'}],

 u'أفلفينا': [{'vocalized': u'أفلفينا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'لأمسى': [{'vocalized': u'لأمسى', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أمسى', 'encletic': u'', 'type': u'فعل', 'original': u'أمسى'}],

 u'أفلغيركما': [{'vocalized': u'أفلغيركما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيركما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'كأبيكم': [{'vocalized': u'كأبيكم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'للحظتهما': [{'vocalized': u'للحظتهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أولخلفها': [{'vocalized': u'أولخلفها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'وبليلكن': [{'vocalized': u'وبليلكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'كأكثرنا': [{'vocalized': u'كأكثرنا', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفبهذا': [{'vocalized': u'أفبهذا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'وسويكما': [{'vocalized': u'وسويكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'عين': [{'vocalized': u'عين', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'فلشبهكما': [{'vocalized': u'فلشبهكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'فهاتان': [{'vocalized': u'فهاتان', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاتان', 'encletic': u'', 'type': u'اسم', 'original': u'هاتان'}],

 u'ولابنكن': [{'vocalized': u'ولابنكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'ولابنكم': [{'vocalized': u'ولابنكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'وإياي': [{'vocalized': u'وإياي', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياي', 'encletic': u'', 'type': u'ضمير', 'original': u'إياي'}],

 u'ألنحوهم': [{'vocalized': u'ألنحوهم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'ألنحوهن': [{'vocalized': u'ألنحوهن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'فشهرهم': [{'vocalized': u'فشهرهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'وحيث': [{'vocalized': u'وحيث', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'وقبلما': [{'vocalized': u'وقبلما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'قبلما', 'encletic': u'', 'type': u'اسم', 'original': u'قبلما'}],

 u'فكشهرها': [{'vocalized': u'فكشهرها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'أفخلفكن': [{'vocalized': u'أفخلفكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'كشبه': [{'vocalized': u'كشبه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'ولفوقكم': [{'vocalized': u'ولفوقكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'بنحوكما': [{'vocalized': u'بنحوكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'وكشهرهما': [{'vocalized': u'وكشهرهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'أفبحسبهم': [{'vocalized': u'أفبحسبهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفبحسبهن': [{'vocalized': u'أفبحسبهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبمثلها': [{'vocalized': u'أوبمثلها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'ولأقل': [{'vocalized': u'ولأقل', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'ش': [{'vocalized': u'ش', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ش', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ش'}],

 u'فللحظة': [{'vocalized': u'فللحظة', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'مثلكما': [{'vocalized': u'مثلكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'بهم': [{'vocalized': u'بهم', 'procletic': u'ب-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'ولأكثركن': [{'vocalized': u'ولأكثركن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولأكثركم': [{'vocalized': u'ولأكثركم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'وحاشاكم': [{'vocalized': u'وحاشاكم', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'حاشا'}],

 u'أفبحسبها': [{'vocalized': u'أفبحسبها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'وحاشاكن': [{'vocalized': u'وحاشاكن', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'حاشا'}],

 u'أوبمثلهم': [{'vocalized': u'أوبمثلهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أوبمثلهن': [{'vocalized': u'أوبمثلهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'أوكبعض': [{'vocalized': u'أوكبعض', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'وأنتما': [{'vocalized': u'وأنتما', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'ألمعنا': [{'vocalized': u'ألمعنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'أفلكله': [{'vocalized': u'أفلكله', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكله', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكله', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكله', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'ألنحوها': [{'vocalized': u'ألنحوها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلكلك': [{'vocalized': u'أفلكلك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'أوبتلك': [{'vocalized': u'أوبتلك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'فبشبهكم': [{'vocalized': u'فبشبهكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'فبشبهكن': [{'vocalized': u'فبشبهكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلكلي': [{'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'فلإنكما': [{'vocalized': u'فلإنكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'فكشهرهن': [{'vocalized': u'فكشهرهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'فكشهرهم': [{'vocalized': u'فكشهرهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'وحين': [{'vocalized': u'وحين', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'حين', 'encletic': u'', 'type': u'اسم', 'original': u'حين'}],

 u'فلحميي': [{'vocalized': u'فلحميي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'فلحميي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'ألشمالكما': [{'vocalized': u'ألشمالكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'فلأخيي': [{'vocalized': u'فلأخيي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'فلأخيي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'فلعليهم': [{'vocalized': u'فلعليهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'فلعليهن': [{'vocalized': u'فلعليهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'فلأخيه': [{'vocalized': u'فلأخيه', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'فلذا': [{'vocalized': u'فلذا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'فلذا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'فكلهما': [{'vocalized': u'فكلهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلهما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'فلأخيك': [{'vocalized': u'فلأخيك', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'ألهاتي': [{'vocalized': u'ألهاتي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'ولحسبنا': [{'vocalized': u'ولحسبنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'لشرقهن': [{'vocalized': u'لشرقهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'لشرقهم': [{'vocalized': u'لشرقهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'أوكأنما': [{'vocalized': u'أوكأنما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف تشبيه;عطف;استفهام', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'أفمعكما': [{'vocalized': u'أفمعكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'وبنفسها': [{'vocalized': u'وبنفسها', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'ألهاته': [{'vocalized': u'ألهاته', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'فلشطرهن': [{'vocalized': u'فلشطرهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'فلشطرهم': [{'vocalized': u'فلشطرهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'ولغروبهما': [{'vocalized': u'ولغروبهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'ككلكن': [{'vocalized': u'ككلكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلكن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'فإليكن': [{'vocalized': u'فإليكن', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليكن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكن'},
 {'vocalized': u'فإليكن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'فمازلتن': [{'vocalized': u'فمازلتن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتن'}],

 u'وكجنوبها': [{'vocalized': u'وكجنوبها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'فإليكم': [{'vocalized': u'فإليكم', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليكم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكم'},
 {'vocalized': u'فإليكم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'فبليلهم': [{'vocalized': u'فبليلهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'فبليلهن': [{'vocalized': u'فبليلهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'فلفوقنا': [{'vocalized': u'فلفوقنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'أولعينكم': [{'vocalized': u'أولعينكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أولعينكن': [{'vocalized': u'أولعينكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'أوكغيرنا': [{'vocalized': u'أوكغيرنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فلشطرها': [{'vocalized': u'فلشطرها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'كإن': [{'vocalized': u'كإن', 'procletic': u'ك-', 'tags': u'حرف;المشبهة بليس;مجرور', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'فبته': [{'vocalized': u'فبته', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'أوكحسبكما': [{'vocalized': u'أوكحسبكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'ولجنوبهما': [{'vocalized': u'ولجنوبهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكجنوبهم': [{'vocalized': u'وكجنوبهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكجنوبهن': [{'vocalized': u'وكجنوبهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'وحميهما': [{'vocalized': u'وحميهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'فبتي': [{'vocalized': u'فبتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'فبليلها': [{'vocalized': u'فبليلها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'وأيتها': [{'vocalized': u'وأيتها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'أكأجمعنا': [{'vocalized': u'أكأجمعنا', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبالتي': [{'vocalized': u'وبالتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'ألذلكن': [{'vocalized': u'ألذلكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'فلذي': [{'vocalized': u'فلذي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'ألذلكم': [{'vocalized': u'ألذلكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'فلعليها': [{'vocalized': u'فلعليها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'فلذه': [{'vocalized': u'فلذه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'وتلقاءه': [{'vocalized': u'وتلقاءه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبجميعكن': [{'vocalized': u'وبجميعكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعكن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'وبجميعكم': [{'vocalized': u'وبجميعكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعكم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'وتلقاءك': [{'vocalized': u'وتلقاءك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبأقلكن': [{'vocalized': u'وبأقلكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'وبأقلكم': [{'vocalized': u'وبأقلكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'وبنفسهم': [{'vocalized': u'وبنفسهم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'وبنفسهن': [{'vocalized': u'وبنفسهن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'ولأقلهن': [{'vocalized': u'ولأقلهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'ولأقلهم': [{'vocalized': u'ولأقلهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'ولنحوها': [{'vocalized': u'ولنحوها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'أهنا': [{'vocalized': u'أهنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هنا', 'encletic': u'', 'type': u'اسم', 'original': u'هنا'}],

 u'وخلانا': [{'vocalized': u'وخلانا', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'خلا'}],

 u'فحموه': [{'vocalized': u'فحموه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمو'}],

 u'فجنوبهما': [{'vocalized': u'فجنوبهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'لجميع': [{'vocalized': u'لجميع', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميع', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميع', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميع', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'ولكنكم': [{'vocalized': u'ولكنكم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنكم', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لكن'}],

 u'ولكنكن': [{'vocalized': u'ولكنكن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنكن', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لكن'}],

 u'وبكلهما': [{'vocalized': u'وبكلهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلهما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'وبأولاء': [{'vocalized': u'وبأولاء', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'أأمام': [{'vocalized': u'أأمام', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'وبفيي': [{'vocalized': u'وبفيي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وبفيي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'}],

 u'لإليهم': [{'vocalized': u'لإليهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'لإليهن': [{'vocalized': u'لإليهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'وبفيه': [{'vocalized': u'وبفيه', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'}],

 u'فكليلك': [{'vocalized': u'فكليلك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'وبفيك': [{'vocalized': u'وبفيك', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'}],

 u'أولأجمعهما': [{'vocalized': u'أولأجمعهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فماانفككتما': [{'vocalized': u'فماانفككتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتما', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتما'},
 {'vocalized': u'فماانفككتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتما', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتما'}],

 u'لتحت': [{'vocalized': u'لتحت', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'ولأبيكما': [{'vocalized': u'ولأبيكما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'وأسفلها': [{'vocalized': u'وأسفلها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولهذا': [{'vocalized': u'ولهذا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'أفمثلكما': [{'vocalized': u'أفمثلكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'ذلك': [{'vocalized': u'ذلك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'فليميننا': [{'vocalized': u'فليميننا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'بساعته': [{'vocalized': u'بساعته', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'بساعتك': [{'vocalized': u'بساعتك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'لإليها': [{'vocalized': u'لإليها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'بساعتي': [{'vocalized': u'بساعتي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'بساعتي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'وكغروبهم': [{'vocalized': u'وكغروبهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'وكعامتكما': [{'vocalized': u'وكعامتكما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'فكأجمعكن': [{'vocalized': u'فكأجمعكن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولهذي': [{'vocalized': u'ولهذي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'ولهذه': [{'vocalized': u'ولهذه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'أففيكما': [{'vocalized': u'أففيكما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'ولنحوهن': [{'vocalized': u'ولنحوهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'ولنحوهم': [{'vocalized': u'ولنحوهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'غربي': [{'vocalized': u'غربي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'غربي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'وعنهم': [{'vocalized': u'وعنهم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'أفكعامتنا': [{'vocalized': u'أفكعامتنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'وبضعنا': [{'vocalized': u'وبضعنا', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بضع'}],

 u'فلذينك': [{'vocalized': u'فلذينك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'أوهاتين': [{'vocalized': u'أوهاتين', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'لتحتكم': [{'vocalized': u'لتحتكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلهي': [{'vocalized': u'أفلهي', 'procletic': u'أ-ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'},
 {'vocalized': u'أفلهي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'ويميننا': [{'vocalized': u'ويميننا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'وشرقكما': [{'vocalized': u'وشرقكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'فكليلهم': [{'vocalized': u'فكليلهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'فبليل': [{'vocalized': u'فبليل', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'فأمامكن': [{'vocalized': u'فأمامكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'وأقلك': [{'vocalized': u'وأقلك', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'فشهرك': [{'vocalized': u'فشهرك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'وأقله': [{'vocalized': u'وأقله', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'وأقلي': [{'vocalized': u'وأقلي', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'وأقلي', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'أفلهن': [{'vocalized': u'أفلهن', 'procletic': u'أ-ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'},
 {'vocalized': u'أفلهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'ودون': [{'vocalized': u'ودون', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'دون', 'encletic': u'', 'type': u'اسم', 'original': u'دون'}],

 u'فلأناه': [{'vocalized': u'فلأناه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'أباها': [{'vocalized': u'أباها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبا'}],

 u'فلأناك': [{'vocalized': u'فلأناك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'وصباح': [{'vocalized': u'وصباح', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'صباح', 'encletic': u'', 'type': u'اسم', 'original': u'صباح'}],

 u'فليسوا': [{'vocalized': u'فليسوا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليسوا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسوا'}],

 u'فكأسفلكما': [{'vocalized': u'فكأسفلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفكأجمعه': [{'vocalized': u'أفكأجمعه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'ساعتنا': [{'vocalized': u'ساعتنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'ليلها': [{'vocalized': u'ليلها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'أفلنحن': [{'vocalized': u'أفلنحن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'أوشبهنا': [{'vocalized': u'أوشبهنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'وكشبهها': [{'vocalized': u'وكشبهها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'كأبيك': [{'vocalized': u'كأبيك', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'فبأيتكما': [{'vocalized': u'فبأيتكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'وكوقتهن': [{'vocalized': u'وكوقتهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'وكوقتهم': [{'vocalized': u'وكوقتهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'أفلنحو': [{'vocalized': u'أفلنحو', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'أباهم': [{'vocalized': u'أباهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبا'}],

 u'أباهن': [{'vocalized': u'أباهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبا'}],

 u'فبشهرنا': [{'vocalized': u'فبشهرنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'وغروبكن': [{'vocalized': u'وغروبكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'شمالك': [{'vocalized': u'شمالك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'ليلهن': [{'vocalized': u'ليلهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'ليلهم': [{'vocalized': u'ليلهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'وكشبههم': [{'vocalized': u'وكشبههم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'وكشبههن': [{'vocalized': u'وكشبههن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'وسوي': [{'vocalized': u'وسوي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'وسوي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'وسوى': [{'vocalized': u'وسوى', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'وسوى', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلغير': [{'vocalized': u'أفلغير', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغير', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وذاك': [{'vocalized': u'وذاك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'وكوقتها': [{'vocalized': u'وكوقتها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'تجاهكن': [{'vocalized': u'تجاهكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تجاه'}],

 u'تجاهكم': [{'vocalized': u'تجاهكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تجاه'}],

 u'وذان': [{'vocalized': u'وذان', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذان', 'encletic': u'', 'type': u'اسم', 'original': u'ذان'}],

 u'فكليلها': [{'vocalized': u'فكليلها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'أفلمنكن': [{'vocalized': u'أفلمنكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'أفلمنكم': [{'vocalized': u'أفلمنكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'فلغروبكما': [{'vocalized': u'فلغروبكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'أوغيركما': [{'vocalized': u'أوغيركما', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'ذووه': [{'vocalized': u'ذووه', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوو'}],

 u'أوبتلكم': [{'vocalized': u'أوبتلكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'ذووك': [{'vocalized': u'ذووك', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوو'}],

 u'فحواليكما': [{'vocalized': u'فحواليكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حوالى'}],

 u'فكأخيهم': [{'vocalized': u'فكأخيهم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'ذووي': [{'vocalized': u'ذووي', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوو'},
 {'vocalized': u'ذووي', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوو'}],

 u'فكأخيهن': [{'vocalized': u'فكأخيهن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'وبهذي': [{'vocalized': u'وبهذي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'وبتانك': [{'vocalized': u'وبتانك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'أبضعكن': [{'vocalized': u'أبضعكن', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بضع'}],

 u'أفبعامتكما': [{'vocalized': u'أفبعامتكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'وبهذه': [{'vocalized': u'وبهذه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'لأقلكما': [{'vocalized': u'لأقلكما', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'أمامها': [{'vocalized': u'أمامها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'لعمري': [{'vocalized': u'لعمري', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لعمر'},
 {'vocalized': u'لعمري', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لعمر'}],

 u'فكحسبنا': [{'vocalized': u'فكحسبنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'وفا': [{'vocalized': u'وفا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'فا', 'encletic': u'', 'type': u'اسم', 'original': u'فا'}],

 u'للحظتنا': [{'vocalized': u'للحظتنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'ومابرحنا': [{'vocalized': u'ومابرحنا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحنا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحنا'}],

 u'فبأثناءكما': [{'vocalized': u'فبأثناءكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'فكجنوبهما': [{'vocalized': u'فكجنوبهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'وفو': [{'vocalized': u'وفو', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'فو', 'encletic': u'', 'type': u'اسم', 'original': u'فو'}],

 u'وفي': [{'vocalized': u'وفي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفي', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'وأخاكم': [{'vocalized': u'وأخاكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخا'}],

 u'وأخاكن': [{'vocalized': u'وأخاكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخا'}],

 u'أمامهن': [{'vocalized': u'أمامهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'أمامهم': [{'vocalized': u'أمامهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'أناكما': [{'vocalized': u'أناكما', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'أثناء': [{'vocalized': u'أثناء', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبساعتنا': [{'vocalized': u'وبساعتنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'بلحظتي': [{'vocalized': u'بلحظتي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'بلحظتي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'وحميكم': [{'vocalized': u'وحميكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'بلحظته': [{'vocalized': u'بلحظته', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'فكغروبكن': [{'vocalized': u'فكغروبكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'حموها': [{'vocalized': u'حموها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمو'}],

 u'ولانقلب': [{'vocalized': u'ولانقلب', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'انقلب', 'encletic': u'', 'type': u'فعل', 'original': u'انقلب'}],

 u'وبليلكم': [{'vocalized': u'وبليلكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'فعندهما': [{'vocalized': u'فعندهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عند'}],

 u'أكعامتنا': [{'vocalized': u'أكعامتنا', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'فكأخيها': [{'vocalized': u'فكأخيها', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'أنحوهن': [{'vocalized': u'أنحوهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'أفعينهما': [{'vocalized': u'أفعينهما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'أنحوهم': [{'vocalized': u'أنحوهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'وبهذا': [{'vocalized': u'وبهذا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'كأولئكم': [{'vocalized': u'كأولئكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'لجميعه': [{'vocalized': u'لجميعه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعه', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'فأما': [{'vocalized': u'فأما', 'procletic': u'ف-', 'tags': u'حرف;حرف شرط وتفصيل وتوكيد;عطف', 'stem': u'أما', 'encletic': u'', 'type': u'حرف', 'original': u'أما'},
 {'vocalized': u'فأما', 'procletic': u'ف-', 'tags': u'حرف;حرف عرض;عطف', 'stem': u'أما', 'encletic': u'', 'type': u'حرف', 'original': u'أما'}],

 u'لجميعك': [{'vocalized': u'لجميعك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعك', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'لجميعي': [{'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'معاذنا': [{'vocalized': u'معاذنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-نا', 'type': u'اسم', 'original': u'معاذ'}],

 u'بذي': [{'vocalized': u'بذي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'ونفسهما': [{'vocalized': u'ونفسهما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'أوهاتان': [{'vocalized': u'أوهاتان', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاتان', 'encletic': u'', 'type': u'اسم', 'original': u'هاتان'}],

 u'بذه': [{'vocalized': u'بذه', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'وحار': [{'vocalized': u'وحار', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'حار', 'encletic': u'', 'type': u'فعل', 'original': u'حار'}],

 u'بأجمعهن': [{'vocalized': u'بأجمعهن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبشطره': [{'vocalized': u'وبشطره', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'وبشطرك': [{'vocalized': u'وبشطرك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'كأبيهما': [{'vocalized': u'كأبيهما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'وكلحظتها': [{'vocalized': u'وكلحظتها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبشطري': [{'vocalized': u'وبشطري', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'وبشطري', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'وكجنوبهما': [{'vocalized': u'وكجنوبهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'بحيث': [{'vocalized': u'بحيث', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'ولفي': [{'vocalized': u'ولفي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'وأخوكن': [{'vocalized': u'وأخوكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخو'}],

 u'وأخوكم': [{'vocalized': u'وأخوكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخو'}],

 u'فبساعتك': [{'vocalized': u'فبساعتك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبشهركم': [{'vocalized': u'وبشهركم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'ولإليهم': [{'vocalized': u'ولإليهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'ولإليهن': [{'vocalized': u'ولإليهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'وبمثلكن': [{'vocalized': u'وبمثلكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'وساعته': [{'vocalized': u'وساعته', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبمثلكم': [{'vocalized': u'وبمثلكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فكجنوب': [{'vocalized': u'فكجنوب', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوشبه': [{'vocalized': u'أوشبه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'وبحسب': [{'vocalized': u'وبحسب', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أيته': [{'vocalized': u'أيته', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'أويمينكن': [{'vocalized': u'أويمينكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'أويمينكم': [{'vocalized': u'أويمينكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'فلعينكن': [{'vocalized': u'فلعينكن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'ولشمالها': [{'vocalized': u'ولشمالها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'فلعينكم': [{'vocalized': u'فلعينكم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أومثلما': [{'vocalized': u'أومثلما', 'procletic': u'أ-و-', 'tags': u'اسم;جار ومجرور;عطف;استفهام', 'stem': u'مثلما', 'encletic': u'', 'type': u'اسم', 'original': u'مثلما'}],

 u'أفليمينها': [{'vocalized': u'أفليمينها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'ولخلف': [{'vocalized': u'ولخلف', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلف', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'فأولاء': [{'vocalized': u'فأولاء', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'فكالتي': [{'vocalized': u'فكالتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'فبليلنا': [{'vocalized': u'فبليلنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'ولخلفهم': [{'vocalized': u'ولخلفهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'وكأيك': [{'vocalized': u'وكأيك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'أوبشبهنا': [{'vocalized': u'أوبشبهنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'لأصبح': [{'vocalized': u'لأصبح', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أصبح', 'encletic': u'', 'type': u'فعل', 'original': u'أصبح'}],

 u'أولشمالكما': [{'vocalized': u'أولشمالكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'أوكهم': [{'vocalized': u'أوكهم', 'procletic': u'أ-و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أوكهن': [{'vocalized': u'أوكهن', 'procletic': u'أ-و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أوكهو': [{'vocalized': u'أوكهو', 'procletic': u'أ-و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'بأيتهم': [{'vocalized': u'بأيتهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'أوكهي': [{'vocalized': u'أوكهي', 'procletic': u'أ-و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'بذا': [{'vocalized': u'بذا', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'بذا', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'لمثلكن': [{'vocalized': u'لمثلكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'لمثلكم': [{'vocalized': u'لمثلكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثلكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'ولدنك': [{'vocalized': u'ولدنك', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدن'}],

 u'أفكمثلنا': [{'vocalized': u'أفكمثلنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'فكزمانكم': [{'vocalized': u'فكزمانكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'وابنكما': [{'vocalized': u'وابنكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'أولاء': [{'vocalized': u'أولاء', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'ولنفس': [{'vocalized': u'ولنفس', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفس', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فبعينها': [{'vocalized': u'فبعينها', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'أوهكذا': [{'vocalized': u'أوهكذا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هكذا', 'encletic': u'', 'type': u'اسم', 'original': u'هكذا'}],

 u'لنفسكم': [{'vocalized': u'لنفسكم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'لنفسكن': [{'vocalized': u'لنفسكن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلديكم': [{'vocalized': u'أفلديكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدى'}],

 u'ألنا': [{'vocalized': u'ألنا', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'لنا', 'encletic': u'', 'type': u'ضمير', 'original': u'لنا'}],

 u'فبنحو': [{'vocalized': u'فبنحو', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحو', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'بذويكما': [{'vocalized': u'بذويكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'وحوالينا': [{'vocalized': u'وحوالينا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حوالى'}],

 u'ولمعها': [{'vocalized': u'ولمعها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'لعامة': [{'vocalized': u'لعامة', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامة', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'مازالا': [{'vocalized': u'مازالا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازالا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالا'}],

 u'فبلحظتهما': [{'vocalized': u'فبلحظتهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفكنفسه': [{'vocalized': u'أفكنفسه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'فعليها': [{'vocalized': u'فعليها', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'وكنفسي': [{'vocalized': u'وكنفسي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'وكنفسي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلشمالي': [{'vocalized': u'أفلشمالي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'أفلشمالي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'وكنفسك': [{'vocalized': u'وكنفسك', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'أفبجميعي': [{'vocalized': u'أفبجميعي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'فغيركن': [{'vocalized': u'فغيركن', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'وكنفسه': [{'vocalized': u'وكنفسه', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'فللحظتكما': [{'vocalized': u'فللحظتكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبهذين': [{'vocalized': u'وبهذين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'أبعضي': [{'vocalized': u'أبعضي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أبعضي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'ولمعهم': [{'vocalized': u'ولمعهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'ومعاذنا': [{'vocalized': u'ومعاذنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-نا', 'type': u'اسم', 'original': u'معاذ'}],

 u'أبعضه': [{'vocalized': u'أبعضه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'ولمعهن': [{'vocalized': u'ولمعهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'أبعضك': [{'vocalized': u'أبعضك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'أولتينك': [{'vocalized': u'أولتينك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'فعليهن': [{'vocalized': u'فعليهن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'فعليهم': [{'vocalized': u'فعليهم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'أولأجمع': [{'vocalized': u'أولأجمع', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمع', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوكهذه': [{'vocalized': u'أوكهذه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'أفبجميعه': [{'vocalized': u'أفبجميعه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'بأقلكن': [{'vocalized': u'بأقلكن', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'معاذكما': [{'vocalized': u'معاذكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'معاذ', 'encletic': u'-كما', 'type': u'اسم', 'original': u'معاذ'}],

 u'بأقلكم': [{'vocalized': u'بأقلكم', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'وكأبيه': [{'vocalized': u'وكأبيه', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'فبأنه': [{'vocalized': u'فبأنه', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'كأني': [{'vocalized': u'كأني', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأني', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'كأني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'فضمنهما': [{'vocalized': u'فضمنهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ضمن'}],

 u'كأنه': [{'vocalized': u'كأنه', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنه', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'فجنوبكم': [{'vocalized': u'فجنوبكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبأني': [{'vocalized': u'فبأني', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فبأني', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'أوراءنا': [{'vocalized': u'أوراءنا', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'أفأناه': [{'vocalized': u'أفأناه', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'فبعينهن': [{'vocalized': u'فبعينهن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'شبهكن': [{'vocalized': u'شبهكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'شبهكم': [{'vocalized': u'شبهكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'فبعينهم': [{'vocalized': u'فبعينهم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'وكأعلى': [{'vocalized': u'وكأعلى', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'وكخلفهن': [{'vocalized': u'وكخلفهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'فاهم': [{'vocalized': u'فاهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فا'}],

 u'فاهن': [{'vocalized': u'فاهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فا'}],

 u'فلأعليهما': [{'vocalized': u'فلأعليهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'بسويهما': [{'vocalized': u'بسويهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'ولغربهما': [{'vocalized': u'ولغربهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'أوإن': [{'vocalized': u'أوإن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'فلأخيكم': [{'vocalized': u'فلأخيكم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'فلأخيكن': [{'vocalized': u'فلأخيكن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'وإلينا': [{'vocalized': u'وإلينا', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'ذان': [{'vocalized': u'ذان', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذان', 'encletic': u'', 'type': u'اسم', 'original': u'ذان'}],

 u'ذاك': [{'vocalized': u'ذاك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'فبساعتكم': [{'vocalized': u'فبساعتكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فإليهما': [{'vocalized': u'فإليهما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'فبساعتكن': [{'vocalized': u'فبساعتكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'بأيهما': [{'vocalized': u'بأيهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'لبعضها': [{'vocalized': u'لبعضها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'بسوى': [{'vocalized': u'بسوى', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'ولأنهم': [{'vocalized': u'ولأنهم', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'أفمعكم': [{'vocalized': u'أفمعكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'أفمعكن': [{'vocalized': u'أفمعكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'وبليلي': [{'vocalized': u'وبليلي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'وبليلي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'أبعينه': [{'vocalized': u'أبعينه', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أأجمعه': [{'vocalized': u'أأجمعه', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلسويكما': [{'vocalized': u'أفلسويكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'فيمينكم': [{'vocalized': u'فيمينكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'فلغروبكم': [{'vocalized': u'فلغروبكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'أنتن': [{'vocalized': u'أنتن', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'فلغيركن': [{'vocalized': u'فلغيركن', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيركن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'فكذويكم': [{'vocalized': u'فكذويكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكذويكن': [{'vocalized': u'فكذويكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلغيركم': [{'vocalized': u'فلغيركم', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيركم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'ولدني': [{'vocalized': u'ولدني', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدن'},
 {'vocalized': u'ولدني', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدن'}],

 u'لبعضهن': [{'vocalized': u'لبعضهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'وتجاهنا': [{'vocalized': u'وتجاهنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تجاه'}],

 u'لبعضهم': [{'vocalized': u'لبعضهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'وبأعليكن': [{'vocalized': u'وبأعليكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'كشرقكن': [{'vocalized': u'كشرقكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'أخلفها': [{'vocalized': u'أخلفها', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'وكعينهما': [{'vocalized': u'وكعينهما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'بعامتهم': [{'vocalized': u'بعامتهم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'فحوالى': [{'vocalized': u'فحوالى', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'حوالى', 'encletic': u'', 'type': u'اسم', 'original': u'حوالى'}],

 u'فبأيتهم': [{'vocalized': u'فبأيتهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'فاها': [{'vocalized': u'فاها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فا'}],

 u'وليتنا': [{'vocalized': u'وليتنا', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-نا', 'type': u'حرف', 'original': u'ليت'}],

 u'وبكليكما': [{'vocalized': u'وبكليكما', 'procletic': u'و-ب-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'ألجميعكما': [{'vocalized': u'ألجميعكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'فكسويه': [{'vocalized': u'فكسويه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'فللحظتهن': [{'vocalized': u'فللحظتهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلجميعهما': [{'vocalized': u'فلجميعهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'فكسويك': [{'vocalized': u'فكسويك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'وأمام': [{'vocalized': u'وأمام', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'لزمانكم': [{'vocalized': u'لزمانكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'مننا': [{'vocalized': u'مننا', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'وبأعليكم': [{'vocalized': u'وبأعليكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبكلك': [{'vocalized': u'فبكلك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلك', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'ألغيرهما': [{'vocalized': u'ألغيرهما', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيرهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فبكله': [{'vocalized': u'فبكله', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكله', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'فليستا': [{'vocalized': u'فليستا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليستا', 'encletic': u'', 'type': u'فعل', 'original': u'ليستا'}],

 u'ولتلقاءنا': [{'vocalized': u'ولتلقاءنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبكلي': [{'vocalized': u'فبكلي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'وباللاتي': [{'vocalized': u'وباللاتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'وذانك': [{'vocalized': u'وذانك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'فلأعلي': [{'vocalized': u'فلأعلي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'فلأعلي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'أفكبعضه': [{'vocalized': u'أفكبعضه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'أفكبعضك': [{'vocalized': u'أفكبعضك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فأينما': [{'vocalized': u'فأينما', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'أينما', 'encletic': u'', 'type': u'اسم', 'original': u'أينما'}],

 u'فبفيها': [{'vocalized': u'فبفيها', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'}],

 u'ألجميعهما': [{'vocalized': u'ألجميعهما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكبعضي': [{'vocalized': u'أفكبعضي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفكبعضي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'أوكنفسنا': [{'vocalized': u'أوكنفسنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'وكشهركن': [{'vocalized': u'وكشهركن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'فبنفسهم': [{'vocalized': u'فبنفسهم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'فبنفسهن': [{'vocalized': u'فبنفسهن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'فإياكن': [{'vocalized': u'فإياكن', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياكن', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكن'}],

 u'أفكأجمعك': [{'vocalized': u'أفكأجمعك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلذاك': [{'vocalized': u'أفلذاك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'وكسوي': [{'vocalized': u'وكسوي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'وكسوي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'وكسوى': [{'vocalized': u'وكسوى', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'ولفيهما': [{'vocalized': u'ولفيهما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفيهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'فبفيهم': [{'vocalized': u'فبفيهم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'}],

 u'أفكأجمعي': [{'vocalized': u'أفكأجمعي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفكأجمعي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'فبفيهن': [{'vocalized': u'فبفيهن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'}],

 u'أعننا': [{'vocalized': u'أعننا', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'بزمانكم': [{'vocalized': u'بزمانكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'فتجاههما': [{'vocalized': u'فتجاههما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تجاه'}],

 u'وكنفسها': [{'vocalized': u'وكنفسها', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'وليلهما': [{'vocalized': u'وليلهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'فبنفسها': [{'vocalized': u'فبنفسها', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أففي': [{'vocalized': u'أففي', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'فليلها': [{'vocalized': u'فليلها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'أفبأجمع': [{'vocalized': u'أفبأجمع', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'بجنوبه': [{'vocalized': u'بجنوبه', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'كوقتهما': [{'vocalized': u'كوقتهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'ولمثلكن': [{'vocalized': u'ولمثلكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'فكأجمعنا': [{'vocalized': u'فكأجمعنا', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولمثلكم': [{'vocalized': u'ولمثلكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'كشبههما': [{'vocalized': u'كشبههما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فكرب': [{'vocalized': u'فكرب', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'كرب', 'encletic': u'', 'type': u'فعل', 'original': u'كرب'}],

 u'فارتد': [{'vocalized': u'فارتد', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ارتد', 'encletic': u'', 'type': u'فعل', 'original': u'ارتد'}],

 u'كحميكما': [{'vocalized': u'كحميكما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'فبأبيهم': [{'vocalized': u'فبأبيهم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'فعندهم': [{'vocalized': u'فعندهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عند'}],

 u'فعندهن': [{'vocalized': u'فعندهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عند'}],

 u'مكانكم': [{'vocalized': u'مكانكم', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'مكانكم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكم'}],

 u'مكانكن': [{'vocalized': u'مكانكن', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'مكانكن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكن'}],

 u'كتينك': [{'vocalized': u'كتينك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'لجميعهم': [{'vocalized': u'لجميعهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'لجميعهن': [{'vocalized': u'لجميعهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فكأكثركما': [{'vocalized': u'فكأكثركما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'وكأعلي': [{'vocalized': u'وكأعلي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'وكأعلي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'أسفل': [{'vocalized': u'أسفل', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوشبههما': [{'vocalized': u'أوشبههما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فللحظتهم': [{'vocalized': u'فللحظتهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فللحظتها': [{'vocalized': u'فللحظتها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبأيتهن': [{'vocalized': u'فبأيتهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'أفبشبهكما': [{'vocalized': u'أفبشبهكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'فبأيتها': [{'vocalized': u'فبأيتها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'ليتها': [{'vocalized': u'ليتها', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-ها', 'type': u'حرف', 'original': u'ليت'}],

 u'فبينك': [{'vocalized': u'فبينك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بين'}],

 u'لعامتكما': [{'vocalized': u'لعامتكما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'كأبيها': [{'vocalized': u'كأبيها', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'لأخيكم': [{'vocalized': u'لأخيكم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'لأخيكن': [{'vocalized': u'لأخيكن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'ولأعليكن': [{'vocalized': u'ولأعليكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'ه': [{'vocalized': u'ه', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ه', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ه'}],

 u'فبكلنا': [{'vocalized': u'فبكلنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلنا', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'ألأنتما': [{'vocalized': u'ألأنتما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'ليتهم': [{'vocalized': u'ليتهم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-هم', 'type': u'حرف', 'original': u'ليت'}],

 u'ليتهن': [{'vocalized': u'ليتهن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-هن', 'type': u'حرف', 'original': u'ليت'}],

 u'لأخيكما': [{'vocalized': u'لأخيكما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'فحواليهم': [{'vocalized': u'فحواليهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حوالى'}],

 u'ألتحتنا': [{'vocalized': u'ألتحتنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'أولهما': [{'vocalized': u'أولهما', 'procletic': u'أ-و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'},
 {'vocalized': u'أولهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'كأبيهن': [{'vocalized': u'كأبيهن', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'ألأولئك': [{'vocalized': u'ألأولئك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'فبغيرهما': [{'vocalized': u'فبغيرهما', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فعندها': [{'vocalized': u'فعندها', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عند'}],

 u'حسبنا': [{'vocalized': u'حسبنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلأمامهما': [{'vocalized': u'أفلأمامهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'أوكهذا': [{'vocalized': u'أوكهذا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'لجميعها': [{'vocalized': u'لجميعها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعها', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'لجميعها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'كحمي': [{'vocalized': u'كحمي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'ولأعليهم': [{'vocalized': u'ولأعليهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'وبغروبكما': [{'vocalized': u'وبغروبكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'بشبهكم': [{'vocalized': u'بشبهكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'بشبهكن': [{'vocalized': u'بشبهكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'ففوقهم': [{'vocalized': u'ففوقهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'ولأقلهما': [{'vocalized': u'ولأقلهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'أخاك': [{'vocalized': u'أخاك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخا'}],

 u'وغروب': [{'vocalized': u'وغروب', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'ألكلكن': [{'vocalized': u'ألكلكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'ألكلكم': [{'vocalized': u'ألكلكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'كلحظتكما': [{'vocalized': u'كلحظتكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'وذين': [{'vocalized': u'وذين', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'ولأسفلكما': [{'vocalized': u'ولأسفلكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبحمينا': [{'vocalized': u'وبحمينا', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'فكلحظتكما': [{'vocalized': u'فكلحظتكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلسوى': [{'vocalized': u'أفلسوى', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلسوي': [{'vocalized': u'أفلسوي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أفلسوي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'فهاهنا': [{'vocalized': u'فهاهنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاهنا', 'encletic': u'', 'type': u'اسم', 'original': u'هاهنا'}],

 u'فكشبه': [{'vocalized': u'فكشبه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'بجنوب': [{'vocalized': u'بجنوب', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'ببعضها': [{'vocalized': u'ببعضها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'أبعينهما': [{'vocalized': u'أبعينهما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'أكتلك': [{'vocalized': u'أكتلك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'فمابرحتن': [{'vocalized': u'فمابرحتن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحتن', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتن'}],

 u'أفليستا': [{'vocalized': u'أفليستا', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليستا', 'encletic': u'', 'type': u'فعل', 'original': u'ليستا'}],

 u'كأجمعهن': [{'vocalized': u'كأجمعهن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'كأبيهم': [{'vocalized': u'كأبيهم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'كأجمعهم': [{'vocalized': u'كأجمعهم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبنحوهما': [{'vocalized': u'وبنحوهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'فخلفنا': [{'vocalized': u'فخلفنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فخلفنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'أوأمامنا': [{'vocalized': u'أوأمامنا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'لغروب': [{'vocalized': u'لغروب', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'فلوقتكن': [{'vocalized': u'فلوقتكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'ببعضهن': [{'vocalized': u'ببعضهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'ببعضهم': [{'vocalized': u'ببعضهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'وعندكما': [{'vocalized': u'وعندكما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عند'}],

 u'فليلكما': [{'vocalized': u'فليلكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'فأسفلكن': [{'vocalized': u'فأسفلكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكذوينا': [{'vocalized': u'وكذوينا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'فأسفلكم': [{'vocalized': u'فأسفلكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'كأولاء': [{'vocalized': u'كأولاء', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'فكعامتها': [{'vocalized': u'فكعامتها', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'بأينا': [{'vocalized': u'بأينا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'كشرقي': [{'vocalized': u'كشرقي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'كشرقي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'ولعمر': [{'vocalized': u'ولعمر', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'لعمر', 'encletic': u'', 'type': u'اسم', 'original': u'لعمر'}],

 u'وذينك': [{'vocalized': u'وذينك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'وذيت': [{'vocalized': u'وذيت', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف', 'stem': u'ذيت', 'encletic': u'', 'type': u'اسم', 'original': u'ذيت'}],

 u'ألعنكما': [{'vocalized': u'ألعنكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'فلعنهم': [{'vocalized': u'فلعنهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'وكهاتي': [{'vocalized': u'وكهاتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'بذويكم': [{'vocalized': u'بذويكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'فشرقها': [{'vocalized': u'فشرقها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'بذويكن': [{'vocalized': u'بذويكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'لديهن': [{'vocalized': u'لديهن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدى'}],

 u'لديهم': [{'vocalized': u'لديهم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدى'}],

 u'فإياكما': [{'vocalized': u'فإياكما', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياكما', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكما'}],

 u'وكهاته': [{'vocalized': u'وكهاته', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'فتارة': [{'vocalized': u'فتارة', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'تارة', 'encletic': u'', 'type': u'اسم', 'original': u'تارة'}],

 u'لحظتهما': [{'vocalized': u'لحظتهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أففيهما': [{'vocalized': u'أففيهما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'ابنهما': [{'vocalized': u'ابنهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'فبأبيكما': [{'vocalized': u'فبأبيكما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'أذواتي': [{'vocalized': u'أذواتي', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'فاهما': [{'vocalized': u'فاهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فا'}],

 u'وبأثناءها': [{'vocalized': u'وبأثناءها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'فأولئك': [{'vocalized': u'فأولئك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'بينك': [{'vocalized': u'بينك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بين'}],

 u'أولمنكما': [{'vocalized': u'أولمنكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'لإن': [{'vocalized': u'لإن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'لإن', 'procletic': u'ل-', 'tags': u'حرف;المشبهة بليس;مجرور', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'أولعلهما': [{'vocalized': u'أولعلهما', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لعل'}],

 u'أذواتا': [{'vocalized': u'أذواتا', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذواتا', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتا'}],

 u'فلازالت': [{'vocalized': u'فلازالت', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'},
 {'vocalized': u'فلازالت', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'}],

 u'واللواتي': [{'vocalized': u'واللواتي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'فلشطرك': [{'vocalized': u'فلشطرك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'وبأثناءهن': [{'vocalized': u'وبأثناءهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلازالا': [{'vocalized': u'فلازالا', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالا'}],

 u'فكلتا': [{'vocalized': u'فكلتا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'وحينئذ': [{'vocalized': u'وحينئذ', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'حينئذ', 'encletic': u'', 'type': u'اسم', 'original': u'حينئذ'}],

 u'فلحظتهن': [{'vocalized': u'فلحظتهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لحظة'}],

 u'فكزمانه': [{'vocalized': u'فكزمانه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'فكزماني': [{'vocalized': u'فكزماني', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'فكزماني', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'أصبح': [{'vocalized': u'أصبح', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'أصبح', 'encletic': u'', 'type': u'فعل', 'original': u'أصبح'}],

 u'فلعنها': [{'vocalized': u'فلعنها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'لخلف': [{'vocalized': u'لخلف', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلف', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'وفانا': [{'vocalized': u'وفانا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فا'}],

 u'وبأسفلي': [{'vocalized': u'وبأسفلي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'وبأسفلي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفأجمعكم': [{'vocalized': u'أفأجمعكم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'لديها': [{'vocalized': u'لديها', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدى'}],

 u'أوكبعضكما': [{'vocalized': u'أوكبعضكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'لأناكم': [{'vocalized': u'لأناكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'وحسب': [{'vocalized': u'وحسب', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'عندكن': [{'vocalized': u'عندكن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عند'}],

 u'لأناكن': [{'vocalized': u'لأناكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'بغروبهما': [{'vocalized': u'بغروبهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'أوكنفسكما': [{'vocalized': u'أوكنفسكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'نفسكن': [{'vocalized': u'نفسكن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'ولذلكما': [{'vocalized': u'ولذلكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'أكتلكم': [{'vocalized': u'أكتلكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'وبأسفله': [{'vocalized': u'وبأسفله', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'فزمان': [{'vocalized': u'فزمان', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'وأبونا': [{'vocalized': u'وأبونا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبو'}],

 u'أوحسبكن': [{'vocalized': u'أوحسبكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فبيننا': [{'vocalized': u'فبيننا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بين'}],

 u'أوبتينك': [{'vocalized': u'أوبتينك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'فكذه': [{'vocalized': u'فكذه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'وكبعضهن': [{'vocalized': u'وكبعضهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'فلجنوبهم': [{'vocalized': u'فلجنوبهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلجنوبهن': [{'vocalized': u'فلجنوبهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكبعضهم': [{'vocalized': u'وكبعضهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'فكعينها': [{'vocalized': u'فكعينها', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'بشرقكن': [{'vocalized': u'بشرقكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'فكذي': [{'vocalized': u'فكذي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'بشرقكم': [{'vocalized': u'بشرقكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'وكجنبهم': [{'vocalized': u'وكجنبهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'وكجنبهن': [{'vocalized': u'وكجنبهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'جنبهن': [{'vocalized': u'جنبهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'وسبحانكم': [{'vocalized': u'وسبحانكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سبحان'}],

 u'وسبحانكن': [{'vocalized': u'وسبحانكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سبحان'}],

 u'جنبهم': [{'vocalized': u'جنبهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'ولحسبكما': [{'vocalized': u'ولحسبكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'كفيكما': [{'vocalized': u'كفيكما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'}],

 u'ذ': [{'vocalized': u'ذ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ذ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ذ'}],

 u'أثناءهما': [{'vocalized': u'أثناءهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولهو': [{'vocalized': u'ولهو', 'procletic': u'و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'},
 {'vocalized': u'ولهو', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'ولهي': [{'vocalized': u'ولهي', 'procletic': u'و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'},
 {'vocalized': u'ولهي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'ولهم': [{'vocalized': u'ولهم', 'procletic': u'و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'},
 {'vocalized': u'ولهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'لكلهم': [{'vocalized': u'لكلهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أولبعض': [{'vocalized': u'أولبعض', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعض', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'ولهن': [{'vocalized': u'ولهن', 'procletic': u'و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'},
 {'vocalized': u'ولهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أفلبعضكم': [{'vocalized': u'أفلبعضكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلبعضكن': [{'vocalized': u'أفلبعضكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أهؤلاء': [{'vocalized': u'أهؤلاء', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'وكجنبها': [{'vocalized': u'وكجنبها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'ولشهرهما': [{'vocalized': u'ولشهرهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'فعامتهن': [{'vocalized': u'فعامتهن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'جنبها': [{'vocalized': u'جنبها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'فعامتهم': [{'vocalized': u'فعامتهم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'ذاتكما': [{'vocalized': u'ذاتكما', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'ولأبيكن': [{'vocalized': u'ولأبيكن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'ولأبيكم': [{'vocalized': u'ولأبيكم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'أفكعينه': [{'vocalized': u'أفكعينه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'وككلنا': [{'vocalized': u'وككلنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلنا', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'ونفسهن': [{'vocalized': u'ونفسهن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أفكعينك': [{'vocalized': u'أفكعينك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'ولهب': [{'vocalized': u'ولهب', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'هب', 'encletic': u'', 'type': u'فعل', 'original': u'هب'}],

 u'ولعين': [{'vocalized': u'ولعين', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعين', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'ولها': [{'vocalized': u'ولها', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لها', 'encletic': u'', 'type': u'ضمير', 'original': u'لها'}],

 u'وكأخيهما': [{'vocalized': u'وكأخيهما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'فغربكما': [{'vocalized': u'فغربكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'أفمعهما': [{'vocalized': u'أفمعهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'ولجنبكما': [{'vocalized': u'ولجنبكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'بأية': [{'vocalized': u'بأية', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'أوكمن': [{'vocalized': u'أوكمن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'ولوقتكن': [{'vocalized': u'ولوقتكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'وأكثركم': [{'vocalized': u'وأكثركم', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'وأكثركن': [{'vocalized': u'وأكثركن', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكذا': [{'vocalized': u'فكذا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'فكذا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'فكذا', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'كذا', 'encletic': u'', 'type': u'اسم', 'original': u'كذا'}],

 u'وكبعضها': [{'vocalized': u'وكبعضها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبهو': [{'vocalized': u'أوبهو', 'procletic': u'أ-و-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'فكشطركن': [{'vocalized': u'فكشطركن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'أولبعضنا': [{'vocalized': u'أولبعضنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'فكعينهم': [{'vocalized': u'فكعينهم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'فكشطركم': [{'vocalized': u'فكشطركم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'أفلأجمعك': [{'vocalized': u'أفلأجمعك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلفوقنا': [{'vocalized': u'أفلفوقنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'أبنحوي': [{'vocalized': u'أبنحوي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أبنحوي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'فلجميعهم': [{'vocalized': u'فلجميعهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلجميعهن': [{'vocalized': u'فلجميعهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'أبنحوه': [{'vocalized': u'أبنحوه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'وكابنها': [{'vocalized': u'وكابنها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'أبنحوك': [{'vocalized': u'أبنحوك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'وأمامي': [{'vocalized': u'وأمامي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'وأمامي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'كالألى': [{'vocalized': u'كالألى', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'لغرب': [{'vocalized': u'لغرب', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'وأمامك': [{'vocalized': u'وأمامك', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أمامك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أمامك'},
 {'vocalized': u'وأمامك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'فطالما': [{'vocalized': u'فطالما', 'procletic': u'ف-', 'tags': u'فعل;فعل جامد;عطف', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'ذاتها': [{'vocalized': u'ذاتها', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'وأمامه': [{'vocalized': u'وأمامه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'فسبحانكما': [{'vocalized': u'فسبحانكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سبحان'}],

 u'سويها': [{'vocalized': u'سويها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أولمثلكما': [{'vocalized': u'أولمثلكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أبذانك': [{'vocalized': u'أبذانك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'ويمينهن': [{'vocalized': u'ويمينهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'أكنحوهم': [{'vocalized': u'أكنحوهم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'ماانفك': [{'vocalized': u'ماانفك', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفك', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفك'}],

 u'فلأكثري': [{'vocalized': u'فلأكثري', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'فلأكثري', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'أكنحوهن': [{'vocalized': u'أكنحوهن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'فلأكثره': [{'vocalized': u'فلأكثره', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلأكثرك': [{'vocalized': u'فلأكثرك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'بوقتكما': [{'vocalized': u'بوقتكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'سويهم': [{'vocalized': u'سويهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'سويهن': [{'vocalized': u'سويهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'فباللائي': [{'vocalized': u'فباللائي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'لوراءكما': [{'vocalized': u'لوراءكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'أفلشبهكما': [{'vocalized': u'أفلشبهكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'أفعامة': [{'vocalized': u'أفعامة', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'لذلكما': [{'vocalized': u'لذلكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'أكنحوها': [{'vocalized': u'أكنحوها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'وكأبيهم': [{'vocalized': u'وكأبيهم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'أفبعامتك': [{'vocalized': u'أفبعامتك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'وجنوبي': [{'vocalized': u'وجنوبي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'وجنوبي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفبعامته': [{'vocalized': u'أفبعامته', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'فلتلقاءنا': [{'vocalized': u'فلتلقاءنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وببعضكم': [{'vocalized': u'وببعضكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أإليهم': [{'vocalized': u'أإليهم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'أفبعامتي': [{'vocalized': u'أفبعامتي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفبعامتي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فلجميعها': [{'vocalized': u'فلجميعها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعها', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'وكابنهن': [{'vocalized': u'وكابنهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'فعين': [{'vocalized': u'فعين', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'وكابنهم': [{'vocalized': u'وكابنهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'أولإن': [{'vocalized': u'أولإن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'ولغروبكن': [{'vocalized': u'ولغروبكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'أوأمامه': [{'vocalized': u'أوأمامه', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'أوأمامي': [{'vocalized': u'أوأمامي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'أوأمامي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'ماانفكا': [{'vocalized': u'ماانفكا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفكا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكا'}],

 u'ذاتهن': [{'vocalized': u'ذاتهن', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'ذاتهم': [{'vocalized': u'ذاتهم', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'أفبضعه': [{'vocalized': u'أفبضعه', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بضع'}],

 u'لشرقها': [{'vocalized': u'لشرقها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'أفبضعك': [{'vocalized': u'أفبضعك', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بضع'}],

 u'كتلقاءكن': [{'vocalized': u'كتلقاءكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكأيكم': [{'vocalized': u'وكأيكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'أفأناكما': [{'vocalized': u'أفأناكما', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'فلنفسهم': [{'vocalized': u'فلنفسهم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'أفبضعي': [{'vocalized': u'أفبضعي', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'},
 {'vocalized': u'أفبضعي', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'}],

 u'أولإنا': [{'vocalized': u'أولإنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'فأمامك': [{'vocalized': u'فأمامك', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أمامك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أمامك'},
 {'vocalized': u'فأمامك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'أوكهاته': [{'vocalized': u'أوكهاته', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'فالألاء': [{'vocalized': u'فالألاء', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'فأمامه': [{'vocalized': u'فأمامه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أمام'}],

 u'وراءكم': [{'vocalized': u'وراءكم', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'وراءكم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وراءكم'},
 {'vocalized': u'وراءكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'أوكهاتي': [{'vocalized': u'أوكهاتي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'فأمامي': [{'vocalized': u'فأمامي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'فأمامي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'أفلهذا': [{'vocalized': u'أفلهذا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'كأثناءهما': [{'vocalized': u'كأثناءهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفيمينها': [{'vocalized': u'أفيمينها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'أبوه': [{'vocalized': u'أبوه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبو'}],

 u'فلنفسنا': [{'vocalized': u'فلنفسنا', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أبوك': [{'vocalized': u'أبوك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبو'}],

 u'بتلقاءها': [{'vocalized': u'بتلقاءها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'إذما': [{'vocalized': u'إذما', 'procletic': u'', 'tags': u'حرف;حرف شرط', 'stem': u'إذما', 'encletic': u'', 'type': u'حرف', 'original': u'إذما'}],

 u'ولعننا': [{'vocalized': u'ولعننا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'أبوي': [{'vocalized': u'أبوي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبو'},
 {'vocalized': u'أبوي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبو'}],

 u'أفلغيرنا': [{'vocalized': u'أفلغيرنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيرنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فأبيها': [{'vocalized': u'فأبيها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'فأولالك': [{'vocalized': u'فأولالك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'أفجميعهما': [{'vocalized': u'أفجميعهما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعهما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'كاللتيا': [{'vocalized': u'كاللتيا', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'أوكجميعه': [{'vocalized': u'أوكجميعه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'وسوينا': [{'vocalized': u'وسوينا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'أفيمينهن': [{'vocalized': u'أفيمينهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'عننا': [{'vocalized': u'عننا', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'أفيمينهم': [{'vocalized': u'أفيمينهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'كعامتهما': [{'vocalized': u'كعامتهما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أوعليكما': [{'vocalized': u'أوعليكما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'بتلقاءهم': [{'vocalized': u'بتلقاءهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وحما': [{'vocalized': u'وحما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'حما', 'encletic': u'', 'type': u'اسم', 'original': u'حما'}],

 u'بتلقاءهن': [{'vocalized': u'بتلقاءهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أوكجميعك': [{'vocalized': u'أوكجميعك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'فللذي': [{'vocalized': u'فللذي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'فأبيهن': [{'vocalized': u'فأبيهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'فبعده': [{'vocalized': u'فبعده', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعد'}],

 u'كابنكما': [{'vocalized': u'كابنكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'فبعدي': [{'vocalized': u'فبعدي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعد'},
 {'vocalized': u'فبعدي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعد'}],

 u'وبأخيهم': [{'vocalized': u'وبأخيهم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'وكابن': [{'vocalized': u'وكابن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'وغروبهما': [{'vocalized': u'وغروبهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'أوكلنا': [{'vocalized': u'أوكلنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلنا', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أوكليهما': [{'vocalized': u'أوكليهما', 'procletic': u'أ-و-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'أونحوها': [{'vocalized': u'أونحوها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'لسويهما': [{'vocalized': u'لسويهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فأباكن': [{'vocalized': u'فأباكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبا'}],

 u'بسويكن': [{'vocalized': u'بسويكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'بأخيكم': [{'vocalized': u'بأخيكم', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'بأخيكن': [{'vocalized': u'بأخيكن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'بسويكم': [{'vocalized': u'بسويكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوأجمعهن': [{'vocalized': u'أوأجمعهن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوأجمعهم': [{'vocalized': u'أوأجمعهم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولطفق': [{'vocalized': u'ولطفق', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'طفق', 'encletic': u'', 'type': u'فعل', 'original': u'طفق'}],

 u'واللتين': [{'vocalized': u'واللتين', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'وإياهما': [{'vocalized': u'وإياهما', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياهما', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهما'}],

 u'ولغربنا': [{'vocalized': u'ولغربنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'أفلحسبكما': [{'vocalized': u'أفلحسبكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'أوكجميعهن': [{'vocalized': u'أوكجميعهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'أوكجميعهم': [{'vocalized': u'أوكجميعهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أبذلك': [{'vocalized': u'أبذلك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'فمابرحا': [{'vocalized': u'فمابرحا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحا'}],

 u'فلوما': [{'vocalized': u'فلوما', 'procletic': u'ف-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لوما', 'encletic': u'', 'type': u'حرف', 'original': u'لوما'}],

 u'حولنا': [{'vocalized': u'حولنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حول'}],

 u'فزماننا': [{'vocalized': u'فزماننا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'ولجميعهن': [{'vocalized': u'ولجميعهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'ولجميعهم': [{'vocalized': u'ولجميعهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلخلف': [{'vocalized': u'فلخلف', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلف', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'فمابرحت': [{'vocalized': u'فمابرحت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'فمابرحت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'فمابرحت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'فمابرحت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'}],

 u'أفلعليكن': [{'vocalized': u'أفلعليكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'ريث': [{'vocalized': u'ريث', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'ريث', 'encletic': u'', 'type': u'اسم', 'original': u'ريث'}],

 u'لأجمعكم': [{'vocalized': u'لأجمعكم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فا': [{'vocalized': u'فا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'فا', 'encletic': u'', 'type': u'اسم', 'original': u'فا'}],

 u'لأجمعكن': [{'vocalized': u'لأجمعكن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفوراءنا': [{'vocalized': u'أفوراءنا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'حولهما': [{'vocalized': u'حولهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حول'}],

 u'ألنحوكما': [{'vocalized': u'ألنحوكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فلشهرهم': [{'vocalized': u'فلشهرهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'ولسوف': [{'vocalized': u'ولسوف', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'سوف', 'encletic': u'', 'type': u'حرف', 'original': u'سوف'}],

 u'فبأنهن': [{'vocalized': u'فبأنهن', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'فبأنهم': [{'vocalized': u'فبأنهم', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'كأي': [{'vocalized': u'كأي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'كأي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'كأي', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'كأي', 'encletic': u'', 'type': u'اسم', 'original': u'كأي'}],

 u'ولسوي': [{'vocalized': u'ولسوي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'ولسوي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'كأن': [{'vocalized': u'كأن', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'كأن', 'procletic': u'ك-', 'tags': u'حرف;حرف نصب;مجرور', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'لحميكن': [{'vocalized': u'لحميكن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'لحميكم': [{'vocalized': u'لحميكم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'فلجنوب': [{'vocalized': u'فلجنوب', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'فو': [{'vocalized': u'فو', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'فو', 'encletic': u'', 'type': u'اسم', 'original': u'فو'}],

 u'في': [{'vocalized': u'في', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'في', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'أوليمينكم': [{'vocalized': u'أوليمينكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'لعمرنا': [{'vocalized': u'لعمرنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لعمر'}],

 u'ولأنكما': [{'vocalized': u'ولأنكما', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'وبجميعك': [{'vocalized': u'وبجميعك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعك', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'فكأعلى': [{'vocalized': u'فكأعلى', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبأنها': [{'vocalized': u'فبأنها', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'وبجميعه': [{'vocalized': u'وبجميعه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعه', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'وبجميعي': [{'vocalized': u'وبجميعي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميعي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أبأجمع': [{'vocalized': u'أبأجمع', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'فوراءنا': [{'vocalized': u'فوراءنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'أوكجميعها': [{'vocalized': u'أوكجميعها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'وحاشاهما': [{'vocalized': u'وحاشاهما', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'حاشا'}],

 u'ولجميعها': [{'vocalized': u'ولجميعها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعها', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'فمادمن': [{'vocalized': u'فمادمن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمن', 'encletic': u'', 'type': u'فعل', 'original': u'مادمن'}],

 u'كأجمعها': [{'vocalized': u'كأجمعها', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'شبههن': [{'vocalized': u'شبههن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'شبههم': [{'vocalized': u'شبههم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'بشطر': [{'vocalized': u'بشطر', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'أفأناكم': [{'vocalized': u'أفأناكم', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'ولحار': [{'vocalized': u'ولحار', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'حار', 'encletic': u'', 'type': u'فعل', 'original': u'حار'}],

 u'وبأخيكم': [{'vocalized': u'وبأخيكم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'أولتحتنا': [{'vocalized': u'أولتحتنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'فجنوبها': [{'vocalized': u'فجنوبها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلجنبهم': [{'vocalized': u'فلجنبهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'أخيك': [{'vocalized': u'أخيك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'فلجنبهن': [{'vocalized': u'فلجنبهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'فأكثرك': [{'vocalized': u'فأكثرك', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'أجمع': [{'vocalized': u'أجمع', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'فأكثره': [{'vocalized': u'فأكثره', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'لنفسهن': [{'vocalized': u'لنفسهن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'فأكثري': [{'vocalized': u'فأكثري', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'فأكثري', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'أخوهم': [{'vocalized': u'أخوهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخو'}],

 u'فكأيته': [{'vocalized': u'فكأيته', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'فلعنهما': [{'vocalized': u'فلعنهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'أخوهن': [{'vocalized': u'أخوهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخو'}],

 u'أوخلفي': [{'vocalized': u'أوخلفي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'أوخلفي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'غرب': [{'vocalized': u'غرب', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'أوخلفه': [{'vocalized': u'أوخلفه', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'فبجميعهم': [{'vocalized': u'فبجميعهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعهم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فبجميعهن': [{'vocalized': u'فبجميعهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعهن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فلديهن': [{'vocalized': u'فلديهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدى'}],

 u'فلديهم': [{'vocalized': u'فلديهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدى'}],

 u'غروبك': [{'vocalized': u'غروبك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'لإليكما': [{'vocalized': u'لإليكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'لنفسها': [{'vocalized': u'لنفسها', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'غروبه': [{'vocalized': u'غروبه', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'ولإليكم': [{'vocalized': u'ولإليكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'فكأيتك': [{'vocalized': u'فكأيتك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'غروبي': [{'vocalized': u'غروبي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'غروبي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'ولإليكن': [{'vocalized': u'ولإليكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'ولحيث': [{'vocalized': u'ولحيث', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'أولجميعهما': [{'vocalized': u'أولجميعهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'فوقتك': [{'vocalized': u'فوقتك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'أخوها': [{'vocalized': u'أخوها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخو'}],

 u'ولمعكم': [{'vocalized': u'ولمعكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'بأيتهما': [{'vocalized': u'بأيتهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'فأعليهما': [{'vocalized': u'فأعليهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولمعكن': [{'vocalized': u'ولمعكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'ألشمال': [{'vocalized': u'ألشمال', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'فعليكن': [{'vocalized': u'فعليكن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'فعليكم': [{'vocalized': u'فعليكم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'فبجميعها': [{'vocalized': u'فبجميعها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعها', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'شبهها': [{'vocalized': u'شبهها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'أكغير': [{'vocalized': u'أكغير', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وأخوهما': [{'vocalized': u'وأخوهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخو'}],

 u'فبأقل': [{'vocalized': u'فبأقل', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'أفسويكما': [{'vocalized': u'أفسويكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'فعلى': [{'vocalized': u'فعلى', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'كأقل': [{'vocalized': u'كأقل', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'فجنوبهم': [{'vocalized': u'فجنوبهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'فجنوبهن': [{'vocalized': u'فجنوبهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلجنبها': [{'vocalized': u'فلجنبها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'جنوبك': [{'vocalized': u'جنوبك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفكأجمعها': [{'vocalized': u'أفكأجمعها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'كشرقها': [{'vocalized': u'كشرقها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'ولإننا': [{'vocalized': u'ولإننا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'أفلشمالها': [{'vocalized': u'أفلشمالها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'فاكم': [{'vocalized': u'فاكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فا'}],

 u'بشرقي': [{'vocalized': u'بشرقي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'بشرقي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'فاكن': [{'vocalized': u'فاكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'فا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فا'}],

 u'فكأخيي': [{'vocalized': u'فكأخيي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'فكأخيي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'أولشبهنا': [{'vocalized': u'أولشبهنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'أفببعضها': [{'vocalized': u'أفببعضها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'فكأخيك': [{'vocalized': u'فكأخيك', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'فكلكما': [{'vocalized': u'فكلكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلكما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فكأخيه': [{'vocalized': u'فكأخيه', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'لذاتهما': [{'vocalized': u'لذاتهما', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'فلزماني': [{'vocalized': u'فلزماني', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'فلزماني', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'فلأخيهم': [{'vocalized': u'فلأخيهم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'فلأخيهن': [{'vocalized': u'فلأخيهن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'فلأثناءكن': [{'vocalized': u'فلأثناءكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'أوكنحوهما': [{'vocalized': u'أوكنحوهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'ألعيننا': [{'vocalized': u'ألعيننا', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعيننا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'فلزمانك': [{'vocalized': u'فلزمانك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'فلأجمع': [{'vocalized': u'فلأجمع', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمع', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'ذا': [{'vocalized': u'ذا', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'ذا', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'ذا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'جنوبي': [{'vocalized': u'جنوبي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'جنوبي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبأكثرنا': [{'vocalized': u'فبأكثرنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولتحتي': [{'vocalized': u'ولتحتي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'ولتحتي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'ألخلفهما': [{'vocalized': u'ألخلفهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'ولذاتكما': [{'vocalized': u'ولذاتكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'فلأخيها': [{'vocalized': u'فلأخيها', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'ولتحتك': [{'vocalized': u'ولتحتك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'ولتحته': [{'vocalized': u'ولتحته', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'فابني': [{'vocalized': u'فابني', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'فابني', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'أفذلك': [{'vocalized': u'أفذلك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'ذه': [{'vocalized': u'ذه', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'فابنك': [{'vocalized': u'فابنك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'ذو': [{'vocalized': u'ذو', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'ذو', 'encletic': u'', 'type': u'اسم', 'original': u'ذو'}],

 u'أكلهما': [{'vocalized': u'أكلهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلهما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'فابنه': [{'vocalized': u'فابنه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'أفكأجمعهم': [{'vocalized': u'أفكأجمعهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكجميعك': [{'vocalized': u'فكجميعك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعك', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'كشرقهن': [{'vocalized': u'كشرقهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'فكجميعه': [{'vocalized': u'فكجميعه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعه', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أبشبهكن': [{'vocalized': u'أبشبهكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'فكجميعي': [{'vocalized': u'فكجميعي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أولدي': [{'vocalized': u'أولدي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'},
 {'vocalized': u'أولدي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'}],

 u'وبليلكما': [{'vocalized': u'وبليلكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'فلأيتنا': [{'vocalized': u'فلأيتنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'حولكم': [{'vocalized': u'حولكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حول'}],

 u'ولجعل': [{'vocalized': u'ولجعل', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'جعل', 'encletic': u'', 'type': u'فعل', 'original': u'جعل'}],

 u'أفككلك': [{'vocalized': u'أفككلك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'أفببعضهم': [{'vocalized': u'أفببعضهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفببعضهن': [{'vocalized': u'أفببعضهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفككله': [{'vocalized': u'أفككله', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككله', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'أككلتا': [{'vocalized': u'أككلتا', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفككلي': [{'vocalized': u'أفككلي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'وكغيركما': [{'vocalized': u'وكغيركما', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فانقلب': [{'vocalized': u'فانقلب', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'انقلب', 'encletic': u'', 'type': u'فعل', 'original': u'انقلب'}],

 u'وحسبكن': [{'vocalized': u'وحسبكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبنحوه': [{'vocalized': u'أوبنحوه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'وبتلقاءكما': [{'vocalized': u'وبتلقاءكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أولفيه': [{'vocalized': u'أولفيه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'أوبنحوك': [{'vocalized': u'أوبنحوك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'أولفيك': [{'vocalized': u'أولفيك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'ألنحوكم': [{'vocalized': u'ألنحوكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'ألنحوكن': [{'vocalized': u'ألنحوكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'أومنهن': [{'vocalized': u'أومنهن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'أومنهم': [{'vocalized': u'أومنهم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فلعنهن': [{'vocalized': u'فلعنهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أووراءكما': [{'vocalized': u'أووراءكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'وشهري': [{'vocalized': u'وشهري', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'وشهري', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فبشطرهما': [{'vocalized': u'فبشطرهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'أفبحسبكم': [{'vocalized': u'أفبحسبكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفبحسبكن': [{'vocalized': u'أفبحسبكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فبأنكما': [{'vocalized': u'فبأنكما', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'أفمعها': [{'vocalized': u'أفمعها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'لتحته': [{'vocalized': u'لتحته', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'لتحتي': [{'vocalized': u'لتحتي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'لتحتي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'أبعين': [{'vocalized': u'أبعين', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'لأثناءه': [{'vocalized': u'لأثناءه', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولأمامكن': [{'vocalized': u'ولأمامكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'لأثناءك': [{'vocalized': u'لأثناءك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلستن': [{'vocalized': u'فلستن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لستن', 'encletic': u'', 'type': u'فعل', 'original': u'لستن'}],

 u'بأولاء': [{'vocalized': u'بأولاء', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'أوبجميع': [{'vocalized': u'أوبجميع', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميع', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'لأثناءي': [{'vocalized': u'لأثناءي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'لأثناءي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'فأخونا': [{'vocalized': u'فأخونا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخو'}],

 u'أفمعهم': [{'vocalized': u'أفمعهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'أفمعهن': [{'vocalized': u'أفمعهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'لجنوبكما': [{'vocalized': u'لجنوبكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'وحاشاهم': [{'vocalized': u'وحاشاهم', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'حاشا'}],

 u'وحاشاهن': [{'vocalized': u'وحاشاهن', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'حاشا'}],

 u'وكرب': [{'vocalized': u'وكرب', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'كرب', 'encletic': u'', 'type': u'فعل', 'original': u'كرب'}],

 u'وكليلها': [{'vocalized': u'وكليلها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'ولبعضهما': [{'vocalized': u'ولبعضهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'ولأولئكم': [{'vocalized': u'ولأولئكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'أوخلفهن': [{'vocalized': u'أوخلفهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أوكنفس': [{'vocalized': u'أوكنفس', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أومنها': [{'vocalized': u'أومنها', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'أفوقنا': [{'vocalized': u'أفوقنا', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'فحار': [{'vocalized': u'فحار', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'حار', 'encletic': u'', 'type': u'فعل', 'original': u'حار'}],

 u'أحسبكما': [{'vocalized': u'أحسبكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'اخلولق': [{'vocalized': u'اخلولق', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'اخلولق', 'encletic': u'', 'type': u'فعل', 'original': u'اخلولق'}],

 u'وأصلا': [{'vocalized': u'وأصلا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أصلا', 'encletic': u'', 'type': u'اسم', 'original': u'أصلا'}],

 u'أفلجميعهما': [{'vocalized': u'أفلجميعهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'فكأيتكما': [{'vocalized': u'فكأيتكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'وبنفسكم': [{'vocalized': u'وبنفسكم', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'وبنفسكن': [{'vocalized': u'وبنفسكن', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'فلشطر': [{'vocalized': u'فلشطر', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'كهنالك': [{'vocalized': u'كهنالك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'أوإليكن': [{'vocalized': u'أوإليكن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'ولمعي': [{'vocalized': u'ولمعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'ولمعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'أوإليكم': [{'vocalized': u'أوإليكم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'وشكان': [{'vocalized': u'وشكان', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'وشكان', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وشكان'}],

 u'فلعليكن': [{'vocalized': u'فلعليكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'ولمعك': [{'vocalized': u'ولمعك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'أكمثلكما': [{'vocalized': u'أكمثلكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'ولمعه': [{'vocalized': u'ولمعه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'فلأقلنا': [{'vocalized': u'فلأقلنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'أنحن': [{'vocalized': u'أنحن', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'ولكني': [{'vocalized': u'ولكني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكني', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكني', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكني', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'}],

 u'أوفوقهما': [{'vocalized': u'أوفوقهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'أنحو': [{'vocalized': u'أنحو', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فلشطركن': [{'vocalized': u'فلشطركن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'فلشطركم': [{'vocalized': u'فلشطركم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'فكجنوبنا': [{'vocalized': u'فكجنوبنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'فهيا': [{'vocalized': u'فهيا', 'procletic': u'ف-', 'tags': u'حرف;حرف نداء;عطف', 'stem': u'هيا', 'encletic': u'', 'type': u'حرف', 'original': u'هيا'}],

 u'لشهرك': [{'vocalized': u'لشهرك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'لشهره': [{'vocalized': u'لشهره', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'وبشهرنا': [{'vocalized': u'وبشهرنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'كجنوب': [{'vocalized': u'كجنوب', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'لشهري': [{'vocalized': u'لشهري', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'لشهري', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فهيت': [{'vocalized': u'فهيت', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'هيت', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هيت'}],

 u'فجنبكم': [{'vocalized': u'فجنبكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'أفبمثلنا': [{'vocalized': u'أفبمثلنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'فمكانكن': [{'vocalized': u'فمكانكن', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانكن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكن'}],

 u'وبأبيي': [{'vocalized': u'وبأبيي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'وبأبيي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'وبأبيه': [{'vocalized': u'وبأبيه', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'وبجنوبهما': [{'vocalized': u'وبجنوبهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'وبأبيك': [{'vocalized': u'وبأبيك', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'فلإنا': [{'vocalized': u'فلإنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'أفقلما': [{'vocalized': u'أفقلما', 'procletic': u'أ-ف-', 'tags': u'فعل;فعل جامد;عطف;استفهام', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'لأناك': [{'vocalized': u'لأناك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'أبكلكما': [{'vocalized': u'أبكلكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلكما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فلبعض': [{'vocalized': u'فلبعض', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعض', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'لنفسكما': [{'vocalized': u'لنفسكما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'أأمامي': [{'vocalized': u'أأمامي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'أأمامي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'إليه': [{'vocalized': u'إليه', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'فلجميعي': [{'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'فلجميعه': [{'vocalized': u'فلجميعه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعه', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'خلالنا': [{'vocalized': u'خلالنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلال'}],

 u'فلجميعك': [{'vocalized': u'فلجميعك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعك', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فلجميعك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أوكأجمعكما': [{'vocalized': u'أوكأجمعكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكسويكما': [{'vocalized': u'أكسويكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'أفأمامهم': [{'vocalized': u'أفأمامهم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'ولفينا': [{'vocalized': u'ولفينا', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ولفينا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'أفأمامهن': [{'vocalized': u'أفأمامهن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'بمثلنا': [{'vocalized': u'بمثلنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'كعامتكن': [{'vocalized': u'كعامتكن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'خلالها': [{'vocalized': u'خلالها', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلال'}],

 u'فأيتكما': [{'vocalized': u'فأيتكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'وكذاتكم': [{'vocalized': u'وكذاتكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'وكذاتكن': [{'vocalized': u'وكذاتكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أفلشمالهم': [{'vocalized': u'أفلشمالهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'أفلشمالهن': [{'vocalized': u'أفلشمالهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شمال'}],

 u'فحموها': [{'vocalized': u'فحموها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمو'}],

 u'صه': [{'vocalized': u'صه', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'صه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'صه'},
 {'vocalized': u'صه', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'صه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'صه'}],

 u'ألكلكما': [{'vocalized': u'ألكلكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'ألكلهن': [{'vocalized': u'ألكلهن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'ألكلهم': [{'vocalized': u'ألكلهم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'كذويي': [{'vocalized': u'كذويي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'كذويي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'كذويه': [{'vocalized': u'كذويه', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'ويمينهم': [{'vocalized': u'ويمينهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'كذويك': [{'vocalized': u'كذويك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'أبعيننا': [{'vocalized': u'أبعيننا', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'بينه': [{'vocalized': u'بينه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بين'}],

 u'ألدى': [{'vocalized': u'ألدى', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام', 'stem': u'لدى', 'encletic': u'', 'type': u'اسم', 'original': u'لدى'}],

 u'ألدي': [{'vocalized': u'ألدي', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'},
 {'vocalized': u'ألدي', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدى'}],

 u'ظ': [{'vocalized': u'ظ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ظ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ظ'}],

 u'فلعمركما': [{'vocalized': u'فلعمركما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لعمر'}],

 u'فكلي': [{'vocalized': u'فكلي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'أفعينكما': [{'vocalized': u'أفعينكما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'ولوقتهما': [{'vocalized': u'ولوقتهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'لأخيهم': [{'vocalized': u'لأخيهم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'أكثر': [{'vocalized': u'أكثر', 'procletic': u'', 'tags': u'اسم;اسم تفضيل', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكلك': [{'vocalized': u'فكلك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلك', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'ببعضكن': [{'vocalized': u'ببعضكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'أولديه': [{'vocalized': u'أولديه', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدى'}],

 u'ويمينها': [{'vocalized': u'ويمينها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'فكله': [{'vocalized': u'فكله', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكله', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'جنوبهن': [{'vocalized': u'جنوبهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'أشبهي': [{'vocalized': u'أشبهي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أشبهي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'أشبهك': [{'vocalized': u'أشبهك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أشبهه': [{'vocalized': u'أشبهه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'فأخوهما': [{'vocalized': u'فأخوهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخو'}],

 u'بلحظتهما': [{'vocalized': u'بلحظتهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'لحظته': [{'vocalized': u'لحظته', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'بيني': [{'vocalized': u'بيني', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بين'},
 {'vocalized': u'بيني', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بين'}],

 u'لحظتك': [{'vocalized': u'لحظتك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'أكبعضكما': [{'vocalized': u'أكبعضكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'ألكلها': [{'vocalized': u'ألكلها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلها', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'لحظتي': [{'vocalized': u'لحظتي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'لحظتي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'أوأناكن': [{'vocalized': u'أوأناكن', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'أبجميعكما': [{'vocalized': u'أبجميعكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعكما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفأولالك': [{'vocalized': u'أفأولالك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فلعنكم': [{'vocalized': u'فلعنكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'فبشرقهم': [{'vocalized': u'فبشرقهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'كاللذين': [{'vocalized': u'كاللذين', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'فلعلهما': [{'vocalized': u'فلعلهما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لعل'}],

 u'سبحانكن': [{'vocalized': u'سبحانكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سبحان'}],

 u'سبحانكم': [{'vocalized': u'سبحانكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سبحان'}],

 u'فلأنانا': [{'vocalized': u'فلأنانا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'وكغيركن': [{'vocalized': u'وكغيركن', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'فبلحظتكما': [{'vocalized': u'فبلحظتكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'وكغيركم': [{'vocalized': u'وكغيركم', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'دونك': [{'vocalized': u'دونك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'دونك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'دونك'}],

 u'لشمالنا': [{'vocalized': u'لشمالنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'عندها': [{'vocalized': u'عندها', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عند'}],

 u'أفلكأنكما': [{'vocalized': u'أفلكأنكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'كجنبكم': [{'vocalized': u'كجنبكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'كجنبكن': [{'vocalized': u'كجنبكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'وكمثلهما': [{'vocalized': u'وكمثلهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'أقلنا': [{'vocalized': u'أقلنا', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'أفذاك': [{'vocalized': u'أفذاك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'بأكثرنا': [{'vocalized': u'بأكثرنا', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'كذويكم': [{'vocalized': u'كذويكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'كذويكن': [{'vocalized': u'كذويكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلكننا': [{'vocalized': u'فلكننا', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكننا', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لكن'}],

 u'ومازلنا': [{'vocalized': u'ومازلنا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'مازلنا'}],

 u'وبأثناءكم': [{'vocalized': u'وبأثناءكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبأثناءكن': [{'vocalized': u'وبأثناءكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'لدننا': [{'vocalized': u'لدننا', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدن'}],

 u'فاللتان': [{'vocalized': u'فاللتان', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللتان', 'encletic': u'', 'type': u'اسم', 'original': u'اللتان'}],

 u'لزمان': [{'vocalized': u'لزمان', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'أوكأجمعهن': [{'vocalized': u'أوكأجمعهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولفوقهن': [{'vocalized': u'ولفوقهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'كعينكن': [{'vocalized': u'كعينكن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'كعينكم': [{'vocalized': u'كعينكم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'كغروبكما': [{'vocalized': u'كغروبكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'هما': [{'vocalized': u'هما', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'ألكأننا': [{'vocalized': u'ألكأننا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'وبشرقك': [{'vocalized': u'وبشرقك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'فكزمانك': [{'vocalized': u'فكزمانك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'ولأكثري': [{'vocalized': u'ولأكثري', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'ولأكثري', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'لحميي': [{'vocalized': u'لحميي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'لحميي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'فساعتكم': [{'vocalized': u'فساعتكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'ولأكثرك': [{'vocalized': u'ولأكثرك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'وكعينهم': [{'vocalized': u'وكعينهم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'وكشطرهما': [{'vocalized': u'وكشطرهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'فكشهرنا': [{'vocalized': u'فكشهرنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'ولأكثره': [{'vocalized': u'ولأكثره', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلوقتكما': [{'vocalized': u'فلوقتكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'عندهم': [{'vocalized': u'عندهم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عند'}],

 u'عندهن': [{'vocalized': u'عندهن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عند'}],

 u'منهم': [{'vocalized': u'منهم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فلعنك': [{'vocalized': u'فلعنك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'أوليمينك': [{'vocalized': u'أوليمينك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'منهن': [{'vocalized': u'منهن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'وكخلفنا': [{'vocalized': u'وكخلفنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'كهي': [{'vocalized': u'كهي', 'procletic': u'ك-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'أفبسوى': [{'vocalized': u'أفبسوى', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أفبسوي': [{'vocalized': u'أفبسوي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أفبسوي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'وته': [{'vocalized': u'وته', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'أفكحسبك': [{'vocalized': u'أفكحسبك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'أكسويها': [{'vocalized': u'أكسويها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أفكحسبه': [{'vocalized': u'أفكحسبه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'فكأخيكم': [{'vocalized': u'فكأخيكم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'فلعنه': [{'vocalized': u'فلعنه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'أفكحسبي': [{'vocalized': u'أفكحسبي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أفكحسبي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'فكأخيكن': [{'vocalized': u'فكأخيكن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'أبضعهم': [{'vocalized': u'أبضعهم', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بضع'}],

 u'وتي': [{'vocalized': u'وتي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'وكاللواتي': [{'vocalized': u'وكاللواتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'ومذ': [{'vocalized': u'ومذ', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'مذ', 'encletic': u'', 'type': u'حرف', 'original': u'مذ'},
 {'vocalized': u'ومذ', 'procletic': u'و-', 'tags': u'حرف;ظرف زمان;عطف', 'stem': u'مذ', 'encletic': u'', 'type': u'حرف', 'original': u'مذ'}],

 u'شهركما': [{'vocalized': u'شهركما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'ليمينكما': [{'vocalized': u'ليمينكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'وبضعهم': [{'vocalized': u'وبضعهم', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بضع'}],

 u'كأيتكما': [{'vocalized': u'كأيتكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'وأخيهما': [{'vocalized': u'وأخيهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'فلوقتنا': [{'vocalized': u'فلوقتنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'ومع': [{'vocalized': u'ومع', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'وما': [{'vocalized': u'وما', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'وما', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'وما', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'وما', 'procletic': u'و-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'حرف', 'original': u'ما'}],

 u'لهؤلاء': [{'vocalized': u'لهؤلاء', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'مافتئتن': [{'vocalized': u'مافتئتن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئتن', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتن'}],

 u'فيما': [{'vocalized': u'فيما', 'procletic': u'', 'tags': u'حرف;حرف استفهام', 'stem': u'فيما', 'encletic': u'', 'type': u'حرف', 'original': u'فيما'}],

 u'أفلست': [{'vocalized': u'أفلست', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'أفلست', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'أفلست', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'}],

 u'فكأننا': [{'vocalized': u'فكأننا', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأننا', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'أوككلهما': [{'vocalized': u'أوككلهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'فلحمي': [{'vocalized': u'فلحمي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'اللائي': [{'vocalized': u'اللائي', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'ومن': [{'vocalized': u'ومن', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'ومن', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'ومن', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'ومن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'وكهذين': [{'vocalized': u'وكهذين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'أمامكن': [{'vocalized': u'أمامكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'أمامكم': [{'vocalized': u'أمامكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'فنعما': [{'vocalized': u'فنعما', 'procletic': u'ف-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'نعما', 'encletic': u'', 'type': u'فعل', 'original': u'نعما'}],

 u'فلأكثرنا': [{'vocalized': u'فلأكثرنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفأجمعكن': [{'vocalized': u'أفأجمعكن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'كعينكما': [{'vocalized': u'كعينكما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'وبنا': [{'vocalized': u'وبنا', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بنا', 'encletic': u'', 'type': u'ضمير', 'original': u'بنا'}],

 u'وجنبها': [{'vocalized': u'وجنبها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'فلتحول': [{'vocalized': u'فلتحول', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'تحول', 'encletic': u'', 'type': u'فعل', 'original': u'تحول'}],

 u'أمعك': [{'vocalized': u'أمعك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'فلدنكن': [{'vocalized': u'فلدنكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدن'}],

 u'فلدنكم': [{'vocalized': u'فلدنكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدن'}],

 u'بذلك': [{'vocalized': u'بذلك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'أكسويهم': [{'vocalized': u'أكسويهم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'وسبحاني': [{'vocalized': u'وسبحاني', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سبحان'},
 {'vocalized': u'وسبحاني', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سبحان'}],

 u'أكسويهن': [{'vocalized': u'أكسويهن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'أمعي': [{'vocalized': u'أمعي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'أمعي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'أوكأجمعهم': [{'vocalized': u'أوكأجمعهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'وسبحانه': [{'vocalized': u'وسبحانه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سبحان'}],

 u'أبضعها': [{'vocalized': u'أبضعها', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بضع'}],

 u'وسبحانك': [{'vocalized': u'وسبحانك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سبحان'}],

 u'أبمثلي': [{'vocalized': u'أبمثلي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أبمثلي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'وساعتكما': [{'vocalized': u'وساعتكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'لبعضكما': [{'vocalized': u'لبعضكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أبمثلك': [{'vocalized': u'أبمثلك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أبمثله': [{'vocalized': u'أبمثله', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'حيني': [{'vocalized': u'حيني', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حين'},
 {'vocalized': u'حيني', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حين'}],

 u'فلذاتها': [{'vocalized': u'فلذاتها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'كشرق': [{'vocalized': u'كشرق', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'كلحظتهما': [{'vocalized': u'كلحظتهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبنحوهم': [{'vocalized': u'وبنحوهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'فخلالهم': [{'vocalized': u'فخلالهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلال'}],

 u'أويمينها': [{'vocalized': u'أويمينها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'لفوقهما': [{'vocalized': u'لفوقهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'عندكم': [{'vocalized': u'عندكم', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عند'}],

 u'بأجمعكم': [{'vocalized': u'بأجمعكم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'بأجمعكن': [{'vocalized': u'بأجمعكن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبمثلها': [{'vocalized': u'وبمثلها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'فتلقاءك': [{'vocalized': u'فتلقاءك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'حذار': [{'vocalized': u'حذار', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'حذار', 'encletic': u'', 'type': u'اسم فعل', 'original': u'حذار'}],

 u'أفهاهنا': [{'vocalized': u'أفهاهنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاهنا', 'encletic': u'', 'type': u'اسم', 'original': u'هاهنا'}],

 u'بأثناءنا': [{'vocalized': u'بأثناءنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلشرقنا': [{'vocalized': u'فلشرقنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'فلحظتهما': [{'vocalized': u'فلحظتهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'أويمينهن': [{'vocalized': u'أويمينهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'عداه': [{'vocalized': u'عداه', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'عدا'}],

 u'فبجنبكم': [{'vocalized': u'فبجنبكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'عداك': [{'vocalized': u'عداك', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'عدا'}],

 u'فبجنبكن': [{'vocalized': u'فبجنبكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'فبتلك': [{'vocalized': u'فبتلك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'وبمثلهن': [{'vocalized': u'وبمثلهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'وبمثلهم': [{'vocalized': u'وبمثلهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'ولوما': [{'vocalized': u'ولوما', 'procletic': u'و-', 'tags': u'حرف;الحروف(حروف);عطف', 'stem': u'لوما', 'encletic': u'', 'type': u'حرف', 'original': u'لوما'}],

 u'أفهنالك': [{'vocalized': u'أفهنالك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فنفس': [{'vocalized': u'فنفس', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فكأثناءه': [{'vocalized': u'فكأثناءه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلذاتهم': [{'vocalized': u'فلذاتهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'فلذاتهن': [{'vocalized': u'فلذاتهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'أببعضنا': [{'vocalized': u'أببعضنا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'فسبحان': [{'vocalized': u'فسبحان', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'سبحان', 'encletic': u'', 'type': u'اسم', 'original': u'سبحان'}],

 u'وفوقكم': [{'vocalized': u'وفوقكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'ولخلفكن': [{'vocalized': u'ولخلفكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'فعنكما': [{'vocalized': u'فعنكما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'وكأنما': [{'vocalized': u'وكأنما', 'procletic': u'و-', 'tags': u'حرف;حرف تشبيه;عطف', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'ككلنا': [{'vocalized': u'ككلنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلنا', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أفهذان': [{'vocalized': u'أفهذان', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هذان', 'encletic': u'', 'type': u'اسم', 'original': u'هذان'}],

 u'لدني': [{'vocalized': u'لدني', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدن'},
 {'vocalized': u'لدني', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لدن'}],

 u'أوأجمعكن': [{'vocalized': u'أوأجمعكن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أومثل': [{'vocalized': u'أومثل', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'فكليكما': [{'vocalized': u'فكليكما', 'procletic': u'ف-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أفعليهما': [{'vocalized': u'أفعليهما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'وبعين': [{'vocalized': u'وبعين', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'جنوبه': [{'vocalized': u'جنوبه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفيمين': [{'vocalized': u'أفيمين', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'أوثم': [{'vocalized': u'أوثم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ثم', 'encletic': u'', 'type': u'اسم', 'original': u'ثم'}],

 u'فلفيهن': [{'vocalized': u'فلفيهن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'بسويها': [{'vocalized': u'بسويها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'فليمينكن': [{'vocalized': u'فليمينكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'أوخلف': [{'vocalized': u'أوخلف', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'لخلفه': [{'vocalized': u'لخلفه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفه', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'كزمانكن': [{'vocalized': u'كزمانكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'لأقلي': [{'vocalized': u'لأقلي', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'لأقلي', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'فلازلتن': [{'vocalized': u'فلازلتن', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتن'}],

 u'لأقله': [{'vocalized': u'لأقله', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'ولعامتكما': [{'vocalized': u'ولعامتكما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'لأقلك': [{'vocalized': u'لأقلك', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'أكنحوكم': [{'vocalized': u'أكنحوكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أكنحوكن': [{'vocalized': u'أكنحوكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'فبأيتهما': [{'vocalized': u'فبأيتهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'وذووكما': [{'vocalized': u'وذووكما', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوو'}],

 u'خلاهما': [{'vocalized': u'خلاهما', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'خلا'}],

 u'فعامتكن': [{'vocalized': u'فعامتكن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أفيمينكن': [{'vocalized': u'أفيمينكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'أفيمينكم': [{'vocalized': u'أفيمينكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'علينا': [{'vocalized': u'علينا', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'فأبيكم': [{'vocalized': u'فأبيكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'فكوقتنا': [{'vocalized': u'فكوقتنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'فأبيكن': [{'vocalized': u'فأبيكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'كأخيي': [{'vocalized': u'كأخيي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'كأخيي', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'أوبجميعكما': [{'vocalized': u'أوبجميعكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أوتحتهما': [{'vocalized': u'أوتحتهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'وبالألاء': [{'vocalized': u'وبالألاء', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'بأعليكم': [{'vocalized': u'بأعليكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'بأعليكن': [{'vocalized': u'بأعليكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'وبأخيكن': [{'vocalized': u'وبأخيكن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'كأخيه': [{'vocalized': u'كأخيه', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'فلأية': [{'vocalized': u'فلأية', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'تلقاءها': [{'vocalized': u'تلقاءها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فكبعض': [{'vocalized': u'فكبعض', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'ولنحوكما': [{'vocalized': u'ولنحوكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'بسويهن': [{'vocalized': u'بسويهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'فكذلكن': [{'vocalized': u'فكذلكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'فكذلكم': [{'vocalized': u'فكذلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'بسويهم': [{'vocalized': u'بسويهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكجميعكن': [{'vocalized': u'أوكجميعكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'وزماني': [{'vocalized': u'وزماني', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'وزماني', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'أوكجميعكم': [{'vocalized': u'أوكجميعكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'وحول': [{'vocalized': u'وحول', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'حول', 'encletic': u'', 'type': u'اسم', 'original': u'حول'}],

 u'ولنفسك': [{'vocalized': u'ولنفسك', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'فلغروبهن': [{'vocalized': u'فلغروبهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'ولنفسي': [{'vocalized': u'ولنفسي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'فأبونا': [{'vocalized': u'فأبونا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبو'}],

 u'فكابن': [{'vocalized': u'فكابن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'أتلكما': [{'vocalized': u'أتلكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'أولشمال': [{'vocalized': u'أولشمال', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'وبلحظته': [{'vocalized': u'وبلحظته', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفبنحوي': [{'vocalized': u'أفبنحوي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أفبنحوي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'وذلكم': [{'vocalized': u'وذلكم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'وذلكن': [{'vocalized': u'وذلكن', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'وبذات': [{'vocalized': u'وبذات', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'أفبنحوك': [{'vocalized': u'أفبنحوك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'لحميها': [{'vocalized': u'لحميها', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'أفبنحوه': [{'vocalized': u'أفبنحوه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'لأجمعهم': [{'vocalized': u'لأجمعهم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'وعداكما': [{'vocalized': u'وعداكما', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'عدا'}],

 u'فلأبيهما': [{'vocalized': u'فلأبيهما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'أبضعك': [{'vocalized': u'أبضعك', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بضع'}],

 u'فلشهركن': [{'vocalized': u'فلشهركن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'فلشهركم': [{'vocalized': u'فلشهركم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'لأسفلك': [{'vocalized': u'لأسفلك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'لحميهن': [{'vocalized': u'لحميهن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'لحميهم': [{'vocalized': u'لحميهم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'وزمانه': [{'vocalized': u'وزمانه', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'لأجمعها': [{'vocalized': u'لأجمعها', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'سبحان': [{'vocalized': u'سبحان', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'سبحان', 'encletic': u'', 'type': u'اسم', 'original': u'سبحان'}],

 u'فلفيها': [{'vocalized': u'فلفيها', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'أفخلف': [{'vocalized': u'أفخلف', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'وكجنوبكما': [{'vocalized': u'وكجنوبكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'ألأناكم': [{'vocalized': u'ألأناكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'فشمالك': [{'vocalized': u'فشمالك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'ولغيرنا': [{'vocalized': u'ولغيرنا', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغيرنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'وليتهما': [{'vocalized': u'وليتهما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-هما', 'type': u'حرف', 'original': u'ليت'}],

 u'أباي': [{'vocalized': u'أباي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبا'},
 {'vocalized': u'أباي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبا'}],

 u'ولذاتك': [{'vocalized': u'ولذاتك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'حمونا': [{'vocalized': u'حمونا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمو'}],

 u'كأخيكما': [{'vocalized': u'كأخيكما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'أباك': [{'vocalized': u'أباك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبا'}],

 u'ولذاتي': [{'vocalized': u'ولذاتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'ولذاتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'أباه': [{'vocalized': u'أباه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبا'}],

 u'وإيه': [{'vocalized': u'وإيه', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إيه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إيه'}],

 u'أولفوق': [{'vocalized': u'أولفوق', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'وأنشأ': [{'vocalized': u'وأنشأ', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أنشأ', 'encletic': u'', 'type': u'فعل', 'original': u'أنشأ'}],

 u'ولأبيك': [{'vocalized': u'ولأبيك', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'وكالتي': [{'vocalized': u'وكالتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'ولأبيه': [{'vocalized': u'ولأبيه', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'وبلحظتكما': [{'vocalized': u'وبلحظتكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'ولذاتهما': [{'vocalized': u'ولذاتهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'أفغيرنا': [{'vocalized': u'أفغيرنا', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فأجمعه': [{'vocalized': u'فأجمعه', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'كحسبكما': [{'vocalized': u'كحسبكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبعامتي': [{'vocalized': u'أوبعامتي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أوبعامتي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'أوبعامته': [{'vocalized': u'أوبعامته', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'فككلكما': [{'vocalized': u'فككلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'أوبعامتك': [{'vocalized': u'أوبعامتك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'أوكأنها': [{'vocalized': u'أوكأنها', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'كاد': [{'vocalized': u'كاد', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'كاد', 'encletic': u'', 'type': u'فعل', 'original': u'كاد'}],

 u'أوليميننا': [{'vocalized': u'أوليميننا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'فجنوبكما': [{'vocalized': u'فجنوبكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'فكليلهما': [{'vocalized': u'فكليلهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'وتحتكم': [{'vocalized': u'وتحتكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'وتحتكن': [{'vocalized': u'وتحتكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'أبعينكما': [{'vocalized': u'أبعينكما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فكأيتكن': [{'vocalized': u'فكأيتكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'كأنكم': [{'vocalized': u'كأنكم', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنكم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'كأنكن': [{'vocalized': u'كأنكن', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنكن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'بابنهما': [{'vocalized': u'بابنهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'فكجنبنا': [{'vocalized': u'فكجنبنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'فلشمالنا': [{'vocalized': u'فلشمالنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'فمننا': [{'vocalized': u'فمننا', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'فلطالما': [{'vocalized': u'فلطالما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'ولمنكما': [{'vocalized': u'ولمنكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'فبفيكم': [{'vocalized': u'فبفيكم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'}],

 u'فبفيكن': [{'vocalized': u'فبفيكن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'}],

 u'أجمعهما': [{'vocalized': u'أجمعهما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكلحظتهما': [{'vocalized': u'فكلحظتهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'لحسب': [{'vocalized': u'لحسب', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أإليكم': [{'vocalized': u'أإليكم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'أولمثلنا': [{'vocalized': u'أولمثلنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'خ': [{'vocalized': u'خ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'خ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'خ'}],

 u'أفأولئكم': [{'vocalized': u'أفأولئكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'فبأجمع': [{'vocalized': u'فبأجمع', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'بجنبكم': [{'vocalized': u'بجنبكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'فلشرق': [{'vocalized': u'فلشرق', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'بجنبكن': [{'vocalized': u'بجنبكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'بل': [{'vocalized': u'بل', 'procletic': u'', 'tags': u'حرف;حرف عطف منفصل', 'stem': u'بل', 'encletic': u'', 'type': u'حرف', 'original': u'بل'}],

 u'فبعدهما': [{'vocalized': u'فبعدهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعد'}],

 u'أوبعض': [{'vocalized': u'أوبعض', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'أوكأنهم': [{'vocalized': u'أوكأنهم', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'أوكأنهن': [{'vocalized': u'أوكأنهن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'ولأناك': [{'vocalized': u'ولأناك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'فبغير': [{'vocalized': u'فبغير', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'ووراء': [{'vocalized': u'ووراء', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'بشبههم': [{'vocalized': u'بشبههم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'بشبههن': [{'vocalized': u'بشبههن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'فلشمالكما': [{'vocalized': u'فلشمالكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'لأجمع': [{'vocalized': u'لأجمع', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمع', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'فخلالكما': [{'vocalized': u'فخلالكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلال'}],

 u'كأيهم': [{'vocalized': u'كأيهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'كأيهن': [{'vocalized': u'كأيهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'أفلذلكما': [{'vocalized': u'أفلذلكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'فبإن': [{'vocalized': u'فبإن', 'procletic': u'ف-ب-', 'tags': u'حرف;المشبهة بليس;مجرور;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'أفبجميعهن': [{'vocalized': u'أفبجميعهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'أفبجميعهم': [{'vocalized': u'أفبجميعهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'وكأكثرك': [{'vocalized': u'وكأكثرك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'فسبحانكن': [{'vocalized': u'فسبحانكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سبحان'}],

 u'فسبحانكم': [{'vocalized': u'فسبحانكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سبحان'}],

 u'وكأكثره': [{'vocalized': u'وكأكثره', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكزمانكن': [{'vocalized': u'فكزمانكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'وكأكثري': [{'vocalized': u'وكأكثري', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'وكأكثري', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولحظتكم': [{'vocalized': u'ولحظتكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'كشرقه': [{'vocalized': u'كشرقه', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'ولحظتكن': [{'vocalized': u'ولحظتكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'ضمن': [{'vocalized': u'ضمن', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'ضمن', 'encletic': u'', 'type': u'اسم', 'original': u'ضمن'}],

 u'أإليكن': [{'vocalized': u'أإليكن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'فللحظتكم': [{'vocalized': u'فللحظتكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبأسفله': [{'vocalized': u'فبأسفله', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'فللحظتكن': [{'vocalized': u'فللحظتكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'أيكن': [{'vocalized': u'أيكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'فبأسفلك': [{'vocalized': u'فبأسفلك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'أيكم': [{'vocalized': u'أيكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'ومابرح': [{'vocalized': u'ومابرح', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرح', 'encletic': u'', 'type': u'فعل', 'original': u'مابرح'}],

 u'فبعدما': [{'vocalized': u'فبعدما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بعدما', 'encletic': u'', 'type': u'اسم', 'original': u'بعدما'}],

 u'أوفيهما': [{'vocalized': u'أوفيهما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'وحاشا': [{'vocalized': u'وحاشا', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف', 'stem': u'حاشا', 'encletic': u'', 'type': u'فعل', 'original': u'حاشا'}],

 u'فممن': [{'vocalized': u'فممن', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'ممن', 'encletic': u'', 'type': u'اسم', 'original': u'ممن'}],

 u'أجمعكما': [{'vocalized': u'أجمعكما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ووراءك': [{'vocalized': u'ووراءك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'فبنفسكن': [{'vocalized': u'فبنفسكن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'كشهركما': [{'vocalized': u'كشهركما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'أحسب': [{'vocalized': u'أحسب', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أوكعينهما': [{'vocalized': u'أوكعينهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فلوراء': [{'vocalized': u'فلوراء', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'ومازالتا': [{'vocalized': u'ومازالتا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالتا'}],

 u'فحينهم': [{'vocalized': u'فحينهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حين'}],

 u'وغيرنا': [{'vocalized': u'وغيرنا', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'بشبهها': [{'vocalized': u'بشبهها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'وخلاله': [{'vocalized': u'وخلاله', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلال'}],

 u'بنفسهما': [{'vocalized': u'بنفسهما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'كأيها': [{'vocalized': u'كأيها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'كوقتي': [{'vocalized': u'كوقتي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'كوقتي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'بخ': [{'vocalized': u'بخ', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'بخ', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بخ'}],

 u'بأثناءهما': [{'vocalized': u'بأثناءهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'فحينهن': [{'vocalized': u'فحينهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حين'}],

 u'أفبجميعها': [{'vocalized': u'أفبجميعها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'فكهؤلاء': [{'vocalized': u'فكهؤلاء', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'أفلأجمع': [{'vocalized': u'أفلأجمع', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمع', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'فبأثناءي': [{'vocalized': u'فبأثناءي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'فبأثناءي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'فبأثناءه': [{'vocalized': u'فبأثناءه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'فبأثناءك': [{'vocalized': u'فبأثناءك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'بدونها': [{'vocalized': u'بدونها', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بدون'}],

 u'فلشمالكن': [{'vocalized': u'فلشمالكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'عندما': [{'vocalized': u'عندما', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'عندما', 'encletic': u'', 'type': u'اسم', 'original': u'عندما'}],

 u'وبجنبها': [{'vocalized': u'وبجنبها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'أوهما': [{'vocalized': u'أوهما', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'ألحسبي': [{'vocalized': u'ألحسبي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'ألحسبي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'فبذينك': [{'vocalized': u'فبذينك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'فلشمالكم': [{'vocalized': u'فلشمالكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'أفكبعض': [{'vocalized': u'أفكبعض', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'ألحسبك': [{'vocalized': u'ألحسبك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'ألإليها': [{'vocalized': u'ألإليها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'ولجنوبهم': [{'vocalized': u'ولجنوبهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'ألحسبه': [{'vocalized': u'ألحسبه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أفكعيني': [{'vocalized': u'أفكعيني', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفكعيني', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وبتلكم': [{'vocalized': u'وبتلكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'إذا': [{'vocalized': u'إذا', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'إذا', 'encletic': u'', 'type': u'اسم', 'original': u'إذا'},
 {'vocalized': u'إذا', 'procletic': u'', 'tags': u'حرف;اسم شرط', 'stem': u'إذا', 'encletic': u'', 'type': u'حرف', 'original': u'إذا'}],

 u'ولحسبهما': [{'vocalized': u'ولحسبهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أفكنفسهن': [{'vocalized': u'أفكنفسهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'وككلهما': [{'vocalized': u'وككلهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككلهما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'أفكنفسهم': [{'vocalized': u'أفكنفسهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'أففوقكم': [{'vocalized': u'أففوقكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'أففوقكن': [{'vocalized': u'أففوقكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'ألإليهن': [{'vocalized': u'ألإليهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'أفبسويكما': [{'vocalized': u'أفبسويكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ألإليهم': [{'vocalized': u'ألإليهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'أنشأ': [{'vocalized': u'أنشأ', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'أنشأ', 'encletic': u'', 'type': u'فعل', 'original': u'أنشأ'}],

 u'حمانا': [{'vocalized': u'حمانا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حما'}],

 u'جنبك': [{'vocalized': u'جنبك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'وجنبكم': [{'vocalized': u'وجنبكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'فلفيكما': [{'vocalized': u'فلفيكما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'وجنبكن': [{'vocalized': u'وجنبكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'أوككليكما': [{'vocalized': u'أوككليكما', 'procletic': u'أ-و-ك-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'لعنكم': [{'vocalized': u'لعنكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'لعنكن': [{'vocalized': u'لعنكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'بعامتكما': [{'vocalized': u'بعامتكما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'شهر': [{'vocalized': u'شهر', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'بدونهن': [{'vocalized': u'بدونهن', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بدون'}],

 u'ليتكما': [{'vocalized': u'ليتكما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-كما', 'type': u'حرف', 'original': u'ليت'}],

 u'فكخلف': [{'vocalized': u'فكخلف', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'ألنحوهما': [{'vocalized': u'ألنحوهما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'وبجنبهم': [{'vocalized': u'وبجنبهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'وبجنبهن': [{'vocalized': u'وبجنبهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'أغيري': [{'vocalized': u'أغيري', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أغيري', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أغيره': [{'vocalized': u'أغيره', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أغيرك': [{'vocalized': u'أغيرك', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'ذويك': [{'vocalized': u'ذويك', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'ذويه': [{'vocalized': u'ذويه', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'ذويي': [{'vocalized': u'ذويي', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'ذويي', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'أونفسهما': [{'vocalized': u'أونفسهما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'أوعين': [{'vocalized': u'أوعين', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'وبك': [{'vocalized': u'وبك', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بك', 'encletic': u'', 'type': u'ضمير', 'original': u'بك'}],

 u'وكتلقاءي': [{'vocalized': u'وكتلقاءي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'وكتلقاءي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكتلقاءها': [{'vocalized': u'وكتلقاءها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبه': [{'vocalized': u'وبه', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'به', 'encletic': u'', 'type': u'ضمير', 'original': u'به'}],

 u'وابتدأ': [{'vocalized': u'وابتدأ', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'ابتدأ', 'encletic': u'', 'type': u'فعل', 'original': u'ابتدأ'}],

 u'وكتلقاءك': [{'vocalized': u'وكتلقاءك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبي': [{'vocalized': u'وبي', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بي', 'encletic': u'', 'type': u'ضمير', 'original': u'بي'}],

 u'وكتلقاءه': [{'vocalized': u'وكتلقاءه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فلأجمعهن': [{'vocalized': u'فلأجمعهن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبأعلي': [{'vocalized': u'وبأعلي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'وبأعلي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'كابنه': [{'vocalized': u'كابنه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'وبأعلى': [{'vocalized': u'وبأعلى', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبهذه': [{'vocalized': u'فبهذه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'كابنك': [{'vocalized': u'كابنك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'لات': [{'vocalized': u'لات', 'procletic': u'', 'tags': u'حرف;المشبهة بليس', 'stem': u'لات', 'encletic': u'', 'type': u'حرف', 'original': u'لات'}],

 u'فبهذي': [{'vocalized': u'فبهذي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'أونحوه': [{'vocalized': u'أونحوه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'كابني': [{'vocalized': u'كابني', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'كابني', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'ولوقتكم': [{'vocalized': u'ولوقتكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'فيها': [{'vocalized': u'فيها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيها', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'ألمعكم': [{'vocalized': u'ألمعكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'ألمعكن': [{'vocalized': u'ألمعكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'وخلفنا': [{'vocalized': u'وخلفنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'كشطر': [{'vocalized': u'كشطر', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'أفليمينكم': [{'vocalized': u'أفليمينكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'فبهذا': [{'vocalized': u'فبهذا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'وبعض': [{'vocalized': u'وبعض', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'فلجنوبها': [{'vocalized': u'فلجنوبها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'وكجميعهم': [{'vocalized': u'وكجميعهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعهم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'وكجميعهن': [{'vocalized': u'وكجميعهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعهن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'ولأثناء': [{'vocalized': u'ولأثناء', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'وبعد': [{'vocalized': u'وبعد', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بعد', 'encletic': u'', 'type': u'اسم', 'original': u'بعد'}],

 u'أولعينه': [{'vocalized': u'أولعينه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'لأكثرك': [{'vocalized': u'لأكثرك', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'فيهم': [{'vocalized': u'فيهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيهم', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'أككلي': [{'vocalized': u'أككلي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'لأكثره': [{'vocalized': u'لأكثره', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'وكي': [{'vocalized': u'وكي', 'procletic': u'و-', 'tags': u'حرف;تعليل;عطف', 'stem': u'كي', 'encletic': u'', 'type': u'حرف', 'original': u'كي'}],

 u'لأكثري': [{'vocalized': u'لأكثري', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'لأكثري', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'أككله': [{'vocalized': u'أككله', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككله', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'أوأولالك': [{'vocalized': u'أوأولالك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فشتان': [{'vocalized': u'فشتان', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'شتان', 'encletic': u'', 'type': u'اسم فعل', 'original': u'شتان'}],

 u'أككلك': [{'vocalized': u'أككلك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلك', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'وبس': [{'vocalized': u'وبس', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بس', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بس'}],

 u'لكأنكما': [{'vocalized': u'لكأنكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'عدا': [{'vocalized': u'عدا', 'procletic': u'', 'tags': u'فعل;حرف استثناء', 'stem': u'عدا', 'encletic': u'', 'type': u'فعل', 'original': u'عدا'}],

 u'وكتلقاءهم': [{'vocalized': u'وكتلقاءهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكتلقاءهن': [{'vocalized': u'وكتلقاءهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفككلتا': [{'vocalized': u'أفككلتا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'وكأيتي': [{'vocalized': u'وكأيتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'وكأيتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'وكأيته': [{'vocalized': u'وكأيته', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'عدس': [{'vocalized': u'عدس', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'عدس', 'encletic': u'', 'type': u'اسم فعل', 'original': u'عدس'}],

 u'وبخ': [{'vocalized': u'وبخ', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بخ', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بخ'}],

 u'فلأجمعها': [{'vocalized': u'فلأجمعها', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبله': [{'vocalized': u'وبله', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بله', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بله'}],

 u'وشهركن': [{'vocalized': u'وشهركن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'وشهركم': [{'vocalized': u'وشهركم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'ت': [{'vocalized': u'ت', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ت', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ت'}],

 u'فكشطرهن': [{'vocalized': u'فكشطرهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'فكعينكن': [{'vocalized': u'فكعينكن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فكعينكم': [{'vocalized': u'فكعينكم', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'فكشطرهم': [{'vocalized': u'فكشطرهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'أفجميعكما': [{'vocalized': u'أفجميعكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعكما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أوراءهما': [{'vocalized': u'أوراءهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'فكابنكما': [{'vocalized': u'فكابنكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'أكنفسكما': [{'vocalized': u'أكنفسكما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'وكأنكن': [{'vocalized': u'وكأنكن', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنكن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'وكأنكم': [{'vocalized': u'وكأنكم', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنكم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'فعامتكما': [{'vocalized': u'فعامتكما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'ولوقتها': [{'vocalized': u'ولوقتها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'وأكثرها': [{'vocalized': u'وأكثرها', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفلأجمعه': [{'vocalized': u'أفلأجمعه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلجنوبكم': [{'vocalized': u'فلجنوبكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'فلجنوبكن': [{'vocalized': u'فلجنوبكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'بطآن': [{'vocalized': u'بطآن', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'بطآن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بطآن'}],

 u'أفلبعضهم': [{'vocalized': u'أفلبعضهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلبعضهن': [{'vocalized': u'أفلبعضهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفككلها': [{'vocalized': u'أفككلها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'فأجمعنا': [{'vocalized': u'فأجمعنا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'وسبحانهم': [{'vocalized': u'وسبحانهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سبحان'}],

 u'وسبحانهن': [{'vocalized': u'وسبحانهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سبحان'}],

 u'فلتحتها': [{'vocalized': u'فلتحتها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'أومثلهم': [{'vocalized': u'أومثلهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أإليها': [{'vocalized': u'أإليها', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'أومثلهن': [{'vocalized': u'أومثلهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'أكجميعه': [{'vocalized': u'أكجميعه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعه', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'شرقكما': [{'vocalized': u'شرقكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'أفلأجمعي': [{'vocalized': u'أفلأجمعي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكجميعك': [{'vocalized': u'أكجميعك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعك', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'ذويها': [{'vocalized': u'ذويها', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'ولمعهما': [{'vocalized': u'ولمعهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'أبعضنا': [{'vocalized': u'أبعضنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'أكجميعي': [{'vocalized': u'أكجميعي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعي', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أففوقي': [{'vocalized': u'أففوقي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'أففوقي', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'أفككلهم': [{'vocalized': u'أفككلهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أفككلهن': [{'vocalized': u'أفككلهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أفلبعضها': [{'vocalized': u'أفلبعضها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'فلتحتهم': [{'vocalized': u'فلتحتهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'أولهؤلاء': [{'vocalized': u'أولهؤلاء', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'وسبحانها': [{'vocalized': u'وسبحانها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سبحان'}],

 u'أومثلها': [{'vocalized': u'أومثلها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'فأيتنا': [{'vocalized': u'فأيتنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'فكشطرها': [{'vocalized': u'فكشطرها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'لكلكما': [{'vocalized': u'لكلكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فعداهما': [{'vocalized': u'فعداهما', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'عدا'}],

 u'وإذما': [{'vocalized': u'وإذما', 'procletic': u'و-', 'tags': u'حرف;حرف شرط;عطف', 'stem': u'إذما', 'encletic': u'', 'type': u'حرف', 'original': u'إذما'}],

 u'فأمامهن': [{'vocalized': u'فأمامهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'فأمامهم': [{'vocalized': u'فأمامهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'فتلقاء': [{'vocalized': u'فتلقاء', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولوقتهن': [{'vocalized': u'ولوقتهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'وأكثرهم': [{'vocalized': u'وأكثرهم', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'وأكثرهن': [{'vocalized': u'وأكثرهن', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولوقتهم': [{'vocalized': u'ولوقتهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'لجنبي': [{'vocalized': u'لجنبي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'لجنبي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'ولظل': [{'vocalized': u'ولظل', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'ظل', 'encletic': u'', 'type': u'فعل', 'original': u'ظل'}],

 u'ولأبيهن': [{'vocalized': u'ولأبيهن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'لجنبك': [{'vocalized': u'لجنبك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'ذاتكن': [{'vocalized': u'ذاتكن', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'ذاتكم': [{'vocalized': u'ذاتكم', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'لجنبه': [{'vocalized': u'لجنبه', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'وبأنهم': [{'vocalized': u'وبأنهم', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'وبأنهن': [{'vocalized': u'وبأنهن', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'فإنا': [{'vocalized': u'فإنا', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'فأنكن': [{'vocalized': u'فأنكن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'مادمتما': [{'vocalized': u'مادمتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمتما', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتما'},
 {'vocalized': u'مادمتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمتما', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتما'}],

 u'فتلقاءهم': [{'vocalized': u'فتلقاءهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'بليلها': [{'vocalized': u'بليلها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'أأولئك': [{'vocalized': u'أأولئك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'فمرة': [{'vocalized': u'فمرة', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'مرة', 'encletic': u'', 'type': u'اسم', 'original': u'مرة'}],

 u'كشهرهم': [{'vocalized': u'كشهرهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'مابرحنا': [{'vocalized': u'مابرحنا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحنا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحنا'}],

 u'فليل': [{'vocalized': u'فليل', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'أوبنحوهما': [{'vocalized': u'أوبنحوهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'ء': [{'vocalized': u'ء', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ء', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ء'}],

 u'وكأبيكما': [{'vocalized': u'وكأبيكما', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'فشهرهما': [{'vocalized': u'فشهرهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'أبأجمعهما': [{'vocalized': u'أبأجمعهما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فبذويهما': [{'vocalized': u'فبذويهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'فبكلكما': [{'vocalized': u'فبكلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فحاشاهم': [{'vocalized': u'فحاشاهم', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'حاشا'}],

 u'حولكما': [{'vocalized': u'حولكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حول'}],

 u'أوفيك': [{'vocalized': u'أوفيك', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'ولكم': [{'vocalized': u'ولكم', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لكم', 'encletic': u'', 'type': u'ضمير', 'original': u'لكم'}],

 u'ولكل': [{'vocalized': u'ولكل', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكل', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكل', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكل', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'أوفيه': [{'vocalized': u'أوفيه', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'ولكن': [{'vocalized': u'ولكن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'لكن', 'encletic': u'', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكن', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف', 'stem': u'لكن', 'encletic': u'', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكن', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لكن', 'encletic': u'', 'type': u'ضمير', 'original': u'لكن'}],

 u'تينك': [{'vocalized': u'تينك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'وساعتهما': [{'vocalized': u'وساعتهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفكعينكن': [{'vocalized': u'أفكعينكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فيهن': [{'vocalized': u'فيهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيهن', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'أولكلهما': [{'vocalized': u'أولكلهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'أولازالوا': [{'vocalized': u'أولازالوا', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالوا'}],

 u'فعل': [{'vocalized': u'فعل', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'عل', 'encletic': u'', 'type': u'حرف', 'original': u'عل'}],

 u'فليس': [{'vocalized': u'فليس', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليس', 'encletic': u'', 'type': u'فعل', 'original': u'ليس'}],

 u'فعن': [{'vocalized': u'فعن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'ذانك': [{'vocalized': u'ذانك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'وبأنها': [{'vocalized': u'وبأنها', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'أوببعضه': [{'vocalized': u'أوببعضه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'فتلقاءها': [{'vocalized': u'فتلقاءها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولحمينا': [{'vocalized': u'ولحمينا', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'فليت': [{'vocalized': u'فليت', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'ليت', 'encletic': u'', 'type': u'حرف', 'original': u'ليت'}],

 u'أوببعضك': [{'vocalized': u'أوببعضك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فعني': [{'vocalized': u'فعني', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'فعني', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'فلأقلكما': [{'vocalized': u'فلأقلكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'أوعامتكما': [{'vocalized': u'أوعامتكما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'فعنه': [{'vocalized': u'فعنه', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'أوببعضي': [{'vocalized': u'أوببعضي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أوببعضي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فعنك': [{'vocalized': u'فعنك', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'أكسويكم': [{'vocalized': u'أكسويكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أولأناه': [{'vocalized': u'أولأناه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'أكسويكن': [{'vocalized': u'أكسويكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أولأناك': [{'vocalized': u'أولأناك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'فليتها': [{'vocalized': u'فليتها', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-ها', 'type': u'حرف', 'original': u'ليت'}],

 u'وغروبه': [{'vocalized': u'وغروبه', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'حميها': [{'vocalized': u'حميها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'وبين': [{'vocalized': u'وبين', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'بين', 'encletic': u'', 'type': u'اسم', 'original': u'بين'}],

 u'أوكأجمعكن': [{'vocalized': u'أوكأجمعكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوكأجمعكم': [{'vocalized': u'أوكأجمعكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولكأنهن': [{'vocalized': u'ولكأنهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'أوعلي': [{'vocalized': u'أوعلي', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أوعلي', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'أوعلى': [{'vocalized': u'أوعلى', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'ولكأنهم': [{'vocalized': u'ولكأنهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'وبأكثري': [{'vocalized': u'وبأكثري', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'وبأكثري', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'زمان': [{'vocalized': u'زمان', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'فلحظتهم': [{'vocalized': u'فلحظتهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبأكثره': [{'vocalized': u'وبأكثره', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلدنها': [{'vocalized': u'فلدنها', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدن'}],

 u'وبأكثرك': [{'vocalized': u'وبأكثرك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'أبجميعي': [{'vocalized': u'أبجميعي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أفبضعكما': [{'vocalized': u'أفبضعكما', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بضع'}],

 u'وأمامها': [{'vocalized': u'وأمامها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'أبجميعك': [{'vocalized': u'أبجميعك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعك', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أوكتينك': [{'vocalized': u'أوكتينك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'كذويها': [{'vocalized': u'كذويها', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'أبجميعه': [{'vocalized': u'أبجميعه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعه', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'وعليهن': [{'vocalized': u'وعليهن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'وعامتكن': [{'vocalized': u'وعامتكن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'وعامتكم': [{'vocalized': u'وعامتكم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أكجميعهما': [{'vocalized': u'أكجميعهما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعهما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'لازلتم': [{'vocalized': u'لازلتم', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتم'}],

 u'فكلحظتك': [{'vocalized': u'فكلحظتك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفبعضك': [{'vocalized': u'أفبعضك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فلشهركما': [{'vocalized': u'فلشهركما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'أفبعضه': [{'vocalized': u'أفبعضه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'كذويهم': [{'vocalized': u'كذويهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'كذويهن': [{'vocalized': u'كذويهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفبعضي': [{'vocalized': u'أفبعضي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفبعضي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'أبكليكما': [{'vocalized': u'أبكليكما', 'procletic': u'أ-ب-', 'tags': u'حرف;توكيد;مجرور;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'للألاء': [{'vocalized': u'للألاء', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'أولتحتي': [{'vocalized': u'أولتحتي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'أولتحتي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلعامتنا': [{'vocalized': u'أفلعامتنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'ارتد': [{'vocalized': u'ارتد', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ارتد', 'encletic': u'', 'type': u'فعل', 'original': u'ارتد'}],

 u'فكزمانهما': [{'vocalized': u'فكزمانهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'وبابنه': [{'vocalized': u'وبابنه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'وبيد': [{'vocalized': u'وبيد', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف', 'stem': u'بيد', 'encletic': u'', 'type': u'اسم', 'original': u'بيد'}],

 u'وبابنك': [{'vocalized': u'وبابنك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'حميهم': [{'vocalized': u'حميهم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'حميهن': [{'vocalized': u'حميهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'لأسفلنا': [{'vocalized': u'لأسفلنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'أولئكم': [{'vocalized': u'أولئكم', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'وبابني': [{'vocalized': u'وبابني', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'وبابني', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'وبخلفه': [{'vocalized': u'وبخلفه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'ولكأنها': [{'vocalized': u'ولكأنها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'وبخلفك': [{'vocalized': u'وبخلفك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'بلحظة': [{'vocalized': u'بلحظة', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'أباكما': [{'vocalized': u'أباكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبا'}],

 u'فلحظتها': [{'vocalized': u'فلحظتها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلدنهن': [{'vocalized': u'فلدنهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدن'}],

 u'فلدنهم': [{'vocalized': u'فلدنهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدن'}],

 u'ولبعضنا': [{'vocalized': u'ولبعضنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'أفشمالها': [{'vocalized': u'أفشمالها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'أخاهما': [{'vocalized': u'أخاهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخا'}],

 u'ولدينا': [{'vocalized': u'ولدينا', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدى'}],

 u'فأكثرهما': [{'vocalized': u'فأكثرهما', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'وأعليكما': [{'vocalized': u'وأعليكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فللاتي': [{'vocalized': u'فللاتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'أولشبهه': [{'vocalized': u'أولشبهه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'بذات': [{'vocalized': u'بذات', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'ألأمامكما': [{'vocalized': u'ألأمامكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'أولتحته': [{'vocalized': u'أولتحته', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'أولشبهك': [{'vocalized': u'أولشبهك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'فأعليكما': [{'vocalized': u'فأعليكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'أولشبهي': [{'vocalized': u'أولشبهي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'وآمين': [{'vocalized': u'وآمين', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'آمين', 'encletic': u'', 'type': u'اسم فعل', 'original': u'آمين'}],

 u'أوأنانا': [{'vocalized': u'أوأنانا', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'بأسفلكما': [{'vocalized': u'بأسفلكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أنحوكن': [{'vocalized': u'أنحوكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'أنحوكم': [{'vocalized': u'أنحوكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أولأجمعه': [{'vocalized': u'أولأجمعه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولأجمعك': [{'vocalized': u'أولأجمعك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوتلكما': [{'vocalized': u'أوتلكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'أولأجمعي': [{'vocalized': u'أولأجمعي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'لأنتما': [{'vocalized': u'لأنتما', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'فبجنبهم': [{'vocalized': u'فبجنبهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'وعامته': [{'vocalized': u'وعامته', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'فبجنبهن': [{'vocalized': u'فبجنبهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'وعامتك': [{'vocalized': u'وعامتك', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'فعليهما': [{'vocalized': u'فعليهما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'لابنهما': [{'vocalized': u'لابنهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'ألشبهه': [{'vocalized': u'ألشبهه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'فلشرقكما': [{'vocalized': u'فلشرقكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'وكمثلنا': [{'vocalized': u'وكمثلنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'فلنحو': [{'vocalized': u'فلنحو', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحو', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'أكبعضهم': [{'vocalized': u'أكبعضهم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'أكبعضهن': [{'vocalized': u'أكبعضهن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'لعينكن': [{'vocalized': u'لعينكن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'بذاك': [{'vocalized': u'بذاك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'لعينكم': [{'vocalized': u'لعينكم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'فلذاتكم': [{'vocalized': u'فلذاتكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'فلذاتكن': [{'vocalized': u'فلذاتكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أفبغيركما': [{'vocalized': u'أفبغيركما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'ببعضك': [{'vocalized': u'ببعضك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'أولدى': [{'vocalized': u'أولدى', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام', 'stem': u'لدى', 'encletic': u'', 'type': u'اسم', 'original': u'لدى'}],

 u'أوكنفسها': [{'vocalized': u'أوكنفسها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'ببعضه': [{'vocalized': u'ببعضه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'فكم': [{'vocalized': u'فكم', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'كم', 'encletic': u'', 'type': u'اسم', 'original': u'كم'},
 {'vocalized': u'فكم', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'كم', 'encletic': u'', 'type': u'اسم', 'original': u'كم'}],

 u'فكل': [{'vocalized': u'فكل', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكل', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'ببعضي': [{'vocalized': u'ببعضي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ببعضي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فكي': [{'vocalized': u'فكي', 'procletic': u'ف-', 'tags': u'حرف;تعليل;عطف', 'stem': u'كي', 'encletic': u'', 'type': u'حرف', 'original': u'كي'}],

 u'أفكذلك': [{'vocalized': u'أفكذلك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'},
 {'vocalized': u'أفكذلك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'كذلك', 'encletic': u'', 'type': u'اسم', 'original': u'كذلك'}],

 u'وبذاك': [{'vocalized': u'وبذاك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'ولئن': [{'vocalized': u'ولئن', 'procletic': u'و-', 'tags': u'حرف;حرف شرط;عطف', 'stem': u'لئن', 'encletic': u'', 'type': u'حرف', 'original': u'لئن'}],

 u'ولوراءنا': [{'vocalized': u'ولوراءنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'لغربكما': [{'vocalized': u'لغربكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'أفكسويه': [{'vocalized': u'أفكسويه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أولعنهم': [{'vocalized': u'أولعنهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'أولعنهن': [{'vocalized': u'أولعنهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أفكسويك': [{'vocalized': u'أفكسويك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فلجنبكم': [{'vocalized': u'فلجنبكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنب'}],

 u'فلجنبكن': [{'vocalized': u'فلجنبكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنب'}],

 u'أوبسوينا': [{'vocalized': u'أوبسوينا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'فبجميعكم': [{'vocalized': u'فبجميعكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعكم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'فبجميعكن': [{'vocalized': u'فبجميعكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فبجميعكن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'لأية': [{'vocalized': u'لأية', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'بأقل': [{'vocalized': u'بأقل', 'procletic': u'ب-', 'tags': u'اسم;اسم تفضيل;مجرور', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'أخوكم': [{'vocalized': u'أخوكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخو'}],

 u'أخوكن': [{'vocalized': u'أخوكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخو'}],

 u'أولعنها': [{'vocalized': u'أولعنها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'فليلي': [{'vocalized': u'فليلي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'فليلي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'وكبعض': [{'vocalized': u'وكبعض', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'أوكعامتنا': [{'vocalized': u'أوكعامتنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'فليله': [{'vocalized': u'فليله', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'فلديكن': [{'vocalized': u'فلديكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدى'}],

 u'فلديكم': [{'vocalized': u'فلديكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدى'}],

 u'بنحوهما': [{'vocalized': u'بنحوهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'لأيك': [{'vocalized': u'لأيك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'ألأناكن': [{'vocalized': u'ألأناكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'مافتئا': [{'vocalized': u'مافتئا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئا'}],

 u'لأيه': [{'vocalized': u'لأيه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'لأيي': [{'vocalized': u'لأيي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'لأيي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'أعينه': [{'vocalized': u'أعينه', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'فلهاذين': [{'vocalized': u'فلهاذين', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'وببعضكن': [{'vocalized': u'وببعضكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'ألوراءكن': [{'vocalized': u'ألوراءكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'أوكنفسهن': [{'vocalized': u'أوكنفسهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'أوكنفسهم': [{'vocalized': u'أوكنفسهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'فمعكما': [{'vocalized': u'فمعكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'فبهما': [{'vocalized': u'فبهما', 'procletic': u'ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'كشهر': [{'vocalized': u'كشهر', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'بليلكم': [{'vocalized': u'بليلكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'وليسوا': [{'vocalized': u'وليسوا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليسوا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسوا'}],

 u'أفكذلكما': [{'vocalized': u'أفكذلكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'بجنبك': [{'vocalized': u'بجنبك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'ولنفسكم': [{'vocalized': u'ولنفسكم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'ولنفسكن': [{'vocalized': u'ولنفسكن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'فكلها': [{'vocalized': u'فكلها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلها', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'وحولك': [{'vocalized': u'وحولك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حول'}],

 u'فلعينك': [{'vocalized': u'فلعينك', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أفببعضكم': [{'vocalized': u'أفببعضكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفببعضكن': [{'vocalized': u'أفببعضكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'وحولي': [{'vocalized': u'وحولي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حول'},
 {'vocalized': u'وحولي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حول'}],

 u'ولشطرهن': [{'vocalized': u'ولشطرهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'ولشطرهم': [{'vocalized': u'ولشطرهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'أبشبهها': [{'vocalized': u'أبشبهها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'تجاههما': [{'vocalized': u'تجاههما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تجاه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تجاه'}],

 u'أبنحوكم': [{'vocalized': u'أبنحوكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أبنحوكن': [{'vocalized': u'أبنحوكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'وجنوبه': [{'vocalized': u'وجنوبه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفلنفسكما': [{'vocalized': u'أفلنفسكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'فكعامتهما': [{'vocalized': u'فكعامتهما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أفككلكما': [{'vocalized': u'أفككلكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فكأيتهما': [{'vocalized': u'فكأيتهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'أولخلفنا': [{'vocalized': u'أولخلفنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'أولفوقكما': [{'vocalized': u'أولفوقكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'فإما': [{'vocalized': u'فإما', 'procletic': u'ف-', 'tags': u'حرف;حرف تخيير وتفصيل;عطف', 'stem': u'إما', 'encletic': u'', 'type': u'حرف', 'original': u'إما'}],

 u'وكلهم': [{'vocalized': u'وكلهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلهم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'إياهما': [{'vocalized': u'إياهما', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياهما', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهما'}],

 u'وكلهن': [{'vocalized': u'وكلهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلهن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أبكما': [{'vocalized': u'أبكما', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'بكما', 'encletic': u'', 'type': u'ضمير', 'original': u'بكما'}],

 u'لمنهم': [{'vocalized': u'لمنهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'أوكلتا': [{'vocalized': u'أوكلتا', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أوكعينها': [{'vocalized': u'أوكعينها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فأيتك': [{'vocalized': u'فأيتك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'أفلعلكم': [{'vocalized': u'أفلعلكم', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لعل'}],

 u'أوأنت': [{'vocalized': u'أوأنت', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'أوأنت', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'فأيته': [{'vocalized': u'فأيته', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'أفلعلكن': [{'vocalized': u'أفلعلكن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لعل'}],

 u'فلتحتك': [{'vocalized': u'فلتحتك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلفيهم': [{'vocalized': u'أفلفيهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'أفلفيكم': [{'vocalized': u'أفلفيكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'فأثناءهن': [{'vocalized': u'فأثناءهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكلها': [{'vocalized': u'وكلها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلها', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'فلمثلنا': [{'vocalized': u'فلمثلنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'ولأمامنا': [{'vocalized': u'ولأمامنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'لمنها': [{'vocalized': u'لمنها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'لشرقهما': [{'vocalized': u'لشرقهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'أمثلي': [{'vocalized': u'أمثلي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أمثلي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أوكعينهم': [{'vocalized': u'أوكعينهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أوكعينهن': [{'vocalized': u'أوكعينهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'أمثله': [{'vocalized': u'أمثله', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'أبعامتكما': [{'vocalized': u'أبعامتكما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'فلأولئكم': [{'vocalized': u'فلأولئكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'أمثلك': [{'vocalized': u'أمثلك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أولديهن': [{'vocalized': u'أولديهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدى'}],

 u'فكلهم': [{'vocalized': u'فكلهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلهم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'فكلهن': [{'vocalized': u'فكلهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلهن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'فتلقاءكما': [{'vocalized': u'فتلقاءكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ولتلقاءي': [{'vocalized': u'ولتلقاءي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'ولتلقاءي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فكأكثري': [{'vocalized': u'فكأكثري', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'فكأكثري', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'فكأكثره': [{'vocalized': u'فكأكثره', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولتلقاءه': [{'vocalized': u'ولتلقاءه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فكأكثرك': [{'vocalized': u'فكأكثرك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولتلقاءك': [{'vocalized': u'ولتلقاءك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أتحتكم': [{'vocalized': u'أتحتكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'ولشطرها': [{'vocalized': u'ولشطرها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'أتحتكن': [{'vocalized': u'أتحتكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'أبشبههن': [{'vocalized': u'أبشبههن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أبشبههم': [{'vocalized': u'أبشبههم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'ولعامتهما': [{'vocalized': u'ولعامتهما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'ونحوهن': [{'vocalized': u'ونحوهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'وكساعة': [{'vocalized': u'وكساعة', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'ونحوهم': [{'vocalized': u'ونحوهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'ولوراءي': [{'vocalized': u'ولوراءي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'ولوراءي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'أوكأنكم': [{'vocalized': u'أوكأنكم', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'أوكأنكن': [{'vocalized': u'أوكأنكن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'أولإليكن': [{'vocalized': u'أولإليكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'أولإليكم': [{'vocalized': u'أولإليكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'ساعتكما': [{'vocalized': u'ساعتكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'وأثناءكم': [{'vocalized': u'وأثناءكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'وضمن': [{'vocalized': u'وضمن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'ضمن', 'encletic': u'', 'type': u'اسم', 'original': u'ضمن'}],

 u'بجنبها': [{'vocalized': u'بجنبها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'أونحوهم': [{'vocalized': u'أونحوهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أهكذا': [{'vocalized': u'أهكذا', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هكذا', 'encletic': u'', 'type': u'اسم', 'original': u'هكذا'}],

 u'أونحوهن': [{'vocalized': u'أونحوهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'وبضعكن': [{'vocalized': u'وبضعكن', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بضع'}],

 u'كأنها': [{'vocalized': u'كأنها', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنها', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'فبذا': [{'vocalized': u'فبذا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'فبذا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'ولكرب': [{'vocalized': u'ولكرب', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كرب', 'encletic': u'', 'type': u'فعل', 'original': u'كرب'}],

 u'هاتين': [{'vocalized': u'هاتين', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'وجميعهن': [{'vocalized': u'وجميعهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعهن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فهلا': [{'vocalized': u'فهلا', 'procletic': u'ف-', 'tags': u'حرف;حرف تحضيض;عطف', 'stem': u'هلا', 'encletic': u'', 'type': u'حرف', 'original': u'هلا'}],

 u'أوكجميعهما': [{'vocalized': u'أوكجميعهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوكجميعهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'وكأنهما': [{'vocalized': u'وكأنهما', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنهما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'فأقلهم': [{'vocalized': u'فأقلهم', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'أبنفسكم': [{'vocalized': u'أبنفسكم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'شهرهن': [{'vocalized': u'شهرهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'فبعينكن': [{'vocalized': u'فبعينكن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فلعينهما': [{'vocalized': u'فلعينهما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فلعينهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'كأنهم': [{'vocalized': u'كأنهم', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنهم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'كأنهن': [{'vocalized': u'كأنهن', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنهن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'ليلكما': [{'vocalized': u'ليلكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'فبذه': [{'vocalized': u'فبذه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'أجميعهما': [{'vocalized': u'أجميعهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعهما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أووراءكن': [{'vocalized': u'أووراءكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'فلأسفل': [{'vocalized': u'فلأسفل', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'ألعليك': [{'vocalized': u'ألعليك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'حماك': [{'vocalized': u'حماك', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حما'}],

 u'وجميعها': [{'vocalized': u'وجميعها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعها', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'وبشهري': [{'vocalized': u'وبشهري', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'وبشهري', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فبذي': [{'vocalized': u'فبذي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فلبات': [{'vocalized': u'فلبات', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'بات', 'encletic': u'', 'type': u'فعل', 'original': u'بات'}],

 u'ونحوها': [{'vocalized': u'ونحوها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'فلتينك': [{'vocalized': u'فلتينك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'كأجمعنا': [{'vocalized': u'كأجمعنا', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'فرب': [{'vocalized': u'فرب', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'رب', 'encletic': u'', 'type': u'حرف', 'original': u'رب'}],

 u'فغيرنا': [{'vocalized': u'فغيرنا', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أوأجمعها': [{'vocalized': u'أوأجمعها', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'بجنبهم': [{'vocalized': u'بجنبهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'كغروب': [{'vocalized': u'كغروب', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'بجنبهن': [{'vocalized': u'بجنبهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'أوبأولالك': [{'vocalized': u'أوبأولالك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'وكلحظة': [{'vocalized': u'وكلحظة', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'عنك': [{'vocalized': u'عنك', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'بساعتكن': [{'vocalized': u'بساعتكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلنفسها': [{'vocalized': u'فلنفسها', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أأمامكم': [{'vocalized': u'أأمامكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'فمازالا': [{'vocalized': u'فمازالا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مازالا', 'encletic': u'', 'type': u'فعل', 'original': u'مازالا'}],

 u'عني': [{'vocalized': u'عني', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'عني', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'حماي': [{'vocalized': u'حماي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حما'},
 {'vocalized': u'حماي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حما'}],

 u'أفبجميعكن': [{'vocalized': u'أفبجميعكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'كأسفلهما': [{'vocalized': u'كأسفلهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفبجميعكم': [{'vocalized': u'أفبجميعكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'وحموك': [{'vocalized': u'وحموك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمو'}],

 u'فلغروب': [{'vocalized': u'فلغروب', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'أوذلكن': [{'vocalized': u'أوذلكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'كأيكم': [{'vocalized': u'كأيكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'كأيكن': [{'vocalized': u'كأيكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'أوذلكم': [{'vocalized': u'أوذلكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'وبفيهما': [{'vocalized': u'وبفيهما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'}],

 u'أول': [{'vocalized': u'أول', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'أول', 'encletic': u'', 'type': u'اسم', 'original': u'أول'}],

 u'أوه': [{'vocalized': u'أوه', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'أوه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أوه'}],

 u'لتحتها': [{'vocalized': u'لتحتها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'أفبأولالك': [{'vocalized': u'أفبأولالك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'واللتيا': [{'vocalized': u'واللتيا', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'وخلفها': [{'vocalized': u'وخلفها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلفها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'أفذانك': [{'vocalized': u'أفذانك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'وككل': [{'vocalized': u'وككل', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككل', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'ولحظتهم': [{'vocalized': u'ولحظتهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فسبحانهن': [{'vocalized': u'فسبحانهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سبحان'}],

 u'فسبحانهم': [{'vocalized': u'فسبحانهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سبحان'}],

 u'فريث': [{'vocalized': u'فريث', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'ريث', 'encletic': u'', 'type': u'اسم', 'original': u'ريث'}],

 u'فذوي': [{'vocalized': u'فذوي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'أعليهما': [{'vocalized': u'أعليهما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أعليهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فذوو': [{'vocalized': u'فذوو', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذوو', 'encletic': u'', 'type': u'اسم', 'original': u'ذوو'}],

 u'وتحتهم': [{'vocalized': u'وتحتهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'وتحتهن': [{'vocalized': u'وتحتهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'وكهنالك': [{'vocalized': u'وكهنالك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'أووراءك': [{'vocalized': u'أووراءك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'وإنهما': [{'vocalized': u'وإنهما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'أسوينا': [{'vocalized': u'أسوينا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'أووراءه': [{'vocalized': u'أووراءه', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'فذوا': [{'vocalized': u'فذوا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذوا', 'encletic': u'', 'type': u'اسم', 'original': u'ذوا'}],

 u'كذويكما': [{'vocalized': u'كذويكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'إننا': [{'vocalized': u'إننا', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'فسبحانها': [{'vocalized': u'فسبحانها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سبحان'}],

 u'ولحظتها': [{'vocalized': u'ولحظتها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'كشهركن': [{'vocalized': u'كشهركن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'أإن': [{'vocalized': u'أإن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'كشهركم': [{'vocalized': u'كشهركم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'لكلتا': [{'vocalized': u'لكلتا', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'},
 {'vocalized': u'لكلتا', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'فحاشاكم': [{'vocalized': u'فحاشاكم', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'حاشا'}],

 u'فحاشاكن': [{'vocalized': u'فحاشاكن', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'حاشا'}],

 u'عند': [{'vocalized': u'عند', 'procletic': u'', 'tags': u'اسم;ظرف', 'stem': u'عند', 'encletic': u'', 'type': u'اسم', 'original': u'عند'}],

 u'وكساعتهم': [{'vocalized': u'وكساعتهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلإننا': [{'vocalized': u'فلإننا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'وكساعتهن': [{'vocalized': u'وكساعتهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'وأسفل': [{'vocalized': u'وأسفل', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'فبجنبه': [{'vocalized': u'فبجنبه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'وبغيرهن': [{'vocalized': u'وبغيرهن', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'وبغيرهم': [{'vocalized': u'وبغيرهم', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'فبجنبك': [{'vocalized': u'فبجنبك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'أكجميع': [{'vocalized': u'أكجميع', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميع', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'فبزمانكما': [{'vocalized': u'فبزمانكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كما', 'type': u'اسم', 'original': u'زمان'}],

 u'أفبذلك': [{'vocalized': u'أفبذلك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'فماداموا': [{'vocalized': u'فماداموا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماداموا', 'encletic': u'', 'type': u'فعل', 'original': u'ماداموا'}],

 u'ولإليكما': [{'vocalized': u'ولإليكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'وببعضهن': [{'vocalized': u'وببعضهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'كأعليكما': [{'vocalized': u'كأعليكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'وببعضهم': [{'vocalized': u'وببعضهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'وكذاتهن': [{'vocalized': u'وكذاتهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'أفكحسبها': [{'vocalized': u'أفكحسبها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'إنكما': [{'vocalized': u'إنكما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'أنفسها': [{'vocalized': u'أنفسها', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'أيها': [{'vocalized': u'أيها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'أفلشمالكن': [{'vocalized': u'أفلشمالكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'وحينهم': [{'vocalized': u'وحينهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حين'}],

 u'فبساعتهما': [{'vocalized': u'فبساعتهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'كخلفها': [{'vocalized': u'كخلفها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'ويمينكم': [{'vocalized': u'ويمينكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'ويمينكن': [{'vocalized': u'ويمينكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'لساعتهم': [{'vocalized': u'لساعتهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فوقكن': [{'vocalized': u'فوقكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'أشبه': [{'vocalized': u'أشبه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'لساعتهن': [{'vocalized': u'لساعتهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفلتحتي': [{'vocalized': u'أفلتحتي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'أفلتحتي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'أنفسهم': [{'vocalized': u'أنفسهم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'تلكم': [{'vocalized': u'تلكم', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أيهن': [{'vocalized': u'أيهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'أيهم': [{'vocalized': u'أيهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'أوأناي': [{'vocalized': u'أوأناي', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'أوأناي', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'فكابنكن': [{'vocalized': u'فكابنكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'فكابنكم': [{'vocalized': u'فكابنكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'وأكثره': [{'vocalized': u'وأكثره', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أكثر'}],

 u'وأكثرك': [{'vocalized': u'وأكثرك', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أكثر'}],

 u'أوكعينه': [{'vocalized': u'أوكعينه', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'وأكثري': [{'vocalized': u'وأكثري', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'},
 {'vocalized': u'وأكثري', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلذانك': [{'vocalized': u'فلذانك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'وبغيرها': [{'vocalized': u'وبغيرها', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'ألازالا': [{'vocalized': u'ألازالا', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازالا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالا'}],

 u'وأخيكما': [{'vocalized': u'وأخيكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'أماذا': [{'vocalized': u'أماذا', 'procletic': u'أ-', 'tags': u'اسم;اسم الاستفهام;استفهام', 'stem': u'ماذا', 'encletic': u'', 'type': u'اسم', 'original': u'ماذا'}],

 u'ليمينهما': [{'vocalized': u'ليمينهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'فخلالها': [{'vocalized': u'فخلالها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلال'}],

 u'وعينهم': [{'vocalized': u'وعينهم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'وبأخيها': [{'vocalized': u'وبأخيها', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'أفلتحتك': [{'vocalized': u'أفلتحتك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'أفليمينك': [{'vocalized': u'أفليمينك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'رب': [{'vocalized': u'رب', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'رب', 'encletic': u'', 'type': u'حرف', 'original': u'رب'}],

 u'أقبل': [{'vocalized': u'أقبل', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'أقبل', 'encletic': u'', 'type': u'فعل', 'original': u'أقبل'}],

 u'أفكحسبهم': [{'vocalized': u'أفكحسبهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفكحسبهن': [{'vocalized': u'أفكحسبهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'وكذاتها': [{'vocalized': u'وكذاتها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'لأجمعكما': [{'vocalized': u'لأجمعكما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولعنه': [{'vocalized': u'ولعنه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'فساعتها': [{'vocalized': u'فساعتها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'لجنوبنا': [{'vocalized': u'لجنوبنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'سبحانهن': [{'vocalized': u'سبحانهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سبحان'}],

 u'سبحانهم': [{'vocalized': u'سبحانهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سبحان'}],

 u'أومثلي': [{'vocalized': u'أومثلي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أومثلي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'وكأخيهن': [{'vocalized': u'وكأخيهن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'أوبنفسكما': [{'vocalized': u'أوبنفسكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'وكغيرهن': [{'vocalized': u'وكغيرهن', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'وكغيرهم': [{'vocalized': u'وكغيرهم', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أومثلك': [{'vocalized': u'أومثلك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أومثله': [{'vocalized': u'أومثله', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'ألعليهما': [{'vocalized': u'ألعليهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'لأعليكما': [{'vocalized': u'لأعليكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'أهاهنا': [{'vocalized': u'أهاهنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هاهنا', 'encletic': u'', 'type': u'اسم', 'original': u'هاهنا'}],

 u'وخلف': [{'vocalized': u'وخلف', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'وخلف', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'فذاتكما': [{'vocalized': u'فذاتكما', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'كجنبهن': [{'vocalized': u'كجنبهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'كعينها': [{'vocalized': u'كعينها', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فلليلي': [{'vocalized': u'فلليلي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'فلليلي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'وكأخيها': [{'vocalized': u'وكأخيها', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'وكغيرها': [{'vocalized': u'وكغيرها', 'procletic': u'و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'فلليلك': [{'vocalized': u'فلليلك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'أفلمثلهما': [{'vocalized': u'أفلمثلهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فلليله': [{'vocalized': u'فلليله', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'وخلا': [{'vocalized': u'وخلا', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف', 'stem': u'خلا', 'encletic': u'', 'type': u'فعل', 'original': u'خلا'}],

 u'فكاللائي': [{'vocalized': u'فكاللائي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'كجنبها': [{'vocalized': u'كجنبها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'كعينهن': [{'vocalized': u'كعينهن', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'كعينهم': [{'vocalized': u'كعينهم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'فأبيهم': [{'vocalized': u'فأبيهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'وبأثناء': [{'vocalized': u'وبأثناء', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'لازلتن': [{'vocalized': u'لازلتن', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتن'}],

 u'أحسبهن': [{'vocalized': u'أحسبهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'فبعدك': [{'vocalized': u'فبعدك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعد'}],

 u'فساعتهم': [{'vocalized': u'فساعتهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فساعتهن': [{'vocalized': u'فساعتهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'وقتكما': [{'vocalized': u'وقتكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'وفيهما': [{'vocalized': u'وفيهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيهما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'سبحانها': [{'vocalized': u'سبحانها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سبحان'}],

 u'أولجميعك': [{'vocalized': u'أولجميعك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'ليمينه': [{'vocalized': u'ليمينه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'فأيهم': [{'vocalized': u'فأيهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'أولجميعه': [{'vocalized': u'أولجميعه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أولجميعي': [{'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'أولعامة': [{'vocalized': u'أولعامة', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامة', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أفكنحونا': [{'vocalized': u'أفكنحونا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'وشهرهم': [{'vocalized': u'وشهرهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'وبذاتنا': [{'vocalized': u'وبذاتنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'ألديها': [{'vocalized': u'ألديها', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدى'}],

 u'أفعيننا': [{'vocalized': u'أفعيننا', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'أولعنهما': [{'vocalized': u'أولعنهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'فكشرقهن': [{'vocalized': u'فكشرقهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شرق'}],

 u'فكشرقهم': [{'vocalized': u'فكشرقهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'أفماذا': [{'vocalized': u'أفماذا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم الاستفهام;عطف;استفهام', 'stem': u'ماذا', 'encletic': u'', 'type': u'اسم', 'original': u'ماذا'}],

 u'أوحسبي': [{'vocalized': u'أوحسبي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أوحسبي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأنهم': [{'vocalized': u'وكأنهم', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنهم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'أوحسبه': [{'vocalized': u'أوحسبه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'أوحسبك': [{'vocalized': u'أوحسبك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'واخلولق': [{'vocalized': u'واخلولق', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'اخلولق', 'encletic': u'', 'type': u'فعل', 'original': u'اخلولق'}],

 u'ألسوى': [{'vocalized': u'ألسوى', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أوطالما': [{'vocalized': u'أوطالما', 'procletic': u'أ-و-', 'tags': u'فعل;فعل جامد;عطف;استفهام', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'ولجنوبك': [{'vocalized': u'ولجنوبك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'ألسوي': [{'vocalized': u'ألسوي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'ألسوي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'فلأثناء': [{'vocalized': u'فلأثناء', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'فلأبيك': [{'vocalized': u'فلأبيك', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'وبأخيهن': [{'vocalized': u'وبأخيهن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'فلأبيه': [{'vocalized': u'فلأبيه', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'ولشهر': [{'vocalized': u'ولشهر', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'وكأنها': [{'vocalized': u'وكأنها', 'procletic': u'و-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وكأنها', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'ولعليه': [{'vocalized': u'ولعليه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'حواليك': [{'vocalized': u'حواليك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حوالى'}],

 u'ولعليك': [{'vocalized': u'ولعليك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'حواليه': [{'vocalized': u'حواليه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حوالى'}],

 u'ليميني': [{'vocalized': u'ليميني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'ليميني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'بضع': [{'vocalized': u'بضع', 'procletic': u'', 'tags': u'اسم;كناية', 'stem': u'بضع', 'encletic': u'', 'type': u'اسم', 'original': u'بضع'}],

 u'وبشهره': [{'vocalized': u'وبشهره', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'ومافتئ': [{'vocalized': u'ومافتئ', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئ', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئ'}],

 u'وتجاههما': [{'vocalized': u'وتجاههما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تجاه'}],

 u'أفككلكم': [{'vocalized': u'أفككلكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أفككلكن': [{'vocalized': u'أفككلكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفككلكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'بشرقهما': [{'vocalized': u'بشرقهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'أفكسويكم': [{'vocalized': u'أفكسويكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'فلساعتنا': [{'vocalized': u'فلساعتنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلتحتكن': [{'vocalized': u'فلتحتكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'أفكسويكن': [{'vocalized': u'أفكسويكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'أووراءكم': [{'vocalized': u'أووراءكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'أفبضعهما': [{'vocalized': u'أفبضعهما', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بضع'}],

 u'وشهرها': [{'vocalized': u'وشهرها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'ألديهم': [{'vocalized': u'ألديهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لدى'}],

 u'ألديهن': [{'vocalized': u'ألديهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لدى'}],

 u'فكشرقها': [{'vocalized': u'فكشرقها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شرق'}],

 u'وكاللذين': [{'vocalized': u'وكاللذين', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللذين', 'encletic': u'', 'type': u'اسم', 'original': u'اللذين'}],

 u'كخلفي': [{'vocalized': u'كخلفي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'كخلفي', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فبأجمعكم': [{'vocalized': u'فبأجمعكم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'ومهما': [{'vocalized': u'ومهما', 'procletic': u'و-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'مهما', 'encletic': u'', 'type': u'اسم', 'original': u'مهما'}],

 u'فأمامكم': [{'vocalized': u'فأمامكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'فبأجمعكن': [{'vocalized': u'فبأجمعكن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفخلفه': [{'vocalized': u'أفخلفه', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'ألمثلنا': [{'vocalized': u'ألمثلنا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'فبزمانهما': [{'vocalized': u'فبزمانهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'لأولئك': [{'vocalized': u'لأولئك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'يمين': [{'vocalized': u'يمين', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'إياي': [{'vocalized': u'إياي', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياي', 'encletic': u'', 'type': u'ضمير', 'original': u'إياي'}],

 u'وبأنكم': [{'vocalized': u'وبأنكم', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'وبأنكن': [{'vocalized': u'وبأنكن', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'إياه': [{'vocalized': u'إياه', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياه', 'encletic': u'', 'type': u'ضمير', 'original': u'إياه'}],

 u'فأنهن': [{'vocalized': u'فأنهن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'وكشهره': [{'vocalized': u'وكشهره', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'فأنهم': [{'vocalized': u'فأنهم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'لذاتكما': [{'vocalized': u'لذاتكما', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'بنفسها': [{'vocalized': u'بنفسها', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'فتلقاءكن': [{'vocalized': u'فتلقاءكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فتلقاءكم': [{'vocalized': u'فتلقاءكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'عينك': [{'vocalized': u'عينك', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'فلأكثركما': [{'vocalized': u'فلأكثركما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'عينه': [{'vocalized': u'عينه', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'فأصبح': [{'vocalized': u'فأصبح', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'أصبح', 'encletic': u'', 'type': u'فعل', 'original': u'أصبح'}],

 u'أفخلفنا': [{'vocalized': u'أفخلفنا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'وخلاكما': [{'vocalized': u'وخلاكما', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'خلا'}],

 u'فكفينا': [{'vocalized': u'فكفينا', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'}],

 u'أحسبها': [{'vocalized': u'أحسبها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'فالتي': [{'vocalized': u'فالتي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'التي', 'encletic': u'', 'type': u'اسم', 'original': u'التي'}],

 u'أعينكما': [{'vocalized': u'أعينكما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'بنفسهم': [{'vocalized': u'بنفسهم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'بنفسهن': [{'vocalized': u'بنفسهن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'فعنده': [{'vocalized': u'فعنده', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عند'}],

 u'أومثلكم': [{'vocalized': u'أومثلكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'فعندي': [{'vocalized': u'فعندي', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عند'},
 {'vocalized': u'فعندي', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عند'}],

 u'أومثلكن': [{'vocalized': u'أومثلكن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'ولآض': [{'vocalized': u'ولآض', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'آض', 'encletic': u'', 'type': u'فعل', 'original': u'آض'}],

 u'أوفوقكن': [{'vocalized': u'أوفوقكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'أوفوقكم': [{'vocalized': u'أوفوقكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'وساءما': [{'vocalized': u'وساءما', 'procletic': u'و-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'ساءما', 'encletic': u'', 'type': u'فعل', 'original': u'ساءما'}],

 u'أفذي': [{'vocalized': u'أفذي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'أوإليها': [{'vocalized': u'أوإليها', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'فأجمعي': [{'vocalized': u'فأجمعي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فأجمعي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'وعداهما': [{'vocalized': u'وعداهما', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'عدا'}],

 u'أوفي': [{'vocalized': u'أوفي', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'ومعاذ': [{'vocalized': u'ومعاذ', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'معاذ', 'encletic': u'', 'type': u'اسم', 'original': u'معاذ'}],

 u'شمالنا': [{'vocalized': u'شمالنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'وليلنا': [{'vocalized': u'وليلنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'بشرق': [{'vocalized': u'بشرق', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'أولإليكما': [{'vocalized': u'أولإليكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'فأنها': [{'vocalized': u'فأنها', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'وتبدل': [{'vocalized': u'وتبدل', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'تبدل', 'encletic': u'', 'type': u'فعل', 'original': u'تبدل'}],

 u'وارتد': [{'vocalized': u'وارتد', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ارتد', 'encletic': u'', 'type': u'فعل', 'original': u'ارتد'}],

 u'بجميعي': [{'vocalized': u'بجميعي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعي', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'ألفوقنا': [{'vocalized': u'ألفوقنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'بجميعك': [{'vocalized': u'بجميعك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعك', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'ضمنكن': [{'vocalized': u'ضمنكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ضمن'}],

 u'فإلينا': [{'vocalized': u'فإلينا', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'بجميعه': [{'vocalized': u'بجميعه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعه', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'فبخلفكما': [{'vocalized': u'فبخلفكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'ولأعليه': [{'vocalized': u'ولأعليه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'بأعليها': [{'vocalized': u'بأعليها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'بأبيه': [{'vocalized': u'بأبيه', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'أفبعضنا': [{'vocalized': u'أفبعضنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'بأبيك': [{'vocalized': u'بأبيك', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'ولكأن': [{'vocalized': u'ولكأن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'أفلكليكما': [{'vocalized': u'أفلكليكما', 'procletic': u'أ-ف-ل-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'فلوقتهم': [{'vocalized': u'فلوقتهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'بأبيي': [{'vocalized': u'بأبيي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'بأبيي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'أوبأجمعكم': [{'vocalized': u'أوبأجمعكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولأولئك': [{'vocalized': u'أولأولئك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'أوبأجمعكن': [{'vocalized': u'أوبأجمعكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكلما': [{'vocalized': u'فكلما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'كلما', 'encletic': u'', 'type': u'اسم', 'original': u'كلما'}],

 u'ببعضكما': [{'vocalized': u'ببعضكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أكغيركم': [{'vocalized': u'أكغيركم', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أكغيركن': [{'vocalized': u'أكغيركن', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'ألمنه': [{'vocalized': u'ألمنه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'ألمنك': [{'vocalized': u'ألمنك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'فلوقتها': [{'vocalized': u'فلوقتها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'وبلحظتهما': [{'vocalized': u'وبلحظتهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'فتجاهنا': [{'vocalized': u'فتجاهنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تجاه'}],

 u'فلابني': [{'vocalized': u'فلابني', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'فلابني', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'ولأناكما': [{'vocalized': u'ولأناكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'لمعك': [{'vocalized': u'لمعك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'وعنكما': [{'vocalized': u'وعنكما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'وكأقلكما': [{'vocalized': u'وكأقلكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'لمعه': [{'vocalized': u'لمعه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'الذي': [{'vocalized': u'الذي', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'لمعي': [{'vocalized': u'لمعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'لمعي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'فأيتهما': [{'vocalized': u'فأيتهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'أفبكلك': [{'vocalized': u'أفبكلك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'شهري': [{'vocalized': u'شهري', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'شهري', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'وشبهكما': [{'vocalized': u'وشبهكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'فبأقلي': [{'vocalized': u'فبأقلي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'فبأقلي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'بأعليهم': [{'vocalized': u'بأعليهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'بأعليهن': [{'vocalized': u'بأعليهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فشرقه': [{'vocalized': u'فشرقه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'فبأقله': [{'vocalized': u'فبأقله', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'فشرقك': [{'vocalized': u'فشرقك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'فبأقلك': [{'vocalized': u'فبأقلك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'فمثلنا': [{'vocalized': u'فمثلنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'وكبعضه': [{'vocalized': u'وكبعضه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'فكغروبكما': [{'vocalized': u'فكغروبكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'أوبعينكم': [{'vocalized': u'أوبعينكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'وكبعضك': [{'vocalized': u'وكبعضك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'أوبعينكن': [{'vocalized': u'أوبعينكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'لتحتهما': [{'vocalized': u'لتحتهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'وكبعضي': [{'vocalized': u'وكبعضي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'وكبعضي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'لشطركما': [{'vocalized': u'لشطركما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'بشبهكما': [{'vocalized': u'بشبهكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'بزماننا': [{'vocalized': u'بزماننا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'فكتين': [{'vocalized': u'فكتين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'فبحسبهن': [{'vocalized': u'فبحسبهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'فبحسبهم': [{'vocalized': u'فبحسبهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فمعهما': [{'vocalized': u'فمعهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'ومثلما': [{'vocalized': u'ومثلما', 'procletic': u'و-', 'tags': u'اسم;جار ومجرور;عطف', 'stem': u'مثلما', 'encletic': u'', 'type': u'اسم', 'original': u'مثلما'}],

 u'إلي': [{'vocalized': u'إلي', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'إلي', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'أبعامة': [{'vocalized': u'أبعامة', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أوبعضي': [{'vocalized': u'أوبعضي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أوبعضي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'ألخلفي': [{'vocalized': u'ألخلفي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ألخلفي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'فخلالكم': [{'vocalized': u'فخلالكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلال'}],

 u'فخلالكن': [{'vocalized': u'فخلالكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلال'}],

 u'أوبعضه': [{'vocalized': u'أوبعضه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'ومابرحوا': [{'vocalized': u'ومابرحوا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحوا', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحوا'}],

 u'أوبعضك': [{'vocalized': u'أوبعضك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فبحسبها': [{'vocalized': u'فبحسبها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'ألإليك': [{'vocalized': u'ألإليك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'أحسبهما': [{'vocalized': u'أحسبهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'ألإليه': [{'vocalized': u'ألإليه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'أوكهاذين': [{'vocalized': u'أوكهاذين', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'ألكأن': [{'vocalized': u'ألكأن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'ولهاتين': [{'vocalized': u'ولهاتين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'أفليمينه': [{'vocalized': u'أفليمينه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'فإني': [{'vocalized': u'فإني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'فإني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'فإنك': [{'vocalized': u'فإنك', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'أوسويهما': [{'vocalized': u'أوسويهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فإنه': [{'vocalized': u'فإنه', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'ألأناهن': [{'vocalized': u'ألأناهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'ألأناهم': [{'vocalized': u'ألأناهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'ولإنهما': [{'vocalized': u'ولإنهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'أفبذاك': [{'vocalized': u'أفبذاك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'فأجمعك': [{'vocalized': u'فأجمعك', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوكسويكما': [{'vocalized': u'أوكسويكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'أفنفسهم': [{'vocalized': u'أفنفسهم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'أفنفسهن': [{'vocalized': u'أفنفسهن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'وحميي': [{'vocalized': u'وحميي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'وحميي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'أولإليك': [{'vocalized': u'أولإليك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'أإليهن': [{'vocalized': u'أإليهن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'أثناءكما': [{'vocalized': u'أثناءكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'وحميك': [{'vocalized': u'وحميك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'وحميه': [{'vocalized': u'وحميه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'فطفق': [{'vocalized': u'فطفق', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'طفق', 'encletic': u'', 'type': u'فعل', 'original': u'طفق'}],

 u'فللألى': [{'vocalized': u'فللألى', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'أبأجمعهم': [{'vocalized': u'أبأجمعهم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلشهرهن': [{'vocalized': u'فلشهرهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'أكمثلنا': [{'vocalized': u'أكمثلنا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'ولكنهم': [{'vocalized': u'ولكنهم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنهم', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لكن'}],

 u'ولكنهن': [{'vocalized': u'ولكنهن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنهن', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لكن'}],

 u'أفلأمامكما': [{'vocalized': u'أفلأمامكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'فحيننا': [{'vocalized': u'فحيننا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حين'}],

 u'لإليكم': [{'vocalized': u'لإليكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'إلى', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إلى'}],

 u'فأكثر': [{'vocalized': u'فأكثر', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلأمامهما': [{'vocalized': u'فلأمامهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'أفلجميع': [{'vocalized': u'أفلجميع', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميع', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميع', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميع', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'لغربهم': [{'vocalized': u'لغربهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'ألازلتما': [{'vocalized': u'ألازلتما', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'},
 {'vocalized': u'ألازلتما', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'}],

 u'ألمثلكما': [{'vocalized': u'ألمثلكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أكأولئكم': [{'vocalized': u'أكأولئكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'بدونه': [{'vocalized': u'بدونه', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بدون'}],

 u'ولكنها': [{'vocalized': u'ولكنها', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'ولكنها', 'procletic': u'و-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لكن'}],

 u'أفليمينكما': [{'vocalized': u'أفليمينكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'فكأعليكن': [{'vocalized': u'فكأعليكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فكأعليكم': [{'vocalized': u'فكأعليكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'لأكثرنا': [{'vocalized': u'لأكثرنا', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'بحميكما': [{'vocalized': u'بحميكما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'وتحته': [{'vocalized': u'وتحته', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'وتحتك': [{'vocalized': u'وتحتك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'وأوشك': [{'vocalized': u'وأوشك', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أوشك', 'encletic': u'', 'type': u'فعل', 'original': u'أوشك'}],

 u'أفبسويهما': [{'vocalized': u'أفبسويهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'والذي': [{'vocalized': u'والذي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'بدونك': [{'vocalized': u'بدونك', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بدون'}],

 u'ولسوى': [{'vocalized': u'ولسوى', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'فبكلتا': [{'vocalized': u'فبكلتا', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفكلنا': [{'vocalized': u'أفكلنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكلنا', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'فبتلقاءكم': [{'vocalized': u'فبتلقاءكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فبتلقاءكن': [{'vocalized': u'فبتلقاءكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وهاذين': [{'vocalized': u'وهاذين', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أغيركن': [{'vocalized': u'أغيركن', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'أوكبعضي': [{'vocalized': u'أوكبعضي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أوكبعضي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فلكيلا': [{'vocalized': u'فلكيلا', 'procletic': u'ف-', 'tags': u'حرف;حرف تعليل;عطف', 'stem': u'لكيلا', 'encletic': u'', 'type': u'حرف', 'original': u'لكيلا'}],

 u'أفأولاء': [{'vocalized': u'أفأولاء', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'أوكبعضك': [{'vocalized': u'أوكبعضك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'ولذوينا': [{'vocalized': u'ولذوينا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفعنكن': [{'vocalized': u'أفعنكن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'أكمثلكم': [{'vocalized': u'أكمثلكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أبسوى': [{'vocalized': u'أبسوى', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أبسوي': [{'vocalized': u'أبسوي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أبسوي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'وزمانكن': [{'vocalized': u'وزمانكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'بجنبكما': [{'vocalized': u'بجنبكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'أولغيرها': [{'vocalized': u'أولغيرها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيرها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'أكأنكن': [{'vocalized': u'أكأنكن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'فلمعهما': [{'vocalized': u'فلمعهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'مافتئتا': [{'vocalized': u'مافتئتا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئتا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتا'}],

 u'وزمانكم': [{'vocalized': u'وزمانكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'أولذينك': [{'vocalized': u'أولذينك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'فشمالهما': [{'vocalized': u'فشمالهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'منذ': [{'vocalized': u'منذ', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'منذ', 'encletic': u'', 'type': u'حرف', 'original': u'منذ'},
 {'vocalized': u'منذ', 'procletic': u'', 'tags': u'حرف;ظرف زمان', 'stem': u'منذ', 'encletic': u'', 'type': u'حرف', 'original': u'منذ'}],

 u'فابننا': [{'vocalized': u'فابننا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'أخلف': [{'vocalized': u'أخلف', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'كسويكما': [{'vocalized': u'كسويكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'فبحميكما': [{'vocalized': u'فبحميكما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'أولعليها': [{'vocalized': u'أولعليها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'ولتحتهما': [{'vocalized': u'ولتحتهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'وأكثرهما': [{'vocalized': u'وأكثرهما', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'ذوو': [{'vocalized': u'ذوو', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذوو', 'encletic': u'', 'type': u'اسم', 'original': u'ذوو'}],

 u'خلفكن': [{'vocalized': u'خلفكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'خلفكم': [{'vocalized': u'خلفكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'أباكم': [{'vocalized': u'أباكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبا'}],

 u'أباكن': [{'vocalized': u'أباكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبا'}],

 u'مني': [{'vocalized': u'مني', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'مني', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'ألنفسي': [{'vocalized': u'ألنفسي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أفعنكم': [{'vocalized': u'أفعنكم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'ألعامتنا': [{'vocalized': u'ألعامتنا', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'ألنفسك': [{'vocalized': u'ألنفسك', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'منك': [{'vocalized': u'منك', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'وكشبهكم': [{'vocalized': u'وكشبهكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'وكشبهكن': [{'vocalized': u'وكشبهكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'منه': [{'vocalized': u'منه', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'فكذاتنا': [{'vocalized': u'فكذاتنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'أوأمام': [{'vocalized': u'أوأمام', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'فأخيكن': [{'vocalized': u'فأخيكن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'فأخيكم': [{'vocalized': u'فأخيكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'أولغيرهم': [{'vocalized': u'أولغيرهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيرهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'كأنكما': [{'vocalized': u'كأنكما', 'procletic': u'ك-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'كأنكما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'أولغيرهن': [{'vocalized': u'أولغيرهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيرهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'فكأكثرها': [{'vocalized': u'فكأكثرها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'أفكأولالك': [{'vocalized': u'أفكأولالك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'فكأقلهما': [{'vocalized': u'فكأقلهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'أوأجمعهما': [{'vocalized': u'أوأجمعهما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفبشبهكن': [{'vocalized': u'أفبشبهكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'كلا': [{'vocalized': u'كلا', 'procletic': u'', 'tags': u'حرف;توكيد', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'},
 {'vocalized': u'كلا', 'procletic': u'', 'tags': u'حرف;حرف ردع', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'}],

 u'لعنها': [{'vocalized': u'لعنها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'عن'}],

 u'وبدوني': [{'vocalized': u'وبدوني', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بدون'},
 {'vocalized': u'وبدوني', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بدون'}],

 u'وذاتهما': [{'vocalized': u'وذاتهما', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'وبدونه': [{'vocalized': u'وبدونه', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بدون'}],

 u'وبدونك': [{'vocalized': u'وبدونك', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بدون'}],

 u'أفينا': [{'vocalized': u'أفينا', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'أفكذلكن': [{'vocalized': u'أفكذلكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'ولأمام': [{'vocalized': u'ولأمام', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'وحينكما': [{'vocalized': u'وحينكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حين'}],

 u'كأخيهما': [{'vocalized': u'كأخيهما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'أفكشبهها': [{'vocalized': u'أفكشبهها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'كأعلينا': [{'vocalized': u'كأعلينا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'وبنفسكما': [{'vocalized': u'وبنفسكما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'أفكذواتي': [{'vocalized': u'أفكذواتي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'أفوقكما': [{'vocalized': u'أفوقكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'فلأبيهن': [{'vocalized': u'فلأبيهن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبي'}],

 u'وبذويهم': [{'vocalized': u'وبذويهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبذويهن': [{'vocalized': u'وبذويهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلأبيهم': [{'vocalized': u'فلأبيهم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'وأعلينا': [{'vocalized': u'وأعلينا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'أولستما': [{'vocalized': u'أولستما', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لستما', 'encletic': u'', 'type': u'فعل', 'original': u'لستما'}],

 u'وبجنوب': [{'vocalized': u'وبجنوب', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'فضمننا': [{'vocalized': u'فضمننا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ضمن'}],

 u'أولكلنا': [{'vocalized': u'أولكلنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أولكلنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أفكأولاء': [{'vocalized': u'أفكأولاء', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'لأبيهم': [{'vocalized': u'لأبيهم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبي'}],

 u'أفلعينه': [{'vocalized': u'أفلعينه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أفلعينك': [{'vocalized': u'أفلعينك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'كنفسنا': [{'vocalized': u'كنفسنا', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'فمهما': [{'vocalized': u'فمهما', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'مهما', 'encletic': u'', 'type': u'اسم', 'original': u'مهما'}],

 u'أفلعيني': [{'vocalized': u'أفلعيني', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعيني', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعيني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعيني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'فلفينا': [{'vocalized': u'فلفينا', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفينا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'فكجميعكما': [{'vocalized': u'فكجميعكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعكما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'فلأبيها': [{'vocalized': u'فلأبيها', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبي'}],

 u'وبذويها': [{'vocalized': u'وبذويها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفكنفسكن': [{'vocalized': u'أفكنفسكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أفكنفسكم': [{'vocalized': u'أفكنفسكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'وجنبهم': [{'vocalized': u'وجنبهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنب'}],

 u'وجنبهن': [{'vocalized': u'وجنبهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنب'}],

 u'كله': [{'vocalized': u'كله', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كله', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'لعنهم': [{'vocalized': u'لعنهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'عن'}],

 u'وحسبنا': [{'vocalized': u'وحسبنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'فكعينك': [{'vocalized': u'فكعينك', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أوإليهما': [{'vocalized': u'أوإليهما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'أفشبهنا': [{'vocalized': u'أفشبهنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'كلي': [{'vocalized': u'كلي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'كلي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'ونحوهما': [{'vocalized': u'ونحوهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'وغير': [{'vocalized': u'وغير', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'أسفلي': [{'vocalized': u'أسفلي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'أسفلي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكذواتي': [{'vocalized': u'فكذواتي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'ولعينهما': [{'vocalized': u'ولعينهما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعينهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فقبلما': [{'vocalized': u'فقبلما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'قبلما', 'encletic': u'', 'type': u'اسم', 'original': u'قبلما'}],

 u'ففوقكما': [{'vocalized': u'ففوقكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'أفكشبههن': [{'vocalized': u'أفكشبههن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفكشبههم': [{'vocalized': u'أفكشبههم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'أفأنانا': [{'vocalized': u'أفأنانا', 'procletic': u'أ-ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'جميعها': [{'vocalized': u'جميعها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعها', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'فلجنبي': [{'vocalized': u'فلجنبي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'فلجنبي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'فلديهما': [{'vocalized': u'فلديهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدى'}],

 u'أوببعضهما': [{'vocalized': u'أوببعضهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'فوراءي': [{'vocalized': u'فوراءي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'فوراءي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'فلأجمعكم': [{'vocalized': u'فلأجمعكم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلأجمعكن': [{'vocalized': u'فلأجمعكن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوعني': [{'vocalized': u'أوعني', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'أوعني', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'أوعنه': [{'vocalized': u'أوعنه', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'أوعنك': [{'vocalized': u'أوعنك', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'لساعتي': [{'vocalized': u'لساعتي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'لساعتي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'أففوقكما': [{'vocalized': u'أففوقكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'فوقي': [{'vocalized': u'فوقي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'فوقي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'وبسويكما': [{'vocalized': u'وبسويكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'فوقه': [{'vocalized': u'فوقه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'لساعته': [{'vocalized': u'لساعته', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'فمابرحن': [{'vocalized': u'فمابرحن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرحن', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحن'}],

 u'أفكعينهما': [{'vocalized': u'أفكعينهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'لشرقك': [{'vocalized': u'لشرقك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'فلنحوها': [{'vocalized': u'فلنحوها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'كزمان': [{'vocalized': u'كزمان', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'وهب': [{'vocalized': u'وهب', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'هب', 'encletic': u'', 'type': u'فعل', 'original': u'هب'}],

 u'وكجنوب': [{'vocalized': u'وكجنوب', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوأمامكم': [{'vocalized': u'أوأمامكم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'وكجميعكم': [{'vocalized': u'وكجميعكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعكم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'أفمثلنا': [{'vocalized': u'أفمثلنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'كغربنا': [{'vocalized': u'كغربنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'لأي': [{'vocalized': u'لأي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'لأي', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'فوقت': [{'vocalized': u'فوقت', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'لأن': [{'vocalized': u'لأن', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'لأن', 'procletic': u'ل-', 'tags': u'حرف;حرف نصب;مجرور', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'لأن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'فلجنبه': [{'vocalized': u'فلجنبه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'لأجمعهما': [{'vocalized': u'لأجمعهما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فلنحوهن': [{'vocalized': u'فلنحوهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'وبشهركن': [{'vocalized': u'وبشهركن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شهر'}],

 u'فلنحوهم': [{'vocalized': u'فلنحوهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'وهي': [{'vocalized': u'وهي', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'فلأجمعهما': [{'vocalized': u'فلأجمعهما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'فلأجمعهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وهن': [{'vocalized': u'وهن', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'وهل': [{'vocalized': u'وهل', 'procletic': u'و-', 'tags': u'حرف;حرف استفهام;عطف', 'stem': u'هل', 'encletic': u'', 'type': u'حرف', 'original': u'هل'}],

 u'وهم': [{'vocalized': u'وهم', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'فحيني': [{'vocalized': u'فحيني', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حين'},
 {'vocalized': u'فحيني', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حين'}],

 u'أبهؤلاء': [{'vocalized': u'أبهؤلاء', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'جميعهم': [{'vocalized': u'جميعهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعهم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فشبهه': [{'vocalized': u'فشبهه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'جميعهن': [{'vocalized': u'جميعهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعهن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فشهركما': [{'vocalized': u'فشهركما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'فشبهك': [{'vocalized': u'فشبهك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'خلالكما': [{'vocalized': u'خلالكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان;ضمير', 'stem': u'خلال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلال'}],

 u'ولكأنما': [{'vocalized': u'ولكأنما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'وبينك': [{'vocalized': u'وبينك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بين'}],

 u'فشبهي': [{'vocalized': u'فشبهي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فشبهي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'فكأجمعكما': [{'vocalized': u'فكأجمعكما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وحينكن': [{'vocalized': u'وحينكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حين'}],

 u'فحاشانا': [{'vocalized': u'فحاشانا', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'حاشا'}],

 u'وحينكم': [{'vocalized': u'وحينكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حين'}],

 u'أووراءهن': [{'vocalized': u'أووراءهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'فلكاد': [{'vocalized': u'فلكاد', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كاد', 'encletic': u'', 'type': u'فعل', 'original': u'كاد'}],

 u'بنفس': [{'vocalized': u'بنفس', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أوكنحوها': [{'vocalized': u'أوكنحوها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'وبغيركن': [{'vocalized': u'وبغيركن', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'وبغيركم': [{'vocalized': u'وبغيركم', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'لأثناءكم': [{'vocalized': u'لأثناءكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولديهما': [{'vocalized': u'ولديهما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدى'}],

 u'أبهذا': [{'vocalized': u'أبهذا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'لأثناءكن': [{'vocalized': u'لأثناءكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفعلى': [{'vocalized': u'أفعلى', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'أفعلي': [{'vocalized': u'أفعلي', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أفعلي', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'فبساعتها': [{'vocalized': u'فبساعتها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'كذاتي': [{'vocalized': u'كذاتي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'كذاتي', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'كذاته': [{'vocalized': u'كذاته', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'وحماكم': [{'vocalized': u'وحماكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حما'}],

 u'كذاتك': [{'vocalized': u'كذاتك', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'ألعامتكما': [{'vocalized': u'ألعامتكما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ألعامتكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'ها': [{'vocalized': u'ها', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'ها', 'encletic': u'', 'type': u'اسم فعل', 'original': u'ها'}],

 u'فبعدهم': [{'vocalized': u'فبعدهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعد'}],

 u'ولتانك': [{'vocalized': u'ولتانك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'هج': [{'vocalized': u'هج', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'هج', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هج'}],

 u'فكابنها': [{'vocalized': u'فكابنها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'أولعينكما': [{'vocalized': u'أولعينكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'وجميع': [{'vocalized': u'وجميع', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميع', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'فتجاهكما': [{'vocalized': u'فتجاهكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تجاه'}],

 u'بضعكما': [{'vocalized': u'بضعكما', 'procletic': u'', 'tags': u'اسم;كناية;ضمير', 'stem': u'بضع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بضع'}],

 u'أكأنما': [{'vocalized': u'أكأنما', 'procletic': u'أ-', 'tags': u'حرف;حرف تشبيه;استفهام', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'فحوله': [{'vocalized': u'فحوله', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حول'}],

 u'ل': [{'vocalized': u'ل', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ل', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ل'}],

 u'ألحسبنا': [{'vocalized': u'ألحسبنا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'فحولي': [{'vocalized': u'فحولي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حول'},
 {'vocalized': u'فحولي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حول'}],

 u'وليلكما': [{'vocalized': u'وليلكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'أيمينهما': [{'vocalized': u'أيمينهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'وكهي': [{'vocalized': u'وكهي', 'procletic': u'و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'وكهو': [{'vocalized': u'وكهو', 'procletic': u'و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'وكنفسنا': [{'vocalized': u'وكنفسنا', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أنفسكن': [{'vocalized': u'أنفسكن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'هل': [{'vocalized': u'هل', 'procletic': u'', 'tags': u'حرف;حرف استفهام', 'stem': u'هل', 'encletic': u'', 'type': u'حرف', 'original': u'هل'}],

 u'أومعنا': [{'vocalized': u'أومعنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'فبعدها': [{'vocalized': u'فبعدها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعد'}],

 u'أولعليهما': [{'vocalized': u'أولعليهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'فكابنهن': [{'vocalized': u'فكابنهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'فكابنهم': [{'vocalized': u'فكابنهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'هو': [{'vocalized': u'هو', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'تلكما': [{'vocalized': u'تلكما', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'أوكنحوهم': [{'vocalized': u'أوكنحوهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أوكنحوهن': [{'vocalized': u'أوكنحوهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'وبأيتك': [{'vocalized': u'وبأيتك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'فلكان': [{'vocalized': u'فلكان', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كان', 'encletic': u'', 'type': u'فعل', 'original': u'كان'}],

 u'أفكحسبكم': [{'vocalized': u'أفكحسبكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفكحسبكن': [{'vocalized': u'أفكحسبكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'أبهذه': [{'vocalized': u'أبهذه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'نحن': [{'vocalized': u'نحن', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'فتلك': [{'vocalized': u'فتلك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'وبغروبهم': [{'vocalized': u'وبغروبهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'فشمالي': [{'vocalized': u'فشمالي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'فشمالي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'فليمينه': [{'vocalized': u'فليمينه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'أب': [{'vocalized': u'أب', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أب', 'encletic': u'', 'type': u'اسم', 'original': u'أب'}],

 u'فليمينك': [{'vocalized': u'فليمينك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'أخ': [{'vocalized': u'أخ', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'أخ', 'encletic': u'', 'type': u'اسم', 'original': u'أخ'}],

 u'أفحسبها': [{'vocalized': u'أفحسبها', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'أوشبهكما': [{'vocalized': u'أوشبهكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'فليميني': [{'vocalized': u'فليميني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'فليميني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'أخاكما': [{'vocalized': u'أخاكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخا'}],

 u'فبينهم': [{'vocalized': u'فبينهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بين'}],

 u'وبساعة': [{'vocalized': u'وبساعة', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكأسفل': [{'vocalized': u'فكأسفل', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولساعتها': [{'vocalized': u'ولساعتها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفلمع': [{'vocalized': u'أفلمع', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'فجنب': [{'vocalized': u'فجنب', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'فلأننا': [{'vocalized': u'فلأننا', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'فأناي': [{'vocalized': u'فأناي', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'فأناي', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'أفهذه': [{'vocalized': u'أفهذه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'فكغروبهما': [{'vocalized': u'فكغروبهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'فوقها': [{'vocalized': u'فوقها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'لتحتك': [{'vocalized': u'لتحتك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'فلحسبهما': [{'vocalized': u'فلحسبهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأخيكم': [{'vocalized': u'وكأخيكم', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'وكأخيكن': [{'vocalized': u'وكأخيكن', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'أبجميعهن': [{'vocalized': u'أبجميعهن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعهن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'أبجميعهم': [{'vocalized': u'أبجميعهم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعهم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'فلوراءكما': [{'vocalized': u'فلوراءكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'فلعلق': [{'vocalized': u'فلعلق', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'علق', 'encletic': u'', 'type': u'فعل', 'original': u'علق'}],

 u'حولي': [{'vocalized': u'حولي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حول'},
 {'vocalized': u'حولي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حول'}],

 u'وكأقلكن': [{'vocalized': u'وكأقلكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'فلديها': [{'vocalized': u'فلديها', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدى'}],

 u'وكأقلكم': [{'vocalized': u'وكأقلكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'وأيتنا': [{'vocalized': u'وأيتنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'أفهذا': [{'vocalized': u'أفهذا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'لساعتكم': [{'vocalized': u'لساعتكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فوقهن': [{'vocalized': u'فوقهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'فأكثركما': [{'vocalized': u'فأكثركما', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'لساعتكن': [{'vocalized': u'لساعتكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أبجميعها': [{'vocalized': u'أبجميعها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعها', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'أكأن': [{'vocalized': u'أكأن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'لنفسهم': [{'vocalized': u'لنفسهم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفسهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'فلليلكم': [{'vocalized': u'فلليلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'ألعنكن': [{'vocalized': u'ألعنكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'أي': [{'vocalized': u'أي', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'أي', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'أي', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'أي', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'أي', 'procletic': u'', 'tags': u'حرف;تعليل', 'stem': u'أي', 'encletic': u'', 'type': u'حرف', 'original': u'أي'}],

 u'فلسوى': [{'vocalized': u'فلسوى', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أو': [{'vocalized': u'أو', 'procletic': u'', 'tags': u'حرف;حرف عطف منفصل', 'stem': u'أو', 'encletic': u'', 'type': u'حرف', 'original': u'أو'}],

 u'فلشهرها': [{'vocalized': u'فلشهرها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'ألعنكم': [{'vocalized': u'ألعنكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'أفحسبهن': [{'vocalized': u'أفحسبهن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'حولك': [{'vocalized': u'حولك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حول', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حول'}],

 u'أف': [{'vocalized': u'أف', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'أف', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أف'},
 {'vocalized': u'أف', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'أف', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أف'}],

 u'أفحسبهم': [{'vocalized': u'أفحسبهم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فلأنهما': [{'vocalized': u'فلأنهما', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'أن': [{'vocalized': u'أن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'أن', 'procletic': u'', 'tags': u'حرف;حرف نصب', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'أم': [{'vocalized': u'أم', 'procletic': u'', 'tags': u'حرف;حرف عطف منفصل', 'stem': u'أم', 'encletic': u'', 'type': u'حرف', 'original': u'أم'}],

 u'لعين': [{'vocalized': u'لعين', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعين', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'لكيلا': [{'vocalized': u'لكيلا', 'procletic': u'', 'tags': u'حرف;حرف تعليل', 'stem': u'لكيلا', 'encletic': u'', 'type': u'حرف', 'original': u'لكيلا'}],

 u'كنفس': [{'vocalized': u'كنفس', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فبينها': [{'vocalized': u'فبينها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بين'}],

 u'ولساعتهن': [{'vocalized': u'ولساعتهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'وأيتكما': [{'vocalized': u'وأيتكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'وكزمانهما': [{'vocalized': u'وكزمانهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'كشطركما': [{'vocalized': u'كشطركما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'لأولئكم': [{'vocalized': u'لأولئكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'وبغروب': [{'vocalized': u'وبغروب', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'أفبمثلكما': [{'vocalized': u'أفبمثلكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أوراءكن': [{'vocalized': u'أوراءكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'بشهرنا': [{'vocalized': u'بشهرنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'أوجميعنا': [{'vocalized': u'أوجميعنا', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعنا', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'كهذين': [{'vocalized': u'كهذين', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'وبوقتهن': [{'vocalized': u'وبوقتهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'فكلحظتكن': [{'vocalized': u'فكلحظتكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'أكعينهن': [{'vocalized': u'أكعينهن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'وشهرك': [{'vocalized': u'وشهرك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'فذووكما': [{'vocalized': u'فذووكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوو'}],

 u'ولكأنكن': [{'vocalized': u'ولكأنكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'فاخلولق': [{'vocalized': u'فاخلولق', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'اخلولق', 'encletic': u'', 'type': u'فعل', 'original': u'اخلولق'}],

 u'ولكأنكم': [{'vocalized': u'ولكأنكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'فبأعليكما': [{'vocalized': u'فبأعليكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فلحظتكم': [{'vocalized': u'فلحظتكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فلحظتكن': [{'vocalized': u'فلحظتكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'وأبا': [{'vocalized': u'وأبا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أبا', 'encletic': u'', 'type': u'اسم', 'original': u'أبا'}],

 u'أبعينهم': [{'vocalized': u'أبعينهم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'وآه': [{'vocalized': u'وآه', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'آه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'آه'}],

 u'غيرهم': [{'vocalized': u'غيرهم', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'غيرهن': [{'vocalized': u'غيرهن', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'فلليلكن': [{'vocalized': u'فلليلكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'وعليكم': [{'vocalized': u'وعليكم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'وعليكن': [{'vocalized': u'وعليكن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'ولارتد': [{'vocalized': u'ولارتد', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'ارتد', 'encletic': u'', 'type': u'فعل', 'original': u'ارتد'}],

 u'وعامتهن': [{'vocalized': u'وعامتهن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'وعامتهم': [{'vocalized': u'وعامتهم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'كلحظتكن': [{'vocalized': u'كلحظتكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'أوككلك': [{'vocalized': u'أوككلك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'وأبي': [{'vocalized': u'وأبي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'أوككله': [{'vocalized': u'أوككله', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككله', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'وأبو': [{'vocalized': u'وأبو', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أبو', 'encletic': u'', 'type': u'اسم', 'original': u'أبو'}],

 u'فماانفككت': [{'vocalized': u'فماانفككت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'},
 {'vocalized': u'فماانفككت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'},
 {'vocalized': u'فماانفككت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككت'}],

 u'أوككلي': [{'vocalized': u'أوككلي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'مكانكما': [{'vocalized': u'مكانكما', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'مكانكما', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكما'}],

 u'فلعلى': [{'vocalized': u'فلعلى', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'فنفسك': [{'vocalized': u'فنفسك', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'ألديك': [{'vocalized': u'ألديك', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدى'}],

 u'وكأولاء': [{'vocalized': u'وكأولاء', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'غيرها': [{'vocalized': u'غيرها', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'كلحظتكم': [{'vocalized': u'كلحظتكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'ألديه': [{'vocalized': u'ألديه', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدى'}],

 u'أفعينه': [{'vocalized': u'أفعينه', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أبغير': [{'vocalized': u'أبغير', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'لعل': [{'vocalized': u'لعل', 'procletic': u'', 'tags': u'حرف;إن و أخواتها', 'stem': u'لعل', 'encletic': u'', 'type': u'حرف', 'original': u'لعل'}],

 u'لعن': [{'vocalized': u'لعن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'فلبعضهما': [{'vocalized': u'فلبعضهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'فلبعضهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'وعامتها': [{'vocalized': u'وعامتها', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'ابنكما': [{'vocalized': u'ابنكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'خلاك': [{'vocalized': u'خلاك', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'خلا'}],

 u'خلاه': [{'vocalized': u'خلاه', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'خلا'}],

 u'خلال': [{'vocalized': u'خلال', 'procletic': u'', 'tags': u'اسم;ظرف زمان/مكان', 'stem': u'خلال', 'encletic': u'', 'type': u'اسم', 'original': u'خلال'}],

 u'خلاي': [{'vocalized': u'خلاي', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'خلا'},
 {'vocalized': u'خلاي', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'خلا'}],

 u'وحينما': [{'vocalized': u'وحينما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'حينما', 'encletic': u'', 'type': u'اسم', 'original': u'حينما'}],

 u'أوخلفك': [{'vocalized': u'أوخلفك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'فليتكم': [{'vocalized': u'فليتكم', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-كم', 'type': u'حرف', 'original': u'ليت'}],

 u'فليتكن': [{'vocalized': u'فليتكن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'ليت', 'encletic': u'-كن', 'type': u'حرف', 'original': u'ليت'}],

 u'ألتحتهما': [{'vocalized': u'ألتحتهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'حميكم': [{'vocalized': u'حميكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'حميكن': [{'vocalized': u'حميكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'لولا': [{'vocalized': u'لولا', 'procletic': u'', 'tags': u'حرف;الحروف(حروف)', 'stem': u'لولا', 'encletic': u'', 'type': u'حرف', 'original': u'لولا'}],

 u'أليمينهما': [{'vocalized': u'أليمينهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'فكأيكم': [{'vocalized': u'فكأيكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'فكأيكن': [{'vocalized': u'فكأيكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'أكبعضكم': [{'vocalized': u'أكبعضكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'فللائي': [{'vocalized': u'فللائي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'أكبعضكن': [{'vocalized': u'أكبعضكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'لعينهن': [{'vocalized': u'لعينهن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'لعينهم': [{'vocalized': u'لعينهم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'فبله': [{'vocalized': u'فبله', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بله', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بله'}],

 u'فكليلي': [{'vocalized': u'فكليلي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'فكليلي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'أولذين': [{'vocalized': u'أولذين', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'أكلاهما': [{'vocalized': u'أكلاهما', 'procletic': u'أ-', 'tags': u'حرف;توكيد;استفهام', 'stem': u'كلاهما', 'encletic': u'', 'type': u'حرف', 'original': u'كلاهما'}],

 u'فبشرقي': [{'vocalized': u'فبشرقي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'},
 {'vocalized': u'فبشرقي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شرق'}],

 u'وجنوبهما': [{'vocalized': u'وجنوبهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبشرقه': [{'vocalized': u'فبشرقه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'ليتك': [{'vocalized': u'ليتك', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-ك', 'type': u'حرف', 'original': u'ليت'}],

 u'فبشرقك': [{'vocalized': u'فبشرقك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'فلغربك': [{'vocalized': u'فلغربك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'وفوقهن': [{'vocalized': u'وفوقهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'وبشطر': [{'vocalized': u'وبشطر', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'أولعلكما': [{'vocalized': u'أولعلكما', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لعل'}],

 u'ولشمالكم': [{'vocalized': u'ولشمالكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'ولشبهكما': [{'vocalized': u'ولشبهكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبهكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'أبغيرها': [{'vocalized': u'أبغيرها', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'أفبنفسنا': [{'vocalized': u'أفبنفسنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'لعمرك': [{'vocalized': u'لعمرك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لعمر'}],

 u'ولأنكم': [{'vocalized': u'ولأنكم', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'ولأنكن': [{'vocalized': u'ولأنكن', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'لعمره': [{'vocalized': u'لعمره', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لعمر'}],

 u'أولسوى': [{'vocalized': u'أولسوى', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أولسوي': [{'vocalized': u'أولسوي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أولسوي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'فوقته': [{'vocalized': u'فوقته', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'فلخلفكما': [{'vocalized': u'فلخلفكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'أوإنكما': [{'vocalized': u'أوإنكما', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إن'}],

 u'أفكشبههما': [{'vocalized': u'أفكشبههما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'أوفوق': [{'vocalized': u'أوفوق', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'أفكنفسي': [{'vocalized': u'أفكنفسي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفكنفسي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أبيهما': [{'vocalized': u'أبيهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'أكعامتهما': [{'vocalized': u'أكعامتهما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أكعامة': [{'vocalized': u'أكعامة', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'وبأي': [{'vocalized': u'وبأي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'وبأي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'أفكنفسك': [{'vocalized': u'أفكنفسك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'فضمنه': [{'vocalized': u'فضمنه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ضمن'}],

 u'وبأن': [{'vocalized': u'وبأن', 'procletic': u'و-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'وبأن', 'procletic': u'و-ب-', 'tags': u'حرف;حرف نصب;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'أنحوها': [{'vocalized': u'أنحوها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'وبأيهما': [{'vocalized': u'وبأيهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'فضمنك': [{'vocalized': u'فضمنك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ضمن'}],

 u'لعينها': [{'vocalized': u'لعينها', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'لعينها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'فبلا': [{'vocalized': u'فبلا', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'بلا', 'encletic': u'', 'type': u'حرف', 'original': u'بلا'}],

 u'ولعلهما': [{'vocalized': u'ولعلهما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لعل'}],

 u'أناك': [{'vocalized': u'أناك', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'لخلفهم': [{'vocalized': u'لخلفهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'ولأينا': [{'vocalized': u'ولأينا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'فمافتئتن': [{'vocalized': u'فمافتئتن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتن', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتن'}],

 u'ووراءكن': [{'vocalized': u'ووراءكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'فبحسبكما': [{'vocalized': u'فبحسبكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'ضمنهن': [{'vocalized': u'ضمنهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ضمن'}],

 u'ضمنهم': [{'vocalized': u'ضمنهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ضمن'}],

 u'فحواليهن': [{'vocalized': u'فحواليهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حوالى'}],

 u'بذويي': [{'vocalized': u'بذويي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'بذويي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'وأناها': [{'vocalized': u'وأناها', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'كفيهما': [{'vocalized': u'كفيهما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'}],

 u'بذويك': [{'vocalized': u'بذويك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'بعضنا': [{'vocalized': u'بعضنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'بذويه': [{'vocalized': u'بذويه', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'آناء': [{'vocalized': u'آناء', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'آناء', 'encletic': u'', 'type': u'اسم', 'original': u'آناء'}],

 u'فكذاتها': [{'vocalized': u'فكذاتها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'فلوقتكم': [{'vocalized': u'فلوقتكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'وبغروبهما': [{'vocalized': u'وبغروبهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'أبتينك': [{'vocalized': u'أبتينك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'وأناهم': [{'vocalized': u'وأناهم', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'لأكثركما': [{'vocalized': u'لأكثركما', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'فلكليكما': [{'vocalized': u'فلكليكما', 'procletic': u'ف-ل-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'وحسبهما': [{'vocalized': u'وحسبهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'لأنكما': [{'vocalized': u'لأنكما', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'وكلما': [{'vocalized': u'وكلما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'كلما', 'encletic': u'', 'type': u'اسم', 'original': u'كلما'}],

 u'لهما': [{'vocalized': u'لهما', 'procletic': u'ل-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'},
 {'vocalized': u'لهما', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'أحسبما': [{'vocalized': u'أحسبما', 'procletic': u'أ-', 'tags': u'اسم;جار ومجرور;استفهام', 'stem': u'حسبما', 'encletic': u'', 'type': u'اسم', 'original': u'حسبما'}],

 u'فلاسيما': [{'vocalized': u'فلاسيما', 'procletic': u'ف-', 'tags': u'حرف;استثناء;عطف', 'stem': u'لاسيما', 'encletic': u'', 'type': u'حرف', 'original': u'لاسيما'}],

 u'أولعينك': [{'vocalized': u'أولعينك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعينك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أكهاتين': [{'vocalized': u'أكهاتين', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'وفوقه': [{'vocalized': u'وفوقه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'لكنهما': [{'vocalized': u'لكنهما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنهما', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لكن'}],

 u'وفوقك': [{'vocalized': u'وفوقك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'أولعيني': [{'vocalized': u'أولعيني', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعيني', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعيني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أولعيني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وكأخي': [{'vocalized': u'وكأخي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'أناه': [{'vocalized': u'أناه', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'وفوقي': [{'vocalized': u'وفوقي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'وفوقي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'أأناهما': [{'vocalized': u'أأناهما', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'أولأمامك': [{'vocalized': u'أولأمامك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'ضمنها': [{'vocalized': u'ضمنها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ضمن'}],

 u'فشطرهما': [{'vocalized': u'فشطرهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شطر'}],

 u'وليمينكما': [{'vocalized': u'وليمينكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'أككلكما': [{'vocalized': u'أككلكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلكما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'أوليسوا': [{'vocalized': u'أوليسوا', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'ليسوا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسوا'}],

 u'بشهري': [{'vocalized': u'بشهري', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'بشهري', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فكحيث': [{'vocalized': u'فكحيث', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'بشهره': [{'vocalized': u'بشهره', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'أولسن': [{'vocalized': u'أولسن', 'procletic': u'أ-و-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لسن', 'encletic': u'', 'type': u'فعل', 'original': u'لسن'}],

 u'بشهرك': [{'vocalized': u'بشهرك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'أباهما': [{'vocalized': u'أباهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبا'}],

 u'أفبهما': [{'vocalized': u'أفبهما', 'procletic': u'أ-ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'أوبعينهم': [{'vocalized': u'أوبعينهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أوبعينهن': [{'vocalized': u'أوبعينهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'ولشمال': [{'vocalized': u'ولشمال', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'أبشبهه': [{'vocalized': u'أبشبهه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'بخلفها': [{'vocalized': u'بخلفها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'أبشبهك': [{'vocalized': u'أبشبهك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أفبأجمعها': [{'vocalized': u'أفبأجمعها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكغيرها': [{'vocalized': u'أكغيرها', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'أبشبهي': [{'vocalized': u'أبشبهي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أبشبهي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'فبحسبكن': [{'vocalized': u'فبحسبكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فبحسبكم': [{'vocalized': u'فبحسبكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'فبغربكن': [{'vocalized': u'فبغربكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'أوبنفسها': [{'vocalized': u'أوبنفسها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'فبغربكم': [{'vocalized': u'فبغربكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'فوقهم': [{'vocalized': u'فوقهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'وثمة': [{'vocalized': u'وثمة', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ثمة', 'encletic': u'', 'type': u'اسم', 'original': u'ثمة'}],

 u'ألكلتا': [{'vocalized': u'ألكلتا', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'},
 {'vocalized': u'ألكلتا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفلأنانا': [{'vocalized': u'أفلأنانا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'ألوراءهن': [{'vocalized': u'ألوراءهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'أولسويهما': [{'vocalized': u'أولسويهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'شرقه': [{'vocalized': u'شرقه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'أكغيرهم': [{'vocalized': u'أكغيرهم', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أفبأجمعهن': [{'vocalized': u'أفبأجمعهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفبأجمعهم': [{'vocalized': u'أفبأجمعهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكغيرهن': [{'vocalized': u'أكغيرهن', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أوبنفسهن': [{'vocalized': u'أوبنفسهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'ولوقتي': [{'vocalized': u'ولوقتي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'ولوقتي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'أوبنفسهم': [{'vocalized': u'أوبنفسهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'وأيتك': [{'vocalized': u'وأيتك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'وتجاه': [{'vocalized': u'وتجاه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'تجاه', 'encletic': u'', 'type': u'اسم', 'original': u'تجاه'}],

 u'جنوبكن': [{'vocalized': u'جنوبكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'وأيتي': [{'vocalized': u'وأيتي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'وأيتي', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'فأخاك': [{'vocalized': u'فأخاك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخا'}],

 u'فأخاه': [{'vocalized': u'فأخاه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخا'}],

 u'أبدا': [{'vocalized': u'أبدا', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'أبدا', 'encletic': u'', 'type': u'اسم', 'original': u'أبدا'}],

 u'فأخاي': [{'vocalized': u'فأخاي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخا'},
 {'vocalized': u'فأخاي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخا'}],

 u'فإيه': [{'vocalized': u'فإيه', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إيه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إيه'}],

 u'أفخلفكما': [{'vocalized': u'أفخلفكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'سرعان': [{'vocalized': u'سرعان', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'سرعان', 'encletic': u'', 'type': u'اسم فعل', 'original': u'سرعان'}],

 u'فلاخلولق': [{'vocalized': u'فلاخلولق', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'اخلولق', 'encletic': u'', 'type': u'فعل', 'original': u'اخلولق'}],

 u'أبعامتكم': [{'vocalized': u'أبعامتكم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أبعامتكن': [{'vocalized': u'أبعامتكن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلخلفكن': [{'vocalized': u'أفلخلفكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'أوبعينها': [{'vocalized': u'أوبعينها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'وكغرب': [{'vocalized': u'وكغرب', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'ولخلفها': [{'vocalized': u'ولخلفها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'أولإليهن': [{'vocalized': u'أولإليهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'أولإليهم': [{'vocalized': u'أولإليهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'فأمد': [{'vocalized': u'فأمد', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أمد', 'encletic': u'', 'type': u'اسم', 'original': u'أمد'}],

 u'فخلانا': [{'vocalized': u'فخلانا', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'خلا'}],

 u'ونحوكن': [{'vocalized': u'ونحوكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'ونحوكم': [{'vocalized': u'ونحوكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ونحوكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'جميعهما': [{'vocalized': u'جميعهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعهما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'فشبهنا': [{'vocalized': u'فشبهنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'أولنفسكما': [{'vocalized': u'أولنفسكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'فأمس': [{'vocalized': u'فأمس', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أمس', 'encletic': u'', 'type': u'اسم', 'original': u'أمس'}],

 u'وطفق': [{'vocalized': u'وطفق', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'طفق', 'encletic': u'', 'type': u'فعل', 'original': u'طفق'}],

 u'بعد': [{'vocalized': u'بعد', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'بعد', 'encletic': u'', 'type': u'اسم', 'original': u'بعد'}],

 u'أوليميني': [{'vocalized': u'أوليميني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'أوليميني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'ولأعليهن': [{'vocalized': u'ولأعليهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'أوبعضكما': [{'vocalized': u'أوبعضكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'ولذاك': [{'vocalized': u'ولذاك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'ولأعليكما': [{'vocalized': u'ولأعليكما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'أتينك': [{'vocalized': u'أتينك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'أوليمينه': [{'vocalized': u'أوليمينه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'وكعينه': [{'vocalized': u'وكعينه', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'وعيننا': [{'vocalized': u'وعيننا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'وكعينك': [{'vocalized': u'وكعينك', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'شبهكما': [{'vocalized': u'شبهكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'أوفوقهم': [{'vocalized': u'أوفوقهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'وكعيني': [{'vocalized': u'وكعيني', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'وكعيني', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'فبعدكما': [{'vocalized': u'فبعدكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعد'}],

 u'فماانفككن': [{'vocalized': u'فماانفككن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككن', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككن'}],

 u'أكسويهما': [{'vocalized': u'أكسويهما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فخلالهن': [{'vocalized': u'فخلالهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلال'}],

 u'أفحسب': [{'vocalized': u'أفحسب', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'فلذاتهما': [{'vocalized': u'فلذاتهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'ولذات': [{'vocalized': u'ولذات', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذات', 'encletic': u'', 'type': u'اسم', 'original': u'ذات'}],

 u'أبعامته': [{'vocalized': u'أبعامته', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'وشرقنا': [{'vocalized': u'وشرقنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'وبضعها': [{'vocalized': u'وبضعها', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بضع'}],

 u'أبعامتك': [{'vocalized': u'أبعامتك', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'بابنكن': [{'vocalized': u'بابنكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'بابنكم': [{'vocalized': u'بابنكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'أبعامتي': [{'vocalized': u'أبعامتي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أبعامتي', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'أولإليها': [{'vocalized': u'أولإليها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'أوسويك': [{'vocalized': u'أوسويك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'أوسويه': [{'vocalized': u'أوسويه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكليكما': [{'vocalized': u'أوكليكما', 'procletic': u'أ-و-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'ألأمامنا': [{'vocalized': u'ألأمامنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'ولتبدل': [{'vocalized': u'ولتبدل', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'تبدل', 'encletic': u'', 'type': u'فعل', 'original': u'تبدل'}],

 u'وبالذي': [{'vocalized': u'وبالذي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'فلغيركما': [{'vocalized': u'فلغيركما', 'procletic': u'ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فلغيركما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'ماذا': [{'vocalized': u'ماذا', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'ماذا', 'encletic': u'', 'type': u'اسم', 'original': u'ماذا'}],

 u'ذويهن': [{'vocalized': u'ذويهن', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوي'}],

 u'فبزمانهن': [{'vocalized': u'فبزمانهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'أفشبههما': [{'vocalized': u'أفشبههما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'ذويهم': [{'vocalized': u'ذويهم', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوي'}],

 u'فأمامكما': [{'vocalized': u'فأمامكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'أولديكما': [{'vocalized': u'أولديكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدى'}],

 u'كشهرها': [{'vocalized': u'كشهرها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'أففينا': [{'vocalized': u'أففينا', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'ألكليهما': [{'vocalized': u'ألكليهما', 'procletic': u'أ-ل-', 'tags': u'حرف;توكيد;مجرور;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'أفكلاهما': [{'vocalized': u'أفكلاهما', 'procletic': u'أ-ف-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كلاهما', 'encletic': u'', 'type': u'حرف', 'original': u'كلاهما'}],

 u'فغير': [{'vocalized': u'فغير', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'فحاشاها': [{'vocalized': u'فحاشاها', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'حاشا'}],

 u'أفلنفسه': [{'vocalized': u'أفلنفسه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'بحميي': [{'vocalized': u'بحميي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'بحميي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'أولذلكم': [{'vocalized': u'أولذلكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'أفلنفسك': [{'vocalized': u'أفلنفسك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'أولذلكن': [{'vocalized': u'أولذلكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'بحميك': [{'vocalized': u'بحميك', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'بحميه': [{'vocalized': u'بحميه', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'أفلنفسي': [{'vocalized': u'أفلنفسي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أفلنفسي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أوعامته': [{'vocalized': u'أوعامته', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'أكحسب': [{'vocalized': u'أكحسب', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أفكغيركم': [{'vocalized': u'أفكغيركم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'ولستن': [{'vocalized': u'ولستن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'لستن', 'encletic': u'', 'type': u'فعل', 'original': u'لستن'}],

 u'أفكغيركن': [{'vocalized': u'أفكغيركن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'وجنبك': [{'vocalized': u'وجنبك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'ولتلقاءكما': [{'vocalized': u'ولتلقاءكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكأبي': [{'vocalized': u'وكأبي', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'وذلكما': [{'vocalized': u'وذلكما', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'وجميعكم': [{'vocalized': u'وجميعكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعكم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'وجميعكن': [{'vocalized': u'وجميعكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وجميعكن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'لعمرهما': [{'vocalized': u'لعمرهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'لعمر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لعمر'}],

 u'فأف': [{'vocalized': u'فأف', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أف', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أف'},
 {'vocalized': u'فأف', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'أف', 'encletic': u'', 'type': u'اسم فعل', 'original': u'أف'}],

 u'فأثناء': [{'vocalized': u'فأثناء', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكغربي': [{'vocalized': u'وكغربي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'وكغربي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'فأثناءها': [{'vocalized': u'فأثناءها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولأسفلي': [{'vocalized': u'ولأسفلي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'ولأسفلي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكساعتكم': [{'vocalized': u'وكساعتكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'أولعله': [{'vocalized': u'أولعله', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لعل'}],

 u'وكساعتكن': [{'vocalized': u'وكساعتكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أولعلك': [{'vocalized': u'أولعلك', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لعل'}],

 u'أوشك': [{'vocalized': u'أوشك', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'أوشك', 'encletic': u'', 'type': u'فعل', 'original': u'أوشك'}],

 u'كأيكما': [{'vocalized': u'كأيكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'أولعلي': [{'vocalized': u'أولعلي', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'أولعلي', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'أولعلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أولعلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'أولعلى': [{'vocalized': u'أولعلى', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'أفكعينكم': [{'vocalized': u'أفكعينكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'بذوي': [{'vocalized': u'بذوي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'فحاشاهن': [{'vocalized': u'فحاشاهن', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'حاشا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'حاشا'}],

 u'فحمانا': [{'vocalized': u'فحمانا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حما'}],

 u'لكأنكن': [{'vocalized': u'لكأنكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'أفأجمعي': [{'vocalized': u'أفأجمعي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفأجمعي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'فأقلها': [{'vocalized': u'فأقلها', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'أفحسبما': [{'vocalized': u'أفحسبما', 'procletic': u'أ-ف-', 'tags': u'اسم;جار ومجرور;عطف;استفهام', 'stem': u'حسبما', 'encletic': u'', 'type': u'اسم', 'original': u'حسبما'}],

 u'فلوراءكن': [{'vocalized': u'فلوراءكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'فلوراءكم': [{'vocalized': u'فلوراءكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'فأضحى': [{'vocalized': u'فأضحى', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'أضحى', 'encletic': u'', 'type': u'فعل', 'original': u'أضحى'}],

 u'أفأجمعك': [{'vocalized': u'أفأجمعك', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'إلينا': [{'vocalized': u'إلينا', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'فلإلينا': [{'vocalized': u'فلإلينا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'أفأجمعه': [{'vocalized': u'أفأجمعه', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'وكغربك': [{'vocalized': u'وكغربك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'وكلحظتهم': [{'vocalized': u'وكلحظتهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبابنكما': [{'vocalized': u'فبابنكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'وخلالكم': [{'vocalized': u'وخلالكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلال'}],

 u'أفكمثلهما': [{'vocalized': u'أفكمثلهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'وخلالكن': [{'vocalized': u'وخلالكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلال'}],

 u'ولدنها': [{'vocalized': u'ولدنها', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدن'}],

 u'لراح': [{'vocalized': u'لراح', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'راح', 'encletic': u'', 'type': u'فعل', 'original': u'راح'}],

 u'فككليكما': [{'vocalized': u'فككليكما', 'procletic': u'ف-ك-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'فهذه': [{'vocalized': u'فهذه', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'لكرب': [{'vocalized': u'لكرب', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كرب', 'encletic': u'', 'type': u'فعل', 'original': u'كرب'}],

 u'فهذي': [{'vocalized': u'فهذي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'فلأبيكن': [{'vocalized': u'فلأبيكن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'وبذويكم': [{'vocalized': u'وبذويكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'وبذويكن': [{'vocalized': u'وبذويكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلأبيكم': [{'vocalized': u'فلأبيكم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'ولدننا': [{'vocalized': u'ولدننا', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدن'}],

 u'لأيتنا': [{'vocalized': u'لأيتنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'ولازلتما': [{'vocalized': u'ولازلتما', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'},
 {'vocalized': u'ولازلتما', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'}],

 u'وليست': [{'vocalized': u'وليست', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليست', 'encletic': u'', 'type': u'فعل', 'original': u'ليست'}],

 u'فلغربنا': [{'vocalized': u'فلغربنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'فهذا': [{'vocalized': u'فهذا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'وليسا': [{'vocalized': u'وليسا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليسا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسا'}],

 u'ألكأنه': [{'vocalized': u'ألكأنه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'وبأثناءهما': [{'vocalized': u'وبأثناءهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أثناء'}],

 u'فأقلهن': [{'vocalized': u'فأقلهن', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'ألكأنك': [{'vocalized': u'ألكأنك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'أفإليها': [{'vocalized': u'أفإليها', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'فكخلفكما': [{'vocalized': u'فكخلفكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'ألكأني': [{'vocalized': u'ألكأني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'ألكأني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'وبحميكما': [{'vocalized': u'وبحميكما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'أفكشبهكن': [{'vocalized': u'أفكشبهكن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفكشبهكم': [{'vocalized': u'أفكشبهكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'أفبشبهنا': [{'vocalized': u'أفبشبهنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'وريث': [{'vocalized': u'وريث', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'ريث', 'encletic': u'', 'type': u'اسم', 'original': u'ريث'}],

 u'كما': [{'vocalized': u'كما', 'procletic': u'', 'tags': u'حرف;حرف تشبيه', 'stem': u'كما', 'encletic': u'', 'type': u'حرف', 'original': u'كما'}],

 u'أوكعيني': [{'vocalized': u'أوكعيني', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أوكعيني', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'ألعينه': [{'vocalized': u'ألعينه', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'وحينهن': [{'vocalized': u'وحينهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حين'}],

 u'أأجمع': [{'vocalized': u'أأجمع', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبطآن': [{'vocalized': u'وبطآن', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بطآن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بطآن'}],

 u'ألعينك': [{'vocalized': u'ألعينك', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعينك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'ولكليكما': [{'vocalized': u'ولكليكما', 'procletic': u'و-ل-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أوكعينك': [{'vocalized': u'أوكعينك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'فوقتنا': [{'vocalized': u'فوقتنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'ألعيني': [{'vocalized': u'ألعيني', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعيني', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعيني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعيني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'أفلعامتي': [{'vocalized': u'أفلعامتي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فبأيكما': [{'vocalized': u'فبأيكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'فكأخي': [{'vocalized': u'فكأخي', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'أوراء': [{'vocalized': u'أوراء', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'وبحميكن': [{'vocalized': u'وبحميكن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'بغربكما': [{'vocalized': u'بغربكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'كنحوه': [{'vocalized': u'كنحوه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوه', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'أفهاتان': [{'vocalized': u'أفهاتان', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاتان', 'encletic': u'', 'type': u'اسم', 'original': u'هاتان'}],

 u'فبشهري': [{'vocalized': u'فبشهري', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'فبشهري', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فأيهن': [{'vocalized': u'فأيهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'كجنبنا': [{'vocalized': u'كجنبنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'فبشهره': [{'vocalized': u'فبشهره', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'أحسبهم': [{'vocalized': u'أحسبهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فلكأنكما': [{'vocalized': u'فلكأنكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'كهذا': [{'vocalized': u'كهذا', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'فبشهرك': [{'vocalized': u'فبشهرك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'فلغربكما': [{'vocalized': u'فلغربكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'بكليكما': [{'vocalized': u'بكليكما', 'procletic': u'ب-', 'tags': u'حرف;توكيد;مجرور', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أومنكم': [{'vocalized': u'أومنكم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'ولعامتها': [{'vocalized': u'ولعامتها', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'أفبسوينا': [{'vocalized': u'أفبسوينا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'وتلقاءكما': [{'vocalized': u'وتلقاءكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ألهؤلاء': [{'vocalized': u'ألهؤلاء', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'ولزماننا': [{'vocalized': u'ولزماننا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'كهذي': [{'vocalized': u'كهذي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'لأعلينا': [{'vocalized': u'لأعلينا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'فأخانا': [{'vocalized': u'فأخانا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخا'}],

 u'فأب': [{'vocalized': u'فأب', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أب', 'encletic': u'', 'type': u'اسم', 'original': u'أب'}],

 u'أفأمامكما': [{'vocalized': u'أفأمامكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'عاد': [{'vocalized': u'عاد', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'عاد', 'encletic': u'', 'type': u'فعل', 'original': u'عاد'}],

 u'فأيها': [{'vocalized': u'فأيها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'أوحسبما': [{'vocalized': u'أوحسبما', 'procletic': u'أ-و-', 'tags': u'اسم;جار ومجرور;عطف;استفهام', 'stem': u'حسبما', 'encletic': u'', 'type': u'اسم', 'original': u'حسبما'}],

 u'كهذه': [{'vocalized': u'كهذه', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'فبنحونا': [{'vocalized': u'فبنحونا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحونا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'ولعامتهم': [{'vocalized': u'ولعامتهم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'ولعامتهن': [{'vocalized': u'ولعامتهن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامتهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'وبفيكما': [{'vocalized': u'وبفيكما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'}],

 u'وكغروب': [{'vocalized': u'وكغروب', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'لغروبهما': [{'vocalized': u'لغروبهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'فلأينا': [{'vocalized': u'فلأينا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'فلنحوكن': [{'vocalized': u'فلنحوكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'وشبهكم': [{'vocalized': u'وشبهكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'وشبهكن': [{'vocalized': u'وشبهكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'فلنحوكم': [{'vocalized': u'فلنحوكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فلنحوكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أبسوينا': [{'vocalized': u'أبسوينا', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلعن': [{'vocalized': u'أفلعن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'وحينها': [{'vocalized': u'وحينها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حين'}],

 u'أفلعل': [{'vocalized': u'أفلعل', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام', 'stem': u'لعل', 'encletic': u'', 'type': u'حرف', 'original': u'لعل'}],

 u'فلحسبنا': [{'vocalized': u'فلحسبنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'بأثناءكم': [{'vocalized': u'بأثناءكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'جميعكم': [{'vocalized': u'جميعكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعكم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'غربكما': [{'vocalized': u'غربكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'جميعكن': [{'vocalized': u'جميعكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'جميعكن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'كساعتهن': [{'vocalized': u'كساعتهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'فبمثل': [{'vocalized': u'فبمثل', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'لأبيك': [{'vocalized': u'لأبيك', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'فبدونه': [{'vocalized': u'فبدونه', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بدون'}],

 u'وكعيننا': [{'vocalized': u'وكعيننا', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'كساعتهم': [{'vocalized': u'كساعتهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فبدونك': [{'vocalized': u'فبدونك', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بدون'}],

 u'فمادمتما': [{'vocalized': u'فمادمتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتما', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتما'},
 {'vocalized': u'فمادمتما', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتما', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتما'}],

 u'فبدوني': [{'vocalized': u'فبدوني', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بدون'},
 {'vocalized': u'فبدوني', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بدون'}],

 u'لأبيه': [{'vocalized': u'لأبيه', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'ذي': [{'vocalized': u'ذي', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'},
 {'vocalized': u'ذي', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فبأجمعها': [{'vocalized': u'فبأجمعها', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفكسويها': [{'vocalized': u'أفكسويها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'أوبعامتنا': [{'vocalized': u'أوبعامتنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'وكشطرهن': [{'vocalized': u'وكشطرهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'فكشرقكن': [{'vocalized': u'فكشرقكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'فكشرقكم': [{'vocalized': u'فكشرقكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شرق'}],

 u'بته': [{'vocalized': u'بته', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'لأيكما': [{'vocalized': u'لأيكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'وكخلفكما': [{'vocalized': u'وكخلفكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'أفلكليهما': [{'vocalized': u'أفلكليهما', 'procletic': u'أ-ف-ل-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'بتي': [{'vocalized': u'بتي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'أولغيري': [{'vocalized': u'أولغيري', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيري', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيري', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيري', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أوأناكم': [{'vocalized': u'أوأناكم', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'ألستن': [{'vocalized': u'ألستن', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لستن', 'encletic': u'', 'type': u'فعل', 'original': u'لستن'}],

 u'أولغيرك': [{'vocalized': u'أولغيرك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيرك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'ولشبههم': [{'vocalized': u'ولشبههم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبههم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'أولغيره': [{'vocalized': u'أولغيره', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيره', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أفكأجمعهن': [{'vocalized': u'أفكأجمعهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكالألاء': [{'vocalized': u'فكالألاء', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'فشمال': [{'vocalized': u'فشمال', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'ألشمالها': [{'vocalized': u'ألشمالها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'كأعليها': [{'vocalized': u'كأعليها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'ألشمالكن': [{'vocalized': u'ألشمالكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'لأوشك': [{'vocalized': u'لأوشك', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أوشك', 'encletic': u'', 'type': u'فعل', 'original': u'أوشك'}],

 u'لخلفهما': [{'vocalized': u'لخلفهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'أولأمامهما': [{'vocalized': u'أولأمامهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'فبتين': [{'vocalized': u'فبتين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'وماانفككتم': [{'vocalized': u'وماانفككتم', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتم', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتم'}],

 u'كشرقهم': [{'vocalized': u'كشرقهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شرق'}],

 u'عداكما': [{'vocalized': u'عداكما', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'عدا'}],

 u'فبأجمعهم': [{'vocalized': u'فبأجمعهم', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلنحونا': [{'vocalized': u'أفلنحونا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'فبأجمعهن': [{'vocalized': u'فبأجمعهن', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفكأن': [{'vocalized': u'أفكأن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'فزماني': [{'vocalized': u'فزماني', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'فزماني', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'أفكسويهم': [{'vocalized': u'أفكسويهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'فزمانه': [{'vocalized': u'فزمانه', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'أفكسويهن': [{'vocalized': u'أفكسويهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'ألديكم': [{'vocalized': u'ألديكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لدى'}],

 u'أكجميعنا': [{'vocalized': u'أكجميعنا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أكجميعنا', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'فزمانك': [{'vocalized': u'فزمانك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'ألديكن': [{'vocalized': u'ألديكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدى'}],

 u'أبشبهكم': [{'vocalized': u'أبشبهكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'فنفسي': [{'vocalized': u'فنفسي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فنفسي', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'فنفسه': [{'vocalized': u'فنفسه', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'ففو': [{'vocalized': u'ففو', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'فو', 'encletic': u'', 'type': u'اسم', 'original': u'فو'}],

 u'ففي': [{'vocalized': u'ففي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففي', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'وبجنوبكما': [{'vocalized': u'وبجنوبكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفكذين': [{'vocalized': u'أفكذين', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'وقتنا': [{'vocalized': u'وقتنا', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'ساءما': [{'vocalized': u'ساءما', 'procletic': u'', 'tags': u'فعل;المدح والذم', 'stem': u'ساءما', 'encletic': u'', 'type': u'فعل', 'original': u'ساءما'}],

 u'أووراءنا': [{'vocalized': u'أووراءنا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وراء'}],

 u'أمعكما': [{'vocalized': u'أمعكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'ح': [{'vocalized': u'ح', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ح', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ح'}],

 u'وشبههما': [{'vocalized': u'وشبههما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'ووراءكم': [{'vocalized': u'ووراءكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'للحظتكما': [{'vocalized': u'للحظتكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لحظة'}],

 u'ولديه': [{'vocalized': u'ولديه', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لدى'}],

 u'وكجميعكما': [{'vocalized': u'وكجميعكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعكما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'أوفوقها': [{'vocalized': u'أوفوقها', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'فتلقاءهما': [{'vocalized': u'فتلقاءهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أأنانا': [{'vocalized': u'أأنانا', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'فوقتها': [{'vocalized': u'فوقتها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'وبأكثركما': [{'vocalized': u'وبأكثركما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'لكنكن': [{'vocalized': u'لكنكن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنكن', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لكن'}],

 u'لكنكم': [{'vocalized': u'لكنكم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنكم', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'لكن'}],

 u'معكن': [{'vocalized': u'معكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'لشمالكن': [{'vocalized': u'لشمالكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'ولديك': [{'vocalized': u'ولديك', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدى'}],

 u'بنفسكم': [{'vocalized': u'بنفسكم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'معكم': [{'vocalized': u'معكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'بنفسكن': [{'vocalized': u'بنفسكن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أولخلف': [{'vocalized': u'أولخلف', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'تحول': [{'vocalized': u'تحول', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'تحول', 'encletic': u'', 'type': u'فعل', 'original': u'تحول'}],

 u'وكحيث': [{'vocalized': u'وكحيث', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'أفلخلفكم': [{'vocalized': u'أفلخلفكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'فبسويكن': [{'vocalized': u'فبسويكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'فبسويكم': [{'vocalized': u'فبسويكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أوفوقهن': [{'vocalized': u'أوفوقهن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'فصار': [{'vocalized': u'فصار', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'صار', 'encletic': u'', 'type': u'فعل', 'original': u'صار'}],

 u'أأجمعهما': [{'vocalized': u'أأجمعهما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ففا': [{'vocalized': u'ففا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'فا', 'encletic': u'', 'type': u'اسم', 'original': u'فا'}],

 u'فكأسفله': [{'vocalized': u'فكأسفله', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'أسفلكما': [{'vocalized': u'أسفلكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولتلكم': [{'vocalized': u'ولتلكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أوكعامة': [{'vocalized': u'أوكعامة', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'وجنبه': [{'vocalized': u'وجنبه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'شطر': [{'vocalized': u'شطر', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'أوككلكما': [{'vocalized': u'أوككلكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فببعض': [{'vocalized': u'فببعض', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'وجنبي': [{'vocalized': u'وجنبي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'},
 {'vocalized': u'وجنبي', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنب'}],

 u'ليلهما': [{'vocalized': u'ليلهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'فإلا': [{'vocalized': u'فإلا', 'procletic': u'ف-', 'tags': u'حرف;حرف استثناء;عطف', 'stem': u'إلا', 'encletic': u'', 'type': u'حرف', 'original': u'إلا'},
 {'vocalized': u'فإلا', 'procletic': u'ف-', 'tags': u'حرف;حرف استثناء;عطف', 'stem': u'إلا', 'encletic': u'', 'type': u'حرف', 'original': u'إلا'}],

 u'فهنالك': [{'vocalized': u'فهنالك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فوراءهن': [{'vocalized': u'فوراءهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'وكليلهن': [{'vocalized': u'وكليلهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'كغيري': [{'vocalized': u'كغيري', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'كغيري', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أبنفسكن': [{'vocalized': u'أبنفسكن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'كغيره': [{'vocalized': u'كغيره', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أومنهما': [{'vocalized': u'أومنهما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'أومنكن': [{'vocalized': u'أومنكن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'كغيرك': [{'vocalized': u'كغيرك', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'لأبيي': [{'vocalized': u'لأبيي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'لأبيي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'ولمثلك': [{'vocalized': u'ولمثلك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'وبنفسي': [{'vocalized': u'وبنفسي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'وبنفسي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'وبجنوبي': [{'vocalized': u'وبجنوبي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'وبجنوبي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'وابني': [{'vocalized': u'وابني', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'وابني', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'ولمثله': [{'vocalized': u'ولمثله', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثله', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلمثلها': [{'vocalized': u'أفلمثلها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'ولمثلي': [{'vocalized': u'ولمثلي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'وابنه': [{'vocalized': u'وابنه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'وبنفسك': [{'vocalized': u'وبنفسك', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'وابنك': [{'vocalized': u'وابنك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'وبنفسه': [{'vocalized': u'وبنفسه', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'كحميكم': [{'vocalized': u'كحميكم', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'وماانفككتن': [{'vocalized': u'وماانفككتن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتن', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتن'}],

 u'وذوينا': [{'vocalized': u'وذوينا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'أوعامتك': [{'vocalized': u'أوعامتك', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلسويهم': [{'vocalized': u'أفلسويهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلسويهن': [{'vocalized': u'أفلسويهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'أليمينك': [{'vocalized': u'أليمينك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'أفلمثلهم': [{'vocalized': u'أفلمثلهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'ألخلف': [{'vocalized': u'ألخلف', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'أليمينه': [{'vocalized': u'أليمينه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'أفلمثلهن': [{'vocalized': u'أفلمثلهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'كساعتها': [{'vocalized': u'كساعتها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'لوراءه': [{'vocalized': u'لوراءه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'أليميني': [{'vocalized': u'أليميني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'أليميني', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'وبذويهما': [{'vocalized': u'وبذويهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'بتلك': [{'vocalized': u'بتلك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'وبجنوبك': [{'vocalized': u'وبجنوبك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'ففاكما': [{'vocalized': u'ففاكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فا'}],

 u'وبجنوبه': [{'vocalized': u'وبجنوبه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'كأثناءه': [{'vocalized': u'كأثناءه', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفجميع': [{'vocalized': u'أفجميع', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميع', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلسويها': [{'vocalized': u'أفلسويها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'فإلي': [{'vocalized': u'فإلي', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'فإلي', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'فإلى': [{'vocalized': u'فإلى', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'وكأعلينا': [{'vocalized': u'وكأعلينا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'حميكما': [{'vocalized': u'حميكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'أعنكما': [{'vocalized': u'أعنكما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'عن'}],

 u'وغربكما': [{'vocalized': u'وغربكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'فأناهن': [{'vocalized': u'فأناهن', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'أوحسبهما': [{'vocalized': u'أوحسبهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'ومافتئن': [{'vocalized': u'ومافتئن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئن', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئن'}],

 u'فلظل': [{'vocalized': u'فلظل', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'ظل', 'encletic': u'', 'type': u'فعل', 'original': u'ظل'}],

 u'كذوينا': [{'vocalized': u'كذوينا', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'هلا': [{'vocalized': u'هلا', 'procletic': u'', 'tags': u'حرف;حرف تحضيض', 'stem': u'هلا', 'encletic': u'', 'type': u'حرف', 'original': u'هلا'}],

 u'ألقلما': [{'vocalized': u'ألقلما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'وي': [{'vocalized': u'وي', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'وي', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وي'}],

 u'وأقلها': [{'vocalized': u'وأقلها', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'فلكم': [{'vocalized': u'فلكم', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لكم', 'encletic': u'', 'type': u'ضمير', 'original': u'لكم'}],

 u'أأمامهم': [{'vocalized': u'أأمامهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'لأيتهن': [{'vocalized': u'لأيتهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'أأمامهن': [{'vocalized': u'أأمامهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أمام'}],

 u'فلازالوا': [{'vocalized': u'فلازالوا', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالوا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالوا'}],

 u'فبعدئذ': [{'vocalized': u'فبعدئذ', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'بعدئذ', 'encletic': u'', 'type': u'اسم', 'original': u'بعدئذ'}],

 u'أوإليهن': [{'vocalized': u'أوإليهن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'أوإليهم': [{'vocalized': u'أوإليهم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'ولأية': [{'vocalized': u'ولأية', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'فكوقتهما': [{'vocalized': u'فكوقتهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'وبابن': [{'vocalized': u'وبابن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'ابن', 'encletic': u'', 'type': u'اسم', 'original': u'ابن'}],

 u'طالما': [{'vocalized': u'طالما', 'procletic': u'', 'tags': u'فعل;فعل جامد', 'stem': u'طالما', 'encletic': u'', 'type': u'فعل', 'original': u'طالما'}],

 u'أفعينك': [{'vocalized': u'أفعينك', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'ولأسفلهم': [{'vocalized': u'ولأسفلهم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولأسفلهن': [{'vocalized': u'ولأسفلهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبأسفلكم': [{'vocalized': u'وبأسفلكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبأسفلكن': [{'vocalized': u'وبأسفلكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'ألعنهما': [{'vocalized': u'ألعنهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'فبسويكما': [{'vocalized': u'فبسويكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ألحسبهم': [{'vocalized': u'ألحسبهم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'فهنا': [{'vocalized': u'فهنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هنا', 'encletic': u'', 'type': u'اسم', 'original': u'هنا'}],

 u'ألحسبهن': [{'vocalized': u'ألحسبهن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'وبغرب': [{'vocalized': u'وبغرب', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'فبغيره': [{'vocalized': u'فبغيره', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'ولأيي': [{'vocalized': u'ولأيي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'ولأيي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'فبغيرك': [{'vocalized': u'فبغيرك', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'ومعنا': [{'vocalized': u'ومعنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'لشمالها': [{'vocalized': u'لشمالها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'ولأنتن': [{'vocalized': u'ولأنتن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'ولأنتم': [{'vocalized': u'ولأنتم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'ولأيك': [{'vocalized': u'ولأيك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'فبغيري': [{'vocalized': u'فبغيري', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'فبغيري', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'فأعلي': [{'vocalized': u'فأعلي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'فأعلي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولأيه': [{'vocalized': u'ولأيه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'ولتين': [{'vocalized': u'ولتين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'ألحسبها': [{'vocalized': u'ألحسبها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'ولتحتكما': [{'vocalized': u'ولتحتكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'لذانك': [{'vocalized': u'لذانك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أفشمالهما': [{'vocalized': u'أفشمالهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شمال'}],

 u'ومافتئا': [{'vocalized': u'ومافتئا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئا'}],

 u'ومافتئت': [{'vocalized': u'ومافتئت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'ومافتئت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'ومافتئت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'ومافتئت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'}],

 u'فكأكثرنا': [{'vocalized': u'فكأكثرنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولوراءك': [{'vocalized': u'ولوراءك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'أحسبي': [{'vocalized': u'أحسبي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أحسبي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'أأجمعنا': [{'vocalized': u'أأجمعنا', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأقلهم': [{'vocalized': u'وأقلهم', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'أأمامها': [{'vocalized': u'أأمامها', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'أحسبك': [{'vocalized': u'أحسبك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'أحسبه': [{'vocalized': u'أحسبه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'وماانفككتما': [{'vocalized': u'وماانفككتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتما', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتما'},
 {'vocalized': u'وماانفككتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككتما', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتما'}],

 u'فبتلقاءها': [{'vocalized': u'فبتلقاءها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'علي': [{'vocalized': u'علي', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'علي', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'على': [{'vocalized': u'على', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'فمابرح': [{'vocalized': u'فمابرح', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مابرح', 'encletic': u'', 'type': u'فعل', 'original': u'مابرح'}],

 u'علق': [{'vocalized': u'علق', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'علق', 'encletic': u'', 'type': u'فعل', 'original': u'علق'}],

 u'أفنفسكم': [{'vocalized': u'أفنفسكم', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'أفنفسكن': [{'vocalized': u'أفنفسكن', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'وبغروبكم': [{'vocalized': u'وبغروبكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'أفلأناكن': [{'vocalized': u'أفلأناكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'أفلأناكم': [{'vocalized': u'أفلأناكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'فلابنهن': [{'vocalized': u'فلابنهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'أشبهنا': [{'vocalized': u'أشبهنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'فلابنهم': [{'vocalized': u'فلابنهم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'أغيرها': [{'vocalized': u'أغيرها', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'فبمثلنا': [{'vocalized': u'فبمثلنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'أيي': [{'vocalized': u'أيي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'أيي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'فغربه': [{'vocalized': u'فغربه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'بك': [{'vocalized': u'بك', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'بك', 'encletic': u'', 'type': u'ضمير', 'original': u'بك'}],

 u'أأنت': [{'vocalized': u'أأنت', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'أأنت', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'وبأقلهما': [{'vocalized': u'وبأقلهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'أيك': [{'vocalized': u'أيك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'وعينكما': [{'vocalized': u'وعينكما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'أين': [{'vocalized': u'أين', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'},
 {'vocalized': u'أين', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'},
 {'vocalized': u'أين', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'أين', 'encletic': u'', 'type': u'اسم', 'original': u'أين'}],

 u'أيه': [{'vocalized': u'أيه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'وبعدي': [{'vocalized': u'وبعدي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعد'},
 {'vocalized': u'وبعدي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعد'}],

 u'وآنذاك': [{'vocalized': u'وآنذاك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آنذاك', 'encletic': u'', 'type': u'اسم', 'original': u'آنذاك'}],

 u'فغربك': [{'vocalized': u'فغربك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'وبعدك': [{'vocalized': u'وبعدك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعد'}],

 u'فذين': [{'vocalized': u'فذين', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'وكمن': [{'vocalized': u'وكمن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'فكأعليهن': [{'vocalized': u'فكأعليهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'فكأعليهم': [{'vocalized': u'فكأعليهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'أية': [{'vocalized': u'أية', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'وذاتكما': [{'vocalized': u'وذاتكما', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'ففوقهما': [{'vocalized': u'ففوقهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'أوعامتي': [{'vocalized': u'أوعامتي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أوعامتي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'أيا': [{'vocalized': u'أيا', 'procletic': u'', 'tags': u'حرف;حرف نداء', 'stem': u'أيا', 'encletic': u'', 'type': u'حرف', 'original': u'أيا'}],

 u'أهم': [{'vocalized': u'أهم', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أولنحو': [{'vocalized': u'أولنحو', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فبهاتي': [{'vocalized': u'فبهاتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'أفلكلهما': [{'vocalized': u'أفلكلهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'فذيت': [{'vocalized': u'فذيت', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'ذيت', 'encletic': u'', 'type': u'اسم', 'original': u'ذيت'}],

 u'أولنحن': [{'vocalized': u'أولنحن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'أكعيننا': [{'vocalized': u'أكعيننا', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'فبهاته': [{'vocalized': u'فبهاته', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'وكما': [{'vocalized': u'وكما', 'procletic': u'و-', 'tags': u'حرف;حرف تشبيه;عطف', 'stem': u'كما', 'encletic': u'', 'type': u'حرف', 'original': u'كما'}],

 u'فبتلقاءهم': [{'vocalized': u'فبتلقاءهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبابنكن': [{'vocalized': u'وبابنكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'وبابنكم': [{'vocalized': u'وبابنكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'فبتلقاءهن': [{'vocalized': u'فبتلقاءهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أوبمثلهما': [{'vocalized': u'أوبمثلهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'ألوراءه': [{'vocalized': u'ألوراءه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'كمن': [{'vocalized': u'كمن', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'ألوراءك': [{'vocalized': u'ألوراءك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'وبتلقاءكم': [{'vocalized': u'وبتلقاءكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبتلقاءكن': [{'vocalized': u'وبتلقاءكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فغربي': [{'vocalized': u'فغربي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'فغربي', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'أشمال': [{'vocalized': u'أشمال', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'فلابنها': [{'vocalized': u'فلابنها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'ليسا': [{'vocalized': u'ليسا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ليسا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسا'}],

 u'أغيرهن': [{'vocalized': u'أغيرهن', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أغيرهم': [{'vocalized': u'أغيرهم', 'procletic': u'أ-', 'tags': u'اسم;استثناء;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'ولمثلكما': [{'vocalized': u'ولمثلكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أفعني': [{'vocalized': u'أفعني', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'أفعني', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'أفعن': [{'vocalized': u'أفعن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'بجنوبي': [{'vocalized': u'بجنوبي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'},
 {'vocalized': u'بجنوبي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جنوب'}],

 u'لعاد': [{'vocalized': u'لعاد', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'عاد', 'encletic': u'', 'type': u'فعل', 'original': u'عاد'}],

 u'لهاذين': [{'vocalized': u'لهاذين', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'وكساعتي': [{'vocalized': u'وكساعتي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'وكساعتي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفعنك': [{'vocalized': u'أفعنك', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'ألفينا': [{'vocalized': u'ألفينا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'أفعنه': [{'vocalized': u'أفعنه', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'أهناك': [{'vocalized': u'أهناك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'ولسويهما': [{'vocalized': u'ولسويهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'وبينكن': [{'vocalized': u'وبينكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بين'}],

 u'أفلكأن': [{'vocalized': u'أفلكأن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'}],

 u'أفلإليهم': [{'vocalized': u'أفلإليهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'فأخيها': [{'vocalized': u'فأخيها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'بتلقاءهما': [{'vocalized': u'بتلقاءهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أببعضي': [{'vocalized': u'أببعضي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أببعضي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'أببعضه': [{'vocalized': u'أببعضه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'أكأنهن': [{'vocalized': u'أكأنهن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'أكأنهم': [{'vocalized': u'أكأنهم', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'لعامتها': [{'vocalized': u'لعامتها', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'وبزمانها': [{'vocalized': u'وبزمانها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'خلفها': [{'vocalized': u'خلفها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'وبكلك': [{'vocalized': u'وبكلك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلك', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'وذلك': [{'vocalized': u'وذلك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'وبكله': [{'vocalized': u'وبكله', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكله', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'وبكلي': [{'vocalized': u'وبكلي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وبكلي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'أفعيني': [{'vocalized': u'أفعيني', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفعيني', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وبسويهما': [{'vocalized': u'وبسويهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'لعامتهن': [{'vocalized': u'لعامتهن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'لعامتهم': [{'vocalized': u'لعامتهم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أفشبههن': [{'vocalized': u'أفشبههن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'وبزمانهم': [{'vocalized': u'وبزمانهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'أفلحسب': [{'vocalized': u'أفلحسب', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'وبزمانهن': [{'vocalized': u'وبزمانهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'أفعنهما': [{'vocalized': u'أفعنهما', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'فحواليه': [{'vocalized': u'فحواليه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حوالى'}],

 u'وبذاتكما': [{'vocalized': u'وبذاتكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'وليمينهما': [{'vocalized': u'وليمينهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'أوكشبهكن': [{'vocalized': u'أوكشبهكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'ولأنانا': [{'vocalized': u'ولأنانا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'أوكشبهكم': [{'vocalized': u'أوكشبهكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'أوكسوى': [{'vocalized': u'أوكسوى', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أوكسوي': [{'vocalized': u'أوكسوي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أوكسوي', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'أولغيركم': [{'vocalized': u'أولغيركم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيركم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'وكنحونا': [{'vocalized': u'وكنحونا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحونا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أولغيركن': [{'vocalized': u'أولغيركن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أولغيركن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'وبشبهكم': [{'vocalized': u'وبشبهكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'منها': [{'vocalized': u'منها', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'أوبغير': [{'vocalized': u'أوبغير', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'أفبغيره': [{'vocalized': u'أفبغيره', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أفبغيري': [{'vocalized': u'أفبغيري', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفبغيري', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'لنحوهما': [{'vocalized': u'لنحوهما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'فبغروبنا': [{'vocalized': u'فبغروبنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'وحوله': [{'vocalized': u'وحوله', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حول'}],

 u'وتلك': [{'vocalized': u'وتلك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'فأخيهن': [{'vocalized': u'فأخيهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'فأخيهم': [{'vocalized': u'فأخيهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'فتينك': [{'vocalized': u'فتينك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'بالألى': [{'vocalized': u'بالألى', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'أكأنها': [{'vocalized': u'أكأنها', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'فأبوهما': [{'vocalized': u'فأبوهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبو'}],

 u'بأثناءكن': [{'vocalized': u'بأثناءكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'بابنها': [{'vocalized': u'بابنها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'وليس': [{'vocalized': u'وليس', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ليس', 'encletic': u'', 'type': u'فعل', 'original': u'ليس'}],

 u'عامتكن': [{'vocalized': u'عامتكن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'عامتكم': [{'vocalized': u'عامتكم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'أكغيرهما': [{'vocalized': u'أكغيرهما', 'procletic': u'أ-ك-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'أأناكما': [{'vocalized': u'أأناكما', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'أوبجميعهما': [{'vocalized': u'أوبجميعهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'عامتي': [{'vocalized': u'عامتي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'عامتي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'وكتلكم': [{'vocalized': u'وكتلكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'عامته': [{'vocalized': u'عامته', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'أوتلك': [{'vocalized': u'أوتلك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'عامتك': [{'vocalized': u'عامتك', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'أفأجمع': [{'vocalized': u'أفأجمع', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولليلهن': [{'vocalized': u'ولليلهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'إيه': [{'vocalized': u'إيه', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'إيه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إيه'}],

 u'وللتيا': [{'vocalized': u'وللتيا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'أناي': [{'vocalized': u'أناي', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'أناي', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'ألعلهما': [{'vocalized': u'ألعلهما', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لعل'}],

 u'أجمعنا': [{'vocalized': u'أجمعنا', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'ومثلكن': [{'vocalized': u'ومثلكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'ومثلكم': [{'vocalized': u'ومثلكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'ولنحوه': [{'vocalized': u'ولنحوه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحوه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'فجميعكما': [{'vocalized': u'فجميعكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعكما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'ومافتئتما': [{'vocalized': u'ومافتئتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتما', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتما'},
 {'vocalized': u'ومافتئتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتما', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتما'}],

 u'وبحسبكن': [{'vocalized': u'وبحسبكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'ولليلها': [{'vocalized': u'ولليلها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'وللتين': [{'vocalized': u'وللتين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'وبذاتكم': [{'vocalized': u'وبذاتكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'أفبجميع': [{'vocalized': u'أفبجميع', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميع', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'بعامتهما': [{'vocalized': u'بعامتهما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'فلعلي': [{'vocalized': u'فلعلي', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'فلعلي', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'فلعلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'فلعلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'فإيانا': [{'vocalized': u'فإيانا', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إيانا', 'encletic': u'', 'type': u'ضمير', 'original': u'إيانا'}],

 u'بشطرنا': [{'vocalized': u'بشطرنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'بابنهن': [{'vocalized': u'بابنهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'فبكما': [{'vocalized': u'فبكما', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بكما', 'encletic': u'', 'type': u'ضمير', 'original': u'بكما'}],

 u'بابنهم': [{'vocalized': u'بابنهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'أوليمينكما': [{'vocalized': u'أوليمينكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'يمين'}],

 u'أومهما': [{'vocalized': u'أومهما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم الشرط;عطف;استفهام', 'stem': u'مهما', 'encletic': u'', 'type': u'اسم', 'original': u'مهما'}],

 u'فجنبهما': [{'vocalized': u'فجنبهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'لزماني': [{'vocalized': u'لزماني', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'لزماني', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'ككلهما': [{'vocalized': u'ككلهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلهما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'وكابنكما': [{'vocalized': u'وكابنكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'وبيننا': [{'vocalized': u'وبيننا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بين'}],

 u'أمثلكما': [{'vocalized': u'أمثلكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'أفكعينهم': [{'vocalized': u'أفكعينهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أفكعينهن': [{'vocalized': u'أفكعينهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'ذويكن': [{'vocalized': u'ذويكن', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'ذويكم': [{'vocalized': u'ذويكم', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلغروبك': [{'vocalized': u'فلغروبك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'لوراءكن': [{'vocalized': u'لوراءكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'لوراءكم': [{'vocalized': u'لوراءكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'لشبهك': [{'vocalized': u'لشبهك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'فلغروبه': [{'vocalized': u'فلغروبه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'ويمينهما': [{'vocalized': u'ويمينهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'لشبهه': [{'vocalized': u'لشبهه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'فلغروبي': [{'vocalized': u'فلغروبي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'فلغروبي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'لشبهي': [{'vocalized': u'لشبهي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبهي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'فغروبها': [{'vocalized': u'فغروبها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'كشطرنا': [{'vocalized': u'كشطرنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'أفبعينك': [{'vocalized': u'أفبعينك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'وعل': [{'vocalized': u'وعل', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'عل', 'encletic': u'', 'type': u'حرف', 'original': u'عل'}],

 u'فمتى': [{'vocalized': u'فمتى', 'procletic': u'ف-', 'tags': u'اسم;اسم استفهام/ظرف زمان;عطف', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'},
 {'vocalized': u'فمتى', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'},
 {'vocalized': u'فمتى', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'متى', 'encletic': u'', 'type': u'اسم', 'original': u'متى'}],

 u'وعن': [{'vocalized': u'وعن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'أوعنهما': [{'vocalized': u'أوعنهما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'راح': [{'vocalized': u'راح', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'راح', 'encletic': u'', 'type': u'فعل', 'original': u'راح'}],

 u'حاشا': [{'vocalized': u'حاشا', 'procletic': u'', 'tags': u'فعل;حرف استثناء', 'stem': u'حاشا', 'encletic': u'', 'type': u'فعل', 'original': u'حاشا'}],

 u'أولأجمعهم': [{'vocalized': u'أولأجمعهم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولأجمعهن': [{'vocalized': u'أولأجمعهن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'فكعامة': [{'vocalized': u'فكعامة', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'وبوقتي': [{'vocalized': u'وبوقتي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'وبوقتي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'بعدكما': [{'vocalized': u'بعدكما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعد'}],

 u'ألهنالك': [{'vocalized': u'ألهنالك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'لعله': [{'vocalized': u'لعله', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لعل'}],

 u'وبوقتك': [{'vocalized': u'وبوقتك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'ولأسفلها': [{'vocalized': u'ولأسفلها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبوقته': [{'vocalized': u'وبوقته', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'أولأجمعها': [{'vocalized': u'أولأجمعها', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'وكأجمعكما': [{'vocalized': u'وكأجمعكما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولذوي': [{'vocalized': u'ولذوي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفكعينها': [{'vocalized': u'أفكعينها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'وشمالكن': [{'vocalized': u'وشمالكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شمال'}],

 u'وشمالكم': [{'vocalized': u'وشمالكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'فالذين': [{'vocalized': u'فالذين', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'فلأيته': [{'vocalized': u'فلأيته', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'وككله': [{'vocalized': u'وككله', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وككله', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'فغروبهن': [{'vocalized': u'فغروبهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'ليست': [{'vocalized': u'ليست', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ليست', 'encletic': u'', 'type': u'فعل', 'original': u'ليست'}],

 u'وبعامتنا': [{'vocalized': u'وبعامتنا', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلبعضك': [{'vocalized': u'أفلبعضك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفلبعضك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'وبغروبكن': [{'vocalized': u'وبغروبكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'فككلهما': [{'vocalized': u'فككلهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلهما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'أفكغيره': [{'vocalized': u'أفكغيره', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أفكغيرك': [{'vocalized': u'أفكغيرك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'أكبعضنا': [{'vocalized': u'أكبعضنا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'أفكغيري': [{'vocalized': u'أفكغيري', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفكغيري', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أفلشبهنا': [{'vocalized': u'أفلشبهنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'أكثرهما': [{'vocalized': u'أكثرهما', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'وبعدهن': [{'vocalized': u'وبعدهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعد'}],

 u'لأثناءهم': [{'vocalized': u'لأثناءهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفكغيرها': [{'vocalized': u'أفكغيرها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'لأثناءهن': [{'vocalized': u'لأثناءهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'فكإن': [{'vocalized': u'فكإن', 'procletic': u'ف-ك-', 'tags': u'حرف;المشبهة بليس;مجرور;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'فبابنك': [{'vocalized': u'فبابنك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'بغيري': [{'vocalized': u'بغيري', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'بغيري', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'فلأثناءكما': [{'vocalized': u'فلأثناءكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'وحماهن': [{'vocalized': u'وحماهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حما'}],

 u'فبأعليهما': [{'vocalized': u'فبأعليهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'بكل': [{'vocalized': u'بكل', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكل', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'بكم': [{'vocalized': u'بكم', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'بكم', 'encletic': u'', 'type': u'اسم', 'original': u'بكم'},
 {'vocalized': u'بكم', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'بكم', 'encletic': u'', 'type': u'ضمير', 'original': u'بكم'}],

 u'بغيرك': [{'vocalized': u'بغيرك', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'بغيره': [{'vocalized': u'بغيره', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'هؤلاء': [{'vocalized': u'هؤلاء', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'ولمنهما': [{'vocalized': u'ولمنهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'أفكغيرهم': [{'vocalized': u'أفكغيرهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'لأثناءها': [{'vocalized': u'لأثناءها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفكغيرهن': [{'vocalized': u'أفكغيرهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أككلكم': [{'vocalized': u'أككلكم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلكم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أككلكن': [{'vocalized': u'أككلكن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلكن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'مافتئتم': [{'vocalized': u'مافتئتم', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئتم', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتم'}],

 u'كنحوكن': [{'vocalized': u'كنحوكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'كنحوكم': [{'vocalized': u'كنحوكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'وذووك': [{'vocalized': u'وذووك', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوو'}],

 u'وبدونكن': [{'vocalized': u'وبدونكن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بدون'}],

 u'وبدونكم': [{'vocalized': u'وبدونكم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بدون'}],

 u'ألازلت': [{'vocalized': u'ألازلت', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'ألازلت', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'ألازلت', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'}],

 u'مادام': [{'vocalized': u'مادام', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادام', 'encletic': u'', 'type': u'فعل', 'original': u'مادام'}],

 u'أولمعكن': [{'vocalized': u'أولمعكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'أولمعكم': [{'vocalized': u'أولمعكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'مازلتن': [{'vocalized': u'مازلتن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتن'}],

 u'لزمانها': [{'vocalized': u'لزمانها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'أصلا': [{'vocalized': u'أصلا', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'أصلا', 'encletic': u'', 'type': u'اسم', 'original': u'أصلا'}],

 u'أولفوقك': [{'vocalized': u'أولفوقك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'أوكنحوكم': [{'vocalized': u'أوكنحوكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أوكنحوكن': [{'vocalized': u'أوكنحوكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'فلعليكم': [{'vocalized': u'فلعليكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'أولذي': [{'vocalized': u'أولذي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'فبك': [{'vocalized': u'فبك', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بك', 'encletic': u'', 'type': u'ضمير', 'original': u'بك'}],

 u'ولساعة': [{'vocalized': u'ولساعة', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'ولوراءه': [{'vocalized': u'ولوراءه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'عداكن': [{'vocalized': u'عداكن', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-كن', 'type': u'فعل', 'original': u'عدا'}],

 u'عداكم': [{'vocalized': u'عداكم', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-كم', 'type': u'فعل', 'original': u'عدا'}],

 u'أولازالتا': [{'vocalized': u'أولازالتا', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالتا'}],

 u'فبي': [{'vocalized': u'فبي', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بي', 'encletic': u'', 'type': u'ضمير', 'original': u'بي'}],

 u'كذاتنا': [{'vocalized': u'كذاتنا', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'فكسوى': [{'vocalized': u'فكسوى', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'ولساعتكن': [{'vocalized': u'ولساعتكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفبغيرها': [{'vocalized': u'أفبغيرها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'ألعنك': [{'vocalized': u'ألعنك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'ألأمام': [{'vocalized': u'ألأمام', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'فبشبههما': [{'vocalized': u'فبشبههما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'أوإنا': [{'vocalized': u'أوإنا', 'procletic': u'أ-و-', 'tags': u'حرف;ناصب ومنصوب;عطف;استفهام', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'وأقلهن': [{'vocalized': u'وأقلهن', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'فأبيهما': [{'vocalized': u'فأبيهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبي'}],

 u'أبشبه': [{'vocalized': u'أبشبه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'كوقتكن': [{'vocalized': u'كوقتكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'كوقتكم': [{'vocalized': u'كوقتكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'وكأقلها': [{'vocalized': u'وكأقلها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'وشطركن': [{'vocalized': u'وشطركن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'وشطركم': [{'vocalized': u'وشطركم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'أفأمامكن': [{'vocalized': u'أفأمامكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'ص': [{'vocalized': u'ص', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ص', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ص'}],

 u'أفأمامها': [{'vocalized': u'أفأمامها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أمام'}],

 u'وكشهرنا': [{'vocalized': u'وكشهرنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'كشبهنا': [{'vocalized': u'كشبهنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'حماكن': [{'vocalized': u'حماكن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حما'}],

 u'أولشمالكم': [{'vocalized': u'أولشمالكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شمال'}],

 u'فلأسفلنا': [{'vocalized': u'فلأسفلنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'فبعدكم': [{'vocalized': u'فبعدكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعد'}],

 u'أوكأنكما': [{'vocalized': u'أوكأنكما', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'كأن'}],

 u'فخلاهما': [{'vocalized': u'فخلاهما', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-هما', 'type': u'فعل', 'original': u'خلا'}],

 u'وأنهما': [{'vocalized': u'وأنهما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'وكأقلهن': [{'vocalized': u'وكأقلهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'فلمع': [{'vocalized': u'فلمع', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'وكأقلهم': [{'vocalized': u'وكأقلهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'أوبسويه': [{'vocalized': u'أوبسويه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'فلأبي': [{'vocalized': u'فلأبي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'فكتلقاءك': [{'vocalized': u'فكتلقاءك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أوبسويك': [{'vocalized': u'أوبسويك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'فكتلقاءه': [{'vocalized': u'فكتلقاءه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فكتلقاءي': [{'vocalized': u'فكتلقاءي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'فكتلقاءي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ألسن': [{'vocalized': u'ألسن', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لسن', 'encletic': u'', 'type': u'فعل', 'original': u'لسن'}],

 u'كأنما': [{'vocalized': u'كأنما', 'procletic': u'', 'tags': u'حرف;حرف تشبيه', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'أوبغيره': [{'vocalized': u'أوبغيره', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'أفكأننا': [{'vocalized': u'أفكأننا', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'أوبغيرك': [{'vocalized': u'أوبغيرك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'أفلمعهما': [{'vocalized': u'أفلمعهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'ولغروبنا': [{'vocalized': u'ولغروبنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'لنفس': [{'vocalized': u'لنفس', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'لنفس', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فبخ': [{'vocalized': u'فبخ', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بخ', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بخ'}],

 u'أفبغيرهم': [{'vocalized': u'أفبغيرهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أفبغيرهن': [{'vocalized': u'أفبغيرهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'وا': [{'vocalized': u'وا', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'وا', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وا'},
 {'vocalized': u'وا', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'وا', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وا'}],

 u'لهناك': [{'vocalized': u'لهناك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'فبس': [{'vocalized': u'فبس', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'بس', 'encletic': u'', 'type': u'اسم فعل', 'original': u'بس'}],

 u'أوإني': [{'vocalized': u'أوإني', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'أوإني', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'أفحسبكن': [{'vocalized': u'أفحسبكن', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فبلحظة': [{'vocalized': u'فبلحظة', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفحسبكم': [{'vocalized': u'أفحسبكم', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'ألستما': [{'vocalized': u'ألستما', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لستما', 'encletic': u'', 'type': u'فعل', 'original': u'لستما'}],

 u'أوإنك': [{'vocalized': u'أوإنك', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'أوإنه': [{'vocalized': u'أوإنه', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'وكعامة': [{'vocalized': u'وكعامة', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أولمنكن': [{'vocalized': u'أولمنكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'فلكني': [{'vocalized': u'فلكني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكني', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكني', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكني', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لكن'}],

 u'أفلتلكما': [{'vocalized': u'أفلتلكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'فأسفلكما': [{'vocalized': u'فأسفلكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'لعنه': [{'vocalized': u'لعنه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'فلكنك': [{'vocalized': u'فلكنك', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنك', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لكن'}],

 u'لعنك': [{'vocalized': u'لعنك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'فلكنه': [{'vocalized': u'فلكنه', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكنه', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف;ضمير', 'stem': u'لكن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لكن'}],

 u'أفكأنه': [{'vocalized': u'أفكأنه', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'وأقبل': [{'vocalized': u'وأقبل', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أقبل', 'encletic': u'', 'type': u'فعل', 'original': u'أقبل'}],

 u'أفلعنهما': [{'vocalized': u'أفلعنهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'أفكأنك': [{'vocalized': u'أفكأنك', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'ولساعتي': [{'vocalized': u'ولساعتي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'ولساعتي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'أفببعضهما': [{'vocalized': u'أفببعضهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'أجميعهم': [{'vocalized': u'أجميعهم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعهم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكأني': [{'vocalized': u'أفكأني', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'أفكأني', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'وماانفككنا': [{'vocalized': u'وماانفككنا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككنا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككنا'}],

 u'لتلقاءنا': [{'vocalized': u'لتلقاءنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفلإنها': [{'vocalized': u'أفلإنها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'لزمانهن': [{'vocalized': u'لزمانهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'أسفلكم': [{'vocalized': u'أسفلكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'كذلكما': [{'vocalized': u'كذلكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'وأبينا': [{'vocalized': u'وأبينا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'لغروبه': [{'vocalized': u'لغروبه', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'أوكهنالك': [{'vocalized': u'أوكهنالك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'لغروبك': [{'vocalized': u'لغروبك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غروب'}],

 u'كأولالك': [{'vocalized': u'كأولالك', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'لزمانهم': [{'vocalized': u'لزمانهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'لغروبي': [{'vocalized': u'لغروبي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'},
 {'vocalized': u'لغروبي', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غروب'}],

 u'أوككليهما': [{'vocalized': u'أوككليهما', 'procletic': u'أ-و-ك-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'أفلإنهن': [{'vocalized': u'أفلإنهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'أفلإنهم': [{'vocalized': u'أفلإنهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'وبشرق': [{'vocalized': u'وبشرق', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'أولقلما': [{'vocalized': u'أولقلما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'وصار': [{'vocalized': u'وصار', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'صار', 'encletic': u'', 'type': u'فعل', 'original': u'صار'}],

 u'فأناها': [{'vocalized': u'فأناها', 'procletic': u'ف-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'فلكليهما': [{'vocalized': u'فلكليهما', 'procletic': u'ف-ل-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'كذاتكما': [{'vocalized': u'كذاتكما', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذات'}],

 u'لكما': [{'vocalized': u'لكما', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'لكما', 'encletic': u'', 'type': u'ضمير', 'original': u'لكما'}],

 u'وبإن': [{'vocalized': u'وبإن', 'procletic': u'و-ب-', 'tags': u'حرف;المشبهة بليس;مجرور;عطف', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'لحرى': [{'vocalized': u'لحرى', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'حرى', 'encletic': u'', 'type': u'فعل', 'original': u'حرى'}],

 u'وكأسفلي': [{'vocalized': u'وكأسفلي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'},
 {'vocalized': u'وكأسفلي', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكأسفله': [{'vocalized': u'وكأسفله', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكأسفلك': [{'vocalized': u'وكأسفلك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أسفل'}],

 u'ألبعض': [{'vocalized': u'ألبعض', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعض', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'كجنوبكما': [{'vocalized': u'كجنوبكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبأي': [{'vocalized': u'فبأي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فبأي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'}],

 u'فبنا': [{'vocalized': u'فبنا', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'بنا', 'encletic': u'', 'type': u'ضمير', 'original': u'بنا'}],

 u'أجميعها': [{'vocalized': u'أجميعها', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعها', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'أفكهما': [{'vocalized': u'أفكهما', 'procletic': u'أ-ف-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'وعنهن': [{'vocalized': u'وعنهن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'عن'}],

 u'أفكسويهما': [{'vocalized': u'أفكسويهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'وماداما': [{'vocalized': u'وماداما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماداما', 'encletic': u'', 'type': u'فعل', 'original': u'ماداما'}],

 u'فكأقلي': [{'vocalized': u'فكأقلي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'فكأقلي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'فبسويها': [{'vocalized': u'فبسويها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'سوى'}],

 u'فكأقلك': [{'vocalized': u'فكأقلك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'كليلنا': [{'vocalized': u'كليلنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'فكأقله': [{'vocalized': u'فكأقله', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'وغيركما': [{'vocalized': u'وغيركما', 'procletic': u'و-', 'tags': u'اسم;استثناء;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فمن': [{'vocalized': u'فمن', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'فمن', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'فمن', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'فمن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'وقته': [{'vocalized': u'وقته', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وقت'}],

 u'فمكانكم': [{'vocalized': u'فمكانكم', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانكم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكم'}],

 u'فلمنكم': [{'vocalized': u'فلمنكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'وأناكن': [{'vocalized': u'وأناكن', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أنا'}],

 u'فلمنكن': [{'vocalized': u'فلمنكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'فلأعليها': [{'vocalized': u'فلأعليها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'فأباهم': [{'vocalized': u'فأباهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أبا'}],

 u'فأباهن': [{'vocalized': u'فأباهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أبا'}],

 u'لكنها': [{'vocalized': u'لكنها', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنها', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لكن'}],

 u'فسويهما': [{'vocalized': u'فسويهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'لعليكم': [{'vocalized': u'لعليكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-كم', 'type': u'حرف', 'original': u'على'}],

 u'لعليكن': [{'vocalized': u'لعليكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-كن', 'type': u'حرف', 'original': u'على'}],

 u'لأكثر': [{'vocalized': u'لأكثر', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'ولأيتنا': [{'vocalized': u'ولأيتنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'أبحسبهما': [{'vocalized': u'أبحسبهما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'وحولكن': [{'vocalized': u'وحولكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حول'}],

 u'فكأعليها': [{'vocalized': u'فكأعليها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'وليميننا': [{'vocalized': u'وليميننا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'وحولكم': [{'vocalized': u'وحولكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حول'}],

 u'فلأعليهم': [{'vocalized': u'فلأعليهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'فلأعليهن': [{'vocalized': u'فلأعليهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'أوعلينا': [{'vocalized': u'أوعلينا', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'فأباها': [{'vocalized': u'فأباها', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أبا'}],

 u'لكنهن': [{'vocalized': u'لكنهن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنهن', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'لكن'}],

 u'لكنهم': [{'vocalized': u'لكنهم', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنهم', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لكن'}],

 u'أسفلها': [{'vocalized': u'أسفلها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'فليلهن': [{'vocalized': u'فليلهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'فلإليكما': [{'vocalized': u'فلإليكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'فبأثناءنا': [{'vocalized': u'فبأثناءنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'فمذ': [{'vocalized': u'فمذ', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'مذ', 'encletic': u'', 'type': u'حرف', 'original': u'مذ'},
 {'vocalized': u'فمذ', 'procletic': u'ف-', 'tags': u'حرف;ظرف زمان;عطف', 'stem': u'مذ', 'encletic': u'', 'type': u'حرف', 'original': u'مذ'}],

 u'وكعامتك': [{'vocalized': u'وكعامتك', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'فبسويهن': [{'vocalized': u'فبسويهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'وكعامته': [{'vocalized': u'وكعامته', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'فبسويهم': [{'vocalized': u'فبسويهم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'سوى'}],

 u'فمع': [{'vocalized': u'فمع', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'ومادمنا': [{'vocalized': u'ومادمنا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمنا', 'encletic': u'', 'type': u'فعل', 'original': u'مادمنا'}],

 u'وكعامتي': [{'vocalized': u'وكعامتي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'وكعامتي', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'أوبهاتي': [{'vocalized': u'أوبهاتي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'ولغروبكم': [{'vocalized': u'ولغروبكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'عليكما': [{'vocalized': u'عليكما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'فما': [{'vocalized': u'فما', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'فما', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'فما', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'اسم', 'original': u'ما'},
 {'vocalized': u'فما', 'procletic': u'ف-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'ما', 'encletic': u'', 'type': u'حرف', 'original': u'ما'}],

 u'فحمينا': [{'vocalized': u'فحمينا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'وبليلها': [{'vocalized': u'وبليلها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ليل'}],

 u'أوبهاته': [{'vocalized': u'أوبهاته', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'أوكأولئكم': [{'vocalized': u'أوكأولئكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'أأنا': [{'vocalized': u'أأنا', 'procletic': u'أ-', 'tags': u'ضمير;ضمير منفصل;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'أأنا', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'وعند': [{'vocalized': u'وعند', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'عند', 'encletic': u'', 'type': u'اسم', 'original': u'عند'}],

 u'جلل': [{'vocalized': u'جلل', 'procletic': u'', 'tags': u'حرف;حرف جواب', 'stem': u'جلل', 'encletic': u'', 'type': u'حرف', 'original': u'جلل'}],

 u'ولغروبه': [{'vocalized': u'ولغروبه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غروب'}],

 u'أوكذانك': [{'vocalized': u'أوكذانك', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'كأقله': [{'vocalized': u'كأقله', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'فلعامتكن': [{'vocalized': u'فلعامتكن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'كأقلك': [{'vocalized': u'كأقلك', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'كأقلي': [{'vocalized': u'كأقلي', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'كأقلي', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'كأيتكم': [{'vocalized': u'كأيتكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'وذووكن': [{'vocalized': u'وذووكن', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوو'}],

 u'وذووكم': [{'vocalized': u'وذووكم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوو'}],

 u'كأيتكن': [{'vocalized': u'كأيتكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'أفلعلي': [{'vocalized': u'أفلعلي', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'أفلعلي', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'أفلعلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'أفلعلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'أولهاتي': [{'vocalized': u'أولهاتي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'أفلعله': [{'vocalized': u'أفلعله', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لعل'}],

 u'أولهاته': [{'vocalized': u'أولهاته', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'أفلعلك': [{'vocalized': u'أفلعلك', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لعل'}],

 u'لأناي': [{'vocalized': u'لأناي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'لأناي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'وكتلقاءكما': [{'vocalized': u'وكتلقاءكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'بغيركما': [{'vocalized': u'بغيركما', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فحواليكن': [{'vocalized': u'فحواليكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حوالى'}],

 u'فحواليكم': [{'vocalized': u'فحواليكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حوالى'}],

 u'فببعضكن': [{'vocalized': u'فببعضكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'شطركم': [{'vocalized': u'شطركم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'شطركن': [{'vocalized': u'شطركن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'فببعضكم': [{'vocalized': u'فببعضكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أفبنفسك': [{'vocalized': u'أفبنفسك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلفيه': [{'vocalized': u'أفلفيه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'ولجنبنا': [{'vocalized': u'ولجنبنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'أفبحسب': [{'vocalized': u'أفبحسب', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلأجمعنا': [{'vocalized': u'أفلأجمعنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبعامتي': [{'vocalized': u'وبعامتي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'وبعامتي', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'وبعامته': [{'vocalized': u'وبعامته', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'وأناكم': [{'vocalized': u'وأناكم', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أنا'}],

 u'فالآن': [{'vocalized': u'فالآن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'الآن', 'encletic': u'', 'type': u'اسم', 'original': u'الآن'}],

 u'حماكما': [{'vocalized': u'حماكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حما', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حما'}],

 u'حيث': [{'vocalized': u'حيث', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'وأثناءك': [{'vocalized': u'وأثناءك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'فبذاتهما': [{'vocalized': u'فبذاتهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'أوبهنالك': [{'vocalized': u'أوبهنالك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'أفبنفسه': [{'vocalized': u'أفبنفسه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'وأثناءي': [{'vocalized': u'وأثناءي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'وأثناءي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'وعداي': [{'vocalized': u'وعداي', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'عدا'},
 {'vocalized': u'وعداي', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'عدا'}],

 u'أولنفسهما': [{'vocalized': u'أولنفسهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'فلعنكن': [{'vocalized': u'فلعنكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'وعني': [{'vocalized': u'وعني', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'وعني', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'وابننا': [{'vocalized': u'وابننا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'ولأكثركما': [{'vocalized': u'ولأكثركما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'وعنه': [{'vocalized': u'وعنه', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'فلأسفلكم': [{'vocalized': u'فلأسفلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'أوذواتي': [{'vocalized': u'أوذواتي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'مادمنا': [{'vocalized': u'مادمنا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادمنا', 'encletic': u'', 'type': u'فعل', 'original': u'مادمنا'}],

 u'وبعده': [{'vocalized': u'وبعده', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعد'}],

 u'أففوقه': [{'vocalized': u'أففوقه', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'أفغيركما': [{'vocalized': u'أفغيركما', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'وهاتان': [{'vocalized': u'وهاتان', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاتان', 'encletic': u'', 'type': u'اسم', 'original': u'هاتان'}],

 u'أبوكما': [{'vocalized': u'أبوكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبو'}],

 u'أوبمثل': [{'vocalized': u'أوبمثل', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلعينكم': [{'vocalized': u'أفلعينكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أفلعينكن': [{'vocalized': u'أفلعينكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'نفسي': [{'vocalized': u'نفسي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'نفسي', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'وبحميك': [{'vocalized': u'وبحميك', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حمي'}],

 u'فبضعك': [{'vocalized': u'فبضعك', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بضع'}],

 u'لتلكما': [{'vocalized': u'لتلكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'وبحميه': [{'vocalized': u'وبحميه', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'فبضعه': [{'vocalized': u'فبضعه', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بضع'}],

 u'وبحميي': [{'vocalized': u'وبحميي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'},
 {'vocalized': u'وبحميي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حمي'}],

 u'نفسك': [{'vocalized': u'نفسك', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'فليلكم': [{'vocalized': u'فليلكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'نفسه': [{'vocalized': u'نفسه', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'فبدونهما': [{'vocalized': u'فبدونهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بدون'}],

 u'وابنهما': [{'vocalized': u'وابنهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'وأمامكما': [{'vocalized': u'وأمامكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'فكهاذين': [{'vocalized': u'فكهاذين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'فبكلهما': [{'vocalized': u'فبكلهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فبكلهما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'فيمين': [{'vocalized': u'فيمين', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'أكبعضهما': [{'vocalized': u'أكبعضهما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'أفبعينهما': [{'vocalized': u'أفبعينهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'زمانهن': [{'vocalized': u'زمانهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'زمانهم': [{'vocalized': u'زمانهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'فبغربهن': [{'vocalized': u'فبغربهن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'فبغربهم': [{'vocalized': u'فبغربهم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'ألهاتين': [{'vocalized': u'ألهاتين', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'فنفسنا': [{'vocalized': u'فنفسنا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أفككليكما': [{'vocalized': u'أفككليكما', 'procletic': u'أ-ف-ك-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أمامكما': [{'vocalized': u'أمامكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أمام', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أمام'}],

 u'أوبكلكما': [{'vocalized': u'أوبكلكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'لأثناء': [{'vocalized': u'لأثناء', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'أثناء', 'encletic': u'', 'type': u'اسم', 'original': u'أثناء'}],

 u'زمانها': [{'vocalized': u'زمانها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'كزمانه': [{'vocalized': u'كزمانه', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'أفبأجمعكن': [{'vocalized': u'أفبأجمعكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفبأجمعكم': [{'vocalized': u'أفبأجمعكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'وكذويه': [{'vocalized': u'وكذويه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'كأجمعه': [{'vocalized': u'كأجمعه', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'معك': [{'vocalized': u'معك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مع'}],

 u'فلأقلهما': [{'vocalized': u'فلأقلهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'وكذويك': [{'vocalized': u'وكذويك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'كأجمعك': [{'vocalized': u'كأجمعك', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'معه': [{'vocalized': u'معه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'أوبنفسكم': [{'vocalized': u'أوبنفسكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'أبعامتها': [{'vocalized': u'أبعامتها', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'معي': [{'vocalized': u'معي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'},
 {'vocalized': u'معي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مع'}],

 u'كأجمعي': [{'vocalized': u'كأجمعي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'كأجمعي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'وكذويي': [{'vocalized': u'وكذويي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'وكذويي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'كأعليك': [{'vocalized': u'كأعليك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'أفعلينا': [{'vocalized': u'أفعلينا', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'فبأيتنا': [{'vocalized': u'فبأيتنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'فللواتي': [{'vocalized': u'فللواتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللواتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللواتي'}],

 u'وضمنكما': [{'vocalized': u'وضمنكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ضمن'}],

 u'فكعامتنا': [{'vocalized': u'فكعامتنا', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'معاذ': [{'vocalized': u'معاذ', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'معاذ', 'encletic': u'', 'type': u'اسم', 'original': u'معاذ'}],

 u'وبتلقاءها': [{'vocalized': u'وبتلقاءها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفبكلكما': [{'vocalized': u'أفبكلكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'أفبعينهم': [{'vocalized': u'أفبعينهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أفبعينهن': [{'vocalized': u'أفبعينهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'فكزمانهن': [{'vocalized': u'فكزمانهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'وبابنها': [{'vocalized': u'وبابنها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ابن'}],

 u'وكعامتهن': [{'vocalized': u'وكعامتهن', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فبعدكن': [{'vocalized': u'فبعدكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعد'}],

 u'أفلأمامي': [{'vocalized': u'أفلأمامي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'أفلأمامي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'وكعامتهم': [{'vocalized': u'وكعامتهم', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلأمامك': [{'vocalized': u'أفلأمامك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أمام'}],

 u'فكنفسهما': [{'vocalized': u'فكنفسهما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'فلابنكن': [{'vocalized': u'فلابنكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ابن'}],

 u'فلابنكم': [{'vocalized': u'فلابنكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ابن'}],

 u'وبلحظتكن': [{'vocalized': u'وبلحظتكن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلأناهن': [{'vocalized': u'أفلأناهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'أفلأناهم': [{'vocalized': u'أفلأناهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'وبلحظتكم': [{'vocalized': u'وبلحظتكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'لحظة'}],

 u'ألشبههن': [{'vocalized': u'ألشبههن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبههن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'كخلفنا': [{'vocalized': u'كخلفنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'ألشبههم': [{'vocalized': u'ألشبههم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبههم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'وحسبك': [{'vocalized': u'وحسبك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'جنوبكم': [{'vocalized': u'جنوبكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وحسبه': [{'vocalized': u'وحسبه', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'ألحسبكم': [{'vocalized': u'ألحسبكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'وبأسفلهم': [{'vocalized': u'وبأسفلهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبأسفلهن': [{'vocalized': u'وبأسفلهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'ألحسبكن': [{'vocalized': u'ألحسبكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'فبخلفه': [{'vocalized': u'فبخلفه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'ألشبهها': [{'vocalized': u'ألشبهها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'انقلب': [{'vocalized': u'انقلب', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'انقلب', 'encletic': u'', 'type': u'فعل', 'original': u'انقلب'}],

 u'فشطرك': [{'vocalized': u'فشطرك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'وكأيهما': [{'vocalized': u'وكأيهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'فشطره': [{'vocalized': u'فشطره', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'فشطري': [{'vocalized': u'فشطري', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'فشطري', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'ألوراءي': [{'vocalized': u'ألوراءي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'ألوراءي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'فبأعلينا': [{'vocalized': u'فبأعلينا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أعلى'}],

 u'وبتلقاءهم': [{'vocalized': u'وبتلقاءهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبتلقاءهن': [{'vocalized': u'وبتلقاءهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفبجميعكما': [{'vocalized': u'أفبجميعكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعكما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'فلقام': [{'vocalized': u'فلقام', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'قام', 'encletic': u'', 'type': u'فعل', 'original': u'قام'}],

 u'أفبعينها': [{'vocalized': u'أفبعينها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'أولعني': [{'vocalized': u'أولعني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'أولعني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'وبابنهن': [{'vocalized': u'وبابنهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ابن'}],

 u'وبابنهم': [{'vocalized': u'وبابنهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ابن'}],

 u'فأيتكن': [{'vocalized': u'فأيتكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'فلتلقاء': [{'vocalized': u'فلتلقاء', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'تلقاء', 'encletic': u'', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وجنوبكما': [{'vocalized': u'وجنوبكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنوب'}],

 u'أمنكما': [{'vocalized': u'أمنكما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'كشرقهما': [{'vocalized': u'كشرقهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'تبدل': [{'vocalized': u'تبدل', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'تبدل', 'encletic': u'', 'type': u'فعل', 'original': u'تبدل'}],

 u'أفكجميع': [{'vocalized': u'أفكجميع', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميع', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'فكعامتهن': [{'vocalized': u'فكعامتهن', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'أوكشبهها': [{'vocalized': u'أوكشبهها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'بأبينا': [{'vocalized': u'بأبينا', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'فكجميعنا': [{'vocalized': u'فكجميعنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعنا', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وبشبهها': [{'vocalized': u'وبشبهها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'فلعمرها': [{'vocalized': u'فلعمرها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لعمر'}],

 u'أوبأجمعه': [{'vocalized': u'أوبأجمعه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفعين': [{'vocalized': u'أفعين', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'بجنوبهم': [{'vocalized': u'بجنوبهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'أوبأجمعي': [{'vocalized': u'أوبأجمعي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أوبأجمعي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولكليهما': [{'vocalized': u'ولكليهما', 'procletic': u'و-ل-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'وبينهن': [{'vocalized': u'وبينهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بين'}],

 u'أفبذين': [{'vocalized': u'أفبذين', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'فغربهن': [{'vocalized': u'فغربهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'بفي': [{'vocalized': u'بفي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'}],

 u'أفلإليكن': [{'vocalized': u'أفلإليكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إلى'}],

 u'فكأي': [{'vocalized': u'فكأي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فكأي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'أي', 'encletic': u'', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فكأي', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'كأي', 'encletic': u'', 'type': u'اسم', 'original': u'كأي'}],

 u'أوهنالك': [{'vocalized': u'أوهنالك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فكأن': [{'vocalized': u'فكأن', 'procletic': u'ف-ك-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فكأن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'كأن', 'encletic': u'', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'فكأن', 'procletic': u'ف-ك-', 'tags': u'حرف;حرف نصب;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'وأثناءكما': [{'vocalized': u'وأثناءكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'فمعاذكما': [{'vocalized': u'فمعاذكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-كما', 'type': u'اسم', 'original': u'معاذ'}],

 u'أبأولئك': [{'vocalized': u'أبأولئك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'أخيهن': [{'vocalized': u'أخيهن', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'ومننا': [{'vocalized': u'ومننا', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'أفلتحتكما': [{'vocalized': u'أفلتحتكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'لعامتكن': [{'vocalized': u'لعامتكن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'لعامتكم': [{'vocalized': u'لعامتكم', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'كهاذين': [{'vocalized': u'كهاذين', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'وبزمانكم': [{'vocalized': u'وبزمانكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'وأبوك': [{'vocalized': u'وأبوك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبو'}],

 u'ولحميهما': [{'vocalized': u'ولحميهما', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'أفبضعهم': [{'vocalized': u'أفبضعهم', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بضع'}],

 u'فبذاته': [{'vocalized': u'فبذاته', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'فكشبهنا': [{'vocalized': u'فكشبهنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'فبذاتك': [{'vocalized': u'فبذاتك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'مابرحت': [{'vocalized': u'مابرحت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'مابرحت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'مابرحت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'},
 {'vocalized': u'مابرحت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحت', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحت'}],

 u'أوكشبههن': [{'vocalized': u'أوكشبههن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'فبذاتي': [{'vocalized': u'فبذاتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'فبذاتي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'أوكشبههم': [{'vocalized': u'أوكشبههم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'وبشبههم': [{'vocalized': u'وبشبههم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'فلعمرهم': [{'vocalized': u'فلعمرهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'لعمر'}],

 u'فلعمرهن': [{'vocalized': u'فلعمرهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'لعمر'}],

 u'وبشبههن': [{'vocalized': u'وبشبههن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'فكأثناءك': [{'vocalized': u'فكأثناءك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'بهؤلاء': [{'vocalized': u'بهؤلاء', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'أفعننا': [{'vocalized': u'أفعننا', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'بجنوبها': [{'vocalized': u'بجنوبها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'وبينها': [{'vocalized': u'وبينها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بين'}],

 u'فكأثناءي': [{'vocalized': u'فكأثناءي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'},
 {'vocalized': u'فكأثناءي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أثناء'}],

 u'آمين': [{'vocalized': u'آمين', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'آمين', 'encletic': u'', 'type': u'اسم فعل', 'original': u'آمين'}],

 u'ألجميعكن': [{'vocalized': u'ألجميعكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'فكشهري': [{'vocalized': u'فكشهري', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'فكشهري', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فبنفس': [{'vocalized': u'فبنفس', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'ألجميعكم': [{'vocalized': u'ألجميعكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'وكأكثرنا': [{'vocalized': u'وكأكثرنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'لغيرهما': [{'vocalized': u'لغيرهما', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيرهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'فلزمانهما': [{'vocalized': u'فلزمانهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'فلوراءهن': [{'vocalized': u'فلوراءهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وراء'}],

 u'فلوراءهم': [{'vocalized': u'فلوراءهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'فكلا': [{'vocalized': u'فكلا', 'procletic': u'ف-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'},
 {'vocalized': u'فكلا', 'procletic': u'ف-', 'tags': u'حرف;حرف ردع;عطف', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'}],

 u'وخلالهم': [{'vocalized': u'وخلالهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلال'}],

 u'وخلالهن': [{'vocalized': u'وخلالهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلال'}],

 u'سبحانهما': [{'vocalized': u'سبحانهما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'سبحان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سبحان'}],

 u'وبعيني': [{'vocalized': u'وبعيني', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'وبعيني', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'وكأسفلكن': [{'vocalized': u'وكأسفلكن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكأسفلكم': [{'vocalized': u'وكأسفلكم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'فبحمينا': [{'vocalized': u'فبحمينا', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'فبجنوبنا': [{'vocalized': u'فبجنوبنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'وبعينك': [{'vocalized': u'وبعينك', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'وبعينه': [{'vocalized': u'وبعينه', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'فكجنبكما': [{'vocalized': u'فكجنبكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'وخلالها': [{'vocalized': u'وخلالها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلال'}],

 u'بجنوبك': [{'vocalized': u'بجنوبك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'ولشبههما': [{'vocalized': u'ولشبههما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ولشبههما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فبذلكم': [{'vocalized': u'فبذلكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'فبذلكن': [{'vocalized': u'فبذلكن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'هيهات': [{'vocalized': u'هيهات', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'هيهات', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هيهات'}],

 u'وضحوة': [{'vocalized': u'وضحوة', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'ضحوة', 'encletic': u'', 'type': u'اسم', 'original': u'ضحوة'}],

 u'وكعامتهما': [{'vocalized': u'وكعامتهما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أوبكن': [{'vocalized': u'أوبكن', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بكن', 'encletic': u'', 'type': u'ضمير', 'original': u'بكن'}],

 u'فجير': [{'vocalized': u'فجير', 'procletic': u'ف-', 'tags': u'حرف;حرف جواب;عطف', 'stem': u'جير', 'encletic': u'', 'type': u'حرف', 'original': u'جير'}],

 u'ذاتهما': [{'vocalized': u'ذاتهما', 'procletic': u'', 'tags': u'اسم;اسم موصول;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'لتلكم': [{'vocalized': u'لتلكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أوبكم': [{'vocalized': u'أوبكم', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بكم', 'encletic': u'', 'type': u'ضمير', 'original': u'بكم'}],

 u'أوأنتن': [{'vocalized': u'أوأنتن', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'بذاتهما': [{'vocalized': u'بذاتهما', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'أوأنتم': [{'vocalized': u'أوأنتم', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'فأقلكم': [{'vocalized': u'فأقلكم', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'وبينكم': [{'vocalized': u'وبينكم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بين'}],

 u'أفلعامتكما': [{'vocalized': u'أفلعامتكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'فأقلكن': [{'vocalized': u'فأقلكن', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'لدنهما': [{'vocalized': u'لدنهما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدن'}],

 u'وأخاك': [{'vocalized': u'وأخاك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخا'}],

 u'فتي': [{'vocalized': u'فتي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'فغربكن': [{'vocalized': u'فغربكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'فلوراءها': [{'vocalized': u'فلوراءها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وراء'}],

 u'وشهر': [{'vocalized': u'وشهر', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'أفكبعضهما': [{'vocalized': u'أفكبعضهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'فته': [{'vocalized': u'فته', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'أوكبعضنا': [{'vocalized': u'أوكبعضنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'لأسفلها': [{'vocalized': u'لأسفلها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'وشبهها': [{'vocalized': u'وشبهها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شبه'}],

 u'لشرق': [{'vocalized': u'لشرق', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'أفكنفسهما': [{'vocalized': u'أفكنفسهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'أفتلك': [{'vocalized': u'أفتلك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'وأيته': [{'vocalized': u'وأيته', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'وشمالك': [{'vocalized': u'وشمالك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'فكبعضكما': [{'vocalized': u'فكبعضكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أبتلكما': [{'vocalized': u'أبتلكما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'أوبعينهما': [{'vocalized': u'أوبعينهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'وقتك': [{'vocalized': u'وقتك', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'فعاد': [{'vocalized': u'فعاد', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'عاد', 'encletic': u'', 'type': u'فعل', 'original': u'عاد'}],

 u'آه': [{'vocalized': u'آه', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'آه', 'encletic': u'', 'type': u'اسم فعل', 'original': u'آه'}],

 u'فكغربكما': [{'vocalized': u'فكغربكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غرب'}],

 u'لاستحال': [{'vocalized': u'لاستحال', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'استحال', 'encletic': u'', 'type': u'فعل', 'original': u'استحال'}],

 u'ذوونا': [{'vocalized': u'ذوونا', 'procletic': u'', 'tags': u'اسم;اسم إشارة;ضمير', 'stem': u'ذوو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوو'}],

 u'ولعلكما': [{'vocalized': u'ولعلكما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لعل'}],

 u'أوبأجمعها': [{'vocalized': u'أوبأجمعها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'فأيكن': [{'vocalized': u'فأيكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'أحسبكم': [{'vocalized': u'أحسبكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'كأقلكن': [{'vocalized': u'كأقلكن', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'وبسويه': [{'vocalized': u'وبسويه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أببعضك': [{'vocalized': u'أببعضك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'لأخيهن': [{'vocalized': u'لأخيهن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'وبسويك': [{'vocalized': u'وبسويك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'وليلكن': [{'vocalized': u'وليلكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'أشمالنا': [{'vocalized': u'أشمالنا', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'ولساعته': [{'vocalized': u'ولساعته', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوبأجمعهم': [{'vocalized': u'أوبأجمعهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أوبأجمعهن': [{'vocalized': u'أوبأجمعهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ببعضكم': [{'vocalized': u'ببعضكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'وبأيكما': [{'vocalized': u'وبأيكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'أولتحتكما': [{'vocalized': u'أولتحتكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'وشبههم': [{'vocalized': u'وشبههم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شبه'}],

 u'وشبههن': [{'vocalized': u'وشبههن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شبه'}],

 u'لذاتكم': [{'vocalized': u'لذاتكم', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'لذاتكن': [{'vocalized': u'لذاتكن', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'أكعامتكما': [{'vocalized': u'أكعامتكما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلإن': [{'vocalized': u'أفلإن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'ولأيته': [{'vocalized': u'ولأيته', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أية'}],

 u'لشرع': [{'vocalized': u'لشرع', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'شرع', 'encletic': u'', 'type': u'فعل', 'original': u'شرع'}],

 u'ولأيتي': [{'vocalized': u'ولأيتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'ولأيتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'ولأعلي': [{'vocalized': u'ولأعلي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'ولأعلي', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'ولأعلى': [{'vocalized': u'ولأعلى', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبأيك': [{'vocalized': u'فبأيك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'بهذا': [{'vocalized': u'بهذا', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'فخلاي': [{'vocalized': u'فخلاي', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'خلا'},
 {'vocalized': u'فخلاي', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'خلا'}],

 u'فبأيه': [{'vocalized': u'فبأيه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'فهو': [{'vocalized': u'فهو', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'فخلاه': [{'vocalized': u'فخلاه', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'خلا'}],

 u'فهن': [{'vocalized': u'فهن', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'فهم': [{'vocalized': u'فهم', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'فبأيي': [{'vocalized': u'فبأيي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فبأيي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'فخلاك': [{'vocalized': u'فخلاك', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'خلا'}],

 u'أوغيرهما': [{'vocalized': u'أوغيرهما', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'لأنت': [{'vocalized': u'لأنت', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'لأنت', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'ولمني': [{'vocalized': u'ولمني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'ولمني', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'فلأنت': [{'vocalized': u'فلأنت', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'فلأنت', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'و': [{'vocalized': u'و', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'و', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'و'},
 {'vocalized': u'و', 'procletic': u'', 'tags': u'حرف;حرف عطف منفصل', 'stem': u'و', 'encletic': u'', 'type': u'حرف', 'original': u'و'},
 {'vocalized': u'و', 'procletic': u'', 'tags': u'حرف;حرف عطف', 'stem': u'و', 'encletic': u'', 'type': u'حرف', 'original': u'و'}],

 u'فبأسفلنا': [{'vocalized': u'فبأسفلنا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'إذ': [{'vocalized': u'إذ', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'إذ', 'encletic': u'', 'type': u'اسم', 'original': u'إذ'},
 {'vocalized': u'إذ', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'إذ', 'encletic': u'', 'type': u'اسم', 'original': u'إذ'}],

 u'أفلوراء': [{'vocalized': u'أفلوراء', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'فكيت': [{'vocalized': u'فكيت', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'كيت', 'encletic': u'', 'type': u'اسم', 'original': u'كيت'}],

 u'لفيها': [{'vocalized': u'لفيها', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'وذاتهم': [{'vocalized': u'وذاتهم', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'وذاتهن': [{'vocalized': u'وذاتهن', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذات'}],

 u'لكنكما': [{'vocalized': u'لكنكما', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لكن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'لكنكما', 'procletic': u'', 'tags': u'حرف;حرف استدراك;ضمير', 'stem': u'لكن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لكن'}],

 u'ألسنا': [{'vocalized': u'ألسنا', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'لسنا', 'encletic': u'', 'type': u'فعل', 'original': u'لسنا'}],

 u'أولعنكم': [{'vocalized': u'أولعنكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'أولعنكن': [{'vocalized': u'أولعنكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'أفلإنا': [{'vocalized': u'أفلإنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'فبماذا': [{'vocalized': u'فبماذا', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'بماذا', 'encletic': u'', 'type': u'اسم', 'original': u'بماذا'}],

 u'بسوينا': [{'vocalized': u'بسوينا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'فجنوبه': [{'vocalized': u'فجنوبه', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبابننا': [{'vocalized': u'فبابننا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'فجنوبك': [{'vocalized': u'فجنوبك', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنوب'}],

 u'فبخلفهما': [{'vocalized': u'فبخلفهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'لفيهم': [{'vocalized': u'لفيهم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'لفيهن': [{'vocalized': u'لفيهن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'وبجنوبهم': [{'vocalized': u'وبجنوبهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جنوب'}],

 u'وذاتها': [{'vocalized': u'وذاتها', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'وتارة': [{'vocalized': u'وتارة', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'تارة', 'encletic': u'', 'type': u'اسم', 'original': u'تارة'}],

 u'فقط': [{'vocalized': u'فقط', 'procletic': u'ف-', 'tags': u'حرف;ظرف;عطف', 'stem': u'قط', 'encletic': u'', 'type': u'حرف', 'original': u'قط'},
 {'vocalized': u'فقط', 'procletic': u'', 'tags': u'حرف;', 'stem': u'فقط', 'encletic': u'', 'type': u'حرف', 'original': u'فقط'}],

 u'أكحسبنا': [{'vocalized': u'أكحسبنا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'معكما': [{'vocalized': u'معكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'لليلنا': [{'vocalized': u'لليلنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'أولمثلي': [{'vocalized': u'أولمثلي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'أوإليه': [{'vocalized': u'أوإليه', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'فعسى': [{'vocalized': u'فعسى', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'عسى', 'encletic': u'', 'type': u'فعل', 'original': u'عسى'}],

 u'أولمثلك': [{'vocalized': u'أولمثلك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أوإليك': [{'vocalized': u'أوإليك', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'أولمثله': [{'vocalized': u'أولمثله', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثله', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'ماانفككتم': [{'vocalized': u'ماانفككتم', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككتم', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتم'}],

 u'لأنه': [{'vocalized': u'لأنه', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'ماانفككتن': [{'vocalized': u'ماانفككتن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككتن', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتن'}],

 u'بهذه': [{'vocalized': u'بهذه', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'لأنك': [{'vocalized': u'لأنك', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'إي': [{'vocalized': u'إي', 'procletic': u'', 'tags': u'حرف;حرف جواب', 'stem': u'إي', 'encletic': u'', 'type': u'حرف', 'original': u'إي'}],

 u'أومنكما': [{'vocalized': u'أومنكما', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'بهذي': [{'vocalized': u'بهذي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'إن': [{'vocalized': u'إن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'إن', 'procletic': u'', 'tags': u'حرف;المشبهة بليس', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'إن', 'procletic': u'', 'tags': u'حرف;حرف جزم', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'إن', 'procletic': u'', 'tags': u'حرف;حرف شرط', 'stem': u'إن', 'encletic': u'', 'type': u'حرف', 'original': u'إن'}],

 u'لحميكما': [{'vocalized': u'لحميكما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'لأني': [{'vocalized': u'لأني', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'لأني', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'فبعينكما': [{'vocalized': u'فبعينكما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'أإليكما': [{'vocalized': u'أإليكما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'فبشطرنا': [{'vocalized': u'فبشطرنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'أوكنفسكن': [{'vocalized': u'أوكنفسكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أوكنفسكم': [{'vocalized': u'أوكنفسكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'أأناها': [{'vocalized': u'أأناها', 'procletic': u'أ-', 'tags': u'حرف;ناصب ومنصوب;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'شرع': [{'vocalized': u'شرع', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'شرع', 'encletic': u'', 'type': u'فعل', 'original': u'شرع'}],

 u'ونفسنا': [{'vocalized': u'ونفسنا', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'لأخيهما': [{'vocalized': u'لأخيهما', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'ولنفسهن': [{'vocalized': u'ولنفسهن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نفس'}],

 u'ولعيننا': [{'vocalized': u'ولعيننا', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ولعيننا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'فكغيرها': [{'vocalized': u'فكغيرها', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'بعضي': [{'vocalized': u'بعضي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'بعضي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'فأعليهم': [{'vocalized': u'فأعليهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'فأعليهن': [{'vocalized': u'فأعليهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أعلى'}],

 u'بعضك': [{'vocalized': u'بعضك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'وهؤلاء': [{'vocalized': u'وهؤلاء', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'وبحميهما': [{'vocalized': u'وبحميهما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'ولشطركن': [{'vocalized': u'ولشطركن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شطر'}],

 u'ففاهما': [{'vocalized': u'ففاهما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فا'}],

 u'أتحتها': [{'vocalized': u'أتحتها', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'تحت'}],

 u'ولشطركم': [{'vocalized': u'ولشطركم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شطر'}],

 u'فبنفسي': [{'vocalized': u'فبنفسي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فبنفسي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'أفلعنه': [{'vocalized': u'أفلعنه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'أبنحوهم': [{'vocalized': u'أبنحوهم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أبنحوهن': [{'vocalized': u'أبنحوهن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'فبنفسك': [{'vocalized': u'فبنفسك', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'وشطر': [{'vocalized': u'وشطر', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'أفلعني': [{'vocalized': u'أفلعني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'أفلعني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'وكته': [{'vocalized': u'وكته', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'وكلكم': [{'vocalized': u'وكلكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلكم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'وكلكن': [{'vocalized': u'وكلكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'وكلكن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'فبأولئكم': [{'vocalized': u'فبأولئكم', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'أولنا': [{'vocalized': u'أولنا', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لنا', 'encletic': u'', 'type': u'ضمير', 'original': u'لنا'}],

 u'لمنكم': [{'vocalized': u'لمنكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'أولتحتكم': [{'vocalized': u'أولتحتكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'وكتي': [{'vocalized': u'وكتي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'بغربهن': [{'vocalized': u'بغربهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'بأنك': [{'vocalized': u'بأنك', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'بأنه': [{'vocalized': u'بأنه', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'أبنحوها': [{'vocalized': u'أبنحوها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'بأني': [{'vocalized': u'بأني', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'بأني', 'procletic': u'ب-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'ألازلنا': [{'vocalized': u'ألازلنا', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'لازلنا'}],

 u'نحوي': [{'vocalized': u'نحوي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوي', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوي', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'وبأخيك': [{'vocalized': u'وبأخيك', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'بغربهم': [{'vocalized': u'بغربهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'أفبهي': [{'vocalized': u'أفبهي', 'procletic': u'أ-ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'فذووكم': [{'vocalized': u'فذووكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوو'}],

 u'فذووكن': [{'vocalized': u'فذووكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوو'}],

 u'فلكأنهما': [{'vocalized': u'فلكأنهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'كأن'}],

 u'بتانك': [{'vocalized': u'بتانك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'نحوه': [{'vocalized': u'نحوه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحوه', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'فلأنكما': [{'vocalized': u'فلأنكما', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'فأثناءكم': [{'vocalized': u'فأثناءكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفببعضي': [{'vocalized': u'أفببعضي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أفببعضي', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'بساعتكما': [{'vocalized': u'بساعتكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'خلفهن': [{'vocalized': u'خلفهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'فلأيكما': [{'vocalized': u'فلأيكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'أوكعينكن': [{'vocalized': u'أوكعينكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'أفببعضك': [{'vocalized': u'أفببعضك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'أولديكن': [{'vocalized': u'أولديكن', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لدى'}],

 u'فكلكم': [{'vocalized': u'فكلكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلكم', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'فكلكن': [{'vocalized': u'فكلكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فكلكن', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أفببعضه': [{'vocalized': u'أفببعضه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'فتانك': [{'vocalized': u'فتانك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'فكغيرهن': [{'vocalized': u'فكغيرهن', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'فكغيرهم': [{'vocalized': u'فكغيرهم', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'فأعليها': [{'vocalized': u'فأعليها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'أعامتكما': [{'vocalized': u'أعامتكما', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'وبضعهن': [{'vocalized': u'وبضعهن', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بضع'}],

 u'أتحتهم': [{'vocalized': u'أتحتهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'م': [{'vocalized': u'م', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'م', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'م'}],

 u'أتحتهن': [{'vocalized': u'أتحتهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'أفلازلت': [{'vocalized': u'أفلازلت', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'أفلازلت', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'أفلازلت', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'}],

 u'أفلأناي': [{'vocalized': u'أفلأناي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'},
 {'vocalized': u'أفلأناي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أنا'}],

 u'شهرهم': [{'vocalized': u'شهرهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شهر'}],

 u'أفلأناه': [{'vocalized': u'أفلأناه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'وحموكما': [{'vocalized': u'وحموكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمو'}],

 u'أفلأناك': [{'vocalized': u'أفلأناك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'أفيكما': [{'vocalized': u'أفيكما', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'حار': [{'vocalized': u'حار', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'حار', 'encletic': u'', 'type': u'فعل', 'original': u'حار'}],

 u'أوكعين': [{'vocalized': u'أوكعين', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'وأيكن': [{'vocalized': u'وأيكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'وأيكم': [{'vocalized': u'وأيكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'أفبكلتا': [{'vocalized': u'أفبكلتا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أفبتينك': [{'vocalized': u'أفبتينك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'عن': [{'vocalized': u'عن', 'procletic': u'', 'tags': u'حرف;حرف جر', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'ألغيرنا': [{'vocalized': u'ألغيرنا', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغيرنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'فبنحوه': [{'vocalized': u'فبنحوه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'فكيف': [{'vocalized': u'فكيف', 'procletic': u'ف-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'كيف', 'encletic': u'', 'type': u'اسم', 'original': u'كيف'}],

 u'فبنحوك': [{'vocalized': u'فبنحوك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'أبنفسهم': [{'vocalized': u'أبنفسهم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نفس'}],

 u'كمثلكما': [{'vocalized': u'كمثلكما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'فلمثلهما': [{'vocalized': u'فلمثلهما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'كحسبها': [{'vocalized': u'كحسبها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلعلها': [{'vocalized': u'أفلعلها', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-ها', 'type': u'حرف', 'original': u'لعل'}],

 u'فبكليهما': [{'vocalized': u'فبكليهما', 'procletic': u'ف-ب-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'فبنحوي': [{'vocalized': u'فبنحوي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فبنحوي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'ولذويكما': [{'vocalized': u'ولذويكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفلسويكم': [{'vocalized': u'أفلسويكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلسويكن': [{'vocalized': u'أفلسويكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'كساعتكن': [{'vocalized': u'كساعتكن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أبينا': [{'vocalized': u'أبينا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبي'}],

 u'كساعتكم': [{'vocalized': u'كساعتكم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'بجميعنا': [{'vocalized': u'بجميعنا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'بجميعنا', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'ذلكم': [{'vocalized': u'ذلكم', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'ذلكن': [{'vocalized': u'ذلكن', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'حينكم': [{'vocalized': u'حينكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حين'}],

 u'أبنفسها': [{'vocalized': u'أبنفسها', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نفس'}],

 u'وأنانا': [{'vocalized': u'وأنانا', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أنا'}],

 u'أفلعلهم': [{'vocalized': u'أفلعلهم', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هم', 'type': u'حرف', 'original': u'لعل'}],

 u'أبهنالك': [{'vocalized': u'أبهنالك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'كحسبهم': [{'vocalized': u'كحسبهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أولكليكما': [{'vocalized': u'أولكليكما', 'procletic': u'أ-و-ل-', 'tags': u'حرف;توكيد;مجرور;عطف;استفهام', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أوكذا': [{'vocalized': u'أوكذا', 'procletic': u'أ-و-', 'tags': u'اسم;كناية;عطف;استفهام', 'stem': u'كذا', 'encletic': u'', 'type': u'اسم', 'original': u'كذا'}],

 u'أفبغيرك': [{'vocalized': u'أفبغيرك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'أفلمثلكم': [{'vocalized': u'أفلمثلكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلمثلكن': [{'vocalized': u'أفلمثلكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أفلمثلكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'بحمينا': [{'vocalized': u'بحمينا', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حمي'}],

 u'مازلت': [{'vocalized': u'مازلت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'},
 {'vocalized': u'مازلت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'},
 {'vocalized': u'مازلت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلت', 'encletic': u'', 'type': u'فعل', 'original': u'مازلت'}],

 u'آنئذ': [{'vocalized': u'آنئذ', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'آنئذ', 'encletic': u'', 'type': u'اسم', 'original': u'آنئذ'}],

 u'حاي': [{'vocalized': u'حاي', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'حاي', 'encletic': u'', 'type': u'اسم فعل', 'original': u'حاي'}],

 u'وبشبهكن': [{'vocalized': u'وبشبهكن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'أفلازلن': [{'vocalized': u'أفلازلن', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلن'}],

 u'فأية': [{'vocalized': u'فأية', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'أأجمعك': [{'vocalized': u'أأجمعك', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'فإليكما': [{'vocalized': u'فإليكما', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'إليكما', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليكما'},
 {'vocalized': u'فإليكما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-كما', 'type': u'حرف', 'original': u'إلى'}],

 u'أففوقهما': [{'vocalized': u'أففوقهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'ألفوقكم': [{'vocalized': u'ألفوقكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'كرب': [{'vocalized': u'كرب', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'كرب', 'encletic': u'', 'type': u'فعل', 'original': u'كرب'}],

 u'أفلحسبكم': [{'vocalized': u'أفلحسبكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلحسبكن': [{'vocalized': u'أفلحسبكن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'وحذار': [{'vocalized': u'وحذار', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'حذار', 'encletic': u'', 'type': u'اسم فعل', 'original': u'حذار'}],

 u'لأناهم': [{'vocalized': u'لأناهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'وبكليهما': [{'vocalized': u'وبكليهما', 'procletic': u'و-ب-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'فبضع': [{'vocalized': u'فبضع', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف', 'stem': u'بضع', 'encletic': u'', 'type': u'اسم', 'original': u'بضع'}],

 u'وبحمي': [{'vocalized': u'وبحمي', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'بشهر': [{'vocalized': u'بشهر', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'أوهاته': [{'vocalized': u'أوهاته', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'أبكلهن': [{'vocalized': u'أبكلهن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلهن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أبكلهم': [{'vocalized': u'أبكلهم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلهم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أأمامكن': [{'vocalized': u'أأمامكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أمام'}],

 u'بأولئكم': [{'vocalized': u'بأولئكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولئكم', 'encletic': u'', 'type': u'اسم', 'original': u'أولئكم'}],

 u'أيميننا': [{'vocalized': u'أيميننا', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'يمين'}],

 u'أوذلك': [{'vocalized': u'أوذلك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'أوهاتي': [{'vocalized': u'أوهاتي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'فلكلكم': [{'vocalized': u'فلكلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'فلكلكن': [{'vocalized': u'فلكلكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'لأناها': [{'vocalized': u'لأناها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'ألخلفنا': [{'vocalized': u'ألخلفنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'أوكلكما': [{'vocalized': u'أوكلكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكلكما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'جنوب': [{'vocalized': u'جنوب', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'أبكلها': [{'vocalized': u'أبكلها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلها', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'أبوهما': [{'vocalized': u'أبوهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أبو'}],

 u'أوعن': [{'vocalized': u'أوعن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'عن', 'encletic': u'', 'type': u'حرف', 'original': u'عن'}],

 u'أولنفسنا': [{'vocalized': u'أولنفسنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أولنفسنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أ': [{'vocalized': u'أ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'أ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'أ'},
 {'vocalized': u'أ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'أ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'أ'}],

 u'فكنفسي': [{'vocalized': u'فكنفسي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فكنفسي', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'ولديكما': [{'vocalized': u'ولديكما', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'لدى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدى'}],

 u'فكنفسك': [{'vocalized': u'فكنفسك', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'فكنفسه': [{'vocalized': u'فكنفسه', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'لحسبكن': [{'vocalized': u'لحسبكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'لحسبكم': [{'vocalized': u'لحسبكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفبنحو': [{'vocalized': u'أفبنحو', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'حاشانا': [{'vocalized': u'حاشانا', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'حاشا'}],

 u'فخلالي': [{'vocalized': u'فخلالي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلال'},
 {'vocalized': u'فخلالي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلال'}],

 u'كلاهما': [{'vocalized': u'كلاهما', 'procletic': u'', 'tags': u'حرف;توكيد', 'stem': u'كلاهما', 'encletic': u'', 'type': u'حرف', 'original': u'كلاهما'}],

 u'فمكانكما': [{'vocalized': u'فمكانكما', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'مكانكما', 'encletic': u'', 'type': u'اسم فعل', 'original': u'مكانكما'}],

 u'فخلاله': [{'vocalized': u'فخلاله', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلال'}],

 u'فخلالك': [{'vocalized': u'فخلالك', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف;ضمير', 'stem': u'خلال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلال'}],

 u'فكذويكما': [{'vocalized': u'فكذويكما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أنفس': [{'vocalized': u'أنفس', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'وكأيتهما': [{'vocalized': u'وكأيتهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'وأقلكن': [{'vocalized': u'وأقلكن', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'وأقلكم': [{'vocalized': u'وأقلكم', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'أوكأجمع': [{'vocalized': u'أوكأجمع', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'أجمع', 'encletic': u'', 'type': u'اسم', 'original': u'أجمع'}],

 u'أكسوى': [{'vocalized': u'أكسوى', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'أكسوي': [{'vocalized': u'أكسوي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أكسوي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'ولأجمعهما': [{'vocalized': u'ولأجمعهما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأنها': [{'vocalized': u'وأنها', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'فكنحوهن': [{'vocalized': u'فكنحوهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'فكنحوهم': [{'vocalized': u'فكنحوهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أفتحتكن': [{'vocalized': u'أفتحتكن', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'تحت'}],

 u'شرق': [{'vocalized': u'شرق', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'لازلنا': [{'vocalized': u'لازلنا', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلنا', 'encletic': u'', 'type': u'فعل', 'original': u'لازلنا'}],

 u'أسويهما': [{'vocalized': u'أسويهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'فعليك': [{'vocalized': u'فعليك', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'عليك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'عليك'},
 {'vocalized': u'فعليك', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'فعليه': [{'vocalized': u'فعليه', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'وماانفكوا': [{'vocalized': u'وماانفكوا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكوا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكوا'}],

 u'وبحسبي': [{'vocalized': u'وبحسبي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'وبحسبي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'لعليها': [{'vocalized': u'لعليها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'وبحسبك': [{'vocalized': u'وبحسبك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فلعامتهم': [{'vocalized': u'فلعامتهم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'كأيتهم': [{'vocalized': u'كأيتهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أية'}],

 u'وذووهن': [{'vocalized': u'وذووهن', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوو'}],

 u'وذووهم': [{'vocalized': u'وذووهم', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوو'}],

 u'كأيتهن': [{'vocalized': u'كأيتهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'أفعامتنا': [{'vocalized': u'أفعامتنا', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'ولابنكما': [{'vocalized': u'ولابنكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'لعليهم': [{'vocalized': u'لعليهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-هم', 'type': u'حرف', 'original': u'على'}],

 u'لعليهن': [{'vocalized': u'لعليهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-هن', 'type': u'حرف', 'original': u'على'}],

 u'فلشمالها': [{'vocalized': u'فلشمالها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'فلعامتها': [{'vocalized': u'فلعامتها', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'وذووها': [{'vocalized': u'وذووها', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوو'}],

 u'كأيتها': [{'vocalized': u'كأيتها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'وبأبيكما': [{'vocalized': u'وبأبيكما', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'بفيكن': [{'vocalized': u'بفيكن', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'}],

 u'فلحميكما': [{'vocalized': u'فلحميكما', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمي'}],

 u'فغروبهما': [{'vocalized': u'فغروبهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'هاؤم': [{'vocalized': u'هاؤم', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'هاؤم', 'encletic': u'', 'type': u'اسم فعل', 'original': u'هاؤم'}],

 u'وبدون': [{'vocalized': u'وبدون', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'بدون', 'encletic': u'', 'type': u'اسم', 'original': u'بدون'}],

 u'فكهنالك': [{'vocalized': u'فكهنالك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فلزمان': [{'vocalized': u'فلزمان', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'زمان', 'encletic': u'', 'type': u'اسم', 'original': u'زمان'}],

 u'وأنهن': [{'vocalized': u'وأنهن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'وأنهم': [{'vocalized': u'وأنهم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أن'}],

 u'فكنحوها': [{'vocalized': u'فكنحوها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'أبنحو': [{'vocalized': u'أبنحو', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'أوراءك': [{'vocalized': u'أوراءك', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وراء'}],

 u'أوراءه': [{'vocalized': u'أوراءه', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'وراء'}],

 u'وعين': [{'vocalized': u'وعين', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'أوراءي': [{'vocalized': u'أوراءي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'أوراءي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'فلأنك': [{'vocalized': u'فلأنك', 'procletic': u'ف-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'ككلي': [{'vocalized': u'ككلي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلي', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'أفلعينهم': [{'vocalized': u'أفلعينهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'أفلعينهن': [{'vocalized': u'أفلعينهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'فأعليكم': [{'vocalized': u'فأعليكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'ككلك': [{'vocalized': u'ككلك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككلك', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'أولشبهكما': [{'vocalized': u'أولشبهكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبهكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'ككله': [{'vocalized': u'ككله', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ككله', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'كغروبها': [{'vocalized': u'كغروبها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'وكابنهما': [{'vocalized': u'وكابنهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'وجنوبنا': [{'vocalized': u'وجنوبنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'ألهناك': [{'vocalized': u'ألهناك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'فأقلكما': [{'vocalized': u'فأقلكما', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'ألتحتي': [{'vocalized': u'ألتحتي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'ألتحتي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'فلئن': [{'vocalized': u'فلئن', 'procletic': u'ف-', 'tags': u'حرف;حرف شرط;عطف', 'stem': u'لئن', 'encletic': u'', 'type': u'حرف', 'original': u'لئن'}],

 u'أفكهنالك': [{'vocalized': u'أفكهنالك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'فببعضها': [{'vocalized': u'فببعضها', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'شطرها': [{'vocalized': u'شطرها', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'شهركم': [{'vocalized': u'شهركم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شهر'}],

 u'الذين': [{'vocalized': u'الذين', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'فكساعتكن': [{'vocalized': u'فكساعتكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكساعتكم': [{'vocalized': u'فكساعتكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'فكخلفنا': [{'vocalized': u'فكخلفنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'فحرى': [{'vocalized': u'فحرى', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'حرى', 'encletic': u'', 'type': u'فعل', 'original': u'حرى'}],

 u'بعدي': [{'vocalized': u'بعدي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعد'},
 {'vocalized': u'بعدي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'بعد', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعد'}],

 u'بليلي': [{'vocalized': u'بليلي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'بليلي', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'فكذويك': [{'vocalized': u'فكذويك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'فببعضهن': [{'vocalized': u'فببعضهن', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'شطرهم': [{'vocalized': u'شطرهم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'شطرهن': [{'vocalized': u'شطرهن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'فكذويه': [{'vocalized': u'فكذويه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكذويي': [{'vocalized': u'فكذويي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'فكذويي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'وللذي': [{'vocalized': u'وللذي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذي', 'encletic': u'', 'type': u'اسم', 'original': u'الذي'}],

 u'فبزماني': [{'vocalized': u'فبزماني', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'},
 {'vocalized': u'فبزماني', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'زمان'}],

 u'أولعليكما': [{'vocalized': u'أولعليكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'وبليل': [{'vocalized': u'وبليل', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'أفكنحو': [{'vocalized': u'أفكنحو', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'حاشاكما': [{'vocalized': u'حاشاكما', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'حاشا', 'encletic': u'-كما', 'type': u'فعل', 'original': u'حاشا'}],

 u'فبزمانك': [{'vocalized': u'فبزمانك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'وخلاك': [{'vocalized': u'وخلاك', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ك', 'type': u'فعل', 'original': u'خلا'}],

 u'فبزمانه': [{'vocalized': u'فبزمانه', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'زمان'}],

 u'أفلعينها': [{'vocalized': u'أفلعينها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعينها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'وأبانا': [{'vocalized': u'وأبانا', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أبا'}],

 u'بليلك': [{'vocalized': u'بليلك', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'أفبشبههما': [{'vocalized': u'أفبشبههما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فبغروبهما': [{'vocalized': u'فبغروبهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'أوكهؤلاء': [{'vocalized': u'أوكهؤلاء', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'أوكحسبهما': [{'vocalized': u'أوكحسبهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'أفبعامتكم': [{'vocalized': u'أفبعامتكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'بتين': [{'vocalized': u'بتين', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'أبأجمعنا': [{'vocalized': u'أبأجمعنا', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'لوراءي': [{'vocalized': u'لوراءي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'},
 {'vocalized': u'لوراءي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وراء'}],

 u'فكأسفلهما': [{'vocalized': u'فكأسفلهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أليست': [{'vocalized': u'أليست', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'ليست', 'encletic': u'', 'type': u'فعل', 'original': u'ليست'}],

 u'عامتهن': [{'vocalized': u'عامتهن', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'ألعلنا': [{'vocalized': u'ألعلنا', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لعل'}],

 u'عامتهم': [{'vocalized': u'عامتهم', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'ولجميعهما': [{'vocalized': u'ولجميعهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ولجميعهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'وبأبيكن': [{'vocalized': u'وبأبيكن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'وبأبيكم': [{'vocalized': u'وبأبيكم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'أليسا': [{'vocalized': u'أليسا', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'ليسا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسا'}],

 u'وضمنهن': [{'vocalized': u'وضمنهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ضمن'}],

 u'لهن': [{'vocalized': u'لهن', 'procletic': u'ل-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'},
 {'vocalized': u'لهن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'وأنا': [{'vocalized': u'وأنا', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'وأنا', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'لهم': [{'vocalized': u'لهم', 'procletic': u'ل-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'},
 {'vocalized': u'لهم', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'لهي': [{'vocalized': u'لهي', 'procletic': u'ل-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'},
 {'vocalized': u'لهي', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'حسبكما': [{'vocalized': u'حسبكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'لهو': [{'vocalized': u'لهو', 'procletic': u'ل-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'},
 {'vocalized': u'لهو', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'ولأسفلهما': [{'vocalized': u'ولأسفلهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'واللاتي': [{'vocalized': u'واللاتي', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'إني': [{'vocalized': u'إني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'إني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'فكشطر': [{'vocalized': u'فكشطر', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'ولليلكن': [{'vocalized': u'ولليلكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ليل'}],

 u'فسبحاني': [{'vocalized': u'فسبحاني', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سبحان'},
 {'vocalized': u'فسبحاني', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سبحان'}],

 u'فسبحانه': [{'vocalized': u'فسبحانه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سبحان'}],

 u'إنك': [{'vocalized': u'إنك', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'كساعة': [{'vocalized': u'كساعة', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'ساعة', 'encletic': u'', 'type': u'اسم', 'original': u'ساعة'}],

 u'فسبحانك': [{'vocalized': u'فسبحانك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سبحان'}],

 u'إنه': [{'vocalized': u'إنه', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'أتحتكما': [{'vocalized': u'أتحتكما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'كلحظتي': [{'vocalized': u'كلحظتي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'كلحظتي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'لها': [{'vocalized': u'لها', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'لها', 'encletic': u'', 'type': u'ضمير', 'original': u'لها'}],

 u'زمانكم': [{'vocalized': u'زمانكم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'كلحظته': [{'vocalized': u'كلحظته', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'لهب': [{'vocalized': u'لهب', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'هب', 'encletic': u'', 'type': u'فعل', 'original': u'هب'}],

 u'كلحظتك': [{'vocalized': u'كلحظتك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'ألذواتي': [{'vocalized': u'ألذواتي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'ماانفككتما': [{'vocalized': u'ماانفككتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككتما', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتما'},
 {'vocalized': u'ماانفككتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماانفككتما', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككتما'}],

 u'فلآض': [{'vocalized': u'فلآض', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'آض', 'encletic': u'', 'type': u'فعل', 'original': u'آض'}],

 u'وكأية': [{'vocalized': u'وكأية', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'أية', 'encletic': u'', 'type': u'اسم', 'original': u'أية'}],

 u'إنا': [{'vocalized': u'إنا', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب', 'stem': u'إنا', 'encletic': u'', 'type': u'حرف', 'original': u'إنا'}],

 u'ولكما': [{'vocalized': u'ولكما', 'procletic': u'و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لكما', 'encletic': u'', 'type': u'ضمير', 'original': u'لكما'}],

 u'وماانفكتا': [{'vocalized': u'وماانفكتا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكتا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكتا'}],

 u'أوعينكما': [{'vocalized': u'أوعينكما', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فكيفما': [{'vocalized': u'فكيفما', 'procletic': u'ف-', 'tags': u'اسم;اسم الشرط;عطف', 'stem': u'كيفما', 'encletic': u'', 'type': u'اسم', 'original': u'كيفما'}],

 u'ولجنوبهن': [{'vocalized': u'ولجنوبهن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جنوب'}],

 u'عامتها': [{'vocalized': u'عامتها', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'نفس': [{'vocalized': u'نفس', 'procletic': u'', 'tags': u'اسم;توكيد', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'لحميه': [{'vocalized': u'لحميه', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حمي'}],

 u'فقبل': [{'vocalized': u'فقبل', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'قبل', 'encletic': u'', 'type': u'اسم', 'original': u'قبل'}],

 u'لأسفلهم': [{'vocalized': u'لأسفلهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'فغروبكم': [{'vocalized': u'فغروبكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غروب'}],

 u'فغروبكن': [{'vocalized': u'فغروبكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غروب'}],

 u'أبكلتا': [{'vocalized': u'أبكلتا', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'أولحسبكم': [{'vocalized': u'أولحسبكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أولحسبكن': [{'vocalized': u'أولحسبكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'بينكم': [{'vocalized': u'بينكم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بين'}],

 u'بينكن': [{'vocalized': u'بينكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بين'}],

 u'لوراءهم': [{'vocalized': u'لوراءهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'وراء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وراء'}],

 u'أوكل': [{'vocalized': u'أوكل', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوكل', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'ومثلها': [{'vocalized': u'ومثلها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'لعلنا': [{'vocalized': u'لعلنا', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لعل'}],

 u'أولأجمعكم': [{'vocalized': u'أولأجمعكم', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولأجمعكن': [{'vocalized': u'أولأجمعكن', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أولأجمعكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفبنحوهم': [{'vocalized': u'أفبنحوهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'أفبنحوهن': [{'vocalized': u'أفبنحوهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'فكأثناءها': [{'vocalized': u'فكأثناءها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'وشرقهما': [{'vocalized': u'وشرقهما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'ومثلهن': [{'vocalized': u'ومثلهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'ومثلهم': [{'vocalized': u'ومثلهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'ولمثل': [{'vocalized': u'ولمثل', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثل', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'فأسفلهما': [{'vocalized': u'فأسفلهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'فذويكما': [{'vocalized': u'فذويكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'وأيكما': [{'vocalized': u'وأيكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'فلكأنما': [{'vocalized': u'فلكأنما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'خلفهم': [{'vocalized': u'خلفهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'خلفهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'وكأقلي': [{'vocalized': u'وكأقلي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'وكأقلي', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'كذوي': [{'vocalized': u'كذوي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكأقله': [{'vocalized': u'وكأقله', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'وكأقلك': [{'vocalized': u'وكأقلك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'وأخوي': [{'vocalized': u'وأخوي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخو'},
 {'vocalized': u'وأخوي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخو'}],

 u'أكهؤلاء': [{'vocalized': u'أكهؤلاء', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'وأخوك': [{'vocalized': u'وأخوك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخو'}],

 u'لزماننا': [{'vocalized': u'لزماننا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'لأناهن': [{'vocalized': u'لأناهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'فآناء': [{'vocalized': u'فآناء', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'آناء', 'encletic': u'', 'type': u'اسم', 'original': u'آناء'}],

 u'وأخوه': [{'vocalized': u'وأخوه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخو'}],

 u'ولذلك': [{'vocalized': u'ولذلك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'وشمالهم': [{'vocalized': u'وشمالهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شمال'}],

 u'فساعتكن': [{'vocalized': u'فساعتكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوإلي': [{'vocalized': u'أوإلي', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'أوإلي', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'أوإلى': [{'vocalized': u'أوإلى', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'فلهذه': [{'vocalized': u'فلهذه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'فلأخذ': [{'vocalized': u'فلأخذ', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'أخذ', 'encletic': u'', 'type': u'فعل', 'original': u'أخذ'}],

 u'وأيهما': [{'vocalized': u'وأيهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'لكلنا': [{'vocalized': u'لكلنا', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلنا', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'لكلنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'فأبي': [{'vocalized': u'فأبي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أبي', 'encletic': u'', 'type': u'اسم', 'original': u'أبي'}],

 u'ألجميعهن': [{'vocalized': u'ألجميعهن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'فلهذي': [{'vocalized': u'فلهذي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذي', 'encletic': u'', 'type': u'اسم', 'original': u'هذي'}],

 u'ألجميعهم': [{'vocalized': u'ألجميعهم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعهم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'لفوقها': [{'vocalized': u'لفوقها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'لهاتي': [{'vocalized': u'لهاتي', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'لهاته': [{'vocalized': u'لهاته', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'ليمينها': [{'vocalized': u'ليمينها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'شرقك': [{'vocalized': u'شرقك', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شرق'}],

 u'فلهن': [{'vocalized': u'فلهن', 'procletic': u'ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'},
 {'vocalized': u'فلهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'ولأمسى': [{'vocalized': u'ولأمسى', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أمسى', 'encletic': u'', 'type': u'فعل', 'original': u'أمسى'}],

 u'فلهم': [{'vocalized': u'فلهم', 'procletic': u'ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'},
 {'vocalized': u'فلهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'فلهي': [{'vocalized': u'فلهي', 'procletic': u'ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'},
 {'vocalized': u'فلهي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'فلهو': [{'vocalized': u'فلهو', 'procletic': u'ف-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'},
 {'vocalized': u'فلهو', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'لحمي': [{'vocalized': u'لحمي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور', 'stem': u'حمي', 'encletic': u'', 'type': u'اسم', 'original': u'حمي'}],

 u'فلشمال': [{'vocalized': u'فلشمال', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'شمال', 'encletic': u'', 'type': u'اسم', 'original': u'شمال'}],

 u'ولعليكما': [{'vocalized': u'ولعليكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'فبالألاء': [{'vocalized': u'فبالألاء', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'وبنحو': [{'vocalized': u'وبنحو', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحو', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'ألجميعه': [{'vocalized': u'ألجميعه', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعه', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أولكأني': [{'vocalized': u'أولكأني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'أولكأني', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'وكابني': [{'vocalized': u'وكابني', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'وكابني', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'ألجميعك': [{'vocalized': u'ألجميعك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعك', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'فليمين': [{'vocalized': u'فليمين', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'وكابنه': [{'vocalized': u'وكابنه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'أولكأنك': [{'vocalized': u'أولكأنك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'ألجميعي': [{'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'وكابنك': [{'vocalized': u'وكابنك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'أولكأنه': [{'vocalized': u'أولكأنه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'فلها': [{'vocalized': u'فلها', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لها', 'encletic': u'', 'type': u'ضمير', 'original': u'لها'}],

 u'فبشطري': [{'vocalized': u'فبشطري', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'فبشطري', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'فبشطره': [{'vocalized': u'فبشطره', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'فوراءكم': [{'vocalized': u'فوراءكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'وراء', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وراء'}],

 u'كأبيكما': [{'vocalized': u'كأبيكما', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أبي'}],

 u'فبشطرك': [{'vocalized': u'فبشطرك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'ولعمرك': [{'vocalized': u'ولعمرك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لعمر'}],

 u'بنحوك': [{'vocalized': u'بنحوك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'ولعمره': [{'vocalized': u'ولعمره', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لعمر'}],

 u'بنحوه': [{'vocalized': u'بنحوه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوه', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'أوكغيركم': [{'vocalized': u'أوكغيركم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'بنحوي': [{'vocalized': u'بنحوي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحوي', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'ولعمري': [{'vocalized': u'ولعمري', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لعمر'},
 {'vocalized': u'ولعمري', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لعمر'}],

 u'أفأنت': [{'vocalized': u'أفأنت', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'أفأنت', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'فلأخي': [{'vocalized': u'فلأخي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'بخلفكم': [{'vocalized': u'بخلفكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'بخلفكن': [{'vocalized': u'بخلفكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'فلهذا': [{'vocalized': u'فلهذا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'وبغيركما': [{'vocalized': u'وبغيركما', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'فساعتهما': [{'vocalized': u'فساعتهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'فأبا': [{'vocalized': u'فأبا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أبا', 'encletic': u'', 'type': u'اسم', 'original': u'أبا'}],

 u'ألجميعها': [{'vocalized': u'ألجميعها', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعها', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'ألجميعها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'وكسويه': [{'vocalized': u'وكسويه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أفلأناهما': [{'vocalized': u'أفلأناهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'وكسويك': [{'vocalized': u'وكسويك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'بأسفلهن': [{'vocalized': u'بأسفلهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولسويهن': [{'vocalized': u'ولسويهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'سوى'}],

 u'كليلهما': [{'vocalized': u'كليلهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'أوكأجمعها': [{'vocalized': u'أوكأجمعها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبأعليهم': [{'vocalized': u'وبأعليهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أعلى'}],

 u'أأولالك': [{'vocalized': u'أأولالك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'لطفق': [{'vocalized': u'لطفق', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'طفق', 'encletic': u'', 'type': u'فعل', 'original': u'طفق'}],

 u'لذاتها': [{'vocalized': u'لذاتها', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذات'}],

 u'وإننا': [{'vocalized': u'وإننا', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'إن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إن'}],

 u'أولفوقكن': [{'vocalized': u'أولفوقكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'أولفوقكم': [{'vocalized': u'أولفوقكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'وبذواتي': [{'vocalized': u'وبذواتي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'وأخذ': [{'vocalized': u'وأخذ', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أخذ', 'encletic': u'', 'type': u'فعل', 'original': u'أخذ'}],

 u'ألفوقهما': [{'vocalized': u'ألفوقهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'فذووه': [{'vocalized': u'فذووه', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوو'}],

 u'فذووك': [{'vocalized': u'فذووك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوو'}],

 u'أفلإلينا': [{'vocalized': u'أفلإلينا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'أبضعهن': [{'vocalized': u'أبضعهن', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بضع'}],

 u'فماانفكتا': [{'vocalized': u'فماانفكتا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكتا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكتا'}],

 u'فذووي': [{'vocalized': u'فذووي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوو'},
 {'vocalized': u'فذووي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوو'}],

 u'وبتلقاءك': [{'vocalized': u'وبتلقاءك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تلقاء'}],

 u'لوقت': [{'vocalized': u'لوقت', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'وبتلقاءه': [{'vocalized': u'وبتلقاءه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وكأسفلهن': [{'vocalized': u'وكأسفلهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبتلقاءي': [{'vocalized': u'وبتلقاءي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'},
 {'vocalized': u'وبتلقاءي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وأكثركما': [{'vocalized': u'وأكثركما', 'procletic': u'و-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أكثر'}],

 u'وأخو': [{'vocalized': u'وأخو', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف', 'stem': u'أخو', 'encletic': u'', 'type': u'اسم', 'original': u'أخو'}],

 u'أفبكلنا': [{'vocalized': u'أفبكلنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكلنا', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أفبكل': [{'vocalized': u'أفبكل', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفبكل', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'أفبكم': [{'vocalized': u'أفبكم', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بكم', 'encletic': u'', 'type': u'ضمير', 'original': u'بكم'}],

 u'أفبكن': [{'vocalized': u'أفبكن', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بكن', 'encletic': u'', 'type': u'ضمير', 'original': u'بكن'}],

 u'وكغربهما': [{'vocalized': u'وكغربهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غرب'}],

 u'أعنك': [{'vocalized': u'أعنك', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'عن'}],

 u'فبوقتكن': [{'vocalized': u'فبوقتكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'فبوقتكم': [{'vocalized': u'فبوقتكم', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'وللائي': [{'vocalized': u'وللائي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللائي', 'encletic': u'', 'type': u'اسم', 'original': u'اللائي'}],

 u'فكأيي': [{'vocalized': u'فكأيي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'فكأيي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'أوعنكن': [{'vocalized': u'أوعنكن', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'نحونا': [{'vocalized': u'نحونا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'نحونا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أولعامتنا': [{'vocalized': u'أولعامتنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'فكأيه': [{'vocalized': u'فكأيه', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'أوبحسبنا': [{'vocalized': u'أوبحسبنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'أوعنكم': [{'vocalized': u'أوعنكم', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'ظل': [{'vocalized': u'ظل', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ظل', 'encletic': u'', 'type': u'فعل', 'original': u'ظل'}],

 u'فكأيك': [{'vocalized': u'فكأيك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'وبأعليها': [{'vocalized': u'وبأعليها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبعامتك': [{'vocalized': u'فبعامتك', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'أخينا': [{'vocalized': u'أخينا', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أخي'}],

 u'وإي': [{'vocalized': u'وإي', 'procletic': u'و-', 'tags': u'حرف;حرف جواب;عطف', 'stem': u'إي', 'encletic': u'', 'type': u'حرف', 'original': u'إي'}],

 u'فبعامته': [{'vocalized': u'فبعامته', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'وأمد': [{'vocalized': u'وأمد', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'أمد', 'encletic': u'', 'type': u'اسم', 'original': u'أمد'}],

 u'لذاتهم': [{'vocalized': u'لذاتهم', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور;ضمير', 'stem': u'ذات', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذات'}],

 u'أفكتلك': [{'vocalized': u'أفكتلك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'فبعامتي': [{'vocalized': u'فبعامتي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فبعامتي', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'بلحظتنا': [{'vocalized': u'بلحظتنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبعامتنا': [{'vocalized': u'فبعامتنا', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أولفيكم': [{'vocalized': u'أولفيكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'أولفيكن': [{'vocalized': u'أولفيكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'وعنكم': [{'vocalized': u'وعنكم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'وكتلقاءهما': [{'vocalized': u'وكتلقاءهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'فلعامتي': [{'vocalized': u'فلعامتي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عامة'}],

 u'فلعامته': [{'vocalized': u'فلعامته', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامته', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'بجنوبنا': [{'vocalized': u'بجنوبنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنوب'}],

 u'ولعلنا': [{'vocalized': u'ولعلنا', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لعل'}],

 u'أولمنهم': [{'vocalized': u'أولمنهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فلعامتك': [{'vocalized': u'فلعامتك', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'فبليلي': [{'vocalized': u'فبليلي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'فبليلي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'فلكأني': [{'vocalized': u'فلكأني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'},
 {'vocalized': u'فلكأني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'كأن'}],

 u'كأقلها': [{'vocalized': u'كأقلها', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'أجميعكن': [{'vocalized': u'أجميعكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعكن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'أجميعكم': [{'vocalized': u'أجميعكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعكم', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'أوبهذا': [{'vocalized': u'أوبهذا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'كزماننا': [{'vocalized': u'كزماننا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'أسوي': [{'vocalized': u'أسوي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'أسوي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'فلكأنك': [{'vocalized': u'فلكأنك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'كأن'}],

 u'كعامتها': [{'vocalized': u'كعامتها', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'فلكأنه': [{'vocalized': u'فلكأنه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'كأن'}],

 u'إياهم': [{'vocalized': u'إياهم', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياهم', 'encletic': u'', 'type': u'ضمير', 'original': u'إياهم'}],

 u'أسفلهن': [{'vocalized': u'أسفلهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'أسفلهم': [{'vocalized': u'أسفلهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبفيكن': [{'vocalized': u'وبفيكن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'}],

 u'لنحوهم': [{'vocalized': u'لنحوهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'كأقلهن': [{'vocalized': u'كأقلهن', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'كأقلهم': [{'vocalized': u'كأقلهم', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'أوبهذه': [{'vocalized': u'أوبهذه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'كعامتهم': [{'vocalized': u'كعامتهم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'فبيد': [{'vocalized': u'فبيد', 'procletic': u'ف-', 'tags': u'اسم;استثناء;عطف', 'stem': u'بيد', 'encletic': u'', 'type': u'اسم', 'original': u'بيد'}],

 u'ألعنه': [{'vocalized': u'ألعنه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'عن'}],

 u'أمننا': [{'vocalized': u'أمننا', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'لقلما': [{'vocalized': u'لقلما', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'قلما', 'encletic': u'', 'type': u'فعل', 'original': u'قلما'}],

 u'فلازلت': [{'vocalized': u'فلازلت', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'فلازلت', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'},
 {'vocalized': u'فلازلت', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلت', 'encletic': u'', 'type': u'فعل', 'original': u'لازلت'}],

 u'أفلإنكن': [{'vocalized': u'أفلإنكن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'أفلإنكم': [{'vocalized': u'أفلإنكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'فثمة': [{'vocalized': u'فثمة', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ثمة', 'encletic': u'', 'type': u'اسم', 'original': u'ثمة'}],

 u'فكجميعهما': [{'vocalized': u'فكجميعهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فكجميعهما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'أفأمامكم': [{'vocalized': u'أفأمامكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أمام'}],

 u'فكذاتهما': [{'vocalized': u'فكذاتهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذات'}],

 u'أوشمالنا': [{'vocalized': u'أوشمالنا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'فلجنبكما': [{'vocalized': u'فلجنبكما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'فكأسفلكم': [{'vocalized': u'فكأسفلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكأسفلكن': [{'vocalized': u'فكأسفلكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وكأيتكم': [{'vocalized': u'وكأيتكم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'وكأيتكن': [{'vocalized': u'وكأيتكن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'أولمنها': [{'vocalized': u'أولمنها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'أفلشبهي': [{'vocalized': u'أفلشبهي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'ألمننا': [{'vocalized': u'ألمننا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-نا', 'type': u'حرف', 'original': u'من'}],

 u'وكنحو': [{'vocalized': u'وكنحو', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحو', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فبغروب': [{'vocalized': u'فبغروب', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'أفجميعنا': [{'vocalized': u'أفجميعنا', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعنا', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'أفلشبهك': [{'vocalized': u'أفلشبهك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'كبعض': [{'vocalized': u'كبعض', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'بعض', 'encletic': u'', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلشبهه': [{'vocalized': u'أفلشبهه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفلشبهه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'فبهاتين': [{'vocalized': u'فبهاتين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'وفيكم': [{'vocalized': u'وفيكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيكم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'ولحرى': [{'vocalized': u'ولحرى', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'حرى', 'encletic': u'', 'type': u'فعل', 'original': u'حرى'}],

 u'وفيكن': [{'vocalized': u'وفيكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيكن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'أفأمامنا': [{'vocalized': u'أفأمامنا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'إليك': [{'vocalized': u'إليك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'إليك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'إليك'},
 {'vocalized': u'إليك', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'أولعامتكما': [{'vocalized': u'أولعامتكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أولعامتكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'وكساعتكما': [{'vocalized': u'وكساعتكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'وبخلفهما': [{'vocalized': u'وبخلفهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'أولإلي': [{'vocalized': u'أولإلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'أولإلي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'فبشبهك': [{'vocalized': u'فبشبهك', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'فبشبهه': [{'vocalized': u'فبشبهه', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'فكنفسنا': [{'vocalized': u'فكنفسنا', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نفس'}],

 u'أيمينها': [{'vocalized': u'أيمينها', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'يمين'}],

 u'فبشبهي': [{'vocalized': u'فبشبهي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فبشبهي', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'فلمنهم': [{'vocalized': u'فلمنهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'وحولها': [{'vocalized': u'وحولها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حول'}],

 u'فلمنهن': [{'vocalized': u'فلمنهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'ع': [{'vocalized': u'ع', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ع', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ع'}],

 u'فأباكم': [{'vocalized': u'فأباكم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبا', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبا'}],

 u'أوبذواتي': [{'vocalized': u'أوبذواتي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'أوبغيرهما': [{'vocalized': u'أوبغيرهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غير'}],

 u'بسويكما': [{'vocalized': u'بسويكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ألازلتم': [{'vocalized': u'ألازلتم', 'procletic': u'أ-', 'tags': u'فعل;كاد و اخواتها;استفهام', 'stem': u'لازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتم'}],

 u'أيمينهن': [{'vocalized': u'أيمينهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'ولعمرنا': [{'vocalized': u'ولعمرنا', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لعمر'}],

 u'أيمينهم': [{'vocalized': u'أيمينهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'وحولهن': [{'vocalized': u'وحولهن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حول'}],

 u'أفلإليه': [{'vocalized': u'أفلإليه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'فلمنها': [{'vocalized': u'فلمنها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'وحولهم': [{'vocalized': u'وحولهم', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حول'}],

 u'بكلكما': [{'vocalized': u'بكلكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلكما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'كل'}],

 u'فلأعليكم': [{'vocalized': u'فلأعليكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'أكلنا': [{'vocalized': u'أكلنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلنا', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'وشرقكن': [{'vocalized': u'وشرقكن', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شرق'}],

 u'أوحسب': [{'vocalized': u'أوحسب', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'لهذين': [{'vocalized': u'لهذين', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'أفلإلي': [{'vocalized': u'أفلإلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'},
 {'vocalized': u'أفلإلي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إلى'}],

 u'أفلإلى': [{'vocalized': u'أفلإلى', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'أفلأمامنا': [{'vocalized': u'أفلأمامنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'وبشطرنا': [{'vocalized': u'وبشطرنا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شطر'}],

 u'فكأثناءهم': [{'vocalized': u'فكأثناءهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'فحينكم': [{'vocalized': u'فحينكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حين'}],

 u'أفكل': [{'vocalized': u'أفكل', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفكل', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'فحينكن': [{'vocalized': u'فحينكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حين'}],

 u'أفمما': [{'vocalized': u'أفمما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم الاستفهام;عطف;استفهام', 'stem': u'مما', 'encletic': u'', 'type': u'اسم', 'original': u'مما'}],

 u'فكأثناءهن': [{'vocalized': u'فكأثناءهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'كغيرنا': [{'vocalized': u'كغيرنا', 'procletic': u'ك-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'أولإلى': [{'vocalized': u'أولإلى', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'فبأسفل': [{'vocalized': u'فبأسفل', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'أفلسن': [{'vocalized': u'أفلسن', 'procletic': u'أ-ف-', 'tags': u'فعل;كان و أخواتها;عطف;استفهام', 'stem': u'لسن', 'encletic': u'', 'type': u'فعل', 'original': u'لسن'}],

 u'أيتنا': [{'vocalized': u'أيتنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'وبدونها': [{'vocalized': u'وبدونها', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بدون'}],

 u'فعدانا': [{'vocalized': u'فعدانا', 'procletic': u'ف-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'عدا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'عدا'}],

 u'لمعهن': [{'vocalized': u'لمعهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'وأيهن': [{'vocalized': u'وأيهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'وأيهم': [{'vocalized': u'وأيهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'لمعهم': [{'vocalized': u'لمعهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'فنحن': [{'vocalized': u'فنحن', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'فنحو': [{'vocalized': u'فنحو', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحو', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'كبعضنا': [{'vocalized': u'كبعضنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'ولدن': [{'vocalized': u'ولدن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'لدن', 'encletic': u'', 'type': u'اسم', 'original': u'لدن'}],

 u'فأنتن': [{'vocalized': u'فأنتن', 'procletic': u'ف-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'أكهذا': [{'vocalized': u'أكهذا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هذا', 'encletic': u'', 'type': u'اسم', 'original': u'هذا'}],

 u'وممن': [{'vocalized': u'وممن', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'ممن', 'encletic': u'', 'type': u'اسم', 'original': u'ممن'}],

 u'وأيها': [{'vocalized': u'وأيها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'لمعها': [{'vocalized': u'لمعها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'فحسب': [{'vocalized': u'فحسب', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أكعامتهم': [{'vocalized': u'أكعامتهم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أوبأولئك': [{'vocalized': u'أوبأولئك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'بجنبه': [{'vocalized': u'بجنبه', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'كحسبكن': [{'vocalized': u'كحسبكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'ومما': [{'vocalized': u'ومما', 'procletic': u'و-', 'tags': u'اسم;اسم الاستفهام;عطف', 'stem': u'مما', 'encletic': u'', 'type': u'اسم', 'original': u'مما'}],

 u'كحسبكم': [{'vocalized': u'كحسبكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبسويكما': [{'vocalized': u'أوبسويكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'ألشمالنا': [{'vocalized': u'ألشمالنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شمال'}],

 u'أنحوه': [{'vocalized': u'أنحوه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'فتحول': [{'vocalized': u'فتحول', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'تحول', 'encletic': u'', 'type': u'فعل', 'original': u'تحول'}],

 u'أفلازالت': [{'vocalized': u'أفلازالت', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالت', 'encletic': u'', 'type': u'فعل', 'original': u'لازالت'}],

 u'فبأخيكما': [{'vocalized': u'فبأخيكما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'لستما': [{'vocalized': u'لستما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لستما', 'encletic': u'', 'type': u'فعل', 'original': u'لستما'}],

 u'لعمر': [{'vocalized': u'لعمر', 'procletic': u'', 'tags': u'اسم;اسم إضافة', 'stem': u'لعمر', 'encletic': u'', 'type': u'اسم', 'original': u'لعمر'}],

 u'أفلازالا': [{'vocalized': u'أفلازالا', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازالا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالا'}],

 u'وتحتكما': [{'vocalized': u'وتحتكما', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'أولجميعكما': [{'vocalized': u'أولجميعكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'وأناهما': [{'vocalized': u'وأناهما', 'procletic': u'و-', 'tags': u'حرف;ناصب ومنصوب;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'لحسبها': [{'vocalized': u'لحسبها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'أكنفس': [{'vocalized': u'أكنفس', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'أوإنها': [{'vocalized': u'أوإنها', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'فجنوب': [{'vocalized': u'فجنوب', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'جنوب', 'encletic': u'', 'type': u'اسم', 'original': u'جنوب'}],

 u'أفلحسبهم': [{'vocalized': u'أفلحسبهم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفلحسبهن': [{'vocalized': u'أفلحسبهن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'لمن': [{'vocalized': u'لمن', 'procletic': u'ل-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'},
 {'vocalized': u'لمن', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'من', 'encletic': u'', 'type': u'حرف', 'original': u'من'}],

 u'لعامتهما': [{'vocalized': u'لعامتهما', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'لعامتهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'وحميهن': [{'vocalized': u'وحميهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'وحميهم': [{'vocalized': u'وحميهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'وأخيها': [{'vocalized': u'وأخيها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'فكذانك': [{'vocalized': u'فكذانك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'أبكلكن': [{'vocalized': u'أبكلكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلكن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أبكلكم': [{'vocalized': u'أبكلكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلكم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'كخلفك': [{'vocalized': u'كخلفك', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'وكذينك': [{'vocalized': u'وكذينك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'كخلفه': [{'vocalized': u'كخلفه', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'ألمنكن': [{'vocalized': u'ألمنكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كن', 'type': u'حرف', 'original': u'من'}],

 u'أمعه': [{'vocalized': u'أمعه', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مع'}],

 u'أوحسبكم': [{'vocalized': u'أوحسبكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'ألمنكم': [{'vocalized': u'ألمنكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'فلكلهن': [{'vocalized': u'فلكلهن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أوجميعي': [{'vocalized': u'أوجميعي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعي', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعي', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'ليمينكم': [{'vocalized': u'ليمينكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'وأخيهم': [{'vocalized': u'وأخيهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'وأخيهن': [{'vocalized': u'وأخيهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'ليمينكن': [{'vocalized': u'ليمينكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'أوجميعك': [{'vocalized': u'أوجميعك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعك', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'فبغيركما': [{'vocalized': u'فبغيركما', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'كنحو': [{'vocalized': u'كنحو', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحو', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'أوجميعه': [{'vocalized': u'أوجميعه', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوجميعه', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'لنحوكن': [{'vocalized': u'لنحوكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'فبضعهما': [{'vocalized': u'فبضعهما', 'procletic': u'ف-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بضع'}],

 u'لنحوكم': [{'vocalized': u'لنحوكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'لبعضي': [{'vocalized': u'لبعضي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضي', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'لأننا': [{'vocalized': u'لأننا', 'procletic': u'ل-', 'tags': u'حرف;إن و أخواتها;مجرور;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'لبعضه': [{'vocalized': u'لبعضه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'لبعضك': [{'vocalized': u'لبعضك', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'لبعضك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فلكلها': [{'vocalized': u'فلكلها', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلها', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'لمع': [{'vocalized': u'لمع', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'ألفوقه': [{'vocalized': u'ألفوقه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'فوق'}],

 u'أخلفنا': [{'vocalized': u'أخلفنا', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'ألفوقي': [{'vocalized': u'ألفوقي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'ألفوقي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'أوكبعضهما': [{'vocalized': u'أوكبعضهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'لحسبهن': [{'vocalized': u'لحسبهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'لحسبهم': [{'vocalized': u'لحسبهم', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'وخلاي': [{'vocalized': u'وخلاي', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'خلا'},
 {'vocalized': u'وخلاي', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'خلا'}],

 u'أوإنهن': [{'vocalized': u'أوإنهن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'أوإنهم': [{'vocalized': u'أوإنهم', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'ألبعضكما': [{'vocalized': u'ألبعضكما', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلحسبها': [{'vocalized': u'أفلحسبها', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'أوبنفسهما': [{'vocalized': u'أوبنفسهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'وخلاه': [{'vocalized': u'وخلاه', 'procletic': u'و-', 'tags': u'فعل;حرف استثناء;عطف;ضمير', 'stem': u'خلا', 'encletic': u'-ه', 'type': u'فعل', 'original': u'خلا'}],

 u'وخلال': [{'vocalized': u'وخلال', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان/مكان;عطف', 'stem': u'خلال', 'encletic': u'', 'type': u'اسم', 'original': u'خلال'}],

 u'أونحوكما': [{'vocalized': u'أونحوكما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'وزمانها': [{'vocalized': u'وزمانها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'وغروبكما': [{'vocalized': u'وغروبكما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'لشبه': [{'vocalized': u'لشبه', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'لشبه', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'ولأيتهما': [{'vocalized': u'ولأيتهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'وكأسفلكما': [{'vocalized': u'وكأسفلكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'فبأعليك': [{'vocalized': u'فبأعليك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'أولمثلهما': [{'vocalized': u'أولمثلهما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أولمثلهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فحسبنا': [{'vocalized': u'فحسبنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'حسب'}],

 u'ألتلك': [{'vocalized': u'ألتلك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلك', 'encletic': u'', 'type': u'اسم', 'original': u'تلك'}],

 u'بتينك': [{'vocalized': u'بتينك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'أذلكم': [{'vocalized': u'أذلكم', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'لشرقنا': [{'vocalized': u'لشرقنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'فلغربه': [{'vocalized': u'فلغربه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'ومافتئتا': [{'vocalized': u'ومافتئتا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مافتئتا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئتا'}],

 u'أفبعينكم': [{'vocalized': u'أفبعينكم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أفبعينكن': [{'vocalized': u'أفبعينكن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فحولها': [{'vocalized': u'فحولها', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حول'}],

 u'آ': [{'vocalized': u'آ', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'آ', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'آ'}],

 u'وشرقه': [{'vocalized': u'وشرقه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'ومادمتما': [{'vocalized': u'ومادمتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتما', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتما'},
 {'vocalized': u'ومادمتما', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتما', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتما'}],

 u'أكتلكما': [{'vocalized': u'أكتلكما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'ولأقلكما': [{'vocalized': u'ولأقلكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أقل'}],

 u'فلمثلي': [{'vocalized': u'فلمثلي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'كمثلي': [{'vocalized': u'كمثلي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'كمثلي', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'كأيتهما': [{'vocalized': u'كأيتهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أية'}],

 u'وبتلكما': [{'vocalized': u'وبتلكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'ولإلى': [{'vocalized': u'ولإلى', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'إلى', 'encletic': u'', 'type': u'حرف', 'original': u'إلى'}],

 u'فلكأنهن': [{'vocalized': u'فلكأنهن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'فلمثلك': [{'vocalized': u'فلمثلك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثلك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'ألشبهكن': [{'vocalized': u'ألشبهكن', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كن', 'type': u'اسم', 'original': u'شبه'}],

 u'كمثلك': [{'vocalized': u'كمثلك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'فلمثله': [{'vocalized': u'فلمثله', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'فلمثله', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'ألشبهكم': [{'vocalized': u'ألشبهكم', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كم', 'type': u'اسم', 'original': u'شبه'}],

 u'فحولهم': [{'vocalized': u'فحولهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حول'}],

 u'أيمين': [{'vocalized': u'أيمين', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'فحولهن': [{'vocalized': u'فحولهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حول'}],

 u'مادامت': [{'vocalized': u'مادامت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مادامت', 'encletic': u'', 'type': u'فعل', 'original': u'مادامت'}],

 u'أفنفس': [{'vocalized': u'أفنفس', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'ماداما': [{'vocalized': u'ماداما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ماداما', 'encletic': u'', 'type': u'فعل', 'original': u'ماداما'}],

 u'أوكمثل': [{'vocalized': u'أوكمثل', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'أوفوقكما': [{'vocalized': u'أوفوقكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'فكجنب': [{'vocalized': u'فكجنب', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'فلكأنها': [{'vocalized': u'فلكأنها', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'بفيهما': [{'vocalized': u'بفيهما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'اسم', 'original': u'في'}],

 u'وبلحظتها': [{'vocalized': u'وبلحظتها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلي': [{'vocalized': u'أفلي', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لي', 'encletic': u'', 'type': u'ضمير', 'original': u'لي'}],

 u'أبهاتين': [{'vocalized': u'أبهاتين', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'كذين': [{'vocalized': u'كذين', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'أوبكلك': [{'vocalized': u'أوبكلك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'أفكبعضكم': [{'vocalized': u'أفكبعضكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'وأخاكما': [{'vocalized': u'وأخاكما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخا'}],

 u'أوبكله': [{'vocalized': u'أوبكله', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكله', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'وبليلنا': [{'vocalized': u'وبليلنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'أوبكلي': [{'vocalized': u'أوبكلي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'أفشمالكما': [{'vocalized': u'أفشمالكما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'ولذين': [{'vocalized': u'ولذين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'وعندنا': [{'vocalized': u'وعندنا', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'عند', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عند'}],

 u'وعامة': [{'vocalized': u'وعامة', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أوككلهن': [{'vocalized': u'أوككلهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلهن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'أوككلهم': [{'vocalized': u'أوككلهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلهم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أكمثلهما': [{'vocalized': u'أكمثلهما', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'فنحوهما': [{'vocalized': u'فنحوهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحوهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'طاق': [{'vocalized': u'طاق', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'طاق', 'encletic': u'', 'type': u'اسم فعل', 'original': u'طاق'}],

 u'بكلهم': [{'vocalized': u'بكلهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلهم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'ألأناه': [{'vocalized': u'ألأناه', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أنا'}],

 u'بكلهن': [{'vocalized': u'بكلهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلهن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'لعنهما': [{'vocalized': u'لعنهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'عن'}],

 u'ألأناك': [{'vocalized': u'ألأناك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أنا'}],

 u'فكخلفك': [{'vocalized': u'فكخلفك', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'أفلازال': [{'vocalized': u'أفلازال', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازال', 'encletic': u'', 'type': u'فعل', 'original': u'لازال'}],

 u'أله': [{'vocalized': u'أله', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'له', 'encletic': u'', 'type': u'ضمير', 'original': u'له'}],

 u'ولأكثرهما': [{'vocalized': u'ولأكثرهما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أكثر'}],

 u'فبخلفكن': [{'vocalized': u'فبخلفكن', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كن', 'type': u'اسم', 'original': u'خلف'}],

 u'فلتلقاءكما': [{'vocalized': u'فلتلقاءكما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'ذينك': [{'vocalized': u'ذينك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'أهنالك': [{'vocalized': u'أهنالك', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'أولديهما': [{'vocalized': u'أولديهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لدى'}],

 u'كليلي': [{'vocalized': u'كليلي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'كليلي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'بجنوبكن': [{'vocalized': u'بجنوبكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنوب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جنوب'}],

 u'لدنكما': [{'vocalized': u'لدنكما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'لدن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'لدن'}],

 u'بمن': [{'vocalized': u'بمن', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'بمن', 'encletic': u'', 'type': u'اسم', 'original': u'بمن'},
 {'vocalized': u'بمن', 'procletic': u'ب-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'فلأيتك': [{'vocalized': u'فلأيتك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أية'}],

 u'أفلأمامهم': [{'vocalized': u'أفلأمامهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أمام'}],

 u'أوبهاذين': [{'vocalized': u'أوبهاذين', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'وبليلهما': [{'vocalized': u'وبليلهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'أولشبه': [{'vocalized': u'أولشبه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'أقل': [{'vocalized': u'أقل', 'procletic': u'', 'tags': u'اسم;اسم تفضيل', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'أفلخلفها': [{'vocalized': u'أفلخلفها', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'وبشبه': [{'vocalized': u'وبشبه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'بما': [{'vocalized': u'بما', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'بما', 'encletic': u'', 'type': u'اسم', 'original': u'بما'}],

 u'بأيتكما': [{'vocalized': u'بأيتكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'ومادامتا': [{'vocalized': u'ومادامتا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادامتا', 'encletic': u'', 'type': u'فعل', 'original': u'مادامتا'}],

 u'ولفوقهما': [{'vocalized': u'ولفوقهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'فغروبهم': [{'vocalized': u'فغروبهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'فبأقلنا': [{'vocalized': u'فبأقلنا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أقل'}],

 u'فلأيتي': [{'vocalized': u'فلأيتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'},
 {'vocalized': u'فلأيتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أية'}],

 u'فكاد': [{'vocalized': u'فكاد', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'كاد', 'encletic': u'', 'type': u'فعل', 'original': u'كاد'}],

 u'أوككلها': [{'vocalized': u'أوككلها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلها', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'كساعتك': [{'vocalized': u'كساعتك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'كساعته': [{'vocalized': u'كساعته', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'كساعتي': [{'vocalized': u'كساعتي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'كساعتي', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'فلرجع': [{'vocalized': u'فلرجع', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'رجع', 'encletic': u'', 'type': u'فعل', 'original': u'رجع'}],

 u'بكلها': [{'vocalized': u'بكلها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلها', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'فكسويهما': [{'vocalized': u'فكسويهما', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سوى'}],

 u'أبضعهما': [{'vocalized': u'أبضعهما', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بضع'}],

 u'ويميني': [{'vocalized': u'ويميني', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'},
 {'vocalized': u'ويميني', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'يمين'}],

 u'أفكنفسكما': [{'vocalized': u'أفكنفسكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'وكوقت': [{'vocalized': u'وكوقت', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'ويمينك': [{'vocalized': u'ويمينك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'فبأكثر': [{'vocalized': u'فبأكثر', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'ويمينه': [{'vocalized': u'ويمينه', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'يمين'}],

 u'وسبحانهما': [{'vocalized': u'وسبحانهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سبحان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'سبحان'}],

 u'فلعمركن': [{'vocalized': u'فلعمركن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'لعمر'}],

 u'كساعتهما': [{'vocalized': u'كساعتهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'ولنفسه': [{'vocalized': u'ولنفسه', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'أبحسبي': [{'vocalized': u'أبحسبي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'أبحسبي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'وبذويكما': [{'vocalized': u'وبذويكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ذوي'}],

 u'أبحسبه': [{'vocalized': u'أبحسبه', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'فكأيهم': [{'vocalized': u'فكأيهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'فكأيهن': [{'vocalized': u'فكأيهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'أبحسبك': [{'vocalized': u'أبحسبك', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'لأقبل': [{'vocalized': u'لأقبل', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'أقبل', 'encletic': u'', 'type': u'فعل', 'original': u'أقبل'}],

 u'ولشمالك': [{'vocalized': u'ولشمالك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شمال'}],

 u'بعينها': [{'vocalized': u'بعينها', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'غروب': [{'vocalized': u'غروب', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'ولشماله': [{'vocalized': u'ولشماله', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شمال'}],

 u'أولأمامي': [{'vocalized': u'أولأمامي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'},
 {'vocalized': u'أولأمامي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أمام'}],

 u'فللألاء': [{'vocalized': u'فللألاء', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'ولشمالي': [{'vocalized': u'ولشمالي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'ولشمالي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'ولفوقكما': [{'vocalized': u'ولفوقكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'فوق'}],

 u'فإليها': [{'vocalized': u'فإليها', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إلى'}],

 u'أفلجميعنا': [{'vocalized': u'أفلجميعنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وبوقتكم': [{'vocalized': u'وبوقتكم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'فلكما': [{'vocalized': u'فلكما', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لكما', 'encletic': u'', 'type': u'ضمير', 'original': u'لكما'}],

 u'عينكما': [{'vocalized': u'عينكما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فذويي': [{'vocalized': u'فذويي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'},
 {'vocalized': u'فذويي', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذوي'}],

 u'ونفس': [{'vocalized': u'ونفس', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فكحميهن': [{'vocalized': u'فكحميهن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'فذويه': [{'vocalized': u'فذويه', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذوي'}],

 u'فكحميهم': [{'vocalized': u'فكحميهم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'فذويك': [{'vocalized': u'فذويك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذوي'}],

 u'فلزمانكن': [{'vocalized': u'فلزمانكن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'فوقتكما': [{'vocalized': u'فوقتكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وقت'}],

 u'فلزمانكم': [{'vocalized': u'فلزمانكم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'ولغير': [{'vocalized': u'ولغير', 'procletic': u'و-ل-', 'tags': u'اسم;استثناء;مجرور;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ولغير', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'أبعينكم': [{'vocalized': u'أبعينكم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أبعينكن': [{'vocalized': u'أبعينكن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'فلابتدأ': [{'vocalized': u'فلابتدأ', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'ابتدأ', 'encletic': u'', 'type': u'فعل', 'original': u'ابتدأ'}],

 u'أوتحتنا': [{'vocalized': u'أوتحتنا', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'غيركم': [{'vocalized': u'غيركم', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'فلأولاء': [{'vocalized': u'فلأولاء', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'غيركن': [{'vocalized': u'غيركن', 'procletic': u'', 'tags': u'اسم;استثناء;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'فوق': [{'vocalized': u'فوق', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'فوق', 'encletic': u'', 'type': u'اسم', 'original': u'فوق'}],

 u'أبجميعكن': [{'vocalized': u'أبجميعكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعكن', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'جميع'}],

 u'أبجميعكم': [{'vocalized': u'أبجميعكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أبجميعكم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جميع'}],

 u'وبنحوكما': [{'vocalized': u'وبنحوكما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وبنحوكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فلعمرهما': [{'vocalized': u'فلعمرهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'لعمر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لعمر'}],

 u'فكشرقهما': [{'vocalized': u'فكشرقهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'أفكشبهك': [{'vocalized': u'أفكشبهك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'أفكشبهه': [{'vocalized': u'أفكشبهه', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شبه'}],

 u'أفكشبهي': [{'vocalized': u'أفكشبهي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أفكشبهي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'ألأمامهما': [{'vocalized': u'ألأمامهما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'بفيه': [{'vocalized': u'بفيه', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'}],

 u'حينما': [{'vocalized': u'حينما', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'حينما', 'encletic': u'', 'type': u'اسم', 'original': u'حينما'}],

 u'ولعليهما': [{'vocalized': u'ولعليهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-هما', 'type': u'حرف', 'original': u'على'}],

 u'بفيك': [{'vocalized': u'بفيك', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'}],

 u'أوليمينكن': [{'vocalized': u'أوليمينكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'اللاتي': [{'vocalized': u'اللاتي', 'procletic': u'', 'tags': u'اسم;اسم موصول', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'فكأيها': [{'vocalized': u'فكأيها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'بفيي': [{'vocalized': u'بفيي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'بفيي', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'}],

 u'فأنهما': [{'vocalized': u'فأنهما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أن'}],

 u'بعينهن': [{'vocalized': u'بعينهن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عين'}],

 u'بعينهم': [{'vocalized': u'بعينهم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عين'}],

 u'فاللاتي': [{'vocalized': u'فاللاتي', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'اللاتي', 'encletic': u'', 'type': u'اسم', 'original': u'اللاتي'}],

 u'أشمالي': [{'vocalized': u'أشمالي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'},
 {'vocalized': u'أشمالي', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شمال'}],

 u'أفلان': [{'vocalized': u'أفلان', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام', 'stem': u'فلان', 'encletic': u'', 'type': u'اسم', 'original': u'فلان'}],

 u'فإليهن': [{'vocalized': u'فإليهن', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'فإليهم': [{'vocalized': u'فإليهم', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'فلعلكما': [{'vocalized': u'فلعلكما', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-كما', 'type': u'حرف', 'original': u'لعل'}],

 u'لوقتكن': [{'vocalized': u'لوقتكن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وقت'}],

 u'لوقتكم': [{'vocalized': u'لوقتكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'وقت'}],

 u'وبات': [{'vocalized': u'وبات', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'بات', 'encletic': u'', 'type': u'فعل', 'original': u'بات'}],

 u'أويمينهم': [{'vocalized': u'أويمينهم', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'فلكله': [{'vocalized': u'فلكله', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكله', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكله', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكله', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'ومثله': [{'vocalized': u'ومثله', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'فلكلك': [{'vocalized': u'فلكلك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلك', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'ومثلك': [{'vocalized': u'ومثلك', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'لعلق': [{'vocalized': u'لعلق', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'علق', 'encletic': u'', 'type': u'فعل', 'original': u'علق'}],

 u'لأبيكن': [{'vocalized': u'لأبيكن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'لعلى': [{'vocalized': u'لعلى', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'فلكلي': [{'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكلي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'فكخلفي': [{'vocalized': u'فكخلفي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فكخلفي', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'لعلي': [{'vocalized': u'لعلي', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'لعلي', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-ي', 'type': u'حرف', 'original': u'لعل'},
 {'vocalized': u'لعلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'لعلي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'فلأسفلهما': [{'vocalized': u'فلأسفلهما', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أسفل'}],

 u'ولأجمعها': [{'vocalized': u'ولأجمعها', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعها', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'بغروب': [{'vocalized': u'بغروب', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'غروب', 'encletic': u'', 'type': u'اسم', 'original': u'غروب'}],

 u'لأبيكم': [{'vocalized': u'لأبيكم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'ولازلتم': [{'vocalized': u'ولازلتم', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتم'}],

 u'ولازلتن': [{'vocalized': u'ولازلتن', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتن'}],

 u'فوقتي': [{'vocalized': u'فوقتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'فوقتي', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'بكما': [{'vocalized': u'بكما', 'procletic': u'', 'tags': u'ضمير;ضمير متصل مجرور', 'stem': u'بكما', 'encletic': u'', 'type': u'ضمير', 'original': u'بكما'}],

 u'أبكل': [{'vocalized': u'أبكل', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكل', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'أبكم': [{'vocalized': u'أبكم', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'بكم', 'encletic': u'', 'type': u'ضمير', 'original': u'بكم'}],

 u'أبكن': [{'vocalized': u'أبكن', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'بكن', 'encletic': u'', 'type': u'ضمير', 'original': u'بكن'}],

 u'ولأجمعهن': [{'vocalized': u'ولأجمعهن', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعهن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولأجمعهم': [{'vocalized': u'ولأجمعهم', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أذلكما': [{'vocalized': u'أذلكما', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'كتلقاءهما': [{'vocalized': u'كتلقاءهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تلقاء'}],

 u'وبعضهما': [{'vocalized': u'وبعضهما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بعض'}],

 u'ورجع': [{'vocalized': u'ورجع', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'رجع', 'encletic': u'', 'type': u'فعل', 'original': u'رجع'}],

 u'حبذا': [{'vocalized': u'حبذا', 'procletic': u'', 'tags': u'فعل;المدح والذم', 'stem': u'حبذا', 'encletic': u'', 'type': u'فعل', 'original': u'حبذا'}],

 u'لحار': [{'vocalized': u'لحار', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'حار', 'encletic': u'', 'type': u'فعل', 'original': u'حار'}],

 u'عداي': [{'vocalized': u'عداي', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'عدا'},
 {'vocalized': u'عداي', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-ي', 'type': u'فعل', 'original': u'عدا'}],

 u'كشهره': [{'vocalized': u'كشهره', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شهر'}],

 u'كشهرك': [{'vocalized': u'كشهرك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'أفشبه': [{'vocalized': u'أفشبه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'فكأعليكما': [{'vocalized': u'فكأعليكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فكبعضنا': [{'vocalized': u'فكبعضنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'كشهري': [{'vocalized': u'كشهري', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'كشهري', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'فكغربه': [{'vocalized': u'فكغربه', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غرب'}],

 u'أفهاتين': [{'vocalized': u'أفهاتين', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'وبحسبهن': [{'vocalized': u'وبحسبهن', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'وبحسبهم': [{'vocalized': u'وبحسبهم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'وكجنبكما': [{'vocalized': u'وكجنبكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'وكخلفها': [{'vocalized': u'وكخلفها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ها', 'type': u'اسم', 'original': u'خلف'}],

 u'بسويه': [{'vocalized': u'بسويه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أولعلنا': [{'vocalized': u'أولعلنا', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-نا', 'type': u'حرف', 'original': u'لعل'}],

 u'فلشطركما': [{'vocalized': u'فلشطركما', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'بسويك': [{'vocalized': u'بسويك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'وبأينا': [{'vocalized': u'وبأينا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'فدونك': [{'vocalized': u'فدونك', 'procletic': u'ف-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'دونك', 'encletic': u'', 'type': u'اسم فعل', 'original': u'دونك'}],

 u'فسوينا': [{'vocalized': u'فسوينا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'ولجنبك': [{'vocalized': u'ولجنبك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جنب'}],

 u'وساعتك': [{'vocalized': u'وساعتك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'أولديك': [{'vocalized': u'أولديك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لدى'}],

 u'ولجنبه': [{'vocalized': u'ولجنبه', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جنب'}],

 u'بساعتهما': [{'vocalized': u'بساعتهما', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ساعة'}],

 u'ولأنها': [{'vocalized': u'ولأنها', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أن'}],

 u'وساعتي': [{'vocalized': u'وساعتي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'},
 {'vocalized': u'وساعتي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ساعة'}],

 u'ألشبهي': [{'vocalized': u'ألشبهي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شبه'}],

 u'وذاتكم': [{'vocalized': u'وذاتكم', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'وذاتكن': [{'vocalized': u'وذاتكن', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'لخلفك': [{'vocalized': u'لخلفك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'فكتلقاءنا': [{'vocalized': u'فكتلقاءنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'لأمامهما': [{'vocalized': u'لأمامهما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أمام', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أمام'}],

 u'ألشبهك': [{'vocalized': u'ألشبهك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'ألشبهك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شبه'}],

 u'لخلفي': [{'vocalized': u'لخلفي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'لخلفي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ي', 'type': u'اسم', 'original': u'خلف'}],

 u'أولأناهم': [{'vocalized': u'أولأناهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'أفبجميعك': [{'vocalized': u'أفبجميعك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفبجميعك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'أبمثلها': [{'vocalized': u'أبمثلها', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مثل'}],

 u'بغربكن': [{'vocalized': u'بغربكن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'بنحونا': [{'vocalized': u'بنحونا', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'بنحونا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أفليمينهن': [{'vocalized': u'أفليمينهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هن', 'type': u'اسم', 'original': u'يمين'}],

 u'أفليمينهم': [{'vocalized': u'أفليمينهم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'لغيركن': [{'vocalized': u'لغيركن', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيركن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'أولجميعنا': [{'vocalized': u'أولجميعنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعنا', 'procletic': u'أ-و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أولجميعنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'ولأنهن': [{'vocalized': u'ولأنهن', 'procletic': u'و-ل-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف;ضمير', 'stem': u'أن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أن'}],

 u'لغيركم': [{'vocalized': u'لغيركم', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيركم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'لفيكم': [{'vocalized': u'لفيكم', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-كم', 'type': u'حرف', 'original': u'في'}],

 u'أوببعضنا': [{'vocalized': u'أوببعضنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'لفيكن': [{'vocalized': u'لفيكن', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-كن', 'type': u'حرف', 'original': u'في'}],

 u'أفلإني': [{'vocalized': u'أفلإني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'},
 {'vocalized': u'أفلإني', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'إن'}],

 u'وبابنهما': [{'vocalized': u'وبابنهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ابن'}],

 u'فلفيك': [{'vocalized': u'فلفيك', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيك', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'أفلإنك': [{'vocalized': u'أفلإنك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إن'}],

 u'وكعامتنا': [{'vocalized': u'وكعامتنا', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أبمثلهم': [{'vocalized': u'أبمثلهم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلإنه': [{'vocalized': u'أفلإنه', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إن'}],

 u'أبمثلهن': [{'vocalized': u'أبمثلهن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مثل'}],

 u'وبحسبها': [{'vocalized': u'وبحسبها', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'ولحسب': [{'vocalized': u'ولحسب', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'عداهن': [{'vocalized': u'عداهن', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-هن', 'type': u'فعل', 'original': u'عدا'}],

 u'لأقل': [{'vocalized': u'لأقل', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور', 'stem': u'أقل', 'encletic': u'', 'type': u'اسم', 'original': u'أقل'}],

 u'فكليلكما': [{'vocalized': u'فكليلكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'أخلفهم': [{'vocalized': u'أخلفهم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'أخلفهن': [{'vocalized': u'أخلفهن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'فلنفسهما': [{'vocalized': u'فلنفسهما', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'وليلي': [{'vocalized': u'وليلي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'},
 {'vocalized': u'وليلي', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ليل'}],

 u'فذووها': [{'vocalized': u'فذووها', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ذوو'}],

 u'أفكحسبكما': [{'vocalized': u'أفكحسبكما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'فلتحتكما': [{'vocalized': u'فلتحتكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'فلفيي': [{'vocalized': u'فلفيي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفيي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'فلفيي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'أولسويكما': [{'vocalized': u'أولسويكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'سوى'}],

 u'فمادمت': [{'vocalized': u'فمادمت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'},
 {'vocalized': u'فمادمت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'},
 {'vocalized': u'فمادمت', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'}],

 u'ولهما': [{'vocalized': u'ولهما', 'procletic': u'و-ل-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'},
 {'vocalized': u'ولهما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'بغربكم': [{'vocalized': u'بغربكم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'تانك': [{'vocalized': u'تانك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'فأعليكن': [{'vocalized': u'فأعليكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أعلى'}],

 u'وساعتكم': [{'vocalized': u'وساعتكم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوكغيركما': [{'vocalized': u'أوكغيركما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غير'}],

 u'وساعتكن': [{'vocalized': u'وساعتكن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ساعة'}],

 u'حول': [{'vocalized': u'حول', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'حول', 'encletic': u'', 'type': u'اسم', 'original': u'حول'}],

 u'بحميهما': [{'vocalized': u'بحميهما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'ففيكما': [{'vocalized': u'ففيكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'ففيكما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'حرف', 'original': u'في'}],

 u'لغربك': [{'vocalized': u'لغربك', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'فكأقلها': [{'vocalized': u'فكأقلها', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أقل'}],

 u'أفلهذه': [{'vocalized': u'أفلهذه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هذه', 'encletic': u'', 'type': u'اسم', 'original': u'هذه'}],

 u'لغربي': [{'vocalized': u'لغربي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'لغربي', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'وكغروبهما': [{'vocalized': u'وكغروبهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'غروب'}],

 u'ولأخيكم': [{'vocalized': u'ولأخيكم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'فنحونا': [{'vocalized': u'فنحونا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فنحونا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-نا', 'type': u'اسم', 'original': u'نحو'}],

 u'أوبنحو': [{'vocalized': u'أوبنحو', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'ولأخيكن': [{'vocalized': u'ولأخيكن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'ألبعضنا': [{'vocalized': u'ألبعضنا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ألبعضنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعض'}],

 u'بأخيهما': [{'vocalized': u'بأخيهما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخي'}],

 u'ولخلفكم': [{'vocalized': u'ولخلفكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'ولخلفكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'بأيه': [{'vocalized': u'بأيه', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أي'}],

 u'وذاتك': [{'vocalized': u'وذاتك', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'بأيك': [{'vocalized': u'بأيك', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أي'}],

 u'فكأقلهن': [{'vocalized': u'فكأقلهن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أقل'}],

 u'فكأقلهم': [{'vocalized': u'فكأقلهم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'حموكما': [{'vocalized': u'حموكما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حمو'}],

 u'ألمعكما': [{'vocalized': u'ألمعكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مع'}],

 u'بأيي': [{'vocalized': u'بأيي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'},
 {'vocalized': u'بأيي', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أي'}],

 u'أفلهاتين': [{'vocalized': u'أفلهاتين', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'فذووهم': [{'vocalized': u'فذووهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ذوو'}],

 u'فذووهن': [{'vocalized': u'فذووهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ذوو'}],

 u'أفلدينا': [{'vocalized': u'أفلدينا', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لدى'}],

 u'لكأننا': [{'vocalized': u'لكأننا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'كأن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'كأن'}],

 u'أفكذاك': [{'vocalized': u'أفكذاك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذاك', 'encletic': u'', 'type': u'اسم', 'original': u'ذاك'}],

 u'وبذلك': [{'vocalized': u'وبذلك', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'جنب': [{'vocalized': u'جنب', 'procletic': u'', 'tags': u'اسم;ظرف مكان', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'أولبعضك': [{'vocalized': u'أولبعضك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بعض'}],

 u'فبغيرنا': [{'vocalized': u'فبغيرنا', 'procletic': u'ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غير'}],

 u'وعلق': [{'vocalized': u'وعلق', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'علق', 'encletic': u'', 'type': u'فعل', 'original': u'علق'}],

 u'أولبعضه': [{'vocalized': u'أولبعضه', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بعض'}],

 u'وعلى': [{'vocalized': u'وعلى', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'على', 'encletic': u'', 'type': u'حرف', 'original': u'على'}],

 u'أولبعضي': [{'vocalized': u'أولبعضي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضي', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضي', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بعض'}],

 u'وعلي': [{'vocalized': u'وعلي', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'},
 {'vocalized': u'وعلي', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'على', 'encletic': u'-ي', 'type': u'حرف', 'original': u'على'}],

 u'فزمانهما': [{'vocalized': u'فزمانهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'فكغيركن': [{'vocalized': u'فكغيركن', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'فكغيركم': [{'vocalized': u'فكغيركم', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'فذووهما': [{'vocalized': u'فذووهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوو'}],

 u'لفيك': [{'vocalized': u'لفيك', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-ك', 'type': u'حرف', 'original': u'في'}],

 u'لفيه': [{'vocalized': u'لفيه', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'لفيي': [{'vocalized': u'لفيي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيي', 'procletic': u'ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'لفيي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'},
 {'vocalized': u'لفيي', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'في', 'encletic': u'-ي', 'type': u'حرف', 'original': u'في'}],

 u'أولفيهم': [{'vocalized': u'أولفيهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'أولفيهن': [{'vocalized': u'أولفيهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'أفنحوكما': [{'vocalized': u'أفنحوكما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'وكأيتها': [{'vocalized': u'وكأيتها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أية'}],

 u'ولغربكن': [{'vocalized': u'ولغربكن', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غرب'}],

 u'ولغربكم': [{'vocalized': u'ولغربكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غرب'}],

 u'فكأسفلها': [{'vocalized': u'فكأسفلها', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'فلتانك': [{'vocalized': u'فلتانك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'وأجمعها': [{'vocalized': u'وأجمعها', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألتحتك': [{'vocalized': u'ألتحتك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'فككليهما': [{'vocalized': u'فككليهما', 'procletic': u'ف-ك-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'أمنها': [{'vocalized': u'أمنها', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ها', 'type': u'حرف', 'original': u'من'}],

 u'فبأبيكن': [{'vocalized': u'فبأبيكن', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبي'}],

 u'فزمانكن': [{'vocalized': u'فزمانكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كن', 'type': u'اسم', 'original': u'زمان'}],

 u'فزمانكم': [{'vocalized': u'فزمانكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-كم', 'type': u'اسم', 'original': u'زمان'}],

 u'فبأبيكم': [{'vocalized': u'فبأبيكم', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبي'}],

 u'ولأخي': [{'vocalized': u'ولأخي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'أخي', 'encletic': u'', 'type': u'اسم', 'original': u'أخي'}],

 u'أبما': [{'vocalized': u'أبما', 'procletic': u'أ-', 'tags': u'اسم;اسم الاستفهام;استفهام', 'stem': u'بما', 'encletic': u'', 'type': u'اسم', 'original': u'بما'}],

 u'فحموهن': [{'vocalized': u'فحموهن', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمو'}],

 u'فحموهم': [{'vocalized': u'فحموهم', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمو'}],

 u'أوأجمعكم': [{'vocalized': u'أوأجمعكم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'أمنهن': [{'vocalized': u'أمنهن', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هن', 'type': u'حرف', 'original': u'من'}],

 u'خلانا': [{'vocalized': u'خلانا', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'خلا', 'encletic': u'-نا', 'type': u'فعل', 'original': u'خلا'}],

 u'عسى': [{'vocalized': u'عسى', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'عسى', 'encletic': u'', 'type': u'فعل', 'original': u'عسى'}],

 u'أمنهم': [{'vocalized': u'أمنهم', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'ألمثلي': [{'vocalized': u'ألمثلي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلي', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلي', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'فبأجمعهما': [{'vocalized': u'فبأجمعهما', 'procletic': u'ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألمثله': [{'vocalized': u'ألمثله', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثله', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'ولعاد': [{'vocalized': u'ولعاد', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'عاد', 'encletic': u'', 'type': u'فعل', 'original': u'عاد'}],

 u'ألمثلك': [{'vocalized': u'ألمثلك', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ألمثلك', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'أبمن': [{'vocalized': u'أبمن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم موصول;مجرور;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'ولأخذ': [{'vocalized': u'ولأخذ', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أخذ', 'encletic': u'', 'type': u'فعل', 'original': u'أخذ'}],

 u'كعامتكم': [{'vocalized': u'كعامتكم', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'وللألاء': [{'vocalized': u'وللألاء', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'أفبنحوهما': [{'vocalized': u'أفبنحوهما', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نحو'}],

 u'فتحتنا': [{'vocalized': u'فتحتنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'ولشرقنا': [{'vocalized': u'ولشرقنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'فلأقلي': [{'vocalized': u'فلأقلي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'},
 {'vocalized': u'فلأقلي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أقل'}],

 u'ولحسبه': [{'vocalized': u'ولحسبه', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'حين': [{'vocalized': u'حين', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'حين', 'encletic': u'', 'type': u'اسم', 'original': u'حين'}],

 u'ولحسبك': [{'vocalized': u'ولحسبك', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'فضمنكن': [{'vocalized': u'فضمنكن', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ضمن'}],

 u'فلأقلك': [{'vocalized': u'فلأقلك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أقل'}],

 u'فلجنب': [{'vocalized': u'فلجنب', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'ولحسبي': [{'vocalized': u'ولحسبي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'ولحسبي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'فلأقله': [{'vocalized': u'فلأقله', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أقل'}],

 u'وشطرهن': [{'vocalized': u'وشطرهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'فمساء': [{'vocalized': u'فمساء', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'مساء', 'encletic': u'', 'type': u'اسم', 'original': u'مساء'}],

 u'وشطرهم': [{'vocalized': u'وشطرهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'وكأيتهن': [{'vocalized': u'وكأيتهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أية'}],

 u'فكأسفلهم': [{'vocalized': u'فكأسفلهم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكأسفلهن': [{'vocalized': u'فكأسفلهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وأجمعهم': [{'vocalized': u'وأجمعهم', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أجمع'}],

 u'لغربنا': [{'vocalized': u'لغربنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'وأجمعهن': [{'vocalized': u'وأجمعهن', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولشبههما': [{'vocalized': u'أولشبههما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'أولشبههما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'فبأيهما': [{'vocalized': u'فبأيهما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أي'}],

 u'فلعني': [{'vocalized': u'فلعني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'فلعني', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'أوكشبهكما': [{'vocalized': u'أوكشبهكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شبه'}],

 u'وفيهم': [{'vocalized': u'وفيهم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيهم', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'حرف', 'original': u'في'}],

 u'وفيهن': [{'vocalized': u'وفيهن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيهن', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'أقلهم': [{'vocalized': u'أقلهم', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أقل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أقل'}],

 u'ويكأنك': [{'vocalized': u'ويكأنك', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-ك', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'لارتد': [{'vocalized': u'لارتد', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'ارتد', 'encletic': u'', 'type': u'فعل', 'original': u'ارتد'}],

 u'ويكأنه': [{'vocalized': u'ويكأنه', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-ه', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'ويكأني': [{'vocalized': u'ويكأني', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-ي', 'type': u'اسم فعل', 'original': u'ويكأن'},
 {'vocalized': u'ويكأني', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-ي', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'مازلتم': [{'vocalized': u'مازلتم', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'مازلتم'}],

 u'فحينها': [{'vocalized': u'فحينها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'حين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حين'}],

 u'فكغروبهن': [{'vocalized': u'فكغروبهن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'فلخلفه': [{'vocalized': u'فلخلفه', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفه', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'وكحسبكما': [{'vocalized': u'وكحسبكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'وبفيها': [{'vocalized': u'وبفيها', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'}],

 u'وكأثناءكما': [{'vocalized': u'وكأثناءكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أثناء'}],

 u'بكليهما': [{'vocalized': u'بكليهما', 'procletic': u'ب-', 'tags': u'حرف;توكيد;مجرور', 'stem': u'كليهما', 'encletic': u'', 'type': u'حرف', 'original': u'كليهما'}],

 u'ولابتدأ': [{'vocalized': u'ولابتدأ', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'ابتدأ', 'encletic': u'', 'type': u'فعل', 'original': u'ابتدأ'}],

 u'بئس': [{'vocalized': u'بئس', 'procletic': u'', 'tags': u'فعل;المدح والذم', 'stem': u'بئس', 'encletic': u'', 'type': u'فعل', 'original': u'بئس'}],

 u'أفإنهما': [{'vocalized': u'أفإنهما', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إن'}],

 u'وشهرنا': [{'vocalized': u'وشهرنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'أفلتحتنا': [{'vocalized': u'أفلتحتنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'أيتكما': [{'vocalized': u'أيتكما', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'أولفيهما': [{'vocalized': u'أولفيهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هما', 'type': u'حرف', 'original': u'في'}],

 u'أناها': [{'vocalized': u'أناها', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-ها', 'type': u'حرف', 'original': u'أنا'}],

 u'وكوقتنا': [{'vocalized': u'وكوقتنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'أبهاته': [{'vocalized': u'أبهاته', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'فشطر': [{'vocalized': u'فشطر', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'وبفيهن': [{'vocalized': u'وبفيهن', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'اسم', 'original': u'في'}],

 u'ولمثلنا': [{'vocalized': u'ولمثلنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'ولمثلنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'وبفيهم': [{'vocalized': u'وبفيهم', 'procletic': u'و-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-هم', 'type': u'اسم', 'original': u'في'}],

 u'وزمانك': [{'vocalized': u'وزمانك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ك', 'type': u'اسم', 'original': u'زمان'}],

 u'بأولالك': [{'vocalized': u'بأولالك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'أبهاتي': [{'vocalized': u'أبهاتي', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'فكأولاء': [{'vocalized': u'فكأولاء', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولاء', 'encletic': u'', 'type': u'اسم', 'original': u'أولاء'}],

 u'أيمينكن': [{'vocalized': u'أيمينكن', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'يمين'}],

 u'ولغربك': [{'vocalized': u'ولغربك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غرب'}],

 u'أيمينكم': [{'vocalized': u'أيمينكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'يمين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'يمين'}],

 u'ك': [{'vocalized': u'ك', 'procletic': u'', 'tags': u'حرف ابجدي;حرف ابجدي', 'stem': u'ك', 'encletic': u'', 'type': u'حرف ابجدي', 'original': u'ك'}],

 u'فكغربنا': [{'vocalized': u'فكغربنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'وفيها': [{'vocalized': u'وفيها', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'وفيها', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'في', 'encletic': u'-ها', 'type': u'حرف', 'original': u'في'}],

 u'فأبيك': [{'vocalized': u'فأبيك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'أفهو': [{'vocalized': u'أفهو', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'وقبل': [{'vocalized': u'وقبل', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'قبل', 'encletic': u'', 'type': u'اسم', 'original': u'قبل'}],

 u'أفهي': [{'vocalized': u'أفهي', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'فأبيه': [{'vocalized': u'فأبيه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'أمثلنا': [{'vocalized': u'أمثلنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'أفلفوقهما': [{'vocalized': u'أفلفوقهما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'فوق'}],

 u'فأبيي': [{'vocalized': u'فأبيي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'فأبيي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'أفهم': [{'vocalized': u'أفهم', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أفهن': [{'vocalized': u'أفهن', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير منفصل;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'مابرحتما': [{'vocalized': u'مابرحتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحتما', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتما'},
 {'vocalized': u'مابرحتما', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مابرحتما', 'encletic': u'', 'type': u'فعل', 'original': u'مابرحتما'}],

 u'أووراءهما': [{'vocalized': u'أووراءهما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'أفغيركن': [{'vocalized': u'أفغيركن', 'procletic': u'أ-ف-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'فبشطركما': [{'vocalized': u'فبشطركما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شطر'}],

 u'فأكثرنا': [{'vocalized': u'فأكثرنا', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أكثر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أكثر'}],

 u'أوبما': [{'vocalized': u'أوبما', 'procletic': u'أ-و-', 'tags': u'اسم;اسم الاستفهام;عطف;استفهام', 'stem': u'بما', 'encletic': u'', 'type': u'اسم', 'original': u'بما'}],

 u'أفلعننا': [{'vocalized': u'أفلعننا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'عن'}],

 u'ولبعضكما': [{'vocalized': u'ولبعضكما', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'ولبعضكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'ولجنبها': [{'vocalized': u'ولجنبها', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنب'}],

 u'فكنحوكن': [{'vocalized': u'فكنحوكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوكن', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'فكنحوكم': [{'vocalized': u'فكنحوكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'فكنحوكم', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'وبغربهن': [{'vocalized': u'وبغربهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'وبغربهم': [{'vocalized': u'وبغربهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'فبه': [{'vocalized': u'فبه', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'به', 'encletic': u'', 'type': u'ضمير', 'original': u'به'}],

 u'فلأناهم': [{'vocalized': u'فلأناهم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'وجنوبها': [{'vocalized': u'وجنوبها', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جنوب'}],

 u'لذويكم': [{'vocalized': u'لذويكم', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذوي'}],

 u'أبحسبكم': [{'vocalized': u'أبحسبكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'لذويكن': [{'vocalized': u'لذويكن', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذوي'}],

 u'وكشبههما': [{'vocalized': u'وكشبههما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'ولقام': [{'vocalized': u'ولقام', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'قام', 'encletic': u'', 'type': u'فعل', 'original': u'قام'}],

 u'وبخلفنا': [{'vocalized': u'وبخلفنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'فلازلتم': [{'vocalized': u'فلازلتم', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتم'}],

 u'أوهؤلاء': [{'vocalized': u'أوهؤلاء', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'هؤلاء', 'encletic': u'', 'type': u'اسم', 'original': u'هؤلاء'}],

 u'أمنك': [{'vocalized': u'أمنك', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'ولأنتما': [{'vocalized': u'ولأنتما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أنتما', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتما'}],

 u'أمنه': [{'vocalized': u'أمنه', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'وبأجمعك': [{'vocalized': u'وبأجمعك', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أجمع'}],

 u'أمني': [{'vocalized': u'أمني', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'أمني', 'procletic': u'أ-', 'tags': u'حرف;حرف جر;استفهام;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'أفبأولئك': [{'vocalized': u'أفبأولئك', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'أولئك', 'encletic': u'', 'type': u'اسم', 'original': u'أولئك'}],

 u'أتحتهما': [{'vocalized': u'أتحتهما', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'تحت'}],

 u'لمنك': [{'vocalized': u'لمنك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-ك', 'type': u'حرف', 'original': u'من'}],

 u'فيمينهما': [{'vocalized': u'فيمينهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'يمين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'يمين'}],

 u'أبعامتهم': [{'vocalized': u'أبعامتهم', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'لمنه': [{'vocalized': u'لمنه', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-ه', 'type': u'حرف', 'original': u'من'}],

 u'وبعامتكما': [{'vocalized': u'وبعامتكما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'لمني': [{'vocalized': u'لمني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'},
 {'vocalized': u'لمني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'من', 'encletic': u'-ي', 'type': u'حرف', 'original': u'من'}],

 u'ولساعتكم': [{'vocalized': u'ولساعتكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ساعة'}],

 u'أمعهما': [{'vocalized': u'أمعهما', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مع'}],

 u'بأسفلنا': [{'vocalized': u'بأسفلنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'فللحظتك': [{'vocalized': u'فللحظتك', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'لحظة'}],

 u'ألكلنا': [{'vocalized': u'ألكلنا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلنا', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ألكلنا', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'فللحظته': [{'vocalized': u'فللحظته', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'فبذوينا': [{'vocalized': u'فبذوينا', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'أفلجميعكما': [{'vocalized': u'أفلجميعكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفلجميعكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جميع'}],

 u'فللحظتي': [{'vocalized': u'فللحظتي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'},
 {'vocalized': u'فللحظتي', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ي', 'type': u'اسم', 'original': u'لحظة'}],

 u'أفلخلفهن': [{'vocalized': u'أفلخلفهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'أوبمن': [{'vocalized': u'أوبمن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'وأنكن': [{'vocalized': u'وأنكن', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'أن'}],

 u'وأنكم': [{'vocalized': u'وأنكم', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'أن'}],

 u'وماانفكت': [{'vocalized': u'وماانفكت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكت', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكت'}],

 u'بخلفك': [{'vocalized': u'بخلفك', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-ك', 'type': u'اسم', 'original': u'خلف'}],

 u'وبغربها': [{'vocalized': u'وبغربها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'وبذين': [{'vocalized': u'وبذين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذين', 'encletic': u'', 'type': u'اسم', 'original': u'ذين'}],

 u'فبزماننا': [{'vocalized': u'فبزماننا', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'وبعضها': [{'vocalized': u'وبعضها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'أفلعلهما': [{'vocalized': u'أفلعلهما', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'لعل', 'encletic': u'-هما', 'type': u'حرف', 'original': u'لعل'}],

 u'مافتئت': [{'vocalized': u'مافتئت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'مافتئت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'مافتئت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'},
 {'vocalized': u'مافتئت', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئت', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئت'}],

 u'ولشرقهما': [{'vocalized': u'ولشرقهما', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'أفبعامتهم': [{'vocalized': u'أفبعامتهم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلتلكم': [{'vocalized': u'أفلتلكم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'أفبعامتهن': [{'vocalized': u'أفبعامتهن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'عامة'}],

 u'فلأولالك': [{'vocalized': u'فلأولالك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'ولازلن': [{'vocalized': u'ولازلن', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازلن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلن'}],

 u'مرة': [{'vocalized': u'مرة', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'مرة', 'encletic': u'', 'type': u'اسم', 'original': u'مرة'}],

 u'منهما': [{'vocalized': u'منهما', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'من', 'encletic': u'-هما', 'type': u'حرف', 'original': u'من'}],

 u'كأكثرها': [{'vocalized': u'كأكثرها', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أكثر'}],

 u'فبوقتي': [{'vocalized': u'فبوقتي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'فبوقتي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'ألنفسكما': [{'vocalized': u'ألنفسكما', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ألنفسكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'وكتينك': [{'vocalized': u'وكتينك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'وكجميعهما': [{'vocalized': u'وكجميعهما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وكجميعهما', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جميع'}],

 u'لتحتهم': [{'vocalized': u'لتحتهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'تحت'}],

 u'لتحتهن': [{'vocalized': u'لتحتهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'تحت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'تحت'}],

 u'بحسبهن': [{'vocalized': u'بحسبهن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'بحسبهم': [{'vocalized': u'بحسبهم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أولإليهما': [{'vocalized': u'أولإليهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هما', 'type': u'حرف', 'original': u'إلى'}],

 u'ولأضحى': [{'vocalized': u'ولأضحى', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'أضحى', 'encletic': u'', 'type': u'فعل', 'original': u'أضحى'}],

 u'بأيكن': [{'vocalized': u'بأيكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أي'}],

 u'بأيكم': [{'vocalized': u'بأيكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أي'}],

 u'وبغيرك': [{'vocalized': u'وبغيرك', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ك', 'type': u'اسم', 'original': u'غير'}],

 u'وهاتي': [{'vocalized': u'وهاتي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'وبغيره': [{'vocalized': u'وبغيره', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ه', 'type': u'اسم', 'original': u'غير'}],

 u'فبينكم': [{'vocalized': u'فبينكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'بين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بين'}],

 u'بحسبها': [{'vocalized': u'بحسبها', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'وبغيري': [{'vocalized': u'وبغيري', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'وبغيري', 'procletic': u'و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'أبكلهما': [{'vocalized': u'أبكلهما', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أبكلهما', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'كل'}],

 u'أفلديها': [{'vocalized': u'أفلديها', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف;عطف;استفهام;ضمير', 'stem': u'لدى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'لدى'}],

 u'وهاته': [{'vocalized': u'وهاته', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'ألخلفكما': [{'vocalized': u'ألخلفكما', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'أبنفسك': [{'vocalized': u'أبنفسك', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'فكشطره': [{'vocalized': u'فكشطره', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شطر'}],

 u'أخيها': [{'vocalized': u'أخيها', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'فبوقتهما': [{'vocalized': u'فبوقتهما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'فكشطرك': [{'vocalized': u'فكشطرك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شطر'}],

 u'شهرها': [{'vocalized': u'شهرها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'أفلفوقكم': [{'vocalized': u'أفلفوقكم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-كم', 'type': u'اسم', 'original': u'فوق'}],

 u'فكشطري': [{'vocalized': u'فكشطري', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'},
 {'vocalized': u'فكشطري', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شطر'}],

 u'ولهاذين': [{'vocalized': u'ولهاذين', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أوبأجمعهما': [{'vocalized': u'أوبأجمعهما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وبعضهن': [{'vocalized': u'وبعضهن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'وبعضهم': [{'vocalized': u'وبعضهم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'فأسفلنا': [{'vocalized': u'فأسفلنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'فمادمتن': [{'vocalized': u'فمادمتن', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتن', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتن'}],

 u'أفلفيهن': [{'vocalized': u'أفلفيهن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-هن', 'type': u'حرف', 'original': u'في'}],

 u'أفبعامتها': [{'vocalized': u'أفبعامتها', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'أفلتحته': [{'vocalized': u'أفلتحته', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'مافتئن': [{'vocalized': u'مافتئن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئن', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئن'}],

 u'فشهر': [{'vocalized': u'فشهر', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'شهر', 'encletic': u'', 'type': u'اسم', 'original': u'شهر'}],

 u'كأسفلنا': [{'vocalized': u'كأسفلنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'بذانك': [{'vocalized': u'بذانك', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'بأيكما': [{'vocalized': u'بأيكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أي'}],

 u'كأكثرهن': [{'vocalized': u'كأكثرهن', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أكثر'}],

 u'كأكثرهم': [{'vocalized': u'كأكثرهم', 'procletic': u'ك-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أكثر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أكثر'}],

 u'وبنفس': [{'vocalized': u'وبنفس', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'فلحميها': [{'vocalized': u'فلحميها', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حمي'}],

 u'وأخيك': [{'vocalized': u'وأخيك', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'ليمينك': [{'vocalized': u'ليمينك', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'يمين'}],

 u'فلأناكما': [{'vocalized': u'فلأناكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'وأخيه': [{'vocalized': u'وأخيه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'فلحيث': [{'vocalized': u'فلحيث', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حيث', 'encletic': u'', 'type': u'اسم', 'original': u'حيث'}],

 u'وأخيي': [{'vocalized': u'وأخيي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'وأخيي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'ففانا': [{'vocalized': u'ففانا', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'فا', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فا'}],

 u'أفبشبه': [{'vocalized': u'أفبشبه', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'أثناءكن': [{'vocalized': u'أثناءكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أثناء'}],

 u'وكشهري': [{'vocalized': u'وكشهري', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'},
 {'vocalized': u'وكشهري', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ي', 'type': u'اسم', 'original': u'شهر'}],

 u'وكفينا': [{'vocalized': u'وكفينا', 'procletic': u'و-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'اسم', 'original': u'في'}],

 u'أفكبعضها': [{'vocalized': u'أفكبعضها', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-ها', 'type': u'اسم', 'original': u'بعض'}],

 u'وكذانك': [{'vocalized': u'وكذانك', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذانك', 'encletic': u'', 'type': u'اسم', 'original': u'ذانك'}],

 u'هناك': [{'vocalized': u'هناك', 'procletic': u'', 'tags': u'اسم;اسم إشارة', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'وكشهرك': [{'vocalized': u'وكشهرك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ك', 'type': u'اسم', 'original': u'شهر'}],

 u'أإنهن': [{'vocalized': u'أإنهن', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إن'}],

 u'فوراء': [{'vocalized': u'فوراء', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'وراء', 'encletic': u'', 'type': u'اسم', 'original': u'وراء'}],

 u'فضمنهم': [{'vocalized': u'فضمنهم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ضمن'}],

 u'أإنهم': [{'vocalized': u'أإنهم', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إن'}],

 u'فبوقت': [{'vocalized': u'فبوقت', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'وقت', 'encletic': u'', 'type': u'اسم', 'original': u'وقت'}],

 u'إلا': [{'vocalized': u'إلا', 'procletic': u'', 'tags': u'حرف;حرف استثناء', 'stem': u'إلا', 'encletic': u'', 'type': u'حرف', 'original': u'إلا'},
 {'vocalized': u'إلا', 'procletic': u'', 'tags': u'حرف;حرف استثناء', 'stem': u'إلا', 'encletic': u'', 'type': u'حرف', 'original': u'إلا'}],

 u'ويكأنهم': [{'vocalized': u'ويكأنهم', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-هم', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'ولإليك': [{'vocalized': u'ولإليك', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ك', 'type': u'حرف', 'original': u'إلى'}],

 u'أوحسبها': [{'vocalized': u'أوحسبها', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'ولإليه': [{'vocalized': u'ولإليه', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'إلى', 'encletic': u'-ه', 'type': u'حرف', 'original': u'إلى'}],

 u'ويكأنهن': [{'vocalized': u'ويكأنهن', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-هن', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'لليلك': [{'vocalized': u'لليلك', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'أوغيرهم': [{'vocalized': u'أوغيرهم', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أوغيرهن': [{'vocalized': u'أوغيرهن', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'أفلمنكما': [{'vocalized': u'أفلمنكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'أوبجميعها': [{'vocalized': u'أوبجميعها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعها', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'جميع'}],

 u'أإنها': [{'vocalized': u'أإنها', 'procletic': u'أ-', 'tags': u'حرف;إن و أخواتها;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'إن'}],

 u'فمعاذ': [{'vocalized': u'فمعاذ', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'معاذ', 'encletic': u'', 'type': u'اسم', 'original': u'معاذ'}],

 u'أوحسبهم': [{'vocalized': u'أوحسبهم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أوحسبهن': [{'vocalized': u'أوحسبهن', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'فحولكم': [{'vocalized': u'فحولكم', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حول', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حول'}],

 u'أفلكلنا': [{'vocalized': u'أفلكلنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلنا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أفلكلنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أوغيرها': [{'vocalized': u'أوغيرها', 'procletic': u'أ-و-', 'tags': u'اسم;استثناء;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'أوبجميعهم': [{'vocalized': u'أوبجميعهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعهم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'جميع'}],

 u'أوبجميعهن': [{'vocalized': u'أوبجميعهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعهن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'لفوقنا': [{'vocalized': u'لفوقنا', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'فلحميهن': [{'vocalized': u'فلحميهن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حمي'}],

 u'فلحميهم': [{'vocalized': u'فلحميهم', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حمي'}],

 u'حميهما': [{'vocalized': u'حميهما', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'حمي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حمي'}],

 u'أوكذلكما': [{'vocalized': u'أوكذلكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكما', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكما'}],

 u'بدوني': [{'vocalized': u'بدوني', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بدون'},
 {'vocalized': u'بدوني', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'بدون', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بدون'}],

 u'وكالألاء': [{'vocalized': u'وكالألاء', 'procletic': u'و-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'كأخيك': [{'vocalized': u'كأخيك', 'procletic': u'ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أخي'}],

 u'فبالذين': [{'vocalized': u'فبالذين', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'أفكبعضهم': [{'vocalized': u'أفكبعضهم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بعض'}],

 u'تلقاءنا': [{'vocalized': u'تلقاءنا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أفكبعضهن': [{'vocalized': u'أفكبعضهن', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بعض'}],

 u'أفكذلكم': [{'vocalized': u'أفكذلكم', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'وكلحظته': [{'vocalized': u'وكلحظته', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبذا': [{'vocalized': u'وبذا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'},
 {'vocalized': u'وبذا', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'ذا', 'encletic': u'', 'type': u'اسم', 'original': u'ذا'}],

 u'بينهما': [{'vocalized': u'بينهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'بين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'بين'}],

 u'أوكلاهما': [{'vocalized': u'أوكلاهما', 'procletic': u'أ-و-', 'tags': u'حرف;توكيد;عطف;استفهام', 'stem': u'كلاهما', 'encletic': u'', 'type': u'حرف', 'original': u'كلاهما'}],

 u'أفكذي': [{'vocalized': u'أفكذي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'أوككلكن': [{'vocalized': u'أوككلكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلكن', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'أوككلكم': [{'vocalized': u'أوككلكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوككلكم', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أبغيرهم': [{'vocalized': u'أبغيرهم', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'أبغيرهن': [{'vocalized': u'أبغيرهن', 'procletic': u'أ-ب-', 'tags': u'اسم;استثناء;مجرور;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'وبغربي': [{'vocalized': u'وبغربي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'},
 {'vocalized': u'وبغربي', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غرب'}],

 u'بكلكم': [{'vocalized': u'بكلكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلكم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'كل'}],

 u'أفكأجمعهما': [{'vocalized': u'أفكأجمعهما', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'وأثناءها': [{'vocalized': u'وأثناءها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'بكلكن': [{'vocalized': u'بكلكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'بكلكن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'كل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'كل'}],

 u'لشرقه': [{'vocalized': u'لشرقه', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-ه', 'type': u'اسم', 'original': u'شرق'}],

 u'فكهذين': [{'vocalized': u'فكهذين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هذين', 'encletic': u'', 'type': u'اسم', 'original': u'هذين'}],

 u'وأبوكم': [{'vocalized': u'وأبوكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبو'}],

 u'وأبوكن': [{'vocalized': u'وأبوكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أبو'}],

 u'ولساعتك': [{'vocalized': u'ولساعتك', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ساعة'}],

 u'وكمثلكما': [{'vocalized': u'وكمثلكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'فبمثلكما': [{'vocalized': u'فبمثلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'مثل'}],

 u'وبضعه': [{'vocalized': u'وبضعه', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بضع'}],

 u'أنت': [{'vocalized': u'أنت', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'أنت', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'وبضعك': [{'vocalized': u'وبضعك', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'بضع'}],

 u'أنا': [{'vocalized': u'أنا', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'أنا', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'وبضعي': [{'vocalized': u'وبضعي', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'},
 {'vocalized': u'وبضعي', 'procletic': u'و-', 'tags': u'اسم;كناية;عطف;ضمير', 'stem': u'بضع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'بضع'}],

 u'فبدوننا': [{'vocalized': u'فبدوننا', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بدون'}],

 u'أوبجميعي': [{'vocalized': u'أوبجميعي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'لليل': [{'vocalized': u'لليل', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور', 'stem': u'ليل', 'encletic': u'', 'type': u'اسم', 'original': u'ليل'}],

 u'أوبجميعه': [{'vocalized': u'أوبجميعه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعه', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أوبجميعك': [{'vocalized': u'أوبجميعك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أوبجميعك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'بأجمعهما': [{'vocalized': u'بأجمعهما', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'أفلعيننا': [{'vocalized': u'أفلعيننا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'أفلعيننا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'بشرقكما': [{'vocalized': u'بشرقكما', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'أني': [{'vocalized': u'أني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'أني', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'أن'}],

 u'فلكأنكن': [{'vocalized': u'فلكأنكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'كأن'}],

 u'فلكأنكم': [{'vocalized': u'فلكأنكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كأن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'كأن'}],

 u'أنى': [{'vocalized': u'أنى', 'procletic': u'', 'tags': u'اسم;اسم الاستفهام', 'stem': u'أنى', 'encletic': u'', 'type': u'اسم', 'original': u'أنى'},
 {'vocalized': u'أنى', 'procletic': u'', 'tags': u'اسم;اسم الشرط', 'stem': u'أنى', 'encletic': u'', 'type': u'اسم', 'original': u'أنى'}],

 u'كتلقاءنا': [{'vocalized': u'كتلقاءنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'تلقاء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تلقاء'}],

 u'أنه': [{'vocalized': u'أنه', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-ه', 'type': u'حرف', 'original': u'أن'}],

 u'أنك': [{'vocalized': u'أنك', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-ك', 'type': u'حرف', 'original': u'أن'}],

 u'وكزماننا': [{'vocalized': u'وكزماننا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-نا', 'type': u'اسم', 'original': u'زمان'}],

 u'أكنحوك': [{'vocalized': u'أكنحوك', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'فحماي': [{'vocalized': u'فحماي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حما'},
 {'vocalized': u'فحماي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حما'}],

 u'أكنحوه': [{'vocalized': u'أكنحوه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'وراءكن': [{'vocalized': u'وراءكن', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'وراءكن', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وراءكن'},
 {'vocalized': u'وراءكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'فحماك': [{'vocalized': u'فحماك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حما'}],

 u'أكنحوي': [{'vocalized': u'أكنحوي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أكنحوي', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'فحماه': [{'vocalized': u'فحماه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حما', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حما'}],

 u'فلكنما': [{'vocalized': u'فلكنما', 'procletic': u'ف-', 'tags': u'حرف;كافة ومكفوفة;عطف', 'stem': u'لكنما', 'encletic': u'', 'type': u'حرف', 'original': u'لكنما'}],

 u'وعينهما': [{'vocalized': u'وعينهما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عين'}],

 u'فلعامتنا': [{'vocalized': u'فلعامتنا', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'فلعامتنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عامة'}],

 u'أفكذا': [{'vocalized': u'أفكذا', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام', 'stem': u'كذا', 'encletic': u'', 'type': u'اسم', 'original': u'كذا'}],

 u'أفكهاتي': [{'vocalized': u'أفكهاتي', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'وبذه': [{'vocalized': u'وبذه', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذه', 'encletic': u'', 'type': u'اسم', 'original': u'ذه'}],

 u'ليتي': [{'vocalized': u'ليتي', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-ي', 'type': u'حرف', 'original': u'ليت'},
 {'vocalized': u'ليتي', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-ي', 'type': u'حرف', 'original': u'ليت'}],

 u'فلحميكن': [{'vocalized': u'فلحميكن', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'ضحوة': [{'vocalized': u'ضحوة', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'ضحوة', 'encletic': u'', 'type': u'اسم', 'original': u'ضحوة'}],

 u'فكسوي': [{'vocalized': u'فكسوي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'},
 {'vocalized': u'فكسوي', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'سوى'}],

 u'ليته': [{'vocalized': u'ليته', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'ليت', 'encletic': u'-ه', 'type': u'حرف', 'original': u'ليت'}],

 u'وبذي': [{'vocalized': u'وبذي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذي', 'encletic': u'', 'type': u'اسم', 'original': u'ذي'}],

 u'أفكهاته': [{'vocalized': u'أفكهاته', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'أوكهما': [{'vocalized': u'أوكهما', 'procletic': u'أ-و-ك-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'فلطفق': [{'vocalized': u'فلطفق', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'طفق', 'encletic': u'', 'type': u'فعل', 'original': u'طفق'}],

 u'ويكأنها': [{'vocalized': u'ويكأنها', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-ها', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'وأثناءهم': [{'vocalized': u'وأثناءهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفبضعنا': [{'vocalized': u'أفبضعنا', 'procletic': u'أ-ف-', 'tags': u'اسم;كناية;عطف;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بضع'}],

 u'وأثناءهن': [{'vocalized': u'وأثناءهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'أكثركم': [{'vocalized': u'أكثركم', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أكثر'}],

 u'أكثركن': [{'vocalized': u'أكثركن', 'procletic': u'', 'tags': u'اسم;اسم تفضيل;ضمير', 'stem': u'أكثر', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أكثر'}],

 u'كغروبنا': [{'vocalized': u'كغروبنا', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'ولمنهم': [{'vocalized': u'ولمنهم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'من', 'encletic': u'-هم', 'type': u'حرف', 'original': u'من'}],

 u'فبأعلى': [{'vocalized': u'فبأعلى', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أعلى', 'encletic': u'', 'type': u'اسم', 'original': u'أعلى'}],

 u'فبأعلي': [{'vocalized': u'فبأعلي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'},
 {'vocalized': u'فبأعلي', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أعلى'}],

 u'لصار': [{'vocalized': u'لصار', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'صار', 'encletic': u'', 'type': u'فعل', 'original': u'صار'}],

 u'ألعين': [{'vocalized': u'ألعين', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'ألعين', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'عين', 'encletic': u'', 'type': u'اسم', 'original': u'عين'}],

 u'حينهم': [{'vocalized': u'حينهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حين'}],

 u'فلعليكما': [{'vocalized': u'فلعليكما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'على', 'encletic': u'-كما', 'type': u'حرف', 'original': u'على'}],

 u'فبغروبكما': [{'vocalized': u'فبغروبكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'غروب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'غروب'}],

 u'وكنحوكما': [{'vocalized': u'وكنحوكما', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'وكنحوكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فأخوكما': [{'vocalized': u'فأخوكما', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخو'}],

 u'أولشمالها': [{'vocalized': u'أولشمالها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'شمال', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شمال'}],

 u'أفلعلينا': [{'vocalized': u'أفلعلينا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-نا', 'type': u'حرف', 'original': u'على'}],

 u'أفلنحوي': [{'vocalized': u'أفلنحوي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'أفلنحوي', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نحو'}],

 u'شهرهما': [{'vocalized': u'شهرهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'شهر', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شهر'}],

 u'أفلنحوه': [{'vocalized': u'أفلنحوه', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلفوقي': [{'vocalized': u'أفلفوقي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'},
 {'vocalized': u'أفلفوقي', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ي', 'type': u'اسم', 'original': u'فوق'}],

 u'أفبهاذين': [{'vocalized': u'أفبهاذين', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'أفلنحوك': [{'vocalized': u'أفلنحوك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نحو'}],

 u'أفلازلتم': [{'vocalized': u'أفلازلتم', 'procletic': u'أ-ف-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتم', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتم'}],

 u'أوكأجمعهما': [{'vocalized': u'أوكأجمعهما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'فشطرهم': [{'vocalized': u'فشطرهم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هم', 'type': u'اسم', 'original': u'شطر'}],

 u'فشطرهن': [{'vocalized': u'فشطرهن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شطر'}],

 u'أبأجمعها': [{'vocalized': u'أبأجمعها', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أجمع'}],

 u'أولوراءهما': [{'vocalized': u'أولوراءهما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وراء'}],

 u'فلشبهنا': [{'vocalized': u'فلشبهنا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'},
 {'vocalized': u'فلشبهنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'وبالألى': [{'vocalized': u'وبالألى', 'procletic': u'و-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'الألى', 'encletic': u'', 'type': u'اسم', 'original': u'الألى'}],

 u'وكوقتهما': [{'vocalized': u'وكوقتهما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'لجنبكما': [{'vocalized': u'لجنبكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'فبأخيه': [{'vocalized': u'فبأخيه', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخي'}],

 u'كخلفهما': [{'vocalized': u'كخلفهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'ولنحن': [{'vocalized': u'ولنحن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'نحن', 'encletic': u'', 'type': u'ضمير', 'original': u'نحن'}],

 u'أفتينك': [{'vocalized': u'أفتينك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تينك', 'encletic': u'', 'type': u'اسم', 'original': u'تينك'}],

 u'أوعامة': [{'vocalized': u'أوعامة', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'ألكن': [{'vocalized': u'ألكن', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'لكن', 'encletic': u'', 'type': u'ضمير', 'original': u'لكن'}],

 u'فشطرها': [{'vocalized': u'فشطرها', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'ولنحو': [{'vocalized': u'ولنحو', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'ولنحو', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'نحو', 'encletic': u'', 'type': u'اسم', 'original': u'نحو'}],

 u'فبأخيي': [{'vocalized': u'فبأخيي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'},
 {'vocalized': u'فبأخيي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخي'}],

 u'أفلعامته': [{'vocalized': u'أفلعامته', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامته', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عامة'}],

 u'عندكما': [{'vocalized': u'عندكما', 'procletic': u'', 'tags': u'اسم;ظرف;ضمير', 'stem': u'عند', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عند'}],

 u'أفلعامتك': [{'vocalized': u'أفلعامتك', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'أفلعامتك', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عامة'}],

 u'كذلكن': [{'vocalized': u'كذلكن', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'كذلكم': [{'vocalized': u'كذلكم', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'فكشهركما': [{'vocalized': u'فكشهركما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شهر'}],

 u'فأقلهما': [{'vocalized': u'فأقلهما', 'procletic': u'ف-', 'tags': u'اسم;اسم تفضيل;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أقل'}],

 u'ألتحته': [{'vocalized': u'ألتحته', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'ابنه': [{'vocalized': u'ابنه', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ابن'}],

 u'أولكأنما': [{'vocalized': u'أولكأنما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كأنما', 'encletic': u'', 'type': u'حرف', 'original': u'كأنما'}],

 u'وحواليك': [{'vocalized': u'وحواليك', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'حوالى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حوالى'}],

 u'ابنك': [{'vocalized': u'ابنك', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ابن'}],

 u'بغروبها': [{'vocalized': u'بغروبها', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غروب'}],

 u'وبمثلهما': [{'vocalized': u'وبمثلهما', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'بخلفهم': [{'vocalized': u'بخلفهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'بخلفهن': [{'vocalized': u'بخلفهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'ابني': [{'vocalized': u'ابني', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'},
 {'vocalized': u'ابني', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ابن'}],

 u'ولعنكن': [{'vocalized': u'ولعنكن', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'عن'}],

 u'حواليها': [{'vocalized': u'حواليها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حوالى'}],

 u'بغربنا': [{'vocalized': u'بغربنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'ولعنكم': [{'vocalized': u'ولعنكم', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'عن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'عن'}],

 u'فلذلكم': [{'vocalized': u'فلذلكم', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'فلذلكن': [{'vocalized': u'فلذلكن', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أفبها': [{'vocalized': u'أفبها', 'procletic': u'أ-ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'بها', 'encletic': u'', 'type': u'ضمير', 'original': u'بها'}],

 u'فبوقتها': [{'vocalized': u'فبوقتها', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'بغربها': [{'vocalized': u'بغربها', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'أوبغيري': [{'vocalized': u'أوبغيري', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أوبغيري', 'procletic': u'أ-و-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-ي', 'type': u'اسم', 'original': u'غير'}],

 u'وسويكن': [{'vocalized': u'وسويكن', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كن', 'type': u'اسم', 'original': u'سوى'}],

 u'وسويكم': [{'vocalized': u'وسويكم', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'سوى'}],

 u'لست': [{'vocalized': u'لست', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'لست', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'},
 {'vocalized': u'لست', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لست', 'encletic': u'', 'type': u'فعل', 'original': u'لست'}],

 u'بخلف': [{'vocalized': u'بخلف', 'procletic': u'ب-', 'tags': u'اسم;ظرف مكان;مجرور', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'أوذينك': [{'vocalized': u'أوذينك', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'أفلغيركم': [{'vocalized': u'أفلغيركم', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيركم', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أفلغيركن': [{'vocalized': u'أفلغيركن', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'أفلغيركن', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'لنحوكما': [{'vocalized': u'لنحوكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوكما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'فذويهما': [{'vocalized': u'فذويهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'فبغرب': [{'vocalized': u'فبغرب', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'غرب', 'encletic': u'', 'type': u'اسم', 'original': u'غرب'}],

 u'أوفوقك': [{'vocalized': u'أوفوقك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ك', 'type': u'اسم', 'original': u'فوق'}],

 u'أثناءهن': [{'vocalized': u'أثناءهن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'أثناءهم': [{'vocalized': u'أثناءهم', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'أوبحسبكما': [{'vocalized': u'أوبحسبكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'حسب'}],

 u'أولفوقهن': [{'vocalized': u'أولفوقهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هن', 'type': u'اسم', 'original': u'فوق'}],

 u'أولفوقهم': [{'vocalized': u'أولفوقهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-هم', 'type': u'اسم', 'original': u'فوق'}],

 u'أوثمة': [{'vocalized': u'أوثمة', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ثمة', 'encletic': u'', 'type': u'اسم', 'original': u'ثمة'}],

 u'فلكن': [{'vocalized': u'فلكن', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف', 'stem': u'لكن', 'encletic': u'', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكن', 'procletic': u'ف-', 'tags': u'حرف;حرف استدراك;عطف', 'stem': u'لكن', 'encletic': u'', 'type': u'حرف', 'original': u'لكن'},
 {'vocalized': u'فلكن', 'procletic': u'ف-', 'tags': u'ضمير;ضمير متصل مجرور;عطف', 'stem': u'لكن', 'encletic': u'', 'type': u'ضمير', 'original': u'لكن'}],

 u'فلكل': [{'vocalized': u'فلكل', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكل', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكل', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فلكل', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'أفجميعي': [{'vocalized': u'أفجميعي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعي', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعي', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'جميع'}],

 u'فبدون': [{'vocalized': u'فبدون', 'procletic': u'ف-', 'tags': u'اسم;ظرف;عطف', 'stem': u'بدون', 'encletic': u'', 'type': u'اسم', 'original': u'بدون'}],

 u'أفجميعك': [{'vocalized': u'أفجميعك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعك', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ك', 'type': u'اسم', 'original': u'جميع'}],

 u'فلكي': [{'vocalized': u'فلكي', 'procletic': u'ف-', 'tags': u'حرف;حرف تعليل;عطف', 'stem': u'لكي', 'encletic': u'', 'type': u'حرف', 'original': u'لكي'}],

 u'أفجميعه': [{'vocalized': u'أفجميعه', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفجميعه', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'جميع'}],

 u'أثناءها': [{'vocalized': u'أثناءها', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولحظتهما': [{'vocalized': u'ولحظتهما', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبخلفهن': [{'vocalized': u'وبخلفهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-هن', 'type': u'اسم', 'original': u'خلف'}],

 u'فماانفككنا': [{'vocalized': u'فماانفككنا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفككنا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفككنا'}],

 u'وكأينا': [{'vocalized': u'وكأينا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أي'}],

 u'أولفوقها': [{'vocalized': u'أولفوقها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'فوق', 'encletic': u'-ها', 'type': u'اسم', 'original': u'فوق'}],

 u'ففوقنا': [{'vocalized': u'ففوقنا', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'فوق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'فوق'}],

 u'فساءما': [{'vocalized': u'فساءما', 'procletic': u'ف-', 'tags': u'فعل;المدح والذم;عطف', 'stem': u'ساءما', 'encletic': u'', 'type': u'فعل', 'original': u'ساءما'}],

 u'أولوراءكما': [{'vocalized': u'أولوراءكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'حينكن': [{'vocalized': u'حينكن', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حين'}],

 u'حواليهن': [{'vocalized': u'حواليهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حوالى'}],

 u'حواليهم': [{'vocalized': u'حواليهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'حوالى', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حوالى'}],

 u'أفكهناك': [{'vocalized': u'أفكهناك', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'أفبهن': [{'vocalized': u'أفبهن', 'procletic': u'أ-ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أفبهو': [{'vocalized': u'أفبهو', 'procletic': u'أ-ف-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;عطف;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'ألإنكن': [{'vocalized': u'ألإنكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'ألإنكم': [{'vocalized': u'ألإنكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'فإذما': [{'vocalized': u'فإذما', 'procletic': u'ف-', 'tags': u'حرف;حرف شرط;عطف', 'stem': u'إذما', 'encletic': u'', 'type': u'حرف', 'original': u'إذما'}],

 u'ألأجمعكن': [{'vocalized': u'ألأجمعكن', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعكن', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ألأجمعكم': [{'vocalized': u'ألأجمعكم', 'procletic': u'أ-ل-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ألأجمعكم', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أجمع'}],

 u'عامتهما': [{'vocalized': u'عامتهما', 'procletic': u'', 'tags': u'اسم;توكيد;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'فلنفسكم': [{'vocalized': u'فلنفسكم', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسكم', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'وعامتكما': [{'vocalized': u'وعامتكما', 'procletic': u'و-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'فلنفسكن': [{'vocalized': u'فلنفسكن', 'procletic': u'ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'فلنفسكن', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'لسن': [{'vocalized': u'لسن', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'لسن', 'encletic': u'', 'type': u'فعل', 'original': u'لسن'}],

 u'فلعله': [{'vocalized': u'فلعله', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ه', 'type': u'حرف', 'original': u'لعل'}],

 u'ومادمت': [{'vocalized': u'ومادمت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'},
 {'vocalized': u'ومادمت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'},
 {'vocalized': u'ومادمت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمت', 'encletic': u'', 'type': u'فعل', 'original': u'مادمت'}],

 u'بأخيكما': [{'vocalized': u'بأخيكما', 'procletic': u'ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;ضمير', 'stem': u'أخي', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أخي'}],

 u'فلعلك': [{'vocalized': u'فلعلك', 'procletic': u'ف-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'لعل', 'encletic': u'-ك', 'type': u'حرف', 'original': u'لعل'}],

 u'أولمنكم': [{'vocalized': u'أولمنكم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'من', 'encletic': u'-كم', 'type': u'حرف', 'original': u'من'}],

 u'فبعضكم': [{'vocalized': u'فبعضكم', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كم', 'type': u'اسم', 'original': u'بعض'}],

 u'أذلكن': [{'vocalized': u'أذلكن', 'procletic': u'أ-', 'tags': u'اسم;اسم إشارة;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أفمع': [{'vocalized': u'أفمع', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إضافة;عطف;استفهام', 'stem': u'مع', 'encletic': u'', 'type': u'اسم', 'original': u'مع'}],

 u'فبعضكن': [{'vocalized': u'فبعضكن', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كن', 'type': u'اسم', 'original': u'بعض'}],

 u'ألسوينا': [{'vocalized': u'ألسوينا', 'procletic': u'أ-ل-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'وبحسبكم': [{'vocalized': u'وبحسبكم', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفإليهم': [{'vocalized': u'أفإليهم', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هم', 'type': u'حرف', 'original': u'إلى'}],

 u'أوتحتكما': [{'vocalized': u'أوتحتكما', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'وإزاء': [{'vocalized': u'وإزاء', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'إزاء', 'encletic': u'', 'type': u'اسم', 'original': u'إزاء'}],

 u'وبليلهم': [{'vocalized': u'وبليلهم', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ليل'}],

 u'وبليلهن': [{'vocalized': u'وبليلهن', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ليل'}],

 u'لعني': [{'vocalized': u'لعني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'},
 {'vocalized': u'لعني', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'عن', 'encletic': u'-ي', 'type': u'حرف', 'original': u'عن'}],

 u'أبضعه': [{'vocalized': u'أبضعه', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-ه', 'type': u'اسم', 'original': u'بضع'}],

 u'أفإليهن': [{'vocalized': u'أفإليهن', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-هن', 'type': u'حرف', 'original': u'إلى'}],

 u'بغروبهم': [{'vocalized': u'بغروبهم', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غروب'}],

 u'وأنتم': [{'vocalized': u'وأنتم', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنتم', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتم'}],

 u'وأنتن': [{'vocalized': u'وأنتن', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل;عطف', 'stem': u'أنتن', 'encletic': u'', 'type': u'ضمير', 'original': u'أنتن'}],

 u'ولليلنا': [{'vocalized': u'ولليلنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ليل'}],

 u'لأجمعهن': [{'vocalized': u'لأجمعهن', 'procletic': u'ل-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'لأجمعهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أجمع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولتي': [{'vocalized': u'ولتي', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'لغيرها': [{'vocalized': u'لغيرها', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيرها', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'تحتنا': [{'vocalized': u'تحتنا', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'ولته': [{'vocalized': u'ولته', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'ولنفسكما': [{'vocalized': u'ولنفسكما', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'ولنفسكما', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'نفس', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نفس'}],

 u'أولهناك': [{'vocalized': u'أولهناك', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هناك', 'encletic': u'', 'type': u'اسم', 'original': u'هناك'}],

 u'ألغير': [{'vocalized': u'ألغير', 'procletic': u'أ-ل-', 'tags': u'اسم;استثناء;مجرور;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'ألغير', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'لغروبنا': [{'vocalized': u'لغروبنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غروب'}],

 u'وجنب': [{'vocalized': u'وجنب', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'جنب', 'encletic': u'', 'type': u'اسم', 'original': u'جنب'}],

 u'لغيرهن': [{'vocalized': u'لغيرهن', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيرهن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'لغيرهم': [{'vocalized': u'لغيرهم', 'procletic': u'ل-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'},
 {'vocalized': u'لغيرهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'ومنكما': [{'vocalized': u'ومنكما', 'procletic': u'و-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'كتي': [{'vocalized': u'كتي', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تي', 'encletic': u'', 'type': u'اسم', 'original': u'تي'}],

 u'كخلفهم': [{'vocalized': u'كخلفهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'خلف', 'encletic': u'-هم', 'type': u'اسم', 'original': u'خلف'}],

 u'وقتي': [{'vocalized': u'وقتي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'},
 {'vocalized': u'وقتي', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'وقت'}],

 u'فبأن': [{'vocalized': u'فبأن', 'procletic': u'ف-ب-', 'tags': u'حرف;إن و أخواتها;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'},
 {'vocalized': u'فبأن', 'procletic': u'ف-ب-', 'tags': u'حرف;حرف نصب;مجرور;عطف', 'stem': u'أن', 'encletic': u'', 'type': u'حرف', 'original': u'أن'}],

 u'أونحوكم': [{'vocalized': u'أونحوكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إضافة;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أبمثلكم': [{'vocalized': u'أبمثلكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'أبمثلكن': [{'vocalized': u'أبمثلكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'كته': [{'vocalized': u'كته', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'ته', 'encletic': u'', 'type': u'اسم', 'original': u'ته'}],

 u'فمعاذهما': [{'vocalized': u'فمعاذهما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'معاذ', 'encletic': u'-هما', 'type': u'اسم', 'original': u'معاذ'}],

 u'وبأسفلها': [{'vocalized': u'وبأسفلها', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أسفل'}],

 u'فأبوه': [{'vocalized': u'فأبوه', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبو'}],

 u'أوكمثلنا': [{'vocalized': u'أوكمثلنا', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مثل'}],

 u'فأبوك': [{'vocalized': u'فأبوك', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبو'}],

 u'أولعليك': [{'vocalized': u'أولعليك', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ك', 'type': u'حرف', 'original': u'على'}],

 u'أخلفكم': [{'vocalized': u'أخلفكم', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-كم', 'type': u'اسم', 'original': u'خلف'}],

 u'أولعليه': [{'vocalized': u'أولعليه', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ه', 'type': u'حرف', 'original': u'على'}],

 u'فأبوي': [{'vocalized': u'فأبوي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبو'},
 {'vocalized': u'فأبوي', 'procletic': u'ف-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أبو', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبو'}],

 u'فذاتنا': [{'vocalized': u'فذاتنا', 'procletic': u'ف-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذات'}],

 u'غربهم': [{'vocalized': u'غربهم', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غرب'}],

 u'غربهن': [{'vocalized': u'غربهن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غرب'}],

 u'كذويهما': [{'vocalized': u'كذويهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إشارة;مجرور;ضمير', 'stem': u'ذوي', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ذوي'}],

 u'لمثل': [{'vocalized': u'لمثل', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'لمثل', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'الآن': [{'vocalized': u'الآن', 'procletic': u'', 'tags': u'اسم;ظرف زمان', 'stem': u'الآن', 'encletic': u'', 'type': u'اسم', 'original': u'الآن'}],

 u'أجميعهن': [{'vocalized': u'أجميعهن', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أجميعهن', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'جميع'}],

 u'ولأيهم': [{'vocalized': u'ولأيهم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أي'}],

 u'ولأيهن': [{'vocalized': u'ولأيهن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أي'}],

 u'لتانك': [{'vocalized': u'لتانك', 'procletic': u'ل-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'تانك', 'encletic': u'', 'type': u'اسم', 'original': u'تانك'}],

 u'ولكلنا': [{'vocalized': u'ولكلنا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلنا', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'ولكلنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'لأيتكما': [{'vocalized': u'لأيتكما', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أية'}],

 u'وساعتهم': [{'vocalized': u'وساعتهم', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هم', 'type': u'اسم', 'original': u'ساعة'}],

 u'ولأخيها': [{'vocalized': u'ولأخيها', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أخي'}],

 u'وساعتهن': [{'vocalized': u'وساعتهن', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-هن', 'type': u'اسم', 'original': u'ساعة'}],

 u'حينه': [{'vocalized': u'حينه', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حين'}],

 u'كنفسهما': [{'vocalized': u'كنفسهما', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'نفس', 'encletic': u'-هما', 'type': u'اسم', 'original': u'نفس'}],

 u'فخلال': [{'vocalized': u'فخلال', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان/مكان;عطف', 'stem': u'خلال', 'encletic': u'', 'type': u'اسم', 'original': u'خلال'}],

 u'أوكتلكما': [{'vocalized': u'أوكتلكما', 'procletic': u'أ-و-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'ولابننا': [{'vocalized': u'ولابننا', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'وكعامتها': [{'vocalized': u'وكعامتها', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عامة'}],

 u'ليس': [{'vocalized': u'ليس', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'ليس', 'encletic': u'', 'type': u'فعل', 'original': u'ليس'}],

 u'ولأخيهم': [{'vocalized': u'ولأخيهم', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أخي'}],

 u'وغدا': [{'vocalized': u'وغدا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف', 'stem': u'غدا', 'encletic': u'', 'type': u'اسم', 'original': u'غدا'},
 {'vocalized': u'وغدا', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'غدا', 'encletic': u'', 'type': u'فعل', 'original': u'غدا'}],

 u'وساعتها': [{'vocalized': u'وساعتها', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ها', 'type': u'اسم', 'original': u'ساعة'}],

 u'ولأخيهن': [{'vocalized': u'ولأخيهن', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أخي'}],

 u'فكغير': [{'vocalized': u'فكغير', 'procletic': u'ف-ك-', 'tags': u'اسم;استثناء;مجرور;عطف', 'stem': u'غير', 'encletic': u'', 'type': u'اسم', 'original': u'غير'}],

 u'وإياكن': [{'vocalized': u'وإياكن', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياكن', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكن'}],

 u'وإياكم': [{'vocalized': u'وإياكم', 'procletic': u'و-', 'tags': u'ضمير;ضمير منفصل منصوب;عطف', 'stem': u'إياكم', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكم'}],

 u'لفوقكن': [{'vocalized': u'لفوقكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'فوق', 'encletic': u'-كن', 'type': u'اسم', 'original': u'فوق'}],

 u'فكأولالك': [{'vocalized': u'فكأولالك', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'أولالك', 'encletic': u'', 'type': u'اسم', 'original': u'أولالك'}],

 u'وأخاي': [{'vocalized': u'وأخاي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخا'},
 {'vocalized': u'وأخاي', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أخا'}],

 u'فكأقلكن': [{'vocalized': u'فكأقلكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'فكأقلكم': [{'vocalized': u'فكأقلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'أوبكل': [{'vocalized': u'أوبكل', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكل', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كل', 'encletic': u'', 'type': u'اسم', 'original': u'كل'}],

 u'لأقلكن': [{'vocalized': u'لأقلكن', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أقل'}],

 u'بعينكن': [{'vocalized': u'بعينكن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عين'}],

 u'غربها': [{'vocalized': u'غربها', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'غرب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غرب'}],

 u'لأقلكم': [{'vocalized': u'لأقلكم', 'procletic': u'ل-', 'tags': u'اسم;اسم تفضيل;مجرور;ضمير', 'stem': u'أقل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أقل'}],

 u'وأخاه': [{'vocalized': u'وأخاه', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أخا'}],

 u'فعامتهما': [{'vocalized': u'فعامتهما', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'أسفلكن': [{'vocalized': u'أسفلكن', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'أسفل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أسفل'}],

 u'وعوض': [{'vocalized': u'وعوض', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف', 'stem': u'عوض', 'encletic': u'', 'type': u'اسم', 'original': u'عوض'}],

 u'فهكذا': [{'vocalized': u'فهكذا', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'هكذا', 'encletic': u'', 'type': u'اسم', 'original': u'هكذا'}],

 u'وبذوي': [{'vocalized': u'وبذوي', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذوي', 'encletic': u'', 'type': u'اسم', 'original': u'ذوي'}],

 u'أولتلكما': [{'vocalized': u'أولتلكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'تلكما', 'encletic': u'', 'type': u'اسم', 'original': u'تلكما'}],

 u'فتحتكما': [{'vocalized': u'فتحتكما', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-كما', 'type': u'اسم', 'original': u'تحت'}],

 u'وكلحظتنا': [{'vocalized': u'وكلحظتنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'لحظة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'لحظة'}],

 u'ولأيها': [{'vocalized': u'ولأيها', 'procletic': u'و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أي', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أي'}],

 u'ولتحتنا': [{'vocalized': u'ولتحتنا', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'تحت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'تحت'}],

 u'فككلنا': [{'vocalized': u'فككلنا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'فككلنا', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'أوبعامتكما': [{'vocalized': u'أوبعامتكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'فإذن': [{'vocalized': u'فإذن', 'procletic': u'ف-', 'tags': u'حرف;حرف جواب;عطف', 'stem': u'إذن', 'encletic': u'', 'type': u'حرف', 'original': u'إذن'}],

 u'كزمانهما': [{'vocalized': u'كزمانهما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'كحسبهما': [{'vocalized': u'كحسبهما', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'حسب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حسب'}],

 u'كالذين': [{'vocalized': u'كالذين', 'procletic': u'ك-', 'tags': u'اسم;اسم موصول;مجرور', 'stem': u'الذين', 'encletic': u'', 'type': u'اسم', 'original': u'الذين'}],

 u'أفإنكن': [{'vocalized': u'أفإنكن', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'وكحسبهن': [{'vocalized': u'وكحسبهن', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'حسب'}],

 u'وكحسبهم': [{'vocalized': u'وكحسبهم', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-هم', 'type': u'اسم', 'original': u'حسب'}],

 u'أفإنكم': [{'vocalized': u'أفإنكم', 'procletic': u'أ-ف-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'فلانقلب': [{'vocalized': u'فلانقلب', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'انقلب', 'encletic': u'', 'type': u'فعل', 'original': u'انقلب'}],

 u'وكمثل': [{'vocalized': u'وكمثل', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'مثل', 'encletic': u'', 'type': u'اسم', 'original': u'مثل'}],

 u'وكأثناءهم': [{'vocalized': u'وكأثناءهم', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هم', 'type': u'اسم', 'original': u'أثناء'}],

 u'حينهما': [{'vocalized': u'حينهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'حين', 'encletic': u'-هما', 'type': u'اسم', 'original': u'حين'}],

 u'وكأثناءهن': [{'vocalized': u'وكأثناءهن', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-هن', 'type': u'اسم', 'original': u'أثناء'}],

 u'وذواتي': [{'vocalized': u'وذواتي', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'فبليلكما': [{'vocalized': u'فبليلكما', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ليل'}],

 u'فكحسب': [{'vocalized': u'فكحسب', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'حسب', 'encletic': u'', 'type': u'اسم', 'original': u'حسب'}],

 u'أوعيننا': [{'vocalized': u'أوعيننا', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'لمعكن': [{'vocalized': u'لمعكن', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مع'}],

 u'عل': [{'vocalized': u'عل', 'procletic': u'', 'tags': u'حرف;إن و أخواتها', 'stem': u'عل', 'encletic': u'', 'type': u'حرف', 'original': u'عل'}],

 u'لمعكم': [{'vocalized': u'لمعكم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'مع', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مع'}],

 u'ووقتنا': [{'vocalized': u'ووقتنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-نا', 'type': u'اسم', 'original': u'وقت'}],

 u'لليلكم': [{'vocalized': u'لليلكم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ليل'}],

 u'أكشبه': [{'vocalized': u'أكشبه', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام', 'stem': u'شبه', 'encletic': u'', 'type': u'اسم', 'original': u'شبه'}],

 u'فليلهما': [{'vocalized': u'فليلهما', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ليل'}],

 u'وبشرقنا': [{'vocalized': u'وبشرقنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شرق'}],

 u'وبأجمعنا': [{'vocalized': u'وبأجمعنا', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أجمع'}],

 u'وذواتا': [{'vocalized': u'وذواتا', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذواتا', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتا'}],

 u'أفتحتكم': [{'vocalized': u'أفتحتكم', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-كم', 'type': u'اسم', 'original': u'تحت'}],

 u'وبساعته': [{'vocalized': u'وبساعته', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'فأمام': [{'vocalized': u'فأمام', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف', 'stem': u'أمام', 'encletic': u'', 'type': u'اسم', 'original': u'أمام'}],

 u'فلزمانها': [{'vocalized': u'فلزمانها', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-ها', 'type': u'اسم', 'original': u'زمان'}],

 u'إياكما': [{'vocalized': u'إياكما', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إياكما', 'encletic': u'', 'type': u'ضمير', 'original': u'إياكما'}],

 u'ألعليها': [{'vocalized': u'ألعليها', 'procletic': u'أ-ل-', 'tags': u';قسم;استفهام;ضمير', 'stem': u'على', 'encletic': u'-ها', 'type': u'حرف', 'original': u'على'}],

 u'فتجاهه': [{'vocalized': u'فتجاهه', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تجاه'}],

 u'ولذاتكم': [{'vocalized': u'ولذاتكم', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كم', 'type': u'اسم', 'original': u'ذات'}],

 u'فإذا': [{'vocalized': u'فإذا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف', 'stem': u'إذا', 'encletic': u'', 'type': u'اسم', 'original': u'إذا'},
 {'vocalized': u'فإذا', 'procletic': u'ف-', 'tags': u'حرف;اسم شرط;عطف', 'stem': u'إذا', 'encletic': u'', 'type': u'حرف', 'original': u'إذا'}],

 u'فتجاهك': [{'vocalized': u'فتجاهك', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تجاه'}],

 u'ولذاتكن': [{'vocalized': u'ولذاتكن', 'procletic': u'و-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-كن', 'type': u'اسم', 'original': u'ذات'}],

 u'ضمنهما': [{'vocalized': u'ضمنهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'ضمن', 'encletic': u'-هما', 'type': u'اسم', 'original': u'ضمن'}],

 u'فتجاهي': [{'vocalized': u'فتجاهي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تجاه'},
 {'vocalized': u'فتجاهي', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'تجاه', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تجاه'}],

 u'وكحسبها': [{'vocalized': u'وكحسبها', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ها', 'type': u'اسم', 'original': u'حسب'}],

 u'فعيني': [{'vocalized': u'فعيني', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'},
 {'vocalized': u'فعيني', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ي', 'type': u'اسم', 'original': u'عين'}],

 u'أفلهاذين': [{'vocalized': u'أفلهاذين', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;استفهام', 'stem': u'هاذين', 'encletic': u'', 'type': u'اسم', 'original': u'هاذين'}],

 u'فلخلفنا': [{'vocalized': u'فلخلفنا', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'},
 {'vocalized': u'فلخلفنا', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-نا', 'type': u'اسم', 'original': u'خلف'}],

 u'لزمانهما': [{'vocalized': u'لزمانهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'زمان', 'encletic': u'-هما', 'type': u'اسم', 'original': u'زمان'}],

 u'بابنكما': [{'vocalized': u'بابنكما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'فعينك': [{'vocalized': u'فعينك', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ك', 'type': u'اسم', 'original': u'عين'}],

 u'أونفسكن': [{'vocalized': u'أونفسكن', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نفس'}],

 u'أونفسكم': [{'vocalized': u'أونفسكم', 'procletic': u'أ-و-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نفس'}],

 u'فعينه': [{'vocalized': u'فعينه', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'عين', 'encletic': u'-ه', 'type': u'اسم', 'original': u'عين'}],

 u'أفإلينا': [{'vocalized': u'أفإلينا', 'procletic': u'أ-ف-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'إلى', 'encletic': u'-نا', 'type': u'حرف', 'original': u'إلى'}],

 u'وكأثناءها': [{'vocalized': u'وكأثناءها', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ها', 'type': u'اسم', 'original': u'أثناء'}],

 u'أفأجمعهما': [{'vocalized': u'أفأجمعهما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أجمع'}],

 u'ولعامة': [{'vocalized': u'ولعامة', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'},
 {'vocalized': u'ولعامة', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'عامة', 'encletic': u'', 'type': u'اسم', 'original': u'عامة'}],

 u'أنفسك': [{'vocalized': u'أنفسك', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ك', 'type': u'اسم', 'original': u'نفس'}],

 u'وليمين': [{'vocalized': u'وليمين', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'يمين', 'encletic': u'', 'type': u'اسم', 'original': u'يمين'}],

 u'أنفسه': [{'vocalized': u'أنفسه', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ه', 'type': u'اسم', 'original': u'نفس'}],

 u'فكعامتكما': [{'vocalized': u'فكعامتكما', 'procletic': u'ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عامة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عامة'}],

 u'أنفسي': [{'vocalized': u'أنفسي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'},
 {'vocalized': u'أنفسي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'نفس', 'encletic': u'-ي', 'type': u'اسم', 'original': u'نفس'}],

 u'ولأعليكم': [{'vocalized': u'ولأعليكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أعلى'}],

 u'لشمالكما': [{'vocalized': u'لشمالكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'شمال', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شمال'}],

 u'وسرعان': [{'vocalized': u'وسرعان', 'procletic': u'و-', 'tags': u'اسم فعل;اسم فعل;عطف', 'stem': u'سرعان', 'encletic': u'', 'type': u'اسم فعل', 'original': u'سرعان'}],

 u'أوتلكم': [{'vocalized': u'أوتلكم', 'procletic': u'أ-و-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'تلكم', 'encletic': u'', 'type': u'اسم', 'original': u'تلكم'}],

 u'فيم': [{'vocalized': u'فيم', 'procletic': u'', 'tags': u'حرف;حرف استفهام', 'stem': u'فيم', 'encletic': u'', 'type': u'حرف', 'original': u'فيم'}],

 u'كجميعنا': [{'vocalized': u'كجميعنا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'كجميعنا', 'procletic': u'ك-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'ولا': [{'vocalized': u'ولا', 'procletic': u'و-', 'tags': u'حرف;المشبهة بليس;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'ولا', 'procletic': u'و-', 'tags': u'حرف;نافية للجنس;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'ولا', 'procletic': u'و-', 'tags': u'حرف;ناهية;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'ولا', 'procletic': u'و-', 'tags': u'حرف;نافية;عطف', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'}],

 u'بهاتي': [{'vocalized': u'بهاتي', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاتي', 'encletic': u'', 'type': u'اسم', 'original': u'هاتي'}],

 u'أليسوا': [{'vocalized': u'أليسوا', 'procletic': u'أ-', 'tags': u'فعل;كان و أخواتها;استفهام', 'stem': u'ليسوا', 'encletic': u'', 'type': u'فعل', 'original': u'ليسوا'}],

 u'ولأجمعي': [{'vocalized': u'ولأجمعي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعي', 'procletic': u'و-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'ولأجمعي', 'procletic': u'و-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أجمع', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أجمع'}],

 u'وحميكن': [{'vocalized': u'وحميكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'بهاته': [{'vocalized': u'بهاته', 'procletic': u'ب-', 'tags': u'اسم;اسم إشارة;مجرور', 'stem': u'هاته', 'encletic': u'', 'type': u'اسم', 'original': u'هاته'}],

 u'مثلكم': [{'vocalized': u'مثلكم', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'مثلكن': [{'vocalized': u'مثلكن', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'أوبمثله': [{'vocalized': u'أوبمثله', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'مثل'}],

 u'وبجميع': [{'vocalized': u'وبجميع', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'وبجميع', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'جميع', 'encletic': u'', 'type': u'اسم', 'original': u'جميع'}],

 u'بساعتنا': [{'vocalized': u'بساعتنا', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ساعة'}],

 u'أوبمثلك': [{'vocalized': u'أوبمثلك', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'مثل'}],

 u'ولجنوبكم': [{'vocalized': u'ولجنوبكم', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنوب', 'encletic': u'-كم', 'type': u'اسم', 'original': u'جنوب'}],

 u'لنحوها': [{'vocalized': u'لنحوها', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوها', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'أوبمثلي': [{'vocalized': u'أوبمثلي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'},
 {'vocalized': u'أوبمثلي', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'مثل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'مثل'}],

 u'فكشرق': [{'vocalized': u'فكشرق', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'شرق', 'encletic': u'', 'type': u'اسم', 'original': u'شرق'}],

 u'وكأسفل': [{'vocalized': u'وكأسفل', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'وبهاتين': [{'vocalized': u'وبهاتين', 'procletic': u'و-ب-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هاتين', 'encletic': u'', 'type': u'اسم', 'original': u'هاتين'}],

 u'ليمينهم': [{'vocalized': u'ليمينهم', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'يمين', 'encletic': u'-هم', 'type': u'اسم', 'original': u'يمين'}],

 u'وأخيكم': [{'vocalized': u'وأخيكم', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أخي'}],

 u'وأخيكن': [{'vocalized': u'وأخيكن', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أخي'}],

 u'أولأمامنا': [{'vocalized': u'أولأمامنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أمام', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أمام'}],

 u'فيه': [{'vocalized': u'فيه', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فيه', 'procletic': u'', 'tags': u'حرف;حرف جر;ضمير', 'stem': u'في', 'encletic': u'-ه', 'type': u'حرف', 'original': u'في'}],

 u'أبعينها': [{'vocalized': u'أبعينها', 'procletic': u'أ-ب-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-ها', 'type': u'اسم', 'original': u'عين'}],

 u'لنحوهن': [{'vocalized': u'لنحوهن', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'لنحوهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'أسوى': [{'vocalized': u'أسوى', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام', 'stem': u'سوى', 'encletic': u'', 'type': u'اسم', 'original': u'سوى'}],

 u'وبجنبكما': [{'vocalized': u'وبجنبكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-كما', 'type': u'اسم', 'original': u'جنب'}],

 u'أوفينا': [{'vocalized': u'أوفينا', 'procletic': u'أ-و-', 'tags': u'حرف;حرف جر;عطف;استفهام;ضمير', 'stem': u'في', 'encletic': u'-نا', 'type': u'حرف', 'original': u'في'}],

 u'أبذلكن': [{'vocalized': u'أبذلكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكن', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكن'}],

 u'أوإنكن': [{'vocalized': u'أوإنكن', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كن', 'type': u'حرف', 'original': u'إن'}],

 u'أوإنكم': [{'vocalized': u'أوإنكم', 'procletic': u'أ-و-', 'tags': u'حرف;إن و أخواتها;عطف;استفهام;ضمير', 'stem': u'إن', 'encletic': u'-كم', 'type': u'حرف', 'original': u'إن'}],

 u'أبذلكم': [{'vocalized': u'أبذلكم', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إشارة;مجرور;استفهام', 'stem': u'ذلكم', 'encletic': u'', 'type': u'اسم', 'original': u'ذلكم'}],

 u'أوبكلنا': [{'vocalized': u'أوبكلنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أوبكلنا', 'procletic': u'أ-و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'كل'}],

 u'وأنكما': [{'vocalized': u'وأنكما', 'procletic': u'و-', 'tags': u'حرف;إن و أخواتها;عطف;ضمير', 'stem': u'أن', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أن'}],

 u'فكجنبهما': [{'vocalized': u'فكجنبهما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'جنب', 'encletic': u'-هما', 'type': u'اسم', 'original': u'جنب'}],

 u'أفكجميعنا': [{'vocalized': u'أفكجميعنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'أفكجميعنا', 'procletic': u'أ-ف-ك-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'وبلحظة': [{'vocalized': u'وبلحظة', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف', 'stem': u'لحظة', 'encletic': u'', 'type': u'اسم', 'original': u'لحظة'}],

 u'وبعدنا': [{'vocalized': u'وبعدنا', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'بعد', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بعد'}],

 u'وكليكما': [{'vocalized': u'وكليكما', 'procletic': u'و-', 'tags': u'حرف;توكيد;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'أولمعها': [{'vocalized': u'أولمعها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-ها', 'type': u'اسم', 'original': u'مع'}],

 u'وتين': [{'vocalized': u'وتين', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تين', 'encletic': u'', 'type': u'اسم', 'original': u'تين'}],

 u'أعيننا': [{'vocalized': u'أعيننا', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-نا', 'type': u'اسم', 'original': u'عين'}],

 u'ألا': [{'vocalized': u'ألا', 'procletic': u'أ-', 'tags': u'حرف;المشبهة بليس;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'ألا', 'procletic': u'', 'tags': u'حرف;حرف عرض', 'stem': u'ألا', 'encletic': u'', 'type': u'حرف', 'original': u'ألا'},
 {'vocalized': u'ألا', 'procletic': u'أ-', 'tags': u'حرف;نافية للجنس;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'ألا', 'procletic': u'أ-', 'tags': u'حرف;ناهية;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'},
 {'vocalized': u'ألا', 'procletic': u'أ-', 'tags': u'حرف;نافية;استفهام', 'stem': u'لا', 'encletic': u'', 'type': u'حرف', 'original': u'لا'}],

 u'فماانفكوا': [{'vocalized': u'فماانفكوا', 'procletic': u'ف-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'ماانفكوا', 'encletic': u'', 'type': u'فعل', 'original': u'ماانفكوا'}],

 u'فشهرها': [{'vocalized': u'فشهرها', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شهر'}],

 u'فأقبل': [{'vocalized': u'فأقبل', 'procletic': u'ف-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'أقبل', 'encletic': u'', 'type': u'فعل', 'original': u'أقبل'}],

 u'بهي': [{'vocalized': u'بهي', 'procletic': u'ب-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'بهو': [{'vocalized': u'بهو', 'procletic': u'ب-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'بهن': [{'vocalized': u'بهن', 'procletic': u'ب-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'أككلها': [{'vocalized': u'أككلها', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلها', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ها', 'type': u'اسم', 'original': u'كل'}],

 u'كنحوها': [{'vocalized': u'كنحوها', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوها', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-ها', 'type': u'اسم', 'original': u'نحو'}],

 u'فلشرع': [{'vocalized': u'فلشرع', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'شرع', 'encletic': u'', 'type': u'فعل', 'original': u'شرع'}],

 u'بمثلهما': [{'vocalized': u'بمثلهما', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'مثل', 'encletic': u'-هما', 'type': u'اسم', 'original': u'مثل'}],

 u'ألم': [{'vocalized': u'ألم', 'procletic': u'أ-', 'tags': u'حرف;حرف جزم;استفهام', 'stem': u'لم', 'encletic': u'', 'type': u'حرف', 'original': u'لم'}],

 u'ألن': [{'vocalized': u'ألن', 'procletic': u'أ-', 'tags': u'حرف;الحروف(حروف);استفهام', 'stem': u'لن', 'encletic': u'', 'type': u'حرف', 'original': u'لن'}],

 u'ولأبيي': [{'vocalized': u'ولأبيي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'ولأبيي', 'procletic': u'و-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'أكعينكما': [{'vocalized': u'أكعينكما', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'فشهرهن': [{'vocalized': u'فشهرهن', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-هن', 'type': u'اسم', 'original': u'شهر'}],

 u'ألك': [{'vocalized': u'ألك', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'لك', 'encletic': u'', 'type': u'ضمير', 'original': u'لك'}],

 u'فلأناهما': [{'vocalized': u'فلأناهما', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف;ضمير', 'stem': u'أنا', 'encletic': u'-هما', 'type': u'حرف', 'original': u'أنا'}],

 u'كليله': [{'vocalized': u'كليله', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'ألو': [{'vocalized': u'ألو', 'procletic': u'أ-', 'tags': u'حرف;الحروف(حروف);استفهام', 'stem': u'لو', 'encletic': u'', 'type': u'حرف', 'original': u'لو'}],

 u'ألي': [{'vocalized': u'ألي', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'لي', 'encletic': u'', 'type': u'ضمير', 'original': u'لي'}],

 u'كليلك': [{'vocalized': u'كليلك', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'فذلك': [{'vocalized': u'فذلك', 'procletic': u'ف-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'ذلك', 'encletic': u'', 'type': u'اسم', 'original': u'ذلك'}],

 u'أخلفه': [{'vocalized': u'أخلفه', 'procletic': u'أ-', 'tags': u'اسم;ظرف مكان;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-ه', 'type': u'اسم', 'original': u'خلف'}],

 u'فبفيكما': [{'vocalized': u'فبفيكما', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'في', 'encletic': u'-كما', 'type': u'اسم', 'original': u'في'}],

 u'أككلهم': [{'vocalized': u'أككلهم', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلهم', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هم', 'type': u'اسم', 'original': u'كل'}],

 u'أككلهن': [{'vocalized': u'أككلهن', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أككلهن', 'procletic': u'أ-ك-', 'tags': u'اسم;توكيد;مجرور;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-هن', 'type': u'اسم', 'original': u'كل'}],

 u'كنحوهن': [{'vocalized': u'كنحوهن', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هن', 'type': u'اسم', 'original': u'نحو'}],

 u'كنحوهم': [{'vocalized': u'كنحوهم', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'},
 {'vocalized': u'كنحوهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'نحو', 'encletic': u'-هم', 'type': u'اسم', 'original': u'نحو'}],

 u'وبدونهن': [{'vocalized': u'وبدونهن', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-هن', 'type': u'اسم', 'original': u'بدون'}],

 u'وبدونهم': [{'vocalized': u'وبدونهم', 'procletic': u'و-', 'tags': u'اسم;ظرف;عطف;ضمير', 'stem': u'بدون', 'encletic': u'-هم', 'type': u'اسم', 'original': u'بدون'}],

 u'لأعليهما': [{'vocalized': u'لأعليهما', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أعلى', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أعلى'}],

 u'وبأسفلنا': [{'vocalized': u'وبأسفلنا', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'أولمعهن': [{'vocalized': u'أولمعهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هن', 'type': u'اسم', 'original': u'مع'}],

 u'أولمعهم': [{'vocalized': u'أولمعهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-هم', 'type': u'اسم', 'original': u'مع'}],

 u'أولكما': [{'vocalized': u'أولكما', 'procletic': u'أ-و-', 'tags': u'ضمير;ضمير متصل مجرور;عطف;استفهام', 'stem': u'لكما', 'encletic': u'', 'type': u'ضمير', 'original': u'لكما'}],

 u'فساعته': [{'vocalized': u'فساعته', 'procletic': u'ف-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ساعة', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ساعة'}],

 u'والألاء': [{'vocalized': u'والألاء', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف', 'stem': u'الألاء', 'encletic': u'', 'type': u'اسم', 'original': u'الألاء'}],

 u'فلعاد': [{'vocalized': u'فلعاد', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'عاد', 'encletic': u'', 'type': u'فعل', 'original': u'عاد'}],

 u'بهما': [{'vocalized': u'بهما', 'procletic': u'ب-', 'tags': u'ضمير;ضمير منفصل;مجرور', 'stem': u'هما', 'encletic': u'', 'type': u'ضمير', 'original': u'هما'}],

 u'فلحسبي': [{'vocalized': u'فلحسبي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'},
 {'vocalized': u'فلحسبي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ي', 'type': u'اسم', 'original': u'حسب'}],

 u'عداهم': [{'vocalized': u'عداهم', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-هم', 'type': u'فعل', 'original': u'عدا'}],

 u'أولكأنهم': [{'vocalized': u'أولكأنهم', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هم', 'type': u'حرف', 'original': u'كأن'}],

 u'أولكأنهن': [{'vocalized': u'أولكأنهن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-هن', 'type': u'حرف', 'original': u'كأن'}],

 u'وليله': [{'vocalized': u'وليله', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ليل'}],

 u'فكاللتين': [{'vocalized': u'فكاللتين', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتين', 'encletic': u'', 'type': u'اسم', 'original': u'اللتين'}],

 u'وليلك': [{'vocalized': u'وليلك', 'procletic': u'و-', 'tags': u'اسم;ظرف زمان;عطف;ضمير', 'stem': u'ليل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ليل'}],

 u'كأسفلكما': [{'vocalized': u'كأسفلكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'أسفل', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أسفل'}],

 u'أكلي': [{'vocalized': u'أكلي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلي', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلي', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ي', 'type': u'اسم', 'original': u'كل'}],

 u'أكشبهنا': [{'vocalized': u'أكشبهنا', 'procletic': u'أ-ك-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شبه'}],

 u'ولتحول': [{'vocalized': u'ولتحول', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'تحول', 'encletic': u'', 'type': u'فعل', 'original': u'تحول'}],

 u'وذاته': [{'vocalized': u'وذاته', 'procletic': u'و-', 'tags': u'اسم;اسم موصول;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'أناهن': [{'vocalized': u'أناهن', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-هن', 'type': u'حرف', 'original': u'أنا'}],

 u'أكلك': [{'vocalized': u'أكلك', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكلك', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ك', 'type': u'اسم', 'original': u'كل'}],

 u'كسويه': [{'vocalized': u'كسويه', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'سوى'}],

 u'أناهم': [{'vocalized': u'أناهم', 'procletic': u'', 'tags': u'حرف;ناصب ومنصوب;ضمير', 'stem': u'أنا', 'encletic': u'-هم', 'type': u'حرف', 'original': u'أنا'}],

 u'أكله': [{'vocalized': u'أكله', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'},
 {'vocalized': u'أكله', 'procletic': u'أ-', 'tags': u'اسم;توكيد;استفهام;ضمير', 'stem': u'كل', 'encletic': u'-ه', 'type': u'اسم', 'original': u'كل'}],

 u'كسويك': [{'vocalized': u'كسويك', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'سوى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'سوى'}],

 u'أمعنا': [{'vocalized': u'أمعنا', 'procletic': u'أ-', 'tags': u'اسم;اسم إضافة;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'فلفي': [{'vocalized': u'فلفي', 'procletic': u'ف-ل-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف', 'stem': u'في', 'encletic': u'', 'type': u'اسم', 'original': u'في'},
 {'vocalized': u'فلفي', 'procletic': u'ف-ل-', 'tags': u';قسم;عطف', 'stem': u'في', 'encletic': u'', 'type': u'حرف', 'original': u'في'}],

 u'كوقتهن': [{'vocalized': u'كوقتهن', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'كوقتهم': [{'vocalized': u'كوقتهم', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'لجنبنا': [{'vocalized': u'لجنبنا', 'procletic': u'ل-', 'tags': u'اسم;ظرف مكان;مجرور;ضمير', 'stem': u'جنب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جنب'}],

 u'ويكأنكم': [{'vocalized': u'ويكأنكم', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-كم', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'ويكأنكن': [{'vocalized': u'ويكأنكن', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل;ضمير', 'stem': u'ويكأن', 'encletic': u'-كن', 'type': u'اسم فعل', 'original': u'ويكأن'}],

 u'لعلكن': [{'vocalized': u'لعلكن', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'لعل', 'encletic': u'-كن', 'type': u'حرف', 'original': u'لعل'}],

 u'ومادمتم': [{'vocalized': u'ومادمتم', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتم', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتم'}],

 u'وكحسبه': [{'vocalized': u'وكحسبه', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'ومادمتن': [{'vocalized': u'ومادمتن', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادمتن', 'encletic': u'', 'type': u'فعل', 'original': u'مادمتن'}],

 u'أفلمعنا': [{'vocalized': u'أفلمعنا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'مع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'مع'}],

 u'فمنكما': [{'vocalized': u'فمنكما', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف;ضمير', 'stem': u'من', 'encletic': u'-كما', 'type': u'حرف', 'original': u'من'}],

 u'أكلا': [{'vocalized': u'أكلا', 'procletic': u'أ-', 'tags': u'حرف;توكيد;استفهام', 'stem': u'كلا', 'encletic': u'', 'type': u'حرف', 'original': u'كلا'}],

 u'وتان': [{'vocalized': u'وتان', 'procletic': u'و-', 'tags': u'اسم;اسم إشارة;عطف', 'stem': u'تان', 'encletic': u'', 'type': u'اسم', 'original': u'تان'}],

 u'أوتحتي': [{'vocalized': u'أوتحتي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'},
 {'vocalized': u'أوتحتي', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ي', 'type': u'اسم', 'original': u'تحت'}],

 u'كوقتها': [{'vocalized': u'كوقتها', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'أوتحته': [{'vocalized': u'أوتحته', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ه', 'type': u'اسم', 'original': u'تحت'}],

 u'وبعضكما': [{'vocalized': u'وبعضكما', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'وشطرها': [{'vocalized': u'وشطرها', 'procletic': u'و-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'شطر', 'encletic': u'-ها', 'type': u'اسم', 'original': u'شطر'}],

 u'أوتحتك': [{'vocalized': u'أوتحتك', 'procletic': u'أ-و-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'تحت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'تحت'}],

 u'أبحسبكن': [{'vocalized': u'أبحسبكن', 'procletic': u'أ-ب-', 'tags': u'اسم;اسم إضافة;مجرور;استفهام;ضمير', 'stem': u'حسب', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حسب'}],

 u'أفبغيركم': [{'vocalized': u'أفبغيركم', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كم', 'type': u'اسم', 'original': u'غير'}],

 u'أفبغيركن': [{'vocalized': u'أفبغيركن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;استثناء;مجرور;عطف;استفهام;ضمير', 'stem': u'غير', 'encletic': u'-كن', 'type': u'اسم', 'original': u'غير'}],

 u'أفلكلتا': [{'vocalized': u'أفلكلتا', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'},
 {'vocalized': u'أفلكلتا', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'كلتا', 'encletic': u'', 'type': u'اسم', 'original': u'كلتا'}],

 u'فبوقتك': [{'vocalized': u'فبوقتك', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'وقت', 'encletic': u'-ك', 'type': u'اسم', 'original': u'وقت'}],

 u'وبشرقهما': [{'vocalized': u'وبشرقهما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'وكأثناءك': [{'vocalized': u'وكأثناءك', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أثناء'}],

 u'ولتحت': [{'vocalized': u'ولتحت', 'procletic': u'و-ل-', 'tags': u';قسم;عطف', 'stem': u'تحت', 'encletic': u'', 'type': u'اسم', 'original': u'تحت'}],

 u'فلأكثر': [{'vocalized': u'فلأكثر', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم تفضيل;مجرور;عطف', 'stem': u'أكثر', 'encletic': u'', 'type': u'اسم', 'original': u'أكثر'}],

 u'عداها': [{'vocalized': u'عداها', 'procletic': u'', 'tags': u'فعل;حرف استثناء;ضمير', 'stem': u'عدا', 'encletic': u'-ها', 'type': u'فعل', 'original': u'عدا'}],

 u'أولكأنها': [{'vocalized': u'أولكأنها', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'كأن', 'encletic': u'-ها', 'type': u'حرف', 'original': u'كأن'}],

 u'فكاللتيا': [{'vocalized': u'فكاللتيا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم موصول;مجرور;عطف', 'stem': u'اللتيا', 'encletic': u'', 'type': u'اسم', 'original': u'اللتيا'}],

 u'أننا': [{'vocalized': u'أننا', 'procletic': u'', 'tags': u'حرف;إن و أخواتها;ضمير', 'stem': u'أن', 'encletic': u'-نا', 'type': u'حرف', 'original': u'أن'}],

 u'أولازلتما': [{'vocalized': u'أولازلتما', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'},
 {'vocalized': u'أولازلتما', 'procletic': u'أ-و-', 'tags': u'فعل;كاد و اخواتها;عطف;استفهام', 'stem': u'لازلتما', 'encletic': u'', 'type': u'فعل', 'original': u'لازلتما'}],

 u'وكأعليكما': [{'vocalized': u'وكأعليكما', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أعلى'}],

 u'فابنكما': [{'vocalized': u'فابنكما', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'ابن', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ابن'}],

 u'أفلخلف': [{'vocalized': u'أفلخلف', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'أولأنت': [{'vocalized': u'أولأنت', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'},
 {'vocalized': u'أولأنت', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنت', 'encletic': u'', 'type': u'ضمير', 'original': u'أنت'}],

 u'فجميعنا': [{'vocalized': u'فجميعنا', 'procletic': u'ف-', 'tags': u'اسم;اسم إضافة;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'},
 {'vocalized': u'فجميعنا', 'procletic': u'ف-', 'tags': u'اسم;توكيد;عطف;ضمير', 'stem': u'جميع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'جميع'}],

 u'مافتئنا': [{'vocalized': u'مافتئنا', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'مافتئنا', 'encletic': u'', 'type': u'فعل', 'original': u'مافتئنا'}],

 u'أولوراءكن': [{'vocalized': u'أولوراءكن', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'وراء', 'encletic': u'-كن', 'type': u'اسم', 'original': u'وراء'}],

 u'أفعامتهما': [{'vocalized': u'أفعامتهما', 'procletic': u'أ-ف-', 'tags': u'اسم;توكيد;عطف;استفهام;ضمير', 'stem': u'عامة', 'encletic': u'-هما', 'type': u'اسم', 'original': u'عامة'}],

 u'فكسوينا': [{'vocalized': u'فكسوينا', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'سوى', 'encletic': u'-نا', 'type': u'اسم', 'original': u'سوى'}],

 u'فلحسبه': [{'vocalized': u'فلحسبه', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ه', 'type': u'اسم', 'original': u'حسب'}],

 u'وكأيتنا': [{'vocalized': u'وكأيتنا', 'procletic': u'و-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'أية', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أية'}],

 u'أولأنا': [{'vocalized': u'أولأنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'ضمير', 'original': u'أنا'},
 {'vocalized': u'أولأنا', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام', 'stem': u'أنا', 'encletic': u'', 'type': u'حرف', 'original': u'أنا'}],

 u'فلحسبك': [{'vocalized': u'فلحسبك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'حسب', 'encletic': u'-ك', 'type': u'اسم', 'original': u'حسب'}],

 u'وككليكما': [{'vocalized': u'وككليكما', 'procletic': u'و-ك-', 'tags': u'حرف;توكيد;مجرور;عطف', 'stem': u'كليكما', 'encletic': u'', 'type': u'حرف', 'original': u'كليكما'}],

 u'وبأعليه': [{'vocalized': u'وبأعليه', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أعلى'}],

 u'فكحميكن': [{'vocalized': u'فكحميكن', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كن', 'type': u'اسم', 'original': u'حمي'}],

 u'وبأعليك': [{'vocalized': u'وبأعليك', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'أعلى', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أعلى'}],

 u'فكحميكم': [{'vocalized': u'فكحميكم', 'procletic': u'ف-ك-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'حمي', 'encletic': u'-كم', 'type': u'اسم', 'original': u'حمي'}],

 u'فبخلف': [{'vocalized': u'فبخلف', 'procletic': u'ف-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'خلف', 'encletic': u'', 'type': u'اسم', 'original': u'خلف'}],

 u'وبعينكما': [{'vocalized': u'وبعينكما', 'procletic': u'و-ب-', 'tags': u'اسم;توكيد;مجرور;عطف;ضمير', 'stem': u'عين', 'encletic': u'-كما', 'type': u'اسم', 'original': u'عين'}],

 u'أفبما': [{'vocalized': u'أفبما', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم الاستفهام;عطف;استفهام', 'stem': u'بما', 'encletic': u'', 'type': u'اسم', 'original': u'بما'}],

 u'ولشهرنا': [{'vocalized': u'ولشهرنا', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'شهر', 'encletic': u'-نا', 'type': u'اسم', 'original': u'شهر'}],

 u'وأسفلنا': [{'vocalized': u'وأسفلنا', 'procletic': u'و-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'أسفل', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكأثناءنا': [{'vocalized': u'فكأثناءنا', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'أثناء', 'encletic': u'-نا', 'type': u'اسم', 'original': u'أثناء'}],

 u'لكان': [{'vocalized': u'لكان', 'procletic': u'ل-', 'tags': u';قسم', 'stem': u'كان', 'encletic': u'', 'type': u'فعل', 'original': u'كان'}],

 u'ومادامت': [{'vocalized': u'ومادامت', 'procletic': u'و-', 'tags': u'فعل;كان و أخواتها;عطف', 'stem': u'مادامت', 'encletic': u'', 'type': u'فعل', 'original': u'مادامت'}],

 u'فلذوينا': [{'vocalized': u'فلذوينا', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف;ضمير', 'stem': u'ذوي', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ذوي'}],

 u'كابننا': [{'vocalized': u'كابننا', 'procletic': u'ك-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'أفذينك': [{'vocalized': u'أفذينك', 'procletic': u'أ-ف-', 'tags': u'اسم;اسم إشارة;عطف;استفهام', 'stem': u'ذينك', 'encletic': u'', 'type': u'اسم', 'original': u'ذينك'}],

 u'وبخلفكما': [{'vocalized': u'وبخلفكما', 'procletic': u'و-ب-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'خلف', 'encletic': u'-كما', 'type': u'اسم', 'original': u'خلف'}],

 u'فلذواتي': [{'vocalized': u'فلذواتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'ذواتي', 'encletic': u'', 'type': u'اسم', 'original': u'ذواتي'}],

 u'أفبمن': [{'vocalized': u'أفبمن', 'procletic': u'أ-ف-ب-', 'tags': u'اسم;اسم موصول;مجرور;عطف;استفهام', 'stem': u'من', 'encletic': u'', 'type': u'اسم', 'original': u'من'}],

 u'وكنفس': [{'vocalized': u'وكنفس', 'procletic': u'و-ك-', 'tags': u'اسم;توكيد;مجرور;عطف', 'stem': u'نفس', 'encletic': u'', 'type': u'اسم', 'original': u'نفس'}],

 u'بغروبهن': [{'vocalized': u'بغروبهن', 'procletic': u'ب-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'غروب', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غروب'}],

 u'فلهنالك': [{'vocalized': u'فلهنالك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم إشارة;مجرور;عطف', 'stem': u'هنالك', 'encletic': u'', 'type': u'اسم', 'original': u'هنالك'}],

 u'لشطر': [{'vocalized': u'لشطر', 'procletic': u'ل-', 'tags': u'اسم;اسم إضافة;مجرور', 'stem': u'شطر', 'encletic': u'', 'type': u'اسم', 'original': u'شطر'}],

 u'أبضعنا': [{'vocalized': u'أبضعنا', 'procletic': u'أ-', 'tags': u'اسم;كناية;استفهام;ضمير', 'stem': u'بضع', 'encletic': u'-نا', 'type': u'اسم', 'original': u'بضع'}],

 u'فكمثلكن': [{'vocalized': u'فكمثلكن', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كن', 'type': u'اسم', 'original': u'مثل'}],

 u'فكمثلكم': [{'vocalized': u'فكمثلكم', 'procletic': u'ف-ك-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;ضمير', 'stem': u'مثل', 'encletic': u'-كم', 'type': u'اسم', 'original': u'مثل'}],

 u'شرقهما': [{'vocalized': u'شرقهما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'شرق', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شرق'}],

 u'ولازالتا': [{'vocalized': u'ولازالتا', 'procletic': u'و-', 'tags': u'فعل;كاد و اخواتها;عطف', 'stem': u'لازالتا', 'encletic': u'', 'type': u'فعل', 'original': u'لازالتا'}],

 u'إيانا': [{'vocalized': u'إيانا', 'procletic': u'', 'tags': u'ضمير;ضمير منفصل منصوب', 'stem': u'إيانا', 'encletic': u'', 'type': u'ضمير', 'original': u'إيانا'}],

 u'أوبشبههما': [{'vocalized': u'أوبشبههما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'شبه', 'encletic': u'-هما', 'type': u'اسم', 'original': u'شبه'}],

 u'بعينكم': [{'vocalized': u'بعينكم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عين', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عين'}],

 u'أوبنحوكم': [{'vocalized': u'أوبنحوكم', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'نحو'}],

 u'أوبنحوكن': [{'vocalized': u'أوبنحوكن', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كن', 'type': u'اسم', 'original': u'نحو'}],

 u'بغيرها': [{'vocalized': u'بغيرها', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-ها', 'type': u'اسم', 'original': u'غير'}],

 u'أوبنحوكما': [{'vocalized': u'أوبنحوكما', 'procletic': u'أ-و-ب-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'نحو', 'encletic': u'-كما', 'type': u'اسم', 'original': u'نحو'}],

 u'ولأسفل': [{'vocalized': u'ولأسفل', 'procletic': u'و-ل-', 'tags': u'اسم;ظرف مكان;مجرور;عطف', 'stem': u'أسفل', 'encletic': u'', 'type': u'اسم', 'original': u'أسفل'}],

 u'فكشرقكما': [{'vocalized': u'فكشرقكما', 'procletic': u'ف-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'شرق', 'encletic': u'-كما', 'type': u'اسم', 'original': u'شرق'}],

 u'لأناكما': [{'vocalized': u'لأناكما', 'procletic': u'ل-', 'tags': u';قسم;ضمير', 'stem': u'أنا', 'encletic': u'-كما', 'type': u'حرف', 'original': u'أنا'}],

 u'أولبعضكما': [{'vocalized': u'أولبعضكما', 'procletic': u'أ-و-ل-', 'tags': u'اسم;اسم إضافة;مجرور;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'},
 {'vocalized': u'أولبعضكما', 'procletic': u'أ-و-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'بعض', 'encletic': u'-كما', 'type': u'اسم', 'original': u'بعض'}],

 u'وقتهما': [{'vocalized': u'وقتهما', 'procletic': u'', 'tags': u'اسم;ظرف زمان;ضمير', 'stem': u'وقت', 'encletic': u'-هما', 'type': u'اسم', 'original': u'وقت'}],

 u'لوقتهن': [{'vocalized': u'لوقتهن', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هن', 'type': u'اسم', 'original': u'وقت'}],

 u'لوقتهم': [{'vocalized': u'لوقتهم', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-هم', 'type': u'اسم', 'original': u'وقت'}],

 u'فضمني': [{'vocalized': u'فضمني', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ضمن'},
 {'vocalized': u'فضمني', 'procletic': u'ف-', 'tags': u'اسم;ظرف مكان;عطف;ضمير', 'stem': u'ضمن', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ضمن'}],

 u'وأخاهما': [{'vocalized': u'وأخاهما', 'procletic': u'و-', 'tags': u'اسم;الأسماء الخمسة;عطف;ضمير', 'stem': u'أخا', 'encletic': u'-هما', 'type': u'اسم', 'original': u'أخا'}],

 u'طق': [{'vocalized': u'طق', 'procletic': u'', 'tags': u'اسم فعل;اسم صوت', 'stem': u'طق', 'encletic': u'', 'type': u'اسم فعل', 'original': u'طق'}],

 u'أبوكم': [{'vocalized': u'أبوكم', 'procletic': u'', 'tags': u'اسم;الأسماء الخمسة;ضمير', 'stem': u'أبو', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أبو'}],

 u'وكغربنا': [{'vocalized': u'وكغربنا', 'procletic': u'و-ك-', 'tags': u'اسم;ظرف مكان;مجرور;عطف;ضمير', 'stem': u'غرب', 'encletic': u'-نا', 'type': u'اسم', 'original': u'غرب'}],

 u'فحتى': [{'vocalized': u'فحتى', 'procletic': u'ف-', 'tags': u'حرف;تعليل;عطف', 'stem': u'حتى', 'encletic': u'', 'type': u'حرف', 'original': u'حتى'},
 {'vocalized': u'فحتى', 'procletic': u'ف-', 'tags': u'حرف;حرف جر;عطف', 'stem': u'حتى', 'encletic': u'', 'type': u'حرف', 'original': u'حتى'}],

 u'أبها': [{'vocalized': u'أبها', 'procletic': u'أ-', 'tags': u'ضمير;ضمير متصل مجرور;استفهام', 'stem': u'بها', 'encletic': u'', 'type': u'ضمير', 'original': u'بها'}],

 u'ابننا': [{'vocalized': u'ابننا', 'procletic': u'', 'tags': u'اسم;اسم إضافة;ضمير', 'stem': u'ابن', 'encletic': u'-نا', 'type': u'اسم', 'original': u'ابن'}],

 u'كساعتكما': [{'vocalized': u'كساعتكما', 'procletic': u'ك-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'ساعة', 'encletic': u'-كما', 'type': u'اسم', 'original': u'ساعة'}],

 u'أبهو': [{'vocalized': u'أبهو', 'procletic': u'أ-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هو', 'encletic': u'', 'type': u'ضمير', 'original': u'هو'}],

 u'أبهي': [{'vocalized': u'أبهي', 'procletic': u'أ-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هي', 'encletic': u'', 'type': u'ضمير', 'original': u'هي'}],

 u'فلزمانهن': [{'vocalized': u'فلزمانهن', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هن', 'type': u'اسم', 'original': u'زمان'}],

 u'فلزمانهم': [{'vocalized': u'فلزمانهم', 'procletic': u'ف-ل-', 'tags': u'اسم;ظرف زمان;مجرور;عطف;ضمير', 'stem': u'زمان', 'encletic': u'-هم', 'type': u'اسم', 'original': u'زمان'}],

 u'أبهم': [{'vocalized': u'أبهم', 'procletic': u'أ-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هم', 'encletic': u'', 'type': u'ضمير', 'original': u'هم'}],

 u'أبهن': [{'vocalized': u'أبهن', 'procletic': u'أ-ب-', 'tags': u'ضمير;ضمير منفصل;مجرور;استفهام', 'stem': u'هن', 'encletic': u'', 'type': u'ضمير', 'original': u'هن'}],

 u'فلذاتك': [{'vocalized': u'فلذاتك', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ك', 'type': u'اسم', 'original': u'ذات'}],

 u'بأيتكم': [{'vocalized': u'بأيتكم', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كم', 'type': u'اسم', 'original': u'أية'}],

 u'بأيتكن': [{'vocalized': u'بأيتكن', 'procletic': u'ب-', 'tags': u'اسم;اسم إضافة;مجرور;ضمير', 'stem': u'أية', 'encletic': u'-كن', 'type': u'اسم', 'original': u'أية'}],

 u'فلذاته': [{'vocalized': u'فلذاته', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ه', 'type': u'اسم', 'original': u'ذات'}],

 u'فلذاتي': [{'vocalized': u'فلذاتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'},
 {'vocalized': u'فلذاتي', 'procletic': u'ف-ل-', 'tags': u'اسم;اسم موصول;مجرور;عطف;ضمير', 'stem': u'ذات', 'encletic': u'-ي', 'type': u'اسم', 'original': u'ذات'}],

 u'كان': [{'vocalized': u'كان', 'procletic': u'', 'tags': u'فعل;كان و أخواتها', 'stem': u'كان', 'encletic': u'', 'type': u'فعل', 'original': u'كان'}],

 u'فبأبيه': [{'vocalized': u'فبأبيه', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ه', 'type': u'اسم', 'original': u'أبي'}],

 u'فبأبيك': [{'vocalized': u'فبأبيك', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ك', 'type': u'اسم', 'original': u'أبي'}],

 u'بعامتكن': [{'vocalized': u'بعامتكن', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كن', 'type': u'اسم', 'original': u'عامة'}],

 u'بغيرهن': [{'vocalized': u'بغيرهن', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هن', 'type': u'اسم', 'original': u'غير'}],

 u'بغيرهم': [{'vocalized': u'بغيرهم', 'procletic': u'ب-', 'tags': u'اسم;استثناء;مجرور;ضمير', 'stem': u'غير', 'encletic': u'-هم', 'type': u'اسم', 'original': u'غير'}],

 u'فبأبيي': [{'vocalized': u'فبأبيي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'},
 {'vocalized': u'فبأبيي', 'procletic': u'ف-ب-', 'tags': u'اسم;الأسماء الخمسة;مجرور;عطف;ضمير', 'stem': u'أبي', 'encletic': u'-ي', 'type': u'اسم', 'original': u'أبي'}],

 u'بعامتكم': [{'vocalized': u'بعامتكم', 'procletic': u'ب-', 'tags': u'اسم;توكيد;مجرور;ضمير', 'stem': u'عامة', 'encletic': u'-كم', 'type': u'اسم', 'original': u'عامة'}],

 u'وراءكما': [{'vocalized': u'وراءكما', 'procletic': u'', 'tags': u'اسم فعل;اسم فعل', 'stem': u'وراءكما', 'encletic': u'', 'type': u'اسم فعل', 'original': u'وراءكما'},
 {'vocalized': u'وراءكما', 'procletic': u'', 'tags': u'اسم;ظرف مكان;ضمير', 'stem': u'وراء', 'encletic': u'-كما', 'type': u'اسم', 'original': u'وراء'}],

 u'لوقتها': [{'vocalized': u'لوقتها', 'procletic': u'ل-', 'tags': u'اسم;ظرف زمان;مجرور;ضمير', 'stem': u'وقت', 'encletic': u'-ها', 'type': u'اسم', 'original': u'وقت'}],

 u'وإما': [{'vocalized': u'وإما', 'procletic': u'و-', 'tags': u'حرف;حرف تخيير وتفصيل;عطف', 'stem': u'إما', 'encletic': u'', 'type': u'حرف', 'original': u'إما'}],

 u'أفخلفهما': [{'vocalized': u'أفخلفهما', 'procletic': u'أ-ف-', 'tags': u'اسم;ظرف مكان;عطف;استفهام;ضمير', 'stem': u'خلف', 'encletic': u'-هما', 'type': u'اسم', 'original': u'خلف'}],

 u'لازلن': [{'vocalized': u'لازلن', 'procletic': u'', 'tags': u'فعل;كاد و اخواتها', 'stem': u'لازلن', 'encletic': u'', 'type': u'فعل', 'original': u'لازلن'}],

 u'أفلأجمعكما': [{'vocalized': u'أفلأجمعكما', 'procletic': u'أ-ف-ل-', 'tags': u'اسم;توكيد;مجرور;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'},
 {'vocalized': u'أفلأجمعكما', 'procletic': u'أ-ف-ل-', 'tags': u';قسم;عطف;استفهام;ضمير', 'stem': u'أجمع', 'encletic': u'-كما', 'type': u'اسم', 'original': u'أجمع'}]}

STOPWORDS_INDEX={u'حم': set([u'حم', u'وحم', u'فحم']),
 u'غداة': set([u'وغداة', u'غداة', u'فغداة']),
 u'جنوب': set([u'جنوب', u'ولجنوبنا', u'فلجنوبهم', u'فلجنوبهن', u'فجنوبها', u'ولجنوبهن', u'ولجنوبهم', u'ولجنوبي', u'فكجنوبكما', u'فجنوبي', u'فجنوبه', u'فجنوبك', u'كجنوبهما', u'وجنوبكم', u'وجنوبكن', u'ولجنوبها', u'وبجنوبك', u'ولجنوبك', u'وبجنوبه', u'فلجنوبهما', u'وبجنوبي', u'فجنوبنا', u'جنوبنا', u'فبجنوبكم', u'كجنوبكما', u'وبجنوبكن', u'وبجنوبكم', u'فلجنوبها', u'فجنوبهم', u'فجنوبهن', u'وبجنوبهما', u'جنوبك', u'فكجنوبك', u'فكجنوبه', u'فكجنوبي', u'جنوبهن', u'فجنوب', u'وجنوبنا', u'بجنوبهم', u'بجنوبهن', u'فبجنوبه', u'فبجنوبك', u'جنوبها', u'وكجنوبها', u'وكجنوبهما', u'لجنوبكم', u'لجنوبكن', u'فلجنوبنا', u'وكجنوبهم', u'بجنوبنا', u'وجنوبهم', u'وجنوبهن', u'كجنوبنا', u'كجنوبهن', u'كجنوبهم', u'وجنوب', u'جنوبهم', u'فلجنوبي', u'لجنوب', u'جنوبه', u'ولجنوبهما', u'جنوبي', u'وكجنوبهن', u'فلجنوبك', u'فلجنوبه', u'فلجنوبكما', u'وكجنوبكما', u'وجنوبها', u'كجنوبها', u'وبجنوبنا', u'وجنوبي', u'وكجنوبنا', u'وجنوبك', u'وجنوبه', u'كجنوب', u'بجنوبها', u'فكجنوبكن', u'ولجنوبه', u'فكجنوبكم', u'فكجنوبهما', u'فجنوبهما', u'ولجنوبكن', u'ولجنوبكم', u'وبجنوبها', u'بجنوب', u'وكجنوبي', u'فلجنوبكم', u'فلجنوبكن', u'وكجنوبه', u'فجنوبكما', u'وكجنوبك', u'وبجنوب', u'وكجنوبكم', u'وكجنوبكن', u'فبجنوبنا', u'بجنوبكما', u'فكجنوبهن', u'كجنوبه', u'فكجنوب', u'كجنوبك', u'بجنوبه', u'كجنوبي', u'فبجنوبهم', u'وجنوبكما', u'فجنوبكم', u'فجنوبكن', u'بجنوبهما', u'وبجنوبهن', u'وبجنوبهم', u'لجنوبهما', u'بجنوبي', u'فبجنوبي', u'فبجنوبكن', u'بجنوبك', u'لجنوبكما', u'فكجنوبهم', u'فبجنوب', u'لجنوبه', u'وجنوبهما', u'لجنوبك', u'لجنوبنا', u'فبجنوبهن', u'لجنوبي', u'بجنوبكم', u'بجنوبكن', u'فكجنوبنا', u'كجنوبكن', u'كجنوبكم', u'ولجنوبكما', u'لجنوبهم', u'لجنوبهن', u'وكجنوب', u'وبجنوبكما', u'فلجنوب', u'فبجنوبكما', u'جنوبكم', u'جنوبكن', u'فبجنوبهما', u'لجنوبها', u'فبجنوبها', u'ولجنوب', u'فكجنوبها', u'جنوبهما', u'جنوبكما']),
 u'ذواتا': set([u'أذواتا', u'أوذواتا', u'فذواتا', u'وذواتا', u'أفذواتا', u'ذواتا']),
 u'حي': set([u'فحي', u'وحي', u'حي']),
 u'لازلنا': set([u'ألازلنا', u'لازلنا', u'أفلازلنا', u'أولازلنا', u'فلازلنا', u'ولازلنا']),
 u'زمان': set([u'وكزماني', u'وكزمانك', u'وكزمانه', u'فلزمانهما', u'زمانهما', u'فكزمانها', u'زمان', u'لزمانه', u'لزمانك', u'بزمانها', u'كزمانهم', u'كزمانهن', u'فزمانكن', u'فزمانكم', u'فلزمانكن', u'فلزمانكم', u'لزمانها', u'بزمانهن', u'بزمانهم', u'وبزمانه', u'كزمانها', u'وبزماني', u'وبزمانهما', u'فبزمانكن', u'فبزمانكم', u'فلزمانه', u'فكزمانهما', u'لزمانهن', u'وبزمانكما', u'لزمانهم', u'بزماني', u'بزمان', u'بزمانك', u'وزمانكن', u'بزمانه', u'وزمانكم', u'فكزمانهم', u'فكزمانهن', u'لزماني', u'وزمان', u'كزماننا', u'فبزمانهما', u'ولزمانهم', u'فلزمانهن', u'ولزمانهن', u'كزمانك', u'كزمانه', u'وكزمانهم', u'كزماني', u'فلزمانهم', u'فلزمانك', u'وكزمانها', u'ولزماننا', u'وزماني', u'وزمانك', u'لزمان', u'وكزماننا', u'وزمانه', u'فبزماني', u'لزمانكما', u'وبزمانكم', u'فبزمانك', u'فكزمان', u'وبزمانكن', u'فبزمانه', u'وكزمانهن', u'فبزمانكما', u'فبزماننا', u'وكزمان', u'ولزمانها', u'وزماننا', u'ولزمانه', u'وزمانها', u'وزمانهما', u'ولزمانك', u'كزمانهما', u'فكزمانكم', u'فكزمانكن', u'ولزماني', u'زمانك', u'زمانه', u'وزمانكما', u'زماني', u'فبزمانها', u'لزمانهما', u'فكزمانكما', u'كزمانكم', u'كزمانكن', u'فزمانهن', u'فزمانهم', u'فبزمانهن', u'فبزمانهم', u'زمانكن', u'زمانكم', u'كزمانكما', u'بزمانكن', u'بزمانكم', u'لزمانكن', u'لزمانكم', u'فزمانها', u'فلزمانكما', u'وزمانهن', u'وزمانهم', u'فلزمان', u'وبزماننا', u'فزماني', u'فزمانه', u'فزمانك', u'وكزمانهما', u'وبزمانك', u'ولزمانكم', u'ولزمانكن', u'ولزمانكما', u'فزماننا', u'زماننا', u'فبزمان', u'بزماننا', u'وكزمانكما', u'فلزمانها', u'وبزمانها', u'وبزمان', u'فزمان', u'كزمان', u'ولزمانهما', u'زمانهن', u'زمانهم', u'فكزماننا', u'فلزماني', u'وبزمانهم', u'ولزمان', u'وبزمانهن', u'فكزمانك', u'فكزمانه', u'زمانها', u'فكزماني', u'زمانكما', u'فلزماننا', u'بزمانهما', u'وكزمانكن', u'وكزمانكم', u'فزمانكما', u'بزمانكما', u'لزماننا', u'فزمانهما']),
 u'عوض': set([u'فعوض', u'وعوض', u'عوض']),
 u'بنا': set([u'أفبنا', u'وبنا', u'أبنا', u'فبنا', u'أوبنا', u'بنا']),
 u'أجمع': set([u'أوكأجمع', u'أفأجمعي', u'كأجمعكما', u'أفلأجمع', u'أفبأجمعي', u'أوأجمعكن', u'أوأجمعكم', u'أوكأجمعنا', u'أوبأجمعكما', u'أفأجمعه', u'أفبأجمعك', u'ولأجمعهما', u'أوأجمعه', u'أكأجمعهما', u'وأجمعها', u'أفلأجمعهما', u'وكأجمعها', u'أجمع', u'فأجمعكم', u'فأجمعكن', u'أفأجمعها', u'كأجمعكن', u'أفأجمع', u'كأجمعكم', u'أوكأجمعهما', u'أولأجمعه', u'أفأجمعهما', u'أفأجمعك', u'أجمعنا', u'فكأجمعها', u'فلأجمعكن', u'أفبأجمعه', u'وكأجمعهم', u'أفكأجمعك', u'فأجمعك', u'أفكأجمعنا', u'فبأجمعهما', u'أفكأجمعه', u'وبأجمعكما', u'أفكأجمعكن', u'أبأجمعك', u'أأجمعكم', u'أوكأجمعكن', u'أبأجمعه', u'أوبأجمع', u'أولأجمعكم', u'أفلأجمعكم', u'أوكأجمعكم', u'فكأجمعهن', u'أولأجمعنا', u'فكأجمعهم', u'ولأجمعكما', u'ولأجمع', u'أبأجمعكن', u'أبأجمعكم', u'ألأجمعهن', u'فبأجمعها', u'وكأجمعه', u'فبأجمعكما', u'أجمعك', u'فبأجمعي', u'فكأجمعنا', u'أجمعه', u'فبأجمعه', u'أجمعي', u'وأجمعهم', u'وأجمعهن', u'ألأجمعها', u'أفكأجمعكما', u'أفلأجمعك', u'وبأجمعهم', u'أوكأجمعي', u'أأجمع', u'أفلأجمعه', u'فكأجمعكن', u'أفلأجمعي', u'أفأجمعهن', u'فلأجمعهما', u'أكأجمعهن', u'أفكأجمعهما', u'أكأجمعها', u'أوبأجمعي', u'بأجمعهم', u'أفكأجمعهم', u'بأجمعهن', u'وأجمعنا', u'أجمعكن', u'أوبأجمعك', u'ولأجمعها', u'أفلأجمعكن', u'أوأجمعكما', u'ولأجمعهم', u'لأجمعهم', u'وبأجمعكن', u'فلأجمع', u'لأجمعهن', u'وأجمعهما', u'أفبأجمعهن', u'فلأجمعهم', u'أولأجمعهم', u'بأجمعهما', u'بأجمعي', u'وأجمعكما', u'أأجمعكما', u'ولأجمعهن', u'وبأجمعهما', u'بأجمعك', u'فأجمعكما', u'أفبأجمعهم', u'أفبأجمعها', u'بأجمعه', u'أفأجمعنا', u'أفبأجمع', u'لأجمعها', u'أفأجمعهم', u'أكأجمعنا', u'فبأجمعنا', u'أوأجمعنا', u'أفبأجمعهما', u'أوبأجمعكم', u'أوبأجمعكن', u'أولأجمعها', u'أفكأجمعها', u'وبأجمعك', u'بأجمعكما', u'وأجمعي', u'وبأجمعه', u'فلأجمعكما', u'أفبأجمعنا', u'وبأجمعي', u'أوأجمع', u'بأجمع', u'وكأجمعنا', u'أكأجمعي', u'أكأجمعكم', u'أكأجمعه', u'وبأجمع', u'أأجمعنا', u'فأجمعهما', u'وكأجمعهما', u'أبأجمعنا', u'وبأجمعكم', u'بأجمعها', u'أفكأجمعكم', u'بأجمعنا', u'فأجمعي', u'أفلأجمعها', u'أولأجمعكما', u'وأجمعكم', u'وبأجمعها', u'وأجمعكن', u'فأجمعه', u'ألأجمعهما', u'أفلأجمعهن', u'كأجمعنا', u'أكأجمعهم', u'أوأجمعها', u'لأجمعنا', u'أوكأجمعها', u'فأجمعهم', u'فأجمعهن', u'ولأجمعنا', u'ألأجمعكما', u'لأجمعه', u'ألأجمعه', u'أكأجمع', u'لأجمعك', u'ألأجمعك', u'أولأجمعهما', u'فلأجمعنا', u'لأجمعي', u'ألأجمعي', u'ولأجمعكن', u'فكأجمعك', u'ولأجمعكم', u'كأجمعهن', u'فكأجمعه', u'كأجمعهم', u'فأجمعنا', u'أبأجمعها', u'أأجمعها', u'أفبأجمعكما', u'أفلأجمعنا', u'وبأجمعنا', u'فكأجمع', u'وأجمع', u'وكأجمعكم', u'وكأجمعكما', u'وكأجمعكن', u'فكأجمعي', u'أولأجمع', u'أأجمعهن', u'كأجمعها', u'أبأجمعهم', u'أأجمعهم', u'فلأجمعك', u'أجمعهما', u'فلأجمعه', u'أفكأجمع', u'أفكأجمعهن', u'وكأجمعي', u'أفلأجمعهم', u'وبأجمعهن', u'كأجمع', u'وكأجمعك', u'فبأجمع', u'فكأجمعكم', u'فبأجمعهم', u'فبأجمعكم', u'فبأجمعهن', u'أوبأجمعنا', u'أوأجمعهن', u'أوأجمعهم', u'أوكأجمعهن', u'أوكأجمعهم', u'فأجمعها', u'أجمعكما', u'أكأجمعك', u'لأجمعكما', u'أفأجمعكم', u'أبأجمعكما', u'كأجمعي', u'أكأجمعكن', u'أوبأجمعه', u'لأجمع', u'أكأجمعكما', u'فلأجمعكم', u'أبأجمعي', u'وكأجمعهن', u'أجمعهم', u'أجمعهن', u'فكأجمعهما', u'أوكأجمعه', u'أوكأجمعك', u'فأجمع', u'أوأجمعي', u'لأجمعكم', u'أوبأجمعهما', u'لأجمعكن', u'بأجمعكم', u'ولأجمعه', u'أوأجمعك', u'بأجمعكن', u'ولأجمعك', u'ألأجمعهم', u'أأجمعكن', u'أولأجمعكن', u'أوبأجمعها', u'أبأجمعهما', u'فلأجمعهن', u'أفكأجمعي', u'وكأجمع', u'كأجمعهما', u'أأجمعه', u'أأجمعك', u'أولأجمعهن', u'أجمعكم', u'لأجمعهما', u'فبأجمعكن', u'أأجمعي', u'أوبأجمعهم', u'أوبأجمعهن', u'أفأجمعكما', u'أوأجمعهما', u'أولأجمعك', u'ولأجمعي', u'فكأجمعكما', u'أبأجمع', u'أفبأجمعكن', u'أفبأجمعكم', u'أأجمعهما', u'كأجمعه', u'أفأجمعكن', u'كأجمعك', u'فلأجمعي', u'وأجمعك', u'وأجمعه', u'ألأجمعكن', u'ألأجمعكم', u'ألأجمع', u'فبأجمعك', u'ألأجمعنا', u'أولأجمعي', u'فلأجمعها', u'أجمعها', u'أوكأجمعكما', u'أفلأجمعكما', u'أبأجمعهن']),
 u'ؤ': set([u'ؤ']),
 u'إيه': set([u'إيه', u'وإيه', u'فإيه']),
 u'لدن': set([u'لدني', u'ولدنكما', u'ولدنها', u'لدنكما', u'لدنك', u'لدنه', u'فلدنها', u'فلدنكن', u'لدن', u'فلدنكم', u'فلدنهما', u'لدنها', u'لدننا', u'ولدننا', u'ولدنهما', u'فلدننا', u'لدنهن', u'لدنهم', u'ولدنك', u'ولدنهم', u'ولدنهن', u'ولدنه', u'لدنكن', u'ولدني', u'فلدن', u'فلدنهن', u'لدنهما', u'ولدنكم', u'ولدنكن', u'ولدن', u'فلدنهم', u'فلدني', u'فلدنه', u'فلدنكما', u'لدنكم', u'فلدنك']),
 u'ها': set([u'ها']),
 u'ش': set([u'ش']),
 u'غرب': set([u'كغربها', u'بغرب', u'فلغرب', u'ولغربكن', u'ولغربكم', u'فلغربكما', u'ولغرب', u'وبغربكن', u'وبغربكم', u'بغربكن', u'بغربكم', u'غرب', u'لغربها', u'فلغربنا', u'لغربهن', u'لغربهم', u'فغربكما', u'كغربهن', u'كغربهم', u'فبغربهن', u'فغربهما', u'فبغربك', u'فكغرب', u'لغربنا', u'وكغربكن', u'وغربك', u'وكغربكم', u'وغربه', u'غربهم', u'غربهن', u'وبغربكما', u'بغربهما', u'وبغربي', u'لغرب', u'فلغربها', u'بغربكما', u'فغربهم', u'فغربهن', u'فغرب', u'وكغربكما', u'وكغربي', u'فكغربها', u'وكغربه', u'وكغربك', u'وغربهما', u'فبغربكن', u'فبغربكم', u'فبغربي', u'وكغربهما', u'وبغربهما', u'فبغربه', u'وغربكما', u'فغربنا', u'وبغرب', u'غربهما', u'ولغربي', u'فكغربهن', u'فكغربهم', u'وغربكن', u'ولغربك', u'وغربكم', u'غربكما', u'فكغربي', u'فكغربك', u'فكغربه', u'ولغربهن', u'غربها', u'فكغربنا', u'وغرب', u'فلغربهن', u'فلغربهم', u'وكغرب', u'فغربها', u'كغربهما', u'فبغربهما', u'كغرب', u'وبغربهن', u'وبغربهم', u'لغربكما', u'بغربهن', u'بغربك', u'بغربهم', u'بغربه', u'ولغربهم', u'بغربي', u'غربنا', u'فلغربكم', u'فغربه', u'وغربي', u'فبغربكما', u'كغربكما', u'فغربك', u'فغربي', u'بغربها', u'ولغربها', u'ولغربهما', u'لغربكن', u'فلغربك', u'لغربكم', u'فلغربه', u'فلغربي', u'كغربكن', u'كغربكم', u'لغربهما', u'كغربه', u'كغربك', u'وبغربها', u'كغربي', u'بغربنا', u'فلغربكن', u'ولغربنا', u'فكغربهما', u'وكغربهن', u'وكغربهم', u'فغربكم', u'غربي', u'فغربكن', u'غربكم', u'غربكن', u'غربك', u'فبغربنا', u'غربه', u'وغربها', u'ولغربه', u'فكغربكما', u'وكغربنا', u'فبغرب', u'لغربه', u'لغربك', u'ولغربكما', u'وبغربنا', u'لغربي', u'فبغربهم', u'وغربهن', u'وغربهم', u'وبغربك', u'وبغربه', u'فكغربكن', u'فكغربكم', u'فلغربهما', u'فبغربها', u'كغربنا', u'وغربنا', u'وكغربها']),
 u'لازلتم': set([u'أفلازلتم', u'ولازلتم', u'فلازلتم', u'ألازلتم', u'لازلتم', u'أولازلتم']),
 u'هج': set([u'هج']),
 u'هب': set([u'فهب', u'لهب', u'ولهب', u'وهب', u'فلهب', u'هب']),
 u'عسى': set([u'عسى', u'لعسى', u'ولعسى', u'فلعسى', u'فعسى', u'وعسى']),
 u'ل': set([u'ل']),
 u'آنفا': set([u'آنفا', u'وآنفا', u'فآنفا']),
 u'لازلتن': set([u'أفلازلتن', u'لازلتن', u'ولازلتن', u'ألازلتن', u'فلازلتن', u'أولازلتن']),
 u'هن': set([u'ألهن', u'فهن', u'أهن', u'أولهن', u'فكهن', u'أفلهن', u'أفكهن', u'لهن', u'أوهن', u'كهن', u'فلهن', u'بهن', u'ولهن', u'وكهن', u'وبهن', u'أبهن', u'فبهن', u'هن', u'وهن', u'أفبهن', u'أكهن', u'أوبهن', u'أوكهن', u'أفهن']),
 u'هم': set([u'ألهم', u'فهم', u'أهم', u'فكهم', u'أولهم', u'أفلهم', u'أفكهم', u'لهم', u'كهم', u'أوهم', u'فلهم', u'ولهم', u'بهم', u'وكهم', u'وبهم', u'أبهم', u'هم', u'فبهم', u'وهم', u'أفبهم', u'أكهم', u'أوبهم', u'أوكهم', u'أفهم']),
 u'هل': set([u'فهل', u'وهل', u'هل']),
 u'هاؤم': set([u'فهاؤم', u'وهاؤم', u'هاؤم']),
 u'ارتد': set([u'وارتد', u'لارتد', u'فلارتد', u'ارتد', u'فارتد', u'ولارتد']),
 u'هي': set([u'أهي', u'فهي', u'ألهي', u'أفلهي', u'أولهي', u'فكهي', u'أوهي', u'كهي', u'لهي', u'أفكهي', u'بهي', u'ولهي', u'فلهي', u'أبهي', u'وبهي', u'وكهي', u'وهي', u'فبهي', u'هي', u'أكهي', u'أفبهي', u'أفهي', u'أوكهي', u'أوبهي']),
 u'هو': set([u'أهو', u'فهو', u'ألهو', u'أفلهو', u'فكهو', u'أولهو', u'أوهو', u'كهو', u'لهو', u'أفكهو', u'ولهو', u'بهو', u'فلهو', u'أبهو', u'وبهو', u'وكهو', u'وهو', u'فبهو', u'هو', u'أكهو', u'أفبهو', u'أفهو', u'أوكهو', u'أوبهو']),
 u'لازالتا': set([u'فلازالتا', u'أولازالتا', u'ألازالتا', u'لازالتا', u'أفلازالتا', u'ولازالتا']),
 u'تلكما': set([u'فبتلكما', u'أفلتلكما', u'أفتلكما', u'لتلكما', u'أفبتلكما', u'أتلكما', u'أبتلكما', u'فكتلكما', u'أكتلكما', u'وتلكما', u'وبتلكما', u'أوتلكما', u'أوكتلكما', u'بتلكما', u'وكتلكما', u'فلتلكما', u'فتلكما', u'تلكما', u'ولتلكما', u'أوبتلكما', u'ألتلكما', u'أولتلكما', u'كتلكما', u'أفكتلكما']),
 u'وقت': set([u'لوقته', u'لوقتك', u'لوقتي', u'وقتكما', u'بوقتها', u'فبوقتكم', u'وبوقتكن', u'وبوقتكم', u'وقتها', u'فبوقت', u'ووقتكن', u'ووقتكم', u'فوقتهم', u'فوقتهن', u'فوقتكما', u'ووقتك', u'فلوقتكن', u'ووقته', u'ووقتي', u'ووقتكما', u'وقتهم', u'وقتهن', u'فوقتي', u'ولوقتهما', u'فوقته', u'وكوقت', u'فوقتك', u'فلوقت', u'وكوقته', u'بوقتهما', u'وكوقتك', u'فكوقتنا', u'وكوقتي', u'وقتي', u'كوقتكما', u'فكوقتهم', u'وقت', u'فوقتهما', u'وقته', u'ولوقتكن', u'كوقتهما', u'ووقتهما', u'فلوقتك', u'ووقت', u'بوقتهن', u'بوقتهم', u'ولوقتك', u'فلوقته', u'فكوقتهن', u'وقتك', u'لوقتكما', u'لوقتكن', u'لوقتكم', u'فوقتنا', u'لوقتهما', u'فكوقتي', u'فكوقت', u'فكوقتهما', u'فكوقتك', u'فكوقته', u'ولوقتها', u'وكوقتكن', u'وكوقتكم', u'ولوقتكم', u'كوقتهن', u'كوقتهم', u'ولوقتي', u'وكوقتنا', u'لوقت', u'وبوقتي', u'كوقتها', u'ولوقته', u'بوقت', u'وبوقتك', u'ولوقتنا', u'وبوقته', u'فبوقتكن', u'فبوقته', u'فبوقتك', u'فلوقتهما', u'فبوقتي', u'وبوقتهما', u'فلوقتكما', u'بوقتكن', u'بوقتكم', u'وبوقتكما', u'وبوقتهن', u'وبوقتهم', u'كوقتنا', u'ووقتهن', u'ووقتهم', u'فوقتكم', u'فوقتكن', u'بوقتكما', u'فلوقتهن', u'فلوقتهم', u'كوقت', u'وبوقتنا', u'وبوقت', u'ولوقتكما', u'ووقتنا', u'وكوقتهما', u'فلوقتكم', u'فكوقتها', u'فلوقتها', u'فكوقتكن', u'وقتكم', u'وقتكن', u'فكوقتكم', u'ولوقت', u'وكوقتكما', u'وبوقتها', u'ووقتها', u'ولوقتهن', u'ولوقتهم', u'فلوقتنا', u'فبوقتها', u'فكوقتكما', u'فبوقتهن', u'لوقتهن', u'لوقتهم', u'وقتنا', u'فلوقتي', u'كوقتكن', u'كوقتكم', u'لوقتنا', u'كوقتي', u'وكوقتهن', u'وكوقتهم', u'فبوقتكما', u'فوقتها', u'فوقت', u'فبوقتنا', u'بوقتك', u'فبوقتهما', u'بوقته', u'بوقتنا', u'بوقتي', u'وكوقتها', u'وقتهما', u'فبوقتهم', u'لوقتها', u'كوقته', u'كوقتك']),
 u'أولئكم': set([u'لأولئكم', u'أوكأولئكم', u'ألأولئكم', u'أبأولئكم', u'فكأولئكم', u'بأولئكم', u'أوأولئكم', u'فبأولئكم', u'أولأولئكم', u'أكأولئكم', u'وأولئكم', u'أفلأولئكم', u'أفكأولئكم', u'وبأولئكم', u'أوبأولئكم', u'فلأولئكم', u'فأولئكم', u'أأولئكم', u'ولأولئكم', u'وكأولئكم', u'أفأولئكم', u'أولئكم', u'أفبأولئكم', u'كأولئكم']),
 u'نحو': set([u'ونحوهن', u'ألنحوهم', u'ألنحوهن', u'ونحوهم', u'أوكنحوك', u'فنحوها', u'ولنحوي', u'فكنحوهن', u'فكنحوهم', u'أفكنحونا', u'ولنحوك', u'أفلنحوهما', u'وكنحوه', u'فكنحوي', u'أفنحوكما', u'لنحو', u'كنحوي', u'أوبنحوك', u'كنحوه', u'أفبنحوه', u'وكنحوي', u'كنحوك', u'أونحوهم', u'ألنحونا', u'أولنحوكم', u'بنحوكما', u'وكنحوها', u'أنحوكن', u'أفكنحوهم', u'فكنحوكما', u'فنحو', u'ألنحوه', u'أفبنحوكما', u'أونحوي', u'أفكنحوه', u'لنحوه', u'أولنحوهم', u'أفكنحوك', u'لنحوك', u'أفبنحوهما', u'لنحوي', u'ولنحوه', u'أفبنحونا', u'وبنحو', u'أكنحو', u'وبنحوي', u'وكنحوهن', u'فنحوي', u'بنحوك', u'فنحوه', u'بنحو', u'وبنحوك', u'أكنحوهن', u'فنحوك', u'وبنحوه', u'أوبنحوي', u'أولنحوك', u'فلنحوهما', u'ولنحوكن', u'ولنحوكم', u'كنحوهن', u'كنحوهم', u'أفنحوه', u'ونحوها', u'ألنحوها', u'فنحوهم', u'بنحوه', u'أوكنحوهن', u'فنحوهن', u'بنحوي', u'ونحو', u'أبنحو', u'بنحوكن', u'بنحوكم', u'فبنحوكن', u'أبنحوكما', u'نحو', u'ولنحوكما', u'أونحوكم', u'أونحوكن', u'أولنحوهن', u'فبنحوهما', u'ألنحوك', u'أولنحونا', u'فبنحوكم', u'أبنحونا', u'أبنحوي', u'أفنحو', u'أبنحوه', u'أبنحوك', u'أفنحونا', u'أوكنحو', u'أوبنحوهم', u'وبنحوهن', u'وبنحوهم', u'أوبنحوهن', u'فكنحوك', u'ونحونا', u'أبنحوهم', u'أبنحوهن', u'فلنحوكما', u'أوكنحوهما', u'نحوها', u'فكنحونا', u'أفنحوكن', u'أفنحوكم', u'أونحوك', u'نحوهم', u'أنحوكم', u'فبنحوكما', u'أكنحوهم', u'فكنحوه', u'وبنحوكما', u'أنحوي', u'وكنحوكن', u'أنحوه', u'وكنحوكم', u'أولنحوه', u'أوبنحونا', u'أنحوك', u'أوكنحوه', u'ونحوك', u'أولنحوكما', u'ونحوه', u'أبنحوها', u'ونحوي', u'أفلنحوهم', u'أفلنحوهن', u'نحوهن', u'كنحو', u'أفبنحوكم', u'لنحوكن', u'نحوي', u'فبنحونا', u'لنحوكم', u'أكنحوه', u'أونحوكما', u'أفكنحو', u'نحوك', u'أكنحوي', u'نحوه', u'أفكنحوكما', u'أولنحوها', u'فبنحوك', u'أكنحوك', u'أولنحوي', u'أفلنحونا', u'نحونا', u'وكنحوهما', u'فلنحو', u'فلنحوكن', u'أفنحوي', u'أكنحوهما', u'أوكنحوي', u'وبنحوها', u'أوبنحوها', u'وكنحوك', u'أوبنحوه', u'بنحوها', u'أفكنحوهن', u'ولنحوها', u'أكنحوها', u'أونحوهن', u'أفنحوهما', u'أنحوهما', u'أفكنحوي', u'أفبنحوها', u'ونحوكن', u'ألنحوكم', u'ألنحوكن', u'ونحوكم', u'ولنحونا', u'أفكنحوكم', u'فبنحوها', u'فكنحوكم', u'أفكنحوكن', u'أكنحونا', u'وكنحوكما', u'أفلنحوها', u'فبنحوه', u'أونحوه', u'أونحونا', u'فبنحو', u'أفلنحوي', u'كنحوهما', u'كنحوكما', u'أفلنحوكما', u'أفلنحوه', u'فبنحوي', u'أفلنحوك', u'أولنحوهما', u'أفبنحوك', u'أفلنحوكم', u'أفلنحوكن', u'وبنحوهما', u'أنحوهن', u'وبنحونا', u'أنحوكما', u'ألنحوكما', u'بنحونا', u'ألنحو', u'فكنحوهما', u'ألنحوهما', u'أفبنحوكن', u'فلنحوكم', u'بنحوهما', u'كنحوكن', u'أولنحو', u'فنحوكم', u'فنحوكن', u'ولنحو', u'بنحوهن', u'بنحوهم', u'ولنحوهن', u'فنحوهما', u'أونحوها', u'كنحوها', u'ولنحوهم', u'فلنحونا', u'ونحوهما', u'أوكنحونا', u'فبنحوهن', u'وكنحو', u'فبنحوهم', u'أوكنحوكم', u'أوكنحوكن', u'ونحوكما', u'أكنحوكم', u'أوبنحوكم', u'أنحوها', u'نحوهما', u'أوبنحوكن', u'أوبنحوكما', u'فلنحوي', u'نحوكما', u'أكنحوكن', u'أبنحوكم', u'فلنحوك', u'أبنحوكن', u'أنحونا', u'ألنحوي', u'فلنحوه', u'أوبنحوهما', u'لنحوكما', u'أفنحوهن', u'أفنحوهم', u'وبنحوكن', u'وبنحوكم', u'أفبنحوي', u'أونحوهما', u'وكنحوهم', u'أنحو', u'فكنحو', u'فلنحوها', u'أولنحوكن', u'أوكنحوهم', u'أفبنحوهم', u'أفبنحوهن', u'أبنحوهما', u'فكنحوها', u'فنحوكما', u'لنحوها', u'أنحوهم', u'أفلنحو', u'أفنحوها', u'فنحونا', u'أوبنحو', u'أوكنحوكما', u'ولنحوهما', u'أونحو', u'أفنحوك', u'فلنحوهن', u'فلنحوهم', u'نحوكم', u'أفكنحوهما', u'نحوكن', u'أوكنحوها', u'أفكنحوها', u'لنحوهن', u'لنحوهم', u'وكنحونا', u'أفبنحو', u'فكنحوكن', u'لنحوهما', u'كنحوكم', u'أكنحوكما', u'كنحونا', u'لنحونا']),
 u'حسب': set([u'فبحسبهما', u'أفلحسبه', u'فبحسبنا', u'أبحسبي', u'أبحسبه', u'أولحسبهم', u'وبحسبكن', u'أوحسبكن', u'وبحسبكم', u'فكحسبهن', u'حسبي', u'فكحسبهم', u'فبحسبكما', u'أفبحسبنا', u'حسبك', u'وكحسبكن', u'وكحسبكم', u'حسبه', u'وبحسبي', u'ألحسبي', u'وبحسبهما', u'بحسبهما', u'أوحسبي', u'أفكحسبهما', u'ألحسبك', u'وبحسبك', u'أوحسبها', u'أوبحسب', u'ألحسبه', u'وبحسبه', u'فكحسبنا', u'حسبكم', u'بحسبكما', u'فكحسب', u'ألحسبكن', u'وبحسبكما', u'أولحسبكما', u'أوبحسبك', u'ولحسبهما', u'وحسبك', u'وحسبهما', u'وحسبه', u'فحسب', u'ألحسبكم', u'أبحسبك', u'لحسبه', u'وحسبي', u'أكحسبنا', u'لحسبك', u'أولحسبهما', u'وحسبكما', u'أفلحسبهما', u'كحسبكن', u'كحسبكم', u'كحسبك', u'فلحسبها', u'أفحسبي', u'كحسبه', u'حسبكن', u'ولحسبه', u'بحسبك', u'ولحسبك', u'بحسبه', u'أكحسبهما', u'وكحسبهما', u'أوحسبكم', u'بحسبي', u'ولحسبي', u'أوحسبنا', u'أوبحسبه', u'فكحسبها', u'وكحسبك', u'فكحسبهما', u'وكحسبه', u'حسب', u'وكحسبي', u'أوكحسبكم', u'أوكحسبها', u'أفبحسبي', u'ألحسبكما', u'أبحسب', u'فبحسب', u'أفحسبها', u'لحسبها', u'أكحسبها', u'أوكحسب', u'أفلحسبي', u'لحسبهما', u'أفلحسبهن', u'أفحسبك', u'فبحسبك', u'وكحسبكما', u'فحسبي', u'فبحسبه', u'أفكحسبكم', u'أحسبهن', u'فحسبهم', u'فحسبهن', u'فبحسبي', u'فلحسبهما', u'فبحسبكن', u'فبحسبكم', u'أوبحسبها', u'ولحسبهن', u'بحسبكن', u'بحسبكم', u'ولحسبهم', u'أفلحسبكما', u'أفكحسبها', u'ألحسبهم', u'أفلحسبنا', u'أبحسبهما', u'أولحسبها', u'فلحسبهن', u'فلحسبهم', u'أحسبها', u'فحسبها', u'أوبحسبهم', u'أوبحسبهن', u'أفبحسبكن', u'وحسبكن', u'وحسبكم', u'فلحسبكما', u'أبحسبكم', u'حسبهما', u'وبحسبنا', u'أبحسبكن', u'أفكحسبكن', u'أحسبكم', u'فلحسبنا', u'أفحسبهن', u'أكحسبك', u'حسبنا', u'لحسبهن', u'لحسبهم', u'أحسبي', u'كحسب', u'ولحسبكم', u'أوكحسبكن', u'أفكحسبهن', u'كحسبها', u'وكحسب', u'أحسبك', u'أفلحسبها', u'أوكحسبه', u'أحسبه', u'ولحسبها', u'وبحسبهن', u'وبحسبهم', u'أفلحسبك', u'كحسبهما', u'بحسب', u'أوحسبك', u'أحسبنا', u'فحسبنا', u'أوحسبهما', u'أوبحسبي', u'وكحسبهن', u'وكحسبهم', u'كحسبكما', u'أولحسبه', u'أكحسبي', u'أفكحسبه', u'أوبحسبكما', u'أفكحسبي', u'أفبحسبهن', u'فكحسبكن', u'أكحسبكما', u'أولحسبنا', u'فكحسبكم', u'أفبحسبكم', u'وبحسب', u'أكحسبه', u'أولحسبكن', u'فلحسبي', u'حسبكما', u'فلحسبه', u'ألحسبهن', u'فلحسبك', u'أفحسبهما', u'ولحسبكن', u'أفبحسبك', u'حسبها', u'أحسبهم', u'فلحسبكن', u'فلحسبكم', u'أبحسبها', u'ألحسبها', u'أوكحسبنا', u'أفبحسب', u'أوبحسبنا', u'أولحسبي', u'لحسبكن', u'كحسبهن', u'لحسبكما', u'كحسبهم', u'أكحسبكن', u'أولحسبك', u'حسبهم', u'حسبهن', u'أفلحسبكن', u'أفبحسبكما', u'أفكحسب', u'لحسب', u'وبحسبها', u'ولحسب', u'وحسبنا', u'أوحسبهن', u'كحسبنا', u'ولحسبنا', u'أفبحسبهم', u'وكحسبها', u'أحسبكما', u'أفكحسبهم', u'أبحسبكما', u'أولحسبكم', u'أوكحسبكما', u'ولحسبكما', u'أفحسبهم', u'أفلحسبكم', u'أفكحسبكما', u'بحسبنا', u'ألحسبهما', u'ألحسب', u'أفبحسبهما', u'أكحسبهم', u'أفلحسبهم', u'فكحسبكما', u'أكحسبهن', u'أوحسبكما', u'أوحسبه', u'أفكحسبنا', u'فحسبكم', u'فحسبكن', u'أولحسب', u'فبحسبهن', u'فبحسبهم', u'أكحسبكم', u'أفحسبنا', u'أوحسبهم', u'وحسبها', u'بحسبهن', u'بحسبهم', u'لحسبي', u'أحسبهما', u'فحسبكما', u'وكحسبنا', u'أحسبكن', u'ألحسبنا', u'أفحسب', u'أوكحسبي', u'فلحسب', u'فبحسبها', u'أوبحسبكم', u'أوبحسبكن', u'لحسبنا', u'أفلحسب', u'أوبحسبهما', u'بحسبها', u'وحسبهن', u'وحسبهم', u'فحسبه', u'أبحسبنا', u'فحسبك', u'فكحسبي', u'أحسب', u'أوكحسبك', u'أفبحسبها', u'فكحسبك', u'فكحسبه', u'أفحسبه', u'كحسبي', u'لحسبكم', u'أوحسب', u'أبحسبهم', u'أوكحسبهما', u'أبحسبهن', u'فحسبهما', u'أفبحسبه', u'أفكحسبك', u'وحسب', u'أكحسب', u'أفحسبكن', u'أفحسبكم', u'أوكحسبهن', u'أوكحسبهم', u'أولحسبهن', u'أفحسبكما']),
 u'نحن': set([u'أنحن', u'فنحن', u'أونحن', u'أفنحن', u'ونحن', u'ألنحن', u'أفلنحن', u'ولنحن', u'نحن', u'لنحن', u'أولنحن', u'فلنحن']),
 u'لئن': set([u'فلئن', u'لئن', u'ولئن']),
 u'اللذين': set([u'وباللذين', u'باللذين', u'فللذين', u'فباللذين', u'كاللذين', u'فكاللذين', u'فاللذين', u'للذين', u'واللذين', u'وكاللذين', u'وللذين', u'اللذين']),
 u'أب': set([u'وأب', u'أب', u'فأب']),
 u'أخ': set([u'وأخ', u'أخ', u'فأخ']),
 u'قبل': set([u'فقبل', u'وقبل', u'قبل']),
 u'بدون': set([u'فبدونه', u'وبدونها', u'فبدونك', u'وبدوني', u'فبدونكن', u'بدوني', u'وبدونه', u'فبدونكم', u'فبدوني', u'بدونها', u'وبدونك', u'فبدونهن', u'فبدونهم', u'فبدونهما', u'بدون', u'فبدوننا', u'فبدونكما', u'فبدون', u'وبدوننا', u'وبدونهما', u'بدوننا', u'بدونكما', u'وبدونكن', u'وبدونكم', u'بدونهما', u'وبدون', u'وبدونهن', u'بدونكن', u'بدونه', u'بدونكم', u'بدونك', u'وبدونهم', u'بدونهن', u'بدونهم', u'فبدونها', u'وبدونكما']),
 u'مادامتا': set([u'مادامتا', u'ومادامتا', u'فمادامتا']),
 u'بئس': set([u'بئس', u'فبئس', u'وبئس']),
 u'د': set([u'د']),
 u'ذا': set([u'وكذا', u'فبذا', u'وبذا', u'بذا', u'فلذا', u'كذا', u'لذا', u'فكذا', u'ذا', u'ولذا', u'وذا', u'فذا']),
 u'لعمر': set([u'ولعمرها', u'ولعمركما', u'لعمرها', u'فلعمرها', u'لعمركما', u'لعمرهما', u'فلعمرهن', u'لعمري', u'فلعمر', u'لعمر', u'لعمره', u'فلعمركما', u'ولعمرهما', u'ولعمرنا', u'فلعمرهما', u'لعمرنا', u'فلعمرك', u'فلعمره', u'ولعمرهم', u'فلعمري', u'ولعمرك', u'فلعمرنا', u'لعمرك', u'ولعمره', u'ولعمرهن', u'ولعمري', u'لعمرهم', u'لعمرهن', u'ولعمركم', u'فلعمرهم', u'ولعمر', u'ولعمركن', u'لعمركم', u'لعمركن', u'فلعمركم', u'فلعمركن']),
 u'هاهنا': set([u'فهاهنا', u'أهاهنا', u'وهاهنا', u'أفهاهنا', u'أوهاهنا', u'هاهنا']),
 u'كما': set([u'كما', u'فكما', u'وكما']),
 u'لستم': set([u'ألستم', u'لستم', u'فلستم', u'أولستم', u'ولستم', u'أفلستم']),
 u'لستن': set([u'ألستن', u'لستن', u'أولستن', u'فلستن', u'أفلستن', u'ولستن']),
 u'حتى': set([u'وحتى', u'حتى', u'فحتى']),
 u'لدى': set([u'أولدي', u'أولدى', u'أولديهما', u'ولدينا', u'فلديهن', u'لديهن', u'لديهم', u'ألديهما', u'لديكما', u'ألديها', u'أفلديهن', u'ولديكم', u'ولديكن', u'أولديكما', u'أفلدى', u'أولديه', u'فلدينا', u'لدي', u'ولديهم', u'ولديهن', u'لدى', u'ولديهما', u'أولديها', u'أفلدي', u'لدينا', u'ألديهن', u'أفلديكم', u'ألدى', u'ألدي', u'أفلديكن', u'أفلديهما', u'أفلديهم', u'فلديها', u'فلديهم', u'ولديها', u'أفلديكما', u'أولديك', u'أولدينا', u'لديهما', u'فلديه', u'فلديكم', u'فلديكن', u'ألديك', u'ألدينا', u'ألديكما', u'أولديهم', u'ألديه', u'فلديك', u'أولديهن', u'ولديكما', u'فلدي', u'أفلديه', u'فلدى', u'أفلدينا', u'لديها', u'ألديكم', u'لديه', u'فلديهما', u'لديك', u'أولديكم', u'ألديهم', u'ولديه', u'أولديكن', u'أفلديها', u'ولديك', u'فلديكما', u'أفلديك', u'ألديكن', u'ولدى', u'لديكن', u'لديكم', u'ولدي']),
 u'ذه': set([u'وكذه', u'فبذه', u'وبذه', u'بذه', u'فلذه', u'كذه', u'لذه', u'فكذه', u'ذه', u'ولذه', u'وذه', u'فذه']),
 u'ذي': set([u'أولذي', u'أفلذي', u'أفكذي', u'فذي', u'بذي', u'فكذي', u'كذي', u'ألذي', u'أوبذي', u'لذي', u'أوكذي', u'أذي', u'أفبذي', u'أفذي', u'أبذي', u'ذي', u'فبذي', u'فلذي', u'ولذي', u'أكذي', u'وكذي', u'وبذي', u'وذي', u'أوذي']),
 u'ذو': set([u'ذو', u'وذو', u'فذو']),
 u'أي': set([u'فبأيك', u'فبأيه', u'فكأيهم', u'فكأيهن', u'فبأيي', u'وأيهما', u'وكأيها', u'وكأيكن', u'وأيهن', u'وأيهم', u'فأيي', u'لأيهن', u'لأيهم', u'بأيهما', u'فأيه', u'وأيها', u'فلأيهما', u'فأيكم', u'كأيي', u'لأيها', u'كأيك', u'كأيه', u'فلأيها', u'فبأي', u'فكأيها', u'ولأيهن', u'فلأيكن', u'فلأيكم', u'فأيكما', u'وبأيي', u'فلأيي', u'وكأيهن', u'وكأيهم', u'وبأيه', u'فلأيكما', u'فلأيك', u'وبأيك', u'فبأيهما', u'وأينا', u'فبأيهن', u'فأينا', u'فبأيكما', u'لأينا', u'كأيكم', u'كأيكن', u'فكأي', u'فأيهن', u'فأي', u'فأيهم', u'فكأينا', u'ولأيهما', u'ولأيكما', u'وبأيهم', u'وبأيهن', u'بأيها', u'ولأيي', u'فأيها', u'ولأيك', u'ولأيه', u'وكأي', u'وبأيها', u'فلأيه', u'أي', u'فكأيي', u'فبأيها', u'ولأي', u'وكأيك', u'فكأيك', u'وأيه', u'فلأيهم', u'وأيك', u'أيك', u'وأيي', u'ولأينا', u'وكأيه', u'وكأيكم', u'وكأينا', u'فكأيكما', u'وأيكن', u'وأيكم', u'وبأينا', u'وكأيكما', u'أيي', u'فلأينا', u'أيها', u'أيه', u'لأيكما', u'فبأيهم', u'بأيهن', u'بأيهم', u'أيهن', u'أيهم', u'لأيك', u'لأيه', u'فأيك', u'لأيي', u'بأينا', u'فلأي', u'أينا', u'لأيهما', u'فكأيكم', u'فكأيكن', u'فكأيه', u'أيهما', u'كأيهم', u'كأيهن', u'فبأيكن', u'فبأيكم', u'بأي', u'كأيهما', u'ولأيكم', u'ولأيكن', u'فأيهما', u'كأينا', u'وبأيكم', u'وبأيكن', u'ولأيهم', u'فأيكن', u'بأيكن', u'بأيكم', u'كأي', u'أيكن', u'أيكم', u'لأيكن', u'لأيكم', u'لأي', u'فلأيهن', u'فكأيهما', u'وأي', u'بأيه', u'أيكما', u'بأيك', u'وبأي', u'وأيكما', u'وكأيي', u'وبأيهما', u'بأيي', u'وبأيكما', u'كأيكما', u'فبأينا', u'كأيها', u'بأيكما', u'وكأيهما', u'ولأيها']),
 u'أو': set([u'أو']),
 u'أف': set([u'أف', u'وأف', u'فأف']),
 u'أن': set([u'وكأننا', u'وأنها', u'وأنكما', u'وكأنهن', u'وكأنهم', u'كأنها', u'وبأننا', u'وكأنه', u'وكأنك', u'وكأني', u'وكأنهما', u'وكأنها', u'لأنكما', u'وأننا', u'كأنهم', u'كأنهن', u'فأنكما', u'فبأنك', u'لأنه', u'كأن', u'فبأن', u'وأنهن', u'لأنك', u'بأنهما', u'فكأنكم', u'فكأنكن', u'فأنهما', u'وكأنكما', u'لأنهما', u'بأنهن', u'بأنهم', u'لأنها', u'وبأنكم', u'وبأنكن', u'لأني', u'أنهن', u'فأنهم', u'بأنكما', u'فأن', u'فبأنكن', u'فبأنكم', u'فكأن', u'وأنهما', u'أنهما', u'فأننا', u'بأنك', u'أني', u'بأنه', u'أنه', u'بأني', u'أنك', u'وكأن', u'لأننا', u'فلأنكما', u'بأنها', u'ولأن', u'فلأنهما', u'كأنكما', u'أنكما', u'لأنهن', u'لأنهم', u'فلأنهم', u'كأنهما', u'فأنها', u'أننا', u'ولأنه', u'وبأني', u'وكأنكن', u'وكأنكم', u'وبأنك', u'فلأنهن', u'وبأنه', u'فلأنها', u'فبأنكما', u'ولأني', u'فلأني', u'بأننا', u'فكأنكما', u'ولأنك', u'فبأنهما', u'فأنه', u'أنها', u'فأنك', u'ولأنكم', u'فأني', u'فكأنها', u'فكأننا', u'كأنكم', u'كأنكن', u'ولأنهم', u'ولأنهن', u'ولأنها', u'ولأنهما', u'فكأنه', u'فكأنهم', u'فكأنهن', u'فلأن', u'فبأنه', u'فبأني', u'وأنه', u'كأني', u'فلأنك', u'كأنه', u'ولأننا', u'فلأنه', u'كأنك', u'وأنكن', u'وأنكم', u'فبأننا', u'وأنهم', u'فكأني', u'وبأنهما', u'فكأنك', u'وبأنهم', u'وبأنهن', u'أن', u'فأنكن', u'بأنكن', u'بأنكم', u'فأنكم', u'بأن', u'فكأنهما', u'أنكن', u'فأنهن', u'أنكم', u'فلأننا', u'فبأنهن', u'فبأنهم', u'أنهم', u'وبأنكما', u'ولأنكن', u'لأن', u'فلأنكن', u'ولأنكما', u'فبأنها', u'فلأنكم', u'وبأن', u'وأنك', u'لأنكن', u'لأنكم', u'كأننا', u'وأني', u'وبأنها', u'وأن']),
 u'أم': set([u'أم']),
 u'نعما': set([u'فنعما', u'ونعما', u'نعما']),
 u'هيت': set([u'فهيت', u'وهيت', u'هيت']),
 u'هيا': set([u'هيا', u'وهيا', u'فهيا']),
 u'مابرح': set([u'ومابرح', u'مابرح', u'فمابرح']),
 u'حينما': set([u'حينما', u'وحينما', u'فحينما']),
 u'هلا': set([u'وهلا', u'فهلا', u'هلا']),
 u'إنما': set([u'وإنما', u'إنما', u'فإنما']),
 u'جعل': set([u'لجعل', u'وجعل', u'جعل', u'ولجعل', u'فلجعل', u'فجعل']),
 u'كخ': set([u'كخ']),
 u'ت': set([u'ت']),
 u'عما': set([u'وعما', u'فعما', u'عما']),
 u'بكن': set([u'أبكن', u'فبكن', u'أوبكن', u'بكن', u'أفبكن', u'وبكن']),
 u'بكم': set([u'أبكم', u'أوبكم', u'فبكم', u'بكم', u'وبكم', u'أفبكم']),
 u'مازلنا': set([u'ومازلنا', u'مازلنا', u'فمازلنا']),
 u'غ': set([u'غ']),
 u'رويدك': set([u'فرويدك', u'رويدك', u'ورويدك']),
 u'دون': set([u'دون', u'ودون', u'فدون']),
 u'أولئك': set([u'أكأولئك', u'وأولئك', u'ولأولئك', u'وبأولئك', u'لأولئك', u'أوكأولئك', u'أأولئك', u'فلأولئك', u'أفكأولئك', u'بأولئك', u'أفلأولئك', u'أبأولئك', u'أولأولئك', u'أولئك', u'أوبأولئك', u'أوأولئك', u'ألأولئك', u'فبأولئك', u'أفبأولئك', u'أفأولئك', u'وكأولئك', u'فأولئك', u'كأولئك', u'فكأولئك']),
 u'كي': set([u'وكي', u'كي', u'فكي']),
 u'هؤلاء': set([u'فكهؤلاء', u'أفلهؤلاء', u'وهؤلاء', u'فهؤلاء', u'لهؤلاء', u'أفهؤلاء', u'ألهؤلاء', u'ولهؤلاء', u'أوهؤلاء', u'أهؤلاء', u'هؤلاء', u'أفكهؤلاء', u'وبهؤلاء', u'فبهؤلاء', u'أولهؤلاء', u'أبهؤلاء', u'كهؤلاء', u'وكهؤلاء', u'أوكهؤلاء', u'أكهؤلاء', u'فلهؤلاء', u'أوبهؤلاء', u'بهؤلاء', u'أفبهؤلاء']),
 u'لها': set([u'ألها', u'لها', u'أولها', u'فلها', u'ولها', u'أفلها']),
 u'ي': set([u'ي']),
 u'مكانكما': set([u'فمكانكما', u'ومكانكما', u'مكانكما']),
 u'كم': set([u'فكم', u'كم', u'وكم']),
 u'كل': set([u'فبكلك', u'فبكلهم', u'كلها', u'فبكله', u'أفكلهما', u'وكلنا', u'ولكلهن', u'ولكلهم', u'أولكلكم', u'أولكلكن', u'فبكلهن', u'لكلنا', u'أفككل', u'ككل', u'ألكلكما', u'ألكلهن', u'ألكلهم', u'فلكلنا', u'فبكلنا', u'أوبكلهن', u'أوككلنا', u'بكلنا', u'لكل', u'أكلكم', u'أولكلك', u'أفبكلهما', u'أفلكلهما', u'أولكله', u'فبكلي', u'وبكل', u'أككلها', u'كلنا', u'أكله', u'فكلي', u'أوبكلها', u'ككلكما', u'أفكلهن', u'أفلكلها', u'فكلك', u'كلهما', u'وككلكما', u'فكله', u'وككلنا', u'أوبكلك', u'كلكما', u'أككلهن', u'فككلهما', u'وبكلكن', u'أفككلكم', u'أفككلكن', u'وبكلكم', u'أوككلكن', u'كلهم', u'كلهن', u'أكلهم', u'أفلكلك', u'وكلهما', u'ألكلهما', u'أفكلنا', u'أوبكله', u'ولكلها', u'أفلكلهم', u'ولكلكما', u'وكلكما', u'أفكلكما', u'أكلهن', u'ككلهما', u'أككلنا', u'أوككلكم', u'ككلي', u'أككلكما', u'فلكلكما', u'أفككلنا', u'فبكلها', u'ككلك', u'ألكلكم', u'ككله', u'فلكلهما', u'أفلكلهن', u'فلكله', u'بكلي', u'وككلها', u'بكلكم', u'كلي', u'بكلكن', u'بكلك', u'فكلكما', u'أفلكلي', u'بكله', u'فلكلي', u'ولكلك', u'فككلهن', u'فككلهم', u'أفلكل', u'ككلكم', u'لكلكم', u'أكلك', u'لكلكن', u'أفبكلي', u'وبكلنا', u'ولكلنا', u'أبكلكن', u'وكلكم', u'أوككلهما', u'وككل', u'وكلكن', u'أكلي', u'فلكلهم', u'أولكلي', u'فلكلهن', u'أبكل', u'فككلها', u'أوبكلهم', u'أبكلهما', u'فكلهما', u'أفبكلنا', u'وككله', u'وكل', u'ألكلي', u'أفبكل', u'وككلي', u'ألكله', u'أكلهما', u'فلكلها', u'أككلك', u'وككلك', u'ولكلهما', u'أكلها', u'أوبكل', u'ألكلها', u'أوكلهما', u'فكلكم', u'فكلكن', u'وككلهم', u'أفبكلهن', u'أفبكلهم', u'وككلهن', u'لكلي', u'أفكلها', u'لكله', u'أفككلي', u'لكلك', u'أككلهما', u'ولكلكن', u'فككلنا', u'ولكلكم', u'أكلكن', u'أككلي', u'فكل', u'أبكلك', u'فبكلكم', u'أوككلهم', u'أبكله', u'فبكلكن', u'ألكلكن', u'فلكلك', u'أوكلكما', u'أفككلك', u'فككلكما', u'أولكلهم', u'أولكلهن', u'وبكلهما', u'أوكلكن', u'أولكل', u'أفلكلكن', u'أوبكلكم', u'أوبكلكن', u'وبكلها', u'أفككلها', u'ألكلك', u'بكل', u'أبكلي', u'أولكلنا', u'أفلكلكما', u'أوككلها', u'أوككلك', u'أوككله', u'فبكل', u'أولكلهما', u'أبكلكم', u'أوككلي', u'أككلكم', u'أككلكن', u'كل', u'وبكلهن', u'أفككلهم', u'أفككلهن', u'وبكلهم', u'أفكلكن', u'أوكلكم', u'أفكلكم', u'أفكلك', u'أفكله', u'أوكلنا', u'أفبكلها', u'أفلكلكم', u'كله', u'لكلكما', u'كلك', u'أوبكلي', u'وبكلكما', u'كلكم', u'كلكن', u'لكلهما', u'أككله', u'أوككلهن', u'أكل', u'فكلنا', u'أولكلها', u'أوكلهن', u'أوكلهم', u'فكلها', u'بكلهم', u'فككل', u'بكلهن', u'ألكل', u'وككلهما', u'أفكلي', u'ألكلنا', u'أفبكلك', u'أفبكله', u'ككلهن', u'ككلهم', u'أفلكله', u'أككلهم', u'أوكل', u'فككلك', u'أبكلهم', u'أوكلي', u'فككله', u'وكلي', u'وكلهم', u'أوكلك', u'وكلهن', u'فككلكن', u'أفككلهما', u'أوكله', u'فككلكم', u'فلكلكم', u'وبكلك', u'فبكلهما', u'فلكلكن', u'لكلهم', u'وبكله', u'لكلهن', u'وبكلي', u'ككلنا', u'فبكلكما', u'أبكلنا', u'أبكلها', u'ولكله', u'فلكل', u'أفكلهم', u'ولكل', u'بكلهما', u'أبكلهن', u'وكلها', u'أفككله', u'ولكلي', u'أوبكلكما', u'بكلكما', u'لكلها', u'أبكلكما', u'ككلكن', u'أكلنا', u'أفلكلنا', u'أوبكلهما', u'أفبكلكما', u'أوكلها', u'فكلهم', u'فكلهن', u'فككلي', u'أوككل', u'وككلكم', u'بكلها', u'أكلكما', u'أفككلكما', u'أولكلكما', u'أفكل', u'أوككلكما', u'أوبكلنا', u'أككل', u'وكلك', u'ككلها', u'وكله', u'أفبكلكن', u'أفبكلكم', u'وككلكن']),
 u'مافتئتن': set([u'ومافتئتن', u'فمافتئتن', u'مافتئتن']),
 u'ماانفككتما': set([u'فماانفككتما', u'ماانفككتما', u'وماانفككتما']),
 u'لعل': set([u'لعلهن', u'لعلهم', u'أولعلكم', u'فلعلكما', u'فلعلهم', u'فلعلك', u'فلعلكن', u'فلعلكم', u'ولعلنا', u'فلعله', u'أفلعلهما', u'فلعلي', u'فلعلهما', u'أولعلهن', u'لعله', u'فلعلهن', u'لعلك', u'ولعلكم', u'ولعلكن', u'لعلي', u'أفلعلنا', u'أولعلهم', u'أفلعلي', u'أفلعله', u'لعلنا', u'ألعلكم', u'ولعلهم', u'ولعلهن', u'ألعلكن', u'أفلعلك', u'ولعلكما', u'فلعلنا', u'ألعلهم', u'ألعلي', u'ألعلهما', u'ألعلهن', u'لعلكما', u'فلعلها', u'ألعلك', u'أولعلهما', u'ولعلها', u'فلعل', u'ولعلي', u'ولعل', u'أفلعلهم', u'أفلعلهن', u'ولعله', u'ولعلك', u'ألعله', u'أولعلها', u'ألعلها', u'لعل', u'أولعلنا', u'أفلعلكما', u'أولعلك', u'لعلها', u'أولعله', u'أولعل', u'أفلعل', u'أفلعلكم', u'أولعلكما', u'أفلعلها', u'أولعلي', u'ولعلهما', u'أولعلكن', u'لعلهما', u'لعلكن', u'لعلكم', u'ألعل', u'أفلعلكن', u'ألعلكما', u'ألعلنا']),
 u'إنا': set([u'فلإنا', u'ألإنا', u'أولإنا', u'أإنا', u'وإنا', u'أفإنا', u'لإنا', u'أفلإنا', u'إنا', u'ولإنا', u'أوإنا', u'فإنا']),
 u'لازال': set([u'أولازال', u'فلازال', u'أفلازال', u'ولازال', u'ألازال', u'لازال']),
 u'متى': set([u'ومتى', u'متى', u'فمتى']),
 u'مابرحوا': set([u'ومابرحوا', u'فمابرحوا', u'مابرحوا']),
 u'خلال': set([u'خلالها', u'وخلالنا', u'فخلال', u'خلالهما', u'وخلالكم', u'فخلالكما', u'وخلالكن', u'وخلالهما', u'وخلالهم', u'وخلالهن', u'خلالي', u'فخلالها', u'خلاله', u'خلالك', u'فخلالكم', u'فخلالكن', u'خلالكم', u'خلالكن', u'وخلالها', u'فخلالهم', u'فخلالهن', u'خلالهم', u'خلالهن', u'خلالكما', u'وخلالكما', u'فخلالنا', u'فخلالي', u'خلال', u'فخلالهما', u'فخلاله', u'خلالنا', u'فخلالك', u'وخلاله', u'وخلالك', u'وخلالي', u'وخلال']),
 u'مازلتن': set([u'فمازلتن', u'مازلتن', u'ومازلتن']),
 u'مازلتم': set([u'فمازلتم', u'ومازلتم', u'مازلتم']),
 u'ثنا': set([u'ثنا', u'وثنا', u'فثنا']),
 u'راح': set([u'فلراح', u'ولراح', u'راح', u'لراح', u'فراح', u'وراح']),
 u'هلم': set([u'هلم']),
 u'لولا': set([u'ولولا', u'لولا', u'فلولا']),
 u'مابرحتما': set([u'مابرحتما', u'ومابرحتما', u'فمابرحتما']),
 u'مافتئت': set([u'ومافتئت', u'مافتئت', u'فمافتئت']),
 u'مافتئتم': set([u'ومافتئتم', u'مافتئتم', u'فمافتئتم']),
 u'تان': set([u'وتان', u'فتان', u'تان']),
 u'مرة': set([u'مرة', u'فمرة', u'ومرة']),
 u'أصلا': set([u'وأصلا', u'أصلا', u'فأصلا']),
 u'وشكان': set([u'وشكان']),
 u'كأنما': set([u'لكأنما', u'أكأنما', u'أفلكأنما', u'كأنما', u'ولكأنما', u'ألكأنما', u'أولكأنما', u'وكأنما', u'أوكأنما', u'فكأنما', u'فلكأنما', u'أفكأنما']),
 u'إياهما': set([u'وإياهما', u'إياهما', u'فإياهما']),
 u'أسفل': set([u'لأسفلهما', u'فكأسفلنا', u'بأسفله', u'ولأسفلهن', u'بأسفلك', u'فبأسفلنا', u'لأسفلكما', u'بأسفلي', u'وأسفلهما', u'فبأسفلي', u'لأسفلها', u'فأسفل', u'أسفلكم', u'فبأسفلهن', u'فبأسفلهم', u'فأسفلهن', u'وبأسفلهم', u'وبأسفلهن', u'فأسفلهم', u'فلأسفل', u'فبأسفلها', u'فلأسفلكما', u'كأسفلكم', u'كأسفلكن', u'وكأسفلي', u'وبأسفلنا', u'وكأسفله', u'لأسفلنا', u'فلأسفلهما', u'وكأسفلك', u'فكأسفلهما', u'بأسفلكن', u'بأسفلكم', u'كأسفل', u'فكأسفلهم', u'فكأسفلهن', u'فلأسفلنا', u'وكأسفلنا', u'بأسفلهما', u'كأسفلهما', u'فلأسفلكم', u'كأسفلكما', u'وأسفلهم', u'كأسفله', u'كأسفلك', u'وكأسفلها', u'ولأسفلهم', u'كأسفلي', u'بأسفلكما', u'بأسفل', u'وبأسفلكم', u'وبأسفلكن', u'وكأسفلهن', u'وكأسفلهم', u'كأسفلنا', u'ولأسفلها', u'وكأسفلهما', u'أسفلك', u'فكأسفلها', u'أسفلكن', u'فأسفلها', u'وأسفلها', u'ولأسفلهما', u'وبأسفلها', u'ولأسفلنا', u'كأسفلها', u'وكأسفلكما', u'ولأسفلكما', u'لأسفلكن', u'بأسفلها', u'فبأسفلكما', u'فبأسفلكن', u'فبأسفلكم', u'وبأسفلهما', u'فلأسفلك', u'أسفلهن', u'وكأسفلكن', u'وكأسفلكم', u'أسفلهم', u'فبأسفلهما', u'فلأسفلي', u'وبأسفل', u'فلأسفله', u'لأسفلي', u'فأسفلكن', u'أسفلها', u'لأسفلكم', u'فأسفلكم', u'وبأسفلكما', u'لأسفلك', u'لأسفله', u'بأسفلنا', u'فكأسفلكم', u'فكأسفلكن', u'فلأسفلكن', u'كأسفلهم', u'كأسفلهن', u'أسفلي', u'فبأسفل', u'أسفله', u'وأسفلنا', u'بأسفلهن', u'بأسفلهم', u'وكأسفل', u'ولأسفل', u'وأسفلكن', u'وأسفلكم', u'أسفلنا', u'فلأسفلهن', u'فلأسفلهم', u'لأسفل', u'ولأسفلكن', u'ولأسفلك', u'وبأسفلي', u'ولأسفله', u'فكأسفلكما', u'ولأسفلي', u'وبأسفله', u'أسفل', u'وبأسفلك', u'فكأسفلي', u'لأسفلهن', u'فبأسفله', u'فكأسفله', u'لأسفلهم', u'فبأسفلك', u'فكأسفلك', u'فأسفلك', u'فأسفله', u'ولأسفلكم', u'فأسفلي', u'فأسفلهما', u'وأسفلكما', u'وأسفل', u'فأسفلكما', u'فأسفلنا', u'أسفلكما', u'فكأسفل', u'وأسفلهن', u'وأسفله', u'أسفلهما', u'وأسفلك', u'فلأسفلها', u'وأسفلي']),
 u'ص': set([u'ص']),
 u'أمامك': set([u'وأمامك', u'أمامك', u'فأمامك']),
 u'م': set([u'م']),
 u'مادمتما': set([u'مادمتما', u'ومادمتما', u'فمادمتما']),
 u'إياهم': set([u'إياهم', u'وإياهم', u'فإياهم']),
 u'ماانفكوا': set([u'فماانفكوا', u'ماانفكوا', u'وماانفكوا']),
 u'استحال': set([u'واستحال', u'لاستحال', u'فلاستحال', u'ولاستحال', u'استحال', u'فاستحال']),
 u'إليك': set([u'فإليك', u'إليك', u'وإليك']),
 u'أمسى': set([u'وأمسى', u'أمسى', u'لأمسى', u'ولأمسى', u'فأمسى', u'فلأمسى']),
 u'انبرى': set([u'وانبرى', u'ولانبرى', u'فلانبرى', u'انبرى', u'فانبرى', u'لانبرى']),
 u'مافتئتا': set([u'ومافتئتا', u'فمافتئتا', u'مافتئتا']),
 u'أنتم': set([u'لأنتم', u'أفلأنتم', u'أأنتم', u'فأنتم', u'ولأنتم', u'أوأنتم', u'وأنتم', u'أفأنتم', u'أولأنتم', u'فلأنتم', u'أنتم', u'ألأنتم']),
 u'لازالوا': set([u'ألازالوا', u'أفلازالوا', u'ولازالوا', u'لازالوا', u'فلازالوا', u'أولازالوا']),
 u'أنتن': set([u'لأنتن', u'أأنتن', u'أوأنتن', u'ولأنتن', u'فأنتن', u'أفأنتن', u'وأنتن', u'أفلأنتن', u'فلأنتن', u'أولأنتن', u'أنتن', u'ألأنتن']),
 u'ليستا': set([u'أوليستا', u'فليستا', u'أليستا', u'وليستا', u'أفليستا', u'ليستا']),
 u'ماانفككن': set([u'ماانفككن', u'وماانفككن', u'فماانفككن']),
 u'أوشك': set([u'أوشك', u'وأوشك', u'فأوشك', u'لأوشك', u'فلأوشك', u'ولأوشك']),
 u'طفق': set([u'وطفق', u'طفق', u'فطفق', u'فلطفق', u'لطفق', u'ولطفق']),
 u'لازالت': set([u'أفلازالت', u'فلازالت', u'ألازالت', u'أولازالت', u'ولازالت', u'لازالت']),
 u'صه': set([u'صه']),
 u'لازالا': set([u'أولازالا', u'ولازالا', u'ألازالا', u'أفلازالا', u'فلازالا', u'لازالا']),
 u'هناك': set([u'أفهناك', u'أوهناك', u'أهناك', u'فبهناك', u'وكهناك', u'ألهناك', u'هناك', u'فلهناك', u'وهناك', u'أكهناك', u'فهناك', u'أفبهناك', u'أولهناك', u'بهناك', u'ولهناك', u'وبهناك', u'فكهناك', u'أفكهناك', u'أفلهناك', u'أبهناك', u'كهناك', u'لهناك', u'أوبهناك', u'أوكهناك']),
 u'ليس': set([u'ليس', u'فليس', u'أوليس', u'أفليس', u'وليس', u'أليس']),
 u'هاذين': set([u'لهاذين', u'فلهاذين', u'أبهاذين', u'أهاذين', u'بهاذين', u'وبهاذين', u'أكهاذين', u'أولهاذين', u'فكهاذين', u'أوهاذين', u'أفكهاذين', u'أوبهاذين', u'أوكهاذين', u'فهاذين', u'ألهاذين', u'أفهاذين', u'فبهاذين', u'ولهاذين', u'هاذين', u'كهاذين', u'وهاذين', u'أفلهاذين', u'أفبهاذين', u'وكهاذين']),
 u'مازالوا': set([u'ومازالوا', u'فمازالوا', u'مازالوا']),
 u'إلا': set([u'فإلا', u'وإلا', u'إلا']),
 u'سوف': set([u'فلسوف', u'فسوف', u'سوف', u'ولسوف', u'لسوف', u'وسوف']),
 u'ب': set([u'ب']),
 u'آمين': set([u'وآمين', u'آمين', u'فآمين']),
 u'آناء': set([u'آناء', u'وآناء', u'فآناء']),
 u'هاتين': set([u'أوهاتين', u'كهاتين', u'وكهاتين', u'وهاتين', u'أوكهاتين', u'فهاتين', u'أفبهاتين', u'لهاتين', u'أهاتين', u'بهاتين', u'هاتين', u'أفلهاتين', u'فلهاتين', u'ألهاتين', u'أفكهاتين', u'وبهاتين', u'ولهاتين', u'أوبهاتين', u'أبهاتين', u'أكهاتين', u'أولهاتين', u'أفهاتين', u'فكهاتين', u'فبهاتين']),
 u'ليت': set([u'فليتكما', u'فليتها', u'وليته', u'وليتكما', u'وليتك', u'وليتي', u'وليتها', u'ليتها', u'وليتكن', u'وليتكم', u'ليت', u'فليتهن', u'ليتكم', u'ليتكن', u'وليتهن', u'وليتهم', u'فليتنا', u'فليتهما', u'ليتهم', u'ليتهن', u'فليتك', u'وليتهما', u'وليتنا', u'فليتهم', u'ليتي', u'فليته', u'ليتنا', u'فليتي', u'ليته', u'ليتكما', u'ليتك', u'فليتكم', u'فليتكن', u'فليت', u'وليت', u'ليتهما']),
 u'و': set([u'و']),
 u'أكثر': set([u'فكأكثر', u'وبأكثري', u'وبأكثره', u'فبأكثرهم', u'وبأكثرك', u'كأكثر', u'فأكثره', u'أكثري', u'أكثره', u'فأكثري', u'أكثرك', u'فأكثر', u'ولأكثرهن', u'لأكثركما', u'فلأكثري', u'فأكثرك', u'ولأكثركن', u'أكثر', u'لأكثرهما', u'لأكثرنا', u'أكثركما', u'بأكثرهما', u'فلأكثركم', u'فلأكثركن', u'فكأكثرهما', u'بأكثرنا', u'بأكثركما', u'وأكثركم', u'وأكثركن', u'فكأكثره', u'فبأكثرها', u'وأكثر', u'كأكثركن', u'كأكثركم', u'لأكثرها', u'فكأكثركما', u'ولأكثرنا', u'بأكثرهم', u'بأكثرهن', u'بأكثر', u'فأكثرهم', u'وبأكثركم', u'فأكثرهن', u'فلأكثركما', u'وكأكثرهم', u'وكأكثرهن', u'فبأكثرهن', u'ولأكثرهم', u'لأكثر', u'فلأكثره', u'ولأكثر', u'فلأكثرهما', u'فلأكثرك', u'وأكثرهما', u'وبأكثركن', u'فأكثرها', u'فأكثركما', u'وأكثركما', u'وكأكثرها', u'لأكثرك', u'ولأكثرها', u'لأكثره', u'لأكثري', u'وأكثرنا', u'فلأكثرهن', u'ولأكثري', u'ولأكثرك', u'فكأكثرنا', u'ولأكثره', u'فلأكثر', u'لأكثرهم', u'لأكثرهن', u'أكثركم', u'أكثركن', u'بأكثرها', u'وكأكثرهما', u'فأكثرنا', u'وكأكثرنا', u'فبأكثركم', u'فبأكثركن', u'وكأكثركما', u'كأكثرهما', u'فلأكثرها', u'وأكثرها', u'فأكثرهما', u'أكثرهما', u'فكأكثرها', u'بأكثره', u'بأكثرك', u'بأكثري', u'فكأكثرهن', u'فكأكثرهم', u'فبأكثرهما', u'وأكثره', u'وأكثرك', u'فلأكثرنا', u'وأكثري', u'ولأكثركما', u'فبأكثرك', u'فبأكثرنا', u'فبأكثره', u'فلأكثرهم', u'فبأكثري', u'وبأكثرنا', u'وأكثرهم', u'وأكثرهن', u'أكثرهم', u'أكثرهن', u'وكأكثر', u'بأكثركم', u'بأكثركن', u'ولأكثرهما', u'فكأكثرك', u'وبأكثر', u'وكأكثركم', u'كأكثرها', u'وكأكثرك', u'أكثرنا', u'وكأكثره', u'وكأكثري', u'فأكثركم', u'فأكثركن', u'فكأكثركن', u'فكأكثركم', u'وبأكثرها', u'ولأكثركم', u'وبأكثركما', u'وكأكثركن', u'وبأكثرهما', u'وبأكثرهن', u'وبأكثرهم', u'كأكثرنا', u'فبأكثركما', u'كأكثري', u'أكثرها', u'فكأكثري', u'كأكثرك', u'كأكثركما', u'كأكثره', u'كأكثرهن', u'كأكثرهم', u'فبأكثر', u'لأكثركم', u'لأكثركن']),
 u'إلى': set([u'أولإليه', u'إليهما', u'أولإليك', u'لإليهما', u'ألإليكم', u'فلإلينا', u'أوإلي', u'أوإلى', u'فإليها', u'أفلإليهن', u'أفإليهن', u'ولإليك', u'ألإلي', u'ألإلى', u'ولإليه', u'فلإليهم', u'فلإليهن', u'فلإلى', u'لإليكم', u'لإليكن', u'فلإلي', u'لإليكما', u'وإليكما', u'إلي', u'أإلينا', u'ولإليكن', u'أفإليكم', u'فلإليها', u'وإلى', u'أولإليكم', u'وإلي', u'أوإليه', u'أولإليكن', u'أوإليك', u'فلإليه', u'إليكن', u'إليكم', u'فلإليك', u'أإليهما', u'فإلي', u'فإلى', u'أإليكما', u'أفلإليهم', u'فإليهن', u'فإليهم', u'ولإليكما', u'أإليها', u'أوإليهن', u'أوإليهم', u'أفلإليكن', u'إليهن', u'إليهم', u'لإلى', u'لإلي', u'أوإلينا', u'ولإليهم', u'ولإليهن', u'أفإليها', u'أوإليكما', u'فلإليهما', u'فلإليكما', u'ولإليهما', u'أإليهم', u'فإليكما', u'أإليهن', u'أإلى', u'أإلي', u'أفإلى', u'أفإلي', u'ألإليها', u'أفإليكن', u'أوإليها', u'أولإليهن', u'أولإليهم', u'وإليكم', u'إليها', u'وإليكن', u'فلإليكم', u'فلإليكن', u'أولإلينا', u'لإليهم', u'لإليهن', u'ألإليهن', u'ولإليها', u'وإليهم', u'وإليهن', u'لإليها', u'فإليهما', u'أفلإلينا', u'ألإليكن', u'إلينا', u'أفإليهم', u'وإليها', u'وإليهما', u'أولإليها', u'ولإلينا', u'ألإلينا', u'فإليكن', u'فإليكم', u'أوإليكم', u'أإليك', u'فإليه', u'أإليه', u'أفإلينا', u'فإليك', u'ألإليهم', u'لإلينا', u'ولإلى', u'ولإلي', u'أفإليكما', u'أوإليكن', u'أولإلى', u'وإلينا', u'أولإلي', u'لإليك', u'لإليه', u'أولإليهما', u'ولإليكم', u'أولإليكما', u'أفلإليهما', u'ألإليك', u'إلى', u'ألإليه', u'إليكما', u'أفلإليك', u'ألإليهما', u'أفلإليه', u'أفإليه', u'فإلينا', u'أفإليك', u'ألإليكما', u'إليه', u'أفلإليكما', u'إليك', u'أوإليهما', u'أفلإلي', u'أفلإلى', u'أفلإليكم', u'أفلإليها', u'أفإليهما', u'أإليكم', u'أإليكن', u'وإليه', u'وإليك']),
 u'أثناء': set([u'كأثناء', u'فبأثناءي', u'أثناءكما', u'فبأثناءه', u'فبأثناءك', u'وكأثناءكم', u'وكأثناءكن', u'لأثناءكم', u'لأثناءكن', u'ولأثناءي', u'أثناءهن', u'فبأثناءهما', u'فأثناءهما', u'فبأثناءها', u'أثناءهما', u'فلأثناء', u'فبأثناءهم', u'فبأثناءهن', u'أثناء', u'وكأثناءهما', u'بأثناءي', u'وأثناءنا', u'فكأثناءك', u'وبأثناءهما', u'كأثناءكم', u'كأثناءكن', u'فأثناءكما', u'فبأثناءنا', u'وكأثناءنا', u'ولأثناءك', u'وبأثناءكما', u'وكأثناءه', u'وكأثناءك', u'ولأثناءه', u'فلأثناءي', u'فلأثناءها', u'فكأثناء', u'وأثناءها', u'فلأثناءك', u'فلأثناءه', u'وكأثناءكما', u'بأثناءكم', u'بأثناءكن', u'وأثناءكما', u'بأثناءك', u'أثناءكن', u'أثناءكم', u'وبأثناءكم', u'وبأثناءكن', u'فكأثناءكما', u'ولأثناء', u'ولأثناءكما', u'بأثناءكما', u'فأثناءكن', u'فأثناءكم', u'وبأثناءه', u'وبأثناءك', u'وبأثناءي', u'فلأثناءهم', u'فكأثناءكم', u'فكأثناءكن', u'فكأثناءه', u'وأثناءهم', u'وأثناءهن', u'بأثناء', u'فكأثناءي', u'فأثناءك', u'كأثناءي', u'فأثناءه', u'فلأثناءهما', u'فأثناءي', u'كأثناءك', u'لأثناءنا', u'كأثناءه', u'وبأثناءنا', u'وكأثناءهم', u'وكأثناءهن', u'ولأثناءهما', u'لأثناءهم', u'لأثناءهن', u'لأثناءه', u'فلأثناءكما', u'ولأثناءها', u'لأثناءك', u'كأثناءها', u'لأثناءي', u'فبأثناءكم', u'فبأثناءكن', u'فبأثناءكما', u'لأثناءها', u'كأثناءكما', u'لأثناءهما', u'وأثناءك', u'وأثناءه', u'كأثناءهم', u'كأثناءهن', u'وأثناءي', u'وأثناء', u'ولأثناءكم', u'ولأثناءكن', u'فلأثناءهن', u'بأثناءنا', u'كأثناءنا', u'كأثناءهما', u'لأثناءكما', u'وكأثناءها', u'فكأثناءنا', u'وأثناءكم', u'وأثناءكن', u'أثناءنا', u'بأثناءهم', u'وكأثناءي', u'بأثناءهن', u'فكأثناءها', u'فأثناء', u'فكأثناءهما', u'فأثناءها', u'فبأثناء', u'وبأثناءها', u'أثناءي', u'أثناءهم', u'بأثناءه', u'أثناءك', u'أثناءه', u'فأثناءهن', u'فأثناءهم', u'وبأثناءهم', u'وبأثناءهن', u'أثناءها', u'لأثناء', u'فلأثناءنا', u'وأثناءهما', u'وكأثناء', u'وبأثناء', u'فأثناءنا', u'ولأثناءهم', u'ولأثناءهن', u'ولأثناءنا', u'بأثناءها', u'بأثناءهما', u'فلأثناءكم', u'فكأثناءهم', u'فكأثناءهن', u'فلأثناءكن']),
 u'ابن': set([u'بابنها', u'وبابنها', u'فابن', u'ابنكم', u'ابنكن', u'فبابنهن', u'فبابنهم', u'وابني', u'فلابنكم', u'ولابنهما', u'وابنه', u'وابنك', u'فكابنهن', u'فلابنك', u'ولابني', u'فلابنه', u'وابنكن', u'فبابننا', u'وابنكم', u'فكابنها', u'ولابنه', u'وكابني', u'بابننا', u'وكابنه', u'وكابننا', u'وكابنك', u'وبابننا', u'ابن', u'بابن', u'فكابنهم', u'فبابنكن', u'وبابنه', u'بابنهن', u'وبابنك', u'بابنهم', u'فبابنهما', u'وبابنهن', u'وبابنهم', u'وبابني', u'فبابنكما', u'لابن', u'فلابنهما', u'فبابنها', u'فكابننا', u'وكابنكما', u'فابنهم', u'فابنهن', u'وكابنها', u'ولابنكما', u'لابنهن', u'لابنهم', u'فكابن', u'وكابنهما', u'فكابنكما', u'كابنه', u'وبابن', u'كابنك', u'فابننا', u'كابني', u'فلابني', u'وابن', u'ولابنك', u'ولابننا', u'فابني', u'فبابني', u'فلابن', u'فابنك', u'فبابنه', u'فابنه', u'فبابنك', u'لابنهما', u'كابنكن', u'فابنها', u'وكابنهن', u'ابني', u'لابنها', u'لابنه', u'لابني', u'ولابنكن', u'بابني', u'بابنه', u'فابنهما', u'بابنك', u'ولابن', u'فبابنكم', u'فابنكما', u'فلابنهن', u'فلابنهم', u'ابنهم', u'ابنهن', u'لابنكما', u'ولابنها', u'لابننا', u'فلابننا', u'فلابنكن', u'وبابنكما', u'بابنهما', u'ولابنهن', u'فكابنكن', u'فكابنكم', u'كابننا', u'وبابنهما', u'بابنكن', u'بابنكم', u'وكابن', u'ابنكما', u'وبابنكن', u'وبابنكم', u'فكابنهما', u'ولابنهم', u'فلابنها', u'ابنه', u'ابنك', u'بابنكما', u'كابنها', u'كابنكم', u'ابنها', u'فبابن', u'فابنكم', u'فابنكن', u'وكابنهم', u'لابنكن', u'لابنكم', u'وابنهما', u'كابن', u'وابنها', u'لابنك', u'ابنهما', u'فكابنه', u'فكابنك', u'ابننا', u'فكابني', u'وابنهن', u'ولابنكم', u'وابنهم', u'وابنكما', u'فلابنكما', u'وكابنكن', u'وكابنكم', u'كابنكما', u'وابننا', u'كابنهما', u'كابنهن', u'كابنهم']),
 u'بعدئذ': set([u'وبعدئذ', u'بعدئذ', u'فبعدئذ']),
 u'فلان': set([u'ففلان', u'أوفلان', u'فلان', u'أفلان', u'وفلان', u'أففلان']),
 u'ليل': set([u'فلليلنا', u'فليلهما', u'ولليلنا', u'ولليلها', u'فكليل', u'وبليلهم', u'وبليلهن', u'وبليل', u'ولليلهما', u'كليلهم', u'كليلهن', u'ولليل', u'كليلكما', u'وكليلكما', u'فليلكما', u'ولليلكما', u'وبليلنا', u'لليلهما', u'كليلي', u'وليلكم', u'وليلكما', u'كليلها', u'وكليلها', u'لليلكما', u'كليلك', u'لليلنا', u'ليل', u'وليلهما', u'بليلكما', u'كليلهما', u'وكليلكم', u'فلليلهما', u'بليلهما', u'وكليلكن', u'وبليلها', u'فكليلكم', u'فكليلكن', u'كليلنا', u'وكليله', u'لليلها', u'وكليلك', u'وليلي', u'وليله', u'وليلك', u'وكليلي', u'ليلك', u'فليلهن', u'فليلهم', u'فلليلكم', u'فلليلكن', u'فبليلهم', u'ولليلي', u'فبليلهن', u'لليل', u'ولليلك', u'ولليله', u'ليلكن', u'ليله', u'ليلكم', u'فليلها', u'فلليله', u'ليلي', u'لليلك', u'فبليلها', u'لليله', u'لليلي', u'وبليلهما', u'بليلكم', u'بليلكن', u'وبليلكما', u'لليلهم', u'لليلهن', u'وليلنا', u'فكليلهن', u'ولليلهم', u'وكليلهما', u'ولليلهن', u'وكليلهم', u'وكليلهن', u'فليلنا', u'وبليلكم', u'وبليلكن', u'فبليلنا', u'وليل', u'كليلكم', u'كليلكن', u'فبليله', u'فبليلك', u'فبليلي', u'فكليلهما', u'ولليلكم', u'وليلها', u'بليل', u'فكليلكما', u'فليلي', u'ولليلكن', u'فليله', u'فليلك', u'وليلهم', u'بليلنا', u'وليلهن', u'وكليل', u'وليلكن', u'ليلنا', u'بليلي', u'بليله', u'بليلك', u'فكليله', u'فبليلكما', u'فكليلك', u'فكليلهم', u'فبليل', u'بليلها', u'فليلكن', u'فليلكم', u'فلليلهم', u'فليل', u'فلليلهن', u'فبليلكم', u'وكليلنا', u'فبليلكن', u'فكليلنا', u'ليلها', u'وبليله', u'فكليلي', u'وبليلك', u'وبليلي', u'فلليلي', u'كليله', u'كليل', u'فلليلك', u'فبليلهما', u'ليلهن', u'ليلهم', u'فلليلكما', u'فلليل', u'فكليلها', u'ليلكما', u'بليلهم', u'بليلهن', u'ليلهما', u'لليلكم', u'فلليلها', u'لليلكن']),
 u'تين': set([u'فبتين', u'بتين', u'فلتين', u'لتين', u'كتين', u'وبتين', u'فتين', u'وكتين', u'ولتين', u'وتين', u'تين', u'فكتين']),
 u'أصبح': set([u'ولأصبح', u'وأصبح', u'لأصبح', u'فلأصبح', u'فأصبح', u'أصبح']),
 u'لكما': set([u'أفلكما', u'ولكما', u'أولكما', u'فلكما', u'ألكما', u'لكما']),
 u'كأين': set([u'فكأين', u'كأين', u'وكأين']),
 u'قد': set([u'وقد', u'لقد', u'ولقد', u'قد', u'فلقد', u'فقد']),
 u'ماانفككت': set([u'فماانفككت', u'ماانفككت', u'وماانفككت']),
 u'قط': set([u'وقط', u'قط', u'فقط']),
 u'لحظة': set([u'فلحظتي', u'فللحظة', u'فلحظتك', u'وبلحظة', u'فلحظته', u'فلحظتهم', u'فلحظتهن', u'فكلحظتهما', u'وللحظتك', u'وبلحظتكن', u'وللحظتكما', u'وبلحظتكم', u'للحظتنا', u'فلحظتنا', u'وللحظته', u'وكلحظتكم', u'وكلحظتكن', u'وللحظتي', u'بلحظتكما', u'بلحظته', u'بلحظتك', u'كلحظة', u'وللحظة', u'للحظتها', u'فبلحظتنا', u'فبلحظتهما', u'بلحظتهما', u'لحظته', u'ولحظتي', u'لحظتك', u'ولحظته', u'فلحظتها', u'ولحظتك', u'لحظتي', u'وكلحظة', u'فللحظتنا', u'وللحظتهما', u'للحظتكم', u'فبلحظتكما', u'للحظتكن', u'فلحظة', u'لحظتهم', u'لحظتهن', u'فللحظتهم', u'وبلحظتك', u'فللحظتهن', u'فبلحظتها', u'وبلحظتي', u'فكلحظته', u'فكلحظتك', u'ولحظتهم', u'وللحظتها', u'بلحظتها', u'ولحظتهن', u'فكلحظتي', u'فكلحظتنا', u'فكلحظة', u'بلحظة', u'لحظتها', u'فللحظتها', u'فبلحظتهم', u'فبلحظتهن', u'بلحظتهم', u'ولحظتها', u'بلحظتهن', u'كلحظتكن', u'كلحظتكم', u'لحظة', u'وللحظتنا', u'بلحظتنا', u'لحظتنا', u'وبلحظتكما', u'للحظتي', u'وللحظتهم', u'فكلحظتكما', u'للحظتك', u'للحظته', u'ولحظتنا', u'فكلحظتكم', u'فلحظتكم', u'فلحظتكن', u'فللحظتهما', u'فكلحظتكن', u'فبلحظتكم', u'فبلحظتكن', u'وللحظتهن', u'وكلحظتها', u'وبلحظتهن', u'فللحظتكما', u'وبلحظتهم', u'كلحظتي', u'كلحظته', u'كلحظتنا', u'وبلحظتهما', u'كلحظتك', u'للحظتهما', u'فكلحظتها', u'وكلحظتهم', u'لحظتكما', u'وكلحظتهن', u'وبلحظتها', u'فللحظتك', u'فللحظته', u'فللحظتي', u'لحظتهما', u'كلحظتكما', u'فكلحظتهن', u'للحظتهم', u'كلحظتها', u'للحظتهن', u'فبلحظته', u'وكلحظتنا', u'فبلحظتك', u'لحظتكم', u'لحظتكن', u'كلحظتهما', u'وبلحظتنا', u'فكلحظتهم', u'فبلحظتي', u'وللحظتكن', u'ولحظتكم', u'ولحظتكن', u'للحظتكما', u'وللحظتكم', u'فللحظتكم', u'فللحظتكن', u'فبلحظة', u'وكلحظته', u'وكلحظتك', u'وبلحظته', u'فلحظتكما', u'وكلحظتكما', u'بلحظتكم', u'وكلحظتي', u'بلحظتكن', u'ولحظتهما', u'ولحظة', u'للحظة', u'وكلحظتهما', u'كلحظتهن', u'ولحظتكما', u'كلحظتهم', u'فلحظتهما', u'بلحظتي']),
 u'شمال': set([u'ولشمالك', u'ألشمالك', u'ولشماله', u'أفلشمالهم', u'أفلشمالهن', u'ألشماله', u'ولشمالي', u'ألشمالي', u'فشمالهن', u'فشمالهم', u'ألشمالها', u'ألشمال', u'أولشمالها', u'أوشمالهم', u'أوشمالهن', u'أفلشمالنا', u'فلشمال', u'أشمالهما', u'ولشمالكم', u'شمالكن', u'شمالكم', u'ولشمالكن', u'لشمالكن', u'أولشمالهن', u'أولشمالهم', u'لشمالكم', u'فشمالكما', u'أوشمالها', u'فلشمالكن', u'فلشمالكم', u'ألشمالنا', u'أشمالك', u'أشماله', u'أشمالي', u'أولشمالنا', u'فشماله', u'فشمالك', u'أوشمال', u'فشمالها', u'ألشمالهم', u'ألشمالهن', u'فشمالي', u'شمال', u'ألشمالكما', u'أشمالكما', u'أوشمالنا', u'أفشمالكما', u'ولشمالنا', u'أولشمال', u'ولشمال', u'لشمالنا', u'أفشمالكن', u'فشمالهما', u'ألشمالكن', u'ألشمالهما', u'ولشمالهم', u'ولشمالهن', u'أولشمالهما', u'أولشمالكن', u'أولشمالكم', u'فشمالنا', u'أوشمالهما', u'أفلشمالها', u'أولشمالي', u'ولشمالها', u'أولشمالك', u'أولشماله', u'لشمالهما', u'أفشمالهما', u'ولشمالكما', u'أشمالكم', u'أوشمالكما', u'أشمالكن', u'أولشمالكما', u'لشمالكما', u'فلشمالها', u'أفشمال', u'فشمالكن', u'فشمالكم', u'ولشمالهما', u'لشمالها', u'أفشمالي', u'أفلشمالكم', u'أفلشمالكن', u'فلشماله', u'شمالها', u'فلشمالك', u'أفلشمالي', u'أفلشماله', u'فلشمالي', u'أوشمالكم', u'أوشمالكن', u'أفلشمالك', u'لشمالهن', u'لشمالهم', u'فلشمالنا', u'أفلشمالكما', u'فشمال', u'شمالهن', u'شمالهم', u'أفشماله', u'وشمالنا', u'أفشمالك', u'لشمالي', u'لشمال', u'شمالنا', u'لشمالك', u'فلشمالهن', u'لشماله', u'فلشمالهم', u'ألشمالكم', u'أشمال', u'أفلشمالهما', u'أفلشمال', u'أشمالها', u'أفشمالهم', u'أفشمالهن', u'فلشمالكما', u'وشمالها', u'وشمالكن', u'أفشمالكم', u'وشمالكم', u'أفشمالنا', u'شماله', u'شمالكما', u'شمالك', u'وشمالهما', u'أشمالنا', u'شمالي', u'شمالهما', u'أوشماله', u'أوشمالك', u'فلشمالهما', u'أوشمالي', u'أشمالهم', u'أشمالهن', u'وشمال', u'أفشمالها', u'وشمالكما', u'وشمالي', u'وشماله', u'وشمالهن', u'وشمالك', u'وشمالهم']),
 u'ثم': set([u'أثم', u'ثم', u'أفثم', u'أوثم', u'فثم', u'وثم']),
 u'أجل': set([u'أجل']),
 u'عليك': set([u'عليك', u'وعليك', u'فعليك']),
 u'دونك': set([u'فدونك', u'دونك', u'ودونك']),
 u'ذلكما': set([u'أولذلكما', u'ذلكما', u'أبذلكما', u'أفلذلكما', u'أفذلكما', u'أوذلكما', u'كذلكما', u'فذلكما', u'وذلكما', u'فكذلكما', u'أوبذلكما', u'أذلكما', u'ألذلكما', u'لذلكما', u'أفبذلكما', u'أكذلكما', u'بذلكما', u'فبذلكما', u'أوكذلكما', u'فلذلكما', u'وبذلكما', u'أفكذلكما', u'ولذلكما', u'وكذلكما']),
 u'حما': set([u'فحماكما', u'فحماهم', u'فحماهما', u'فحماهن', u'فحما', u'فحماكم', u'وحمانا', u'فحماكن', u'حما', u'وحماكن', u'فحمانا', u'وحماكم', u'وحما', u'وحماهن', u'وحماهم', u'حماكم', u'حمانا', u'حماكما', u'فحماي', u'حماها', u'فحماك', u'حماهما', u'فحماه', u'حماه', u'حماكن', u'حماك', u'وحماكما', u'فحماها', u'حماهم', u'حماي', u'حماهن', u'وحماهما', u'وحماي', u'وحماه', u'وحماك', u'وحماها']),
 u'أنت': set([u'أولأنت', u'فلأنت', u'أنت', u'أأنت', u'ولأنت', u'أفأنت', u'وأنت', u'لأنت', u'ألأنت', u'فأنت', u'أوأنت', u'أفلأنت']),
 u'التي': set([u'وللتي', u'وكالتي', u'التي', u'فكالتي', u'بالتي', u'والتي', u'كالتي', u'فبالتي', u'فللتي', u'وبالتي', u'للتي', u'فالتي']),
 u'أوه': set([u'وأوه', u'فأوه', u'أوه']),
 u'أنا': set([u'أولأناه', u'لأنا', u'أوأنانا', u'أولأناك', u'فلأناكما', u'أوأناهن', u'أوأناهم', u'أفلأنانا', u'أولأناي', u'أفأناكم', u'أوأناي', u'أوأناك', u'أوأناه', u'وأناها', u'فأناهن', u'ولأناهما', u'أفلأناهم', u'فأناهم', u'أفأناهما', u'أناي', u'فلأناهن', u'أناك', u'أناه', u'وأناهم', u'وأناهن', u'أفلأناها', u'فأناها', u'فلأناهما', u'أناكما', u'أفأناكما', u'فلأناها', u'أفلأناك', u'لأنانا', u'أفأنا', u'أوأناها', u'أأناهما', u'وأناهما', u'لأناي', u'وأناكما', u'أفلأناكن', u'أولأناهما', u'ولأناهم', u'ولأناهن', u'أنانا', u'فلأنانا', u'لأناها', u'ولأنانا', u'أناهن', u'أنا', u'أناهم', u'أأناكما', u'أفأناكن', u'أفلأناهما', u'أولأناكن', u'أناها', u'أولأناكم', u'ألأناكن', u'ألأناكم', u'ولأناها', u'أأناكم', u'أأناكن', u'أولأناكما', u'أفلأناكما', u'أفلأناهن', u'لأناهم', u'لأناهن', u'أأناي', u'أأنا', u'أفلأناي', u'أفلأناه', u'أأناك', u'فلأنا', u'أأناه', u'أوأناكن', u'أوأناكم', u'فلأناهم', u'فلأناكم', u'ولأناي', u'فلأناكن', u'أولأناهن', u'ولأناه', u'أولأنا', u'ولأناك', u'فأناكن', u'فأناكم', u'فأنانا', u'وأناك', u'لأناكما', u'وأناه', u'أوأناهما', u'وأناي', u'ولأنا', u'وأناكم', u'لأناهما', u'وأناكن', u'فأنا', u'ولأناكما', u'أوأناكما', u'أفأناه', u'فأناي', u'فأناك', u'فأناه', u'أفأنانا', u'ألأناها', u'وأنا', u'ألأناي', u'ألأناه', u'ألأناك', u'فلأناه', u'أفأناهم', u'أفأناهن', u'فلأناك', u'أناهما', u'فلأناي', u'أوأنا', u'لأناكن', u'أناكن', u'أناكم', u'أولأنانا', u'أولأناها', u'أأناها', u'أأنانا', u'أفأناها', u'ألأنانا', u'ألأناهما', u'لأناه', u'أفلأناكم', u'لأناك', u'ألأنا', u'أأناهم', u'أأناهن', u'أولأناهم', u'وأنانا', u'أفأناك', u'ألأناهن', u'ألأناهم', u'فأناهما', u'أفلأنا', u'أفأناي', u'لأناكم', u'فأناكما', u'ألأناكما', u'ولأناكم', u'ولأناكن']),
 u'مثل': set([u'أفكمثلكما', u'أكمثله', u'بمثلنا', u'أفمثلها', u'مثلهما', u'أومثل', u'أومثلكما', u'أفلمثلكن', u'أفكمثلكم', u'فلمثل', u'أفلمثلكم', u'أكمثلهن', u'أفكمثلهما', u'أوبمثلنا', u'فكمثلها', u'ولمثلك', u'أكمثلك', u'بمثلهن', u'بمثلهم', u'فبمثلكن', u'ولمثلي', u'فمثلكم', u'فمثلكن', u'ألمثلهن', u'فبمثلكم', u'فمثلهما', u'بمثله', u'فبمثل', u'أوبمثلكن', u'بمثلك', u'أكمثلهم', u'ومثلكن', u'ومثلكم', u'أبمثلهن', u'مثلكما', u'ألمثلكما', u'بمثلي', u'بمثلهما', u'أوبمثلها', u'فمثلي', u'بمثلها', u'ألمثلي', u'أفلمثلهن', u'ألمثله', u'ألمثلها', u'فمثلك', u'ألمثلك', u'فمثله', u'أوبمثلهم', u'أوبمثلهن', u'وبمثلكما', u'أولمثلكم', u'أولمثلكن', u'أولمثلك', u'أومثلهما', u'أولمثله', u'أفبمثلهم', u'ألمثلهما', u'أفبمثلهن', u'أفمثلهن', u'أفمثلهم', u'أبمثلكم', u'أولمثلنا', u'أبمثلكن', u'فكمثل', u'أوبمثلي', u'فبمثلهن', u'فبمثلكما', u'بمثلكما', u'فبمثلهم', u'ولمثلكم', u'فكمثلهن', u'فكمثلهم', u'أفلمثلك', u'وكمثله', u'ولمثلهم', u'أفبمثلهما', u'وكمثلك', u'أمثلكما', u'ألمثلنا', u'كمثل', u'لمثل', u'ومثله', u'أمثلهما', u'أفكمثلك', u'كمثلها', u'ومثلك', u'أوبمثل', u'مثلنا', u'أفبمثلكن', u'ومثلي', u'وكمثلكما', u'أمثلنا', u'أفكمثلهن', u'أفكمثله', u'ومثلهم', u'فلمثلهن', u'أفمثله', u'أبمثل', u'مثل', u'وكمثلها', u'أفكمثلي', u'أولمثلكما', u'أومثلكم', u'أوكمثلها', u'أفلمثل', u'وكمثلهما', u'أمثلها', u'أفلمثلي', u'ولمثلكن', u'ألمثلكن', u'أولمثلهما', u'مثلهم', u'مثلهن', u'أفمثلك', u'وبمثلكن', u'وبمثلكم', u'أفبمثلي', u'ولمثلنا', u'لمثلكما', u'أومثلكن', u'أفبمثلك', u'وكمثلهن', u'وكمثلهم', u'فمثلكما', u'أوكمثلهن', u'بمثل', u'كمثلنا', u'أمثلهم', u'فبمثلها', u'أفبمثل', u'مثلها', u'أوكمثلهم', u'أفلمثلها', u'أفكمثل', u'أولمثلها', u'أوبمثله', u'وكمثلنا', u'أكمثلنا', u'لمثلي', u'كمثلهن', u'فلمثلكن', u'فلمثلكم', u'كمثلهم', u'أمثلهن', u'لمثلك', u'ولمثلكما', u'لمثلهما', u'لمثلكن', u'لمثلكم', u'أفكمثلنا', u'أفبمثلكما', u'ولمثلها', u'ولمثلهما', u'أفمثلهما', u'أوبمثلكما', u'أولمثلي', u'أفمثل', u'أكمثلكن', u'بمثلكن', u'بمثلكم', u'ألمثلكم', u'فمثلهم', u'فمثلهن', u'فبمثلنا', u'أبمثلكما', u'أفلمثلنا', u'كمثلكما', u'فلمثلهما', u'أفلمثلهم', u'أبمثلك', u'أفبمثلها', u'كمثلهما', u'كمثلي', u'كمثله', u'فلمثلك', u'أفمثلكما', u'فلمثلكما', u'وبمثل', u'فلمثله', u'أومثلهن', u'أبمثلنا', u'أولمثلهم', u'أفكمثلها', u'فكمثلهما', u'أوكمثل', u'لمثلنا', u'فبمثله', u'فبمثلك', u'أفمثلكن', u'أفمثلكم', u'وكمثلي', u'أبمثلهم', u'أوبمثلكم', u'أومثلها', u'فبمثلي', u'ومثلهما', u'ومثلنا', u'أوكمثلكما', u'أوبمثلهما', u'ولمثلهن', u'أومثلهم', u'وبمثلنا', u'فمثل', u'أفبمثلكم', u'كمثلك', u'فكمثلكن', u'أبمثلهما', u'فكمثلكم', u'فكمثلي', u'أبمثلها', u'وبمثلهما', u'فكمثله', u'أفمثلي', u'فكمثلك', u'أمثلكم', u'فمثلها', u'فمثلنا', u'أبمثلي', u'وكمثل', u'أكمثلهما', u'أكمثلها', u'فلمثلها', u'أبمثله', u'ولمثله', u'أكمثل', u'لمثلها', u'ومثلكما', u'أوكمثلي', u'أكمثلكما', u'أوكمثله', u'فبمثلهما', u'أوكمثلك', u'أوكمثلنا', u'أومثلي', u'ومثلها', u'أولمثلهن', u'ألمثلهم', u'أكمثلي', u'فلمثلي', u'أفبمثلنا', u'فكمثلكما', u'أومثله', u'وبمثلها', u'أفكمثلكن', u'مثلكم', u'مثلكن', u'أولمثل', u'مثلي', u'أوبمثلك', u'ومثل', u'مثله', u'أكمثلكم', u'مثلك', u'أفمثلنا', u'وكمثلكن', u'وكمثلكم', u'أفلمثله', u'ومثلهن', u'ألمثل', u'أفكمثلهم', u'أمثلكن', u'ولمثل', u'أفلمثلهما', u'فلمثلنا', u'وبمثلهن', u'أمثل', u'وبمثلهم', u'أمثلي', u'أومثلك', u'أمثله', u'فكمثلنا', u'أوكمثلكم', u'أمثلك', u'أفلمثلكما', u'أوكمثلكن', u'أومثلنا', u'وبمثلي', u'أوكمثلهما', u'كمثلكن', u'وبمثله', u'فلمثلهم', u'كمثلكم', u'وبمثلك', u'لمثلهن', u'لمثلهم', u'لمثله', u'أفبمثله']),
 u'هذين': set([u'وهذين', u'لهذين', u'فبهذين', u'هذين', u'كهذين', u'فلهذين', u'ولهذين', u'بهذين', u'وكهذين', u'فهذين', u'فكهذين', u'وبهذين']),
 u'س': set([u'س']),
 u'لازلتما': set([u'لازلتما', u'أفلازلتما', u'ولازلتما', u'فلازلتما', u'أولازلتما', u'ألازلتما']),
 u'ك': set([u'ك']),
 u'أنى': set([u'وأنى', u'فأنى', u'أنى']),
 u'حمو': set([u'وحموكما', u'حموهن', u'حموهم', u'وحموهما', u'فحموه', u'وحموه', u'وحموك', u'فحمونا', u'وحموي', u'فحموي', u'فحموكما', u'حموي', u'حمونا', u'حموهما', u'حموه', u'حموك', u'وحمونا', u'وحموكم', u'وحموكن', u'فحموهن', u'فحموهم', u'وحموهم', u'وحموهن', u'وحمو', u'فحموكن', u'فحموكم', u'حمو', u'فحموهما', u'فحموها', u'حموكما', u'وحموها', u'فحمو', u'حموها', u'فحموك', u'حموكن', u'حموكم']),
 u'حمي': set([u'فلحميها', u'وحميي', u'فكحمينا', u'وحميك', u'حميها', u'وحميه', u'بحميه', u'ولحميي', u'فكحميهن', u'فكحميهم', u'ولحميها', u'لحمي', u'فلحميهما', u'فلحمينا', u'فكحميها', u'فحميه', u'ولحميهن', u'ولحميهم', u'فلحميهن', u'فلحميهم', u'فحمي', u'حميهما', u'حميهم', u'حميهن', u'لحمينا', u'لحميكما', u'وبحميكما', u'حميكما', u'لحميهما', u'كحميهم', u'كحميكما', u'وكحميها', u'وكحميي', u'وكحميه', u'بحميكن', u'بحميكم', u'فبحميهن', u'فبحميهم', u'فبحميي', u'فبحميه', u'وبحميهما', u'فبحميك', u'وحميهن', u'وحميهم', u'وكحمينا', u'لحميها', u'فحميك', u'فحميها', u'فحميي', u'كحميهن', u'وحمينا', u'وحميها', u'ولحميه', u'وبحميكن', u'ولحميك', u'وبحميكم', u'وكحميهما', u'ولحميكما', u'وحميهما', u'لحميهن', u'لحميهم', u'حمي', u'فحميهم', u'فحميهن', u'وحميكما', u'وكحمي', u'كحميها', u'ولحميهما', u'وكحميهن', u'وكحميهم', u'لحميي', u'لحميه', u'لحميك', u'وكحميك', u'فبحميها', u'كحمي', u'فحمينا', u'وبحمينا', u'فحميهما', u'كحمينا', u'حميك', u'حميه', u'حميي', u'فكحميكن', u'فبحميكن', u'وبحميهن', u'ولحميكم', u'وبحميهم', u'فكحميك', u'فلحمي', u'فبحمينا', u'كحميه', u'كحميك', u'وبحميها', u'كحميي', u'بحمينا', u'فلحميك', u'فلحميه', u'فلحميي', u'فلحميكن', u'فلحميكم', u'حميكم', u'حميكن', u'بحميهن', u'بحميهم', u'ولحمي', u'فكحمي', u'فبحميكم', u'فبحمي', u'وبحميك', u'وبحميه', u'وبحميي', u'وبحمي', u'فكحميكم', u'بحمي', u'بحميي', u'بحميك', u'فكحميهما', u'بحميهما', u'وحميكن', u'وحميكم', u'كحميكن', u'ولحميكن', u'كحميكم', u'بحميكما', u'فكحميكما', u'وحمي', u'لحميكن', u'لحميكم', u'كحميهما', u'حمينا', u'فبحميكما', u'وكحميكما', u'وكحميكن', u'وكحميكم', u'فبحميهما', u'بحميها', u'فحميكم', u'فحميكن', u'فكحميه', u'فكحميي', u'ولحمينا', u'فلحميكما', u'فحميكما']),
 u'هما': set([u'أفبهما', u'أوبهما', u'بهما', u'فكهما', u'أفكهما', u'ولهما', u'أوهما', u'وهما', u'وكهما', u'أبهما', u'أفهما', u'أهما', u'لهما', u'هما', u'أولهما', u'وبهما', u'فبهما', u'أكهما', u'ألهما', u'كهما', u'أوكهما', u'أفلهما', u'فهما', u'فلهما']),
 u'جير': set([u'جير', u'فجير', u'وجير']),
 u'أبدا': set([u'فأبدا', u'وأبدا', u'أبدا']),
 u'اللذان': set([u'اللذان', u'واللذان', u'فاللذان']),
 u'عند': set([u'وعند', u'فعندهم', u'فعندهن', u'فعندكم', u'فعندكن', u'فعند', u'عندها', u'فعندكما', u'فعندنا', u'وعندها', u'وعندكن', u'فعندي', u'وعنده', u'فعندك', u'وعندكما', u'وعندك', u'فعنده', u'عندهما', u'وعندكم', u'وعندي', u'وعندهما', u'وعندهن', u'وعندهم', u'عندنا', u'فعندها', u'فعندهما', u'عند', u'عندهم', u'عندكم', u'عندكن', u'وعندنا', u'عندي', u'عنده', u'عندكما', u'عندهن', u'عندك']),
 u'ظل': set([u'ولظل', u'فلظل', u'وظل', u'ظل', u'فظل', u'لظل']),
 u'سرعان': set([u'فسرعان', u'وسرعان', u'سرعان']),
 u'خلف': set([u'خلفه', u'خلفك', u'فبخلفنا', u'خلفي', u'كخلفهم', u'فخلفكن', u'فخلفكم', u'كخلفهن', u'فلخلفي', u'فبخلفهم', u'وخلفهم', u'وخلفهن', u'فلخلفه', u'بخلفهما', u'أفخلفنا', u'فلخلفك', u'بخلفكما', u'فكخلفهما', u'فكخلفكن', u'أوخلف', u'كخلفنا', u'أوخلفي', u'وكخلفكم', u'وكخلفكن', u'لخلفها', u'أوخلفه', u'أولخلفه', u'أوخلفهن', u'وخلفهما', u'أولخلفك', u'أوخلفهم', u'فكخلفه', u'فبخلفي', u'فكخلفك', u'فلخلفها', u'فكخلفي', u'فبخلفه', u'أخلفك', u'أفخلفهم', u'أخلفه', u'لخلفهم', u'لخلفهن', u'أخلفي', u'أوخلفها', u'فكخلفهم', u'وكخلفك', u'فبخلفكم', u'فبخلفكن', u'ولخلفه', u'بخلفكم', u'فكخلف', u'وبخلفه', u'كخلفها', u'فكخلفهن', u'وبخلفك', u'لخلفنا', u'فبخلفهما', u'وخلفها', u'أخلفكم', u'وبخلفي', u'وبخلف', u'أخلفكن', u'أولخلفهم', u'أوخلفهما', u'أفلخلفكما', u'فخلف', u'ولخلفها', u'بخلفكن', u'أوخلفنا', u'وبخلفهم', u'أفلخلفها', u'أولخلفهما', u'ألخلفكن', u'أولخلفكن', u'أولخلفكم', u'ألخلفكم', u'كخلفكم', u'أفخلفكم', u'فكخلفها', u'أفخلفكن', u'كخلفك', u'ولخلفي', u'أوخلفكما', u'كخلفه', u'فكخلفنا', u'ولخلفك', u'كخلفي', u'وخلفنا', u'أفلخلفهن', u'وبخلفها', u'أفلخلفهم', u'ألخلفهما', u'خلفكن', u'خلفكم', u'فلخلفكم', u'فلخلفكن', u'ولخلفنا', u'أفخلفهما', u'أفخلف', u'فبخلفها', u'أخلفنا', u'أفخلفك', u'ولخلفهم', u'أفخلفكما', u'ولخلفهن', u'خلفكما', u'أولخلف', u'ألخلف', u'أفلخلفنا', u'لخلفكما', u'فكخلفكم', u'كخلف', u'وكخلفها', u'وكخلفنا', u'أفلخلفكم', u'وخلفكم', u'وخلفكن', u'أفلخلفهما', u'أخلفها', u'أفلخلف', u'بخلفها', u'فخلفكما', u'فخلفهن', u'فخلفهم', u'كخلفكن', u'وكخلفهما', u'خلف', u'وكخلفهم', u'وكخلفهن', u'وكخلف', u'أوخلفكن', u'لخلفك', u'وبخلفنا', u'أخلف', u'لخلفه', u'وكخلفكما', u'لخلفي', u'فخلفنا', u'بخلفك', u'بخلفي', u'أوخلفكم', u'أولخلفي', u'أفلخلفي', u'وبخلفكما', u'أفلخلفك', u'فبخلفهن', u'بخلفنا', u'أفلخلفه', u'لخلفكم', u'لخلفكن', u'بخلفه', u'خلفهما', u'فخلفهما', u'أوخلفك', u'أخلفهم', u'أخلفهن', u'فلخلفنا', u'أفخلفي', u'أفخلفه', u'بخلفهم', u'بخلفهن', u'فخلفها', u'فبخلفكما', u'وبخلفكن', u'أفخلفها', u'ولخلفكما', u'وبخلفكم', u'وخلفي', u'بخلف', u'ألخلفهن', u'لخلفهما', u'وبخلفهما', u'فلخلف', u'ألخلفهم', u'وخلفك', u'وخلفه', u'أولخلفكما', u'ولخلفهما', u'خلفها', u'ألخلفك', u'وكخلفي', u'ألخلفه', u'ألخلفنا', u'وخلف', u'ألخلفي', u'أولخلفهن', u'ولخلف', u'أفخلفهن', u'وكخلفه', u'وخلفكما', u'أخلفهما', u'فبخلفك', u'فلخلفكما', u'أخلفكما', u'ألخلفكما', u'خلفهن', u'خلفهم', u'وبخلفهن', u'أفلخلفكن', u'فلخلفهم', u'فلخلفهن', u'فخلفي', u'أولخلفها', u'فلخلفهما', u'فخلفه', u'فخلفك', u'فبخلف', u'كخلفهما', u'لخلف', u'فكخلفكما', u'كخلفكما', u'خلفنا', u'ولخلفكم', u'ألخلفها', u'ولخلفكن', u'أولخلفنا']),
 u'تحول': set([u'ولتحول', u'فلتحول', u'تحول', u'وتحول', u'لتحول', u'فتحول']),
 u'هاته': set([u'فهاته', u'أهاته', u'وكهاته', u'أوكهاته', u'ألهاته', u'أوهاته', u'كهاته', u'لهاته', u'أولهاته', u'بهاته', u'أفلهاته', u'فكهاته', u'أبهاته', u'أفبهاته', u'فلهاته', u'وهاته', u'ولهاته', u'فبهاته', u'وبهاته', u'أكهاته', u'أفهاته', u'أفكهاته', u'هاته', u'أوبهاته']),
 u'هاتي': set([u'وكهاتي', u'أهاتي', u'فهاتي', u'ألهاتي', u'أوكهاتي', u'بهاتي', u'أولهاتي', u'لهاتي', u'كهاتي', u'أوهاتي', u'فكهاتي', u'أفلهاتي', u'وهاتي', u'فلهاتي', u'أفبهاتي', u'أبهاتي', u'فبهاتي', u'ولهاتي', u'أفهاتي', u'أفكهاتي', u'أكهاتي', u'وبهاتي', u'أوبهاتي', u'هاتي']),
 u'حوالى': set([u'وحواليك', u'حوالي', u'حوالى', u'حواليهما', u'وحواليه', u'حواليها', u'وحواليهما', u'فحواليهما', u'حواليكما', u'وحواليكم', u'وحواليهم', u'وحواليكن', u'وحواليكما', u'فحواليهن', u'فحواليهم', u'وحوالينا', u'وحواليهن', u'فحواليكن', u'فحوالينا', u'فحواليكم', u'فحواليها', u'حواليك', u'حواليه', u'فحواليكما', u'فحواليك', u'حواليهن', u'حواليهم', u'وحواليها', u'وحوالى', u'وحوالي', u'حواليكن', u'حواليكم', u'فحوالي', u'فحوالى', u'فحواليه', u'حوالينا']),
 u'جلل': set([u'جلل']),
 u'تينك': set([u'فكتينك', u'أولتينك', u'بتينك', u'أوبتينك', u'أفبتينك', u'وكتينك', u'أكتينك', u'أوكتينك', u'أتينك', u'فبتينك', u'أبتينك', u'وبتينك', u'أفكتينك', u'كتينك', u'ولتينك', u'تينك', u'لتينك', u'أفتينك', u'أوتينك', u'أفلتينك', u'ألتينك', u'فلتينك', u'وتينك', u'فتينك']),
 u'أولاء': set([u'أفلأولاء', u'أولاء', u'أبأولاء', u'وبأولاء', u'أكأولاء', u'ولأولاء', u'لأولاء', u'أأولاء', u'بأولاء', u'فلأولاء', u'أفكأولاء', u'أوكأولاء', u'فبأولاء', u'أفبأولاء', u'فكأولاء', u'وكأولاء', u'كأولاء', u'وأولاء', u'فأولاء', u'أولأولاء', u'أوبأولاء', u'أفأولاء', u'ألأولاء', u'أوأولاء']),
 u'آنذاك': set([u'وآنذاك', u'فآنذاك', u'آنذاك']),
 u'بعد': set([u'وبعدكما', u'فبعدها', u'وبعدنا', u'بعدك', u'فبعدنا', u'بعدها', u'بعد', u'وبعدهن', u'وبعدهم', u'وبعدي', u'فبعدهم', u'فبعدهن', u'وبعدك', u'وبعدهما', u'وبعدكن', u'وبعدكم', u'فبعدكما', u'فبعدكم', u'فبعدكن', u'فبعد', u'بعدهما', u'بعده', u'بعدهم', u'بعدي', u'وبعدها', u'بعدكما', u'فبعدك', u'بعدكم', u'بعدكن', u'فبعده', u'فبعدي', u'وبعد', u'بعدنا', u'وبعده', u'فبعدهما', u'بعدهن']),
 u'حين': set([u'فحين', u'وحينهن', u'وحينهم', u'حينها', u'حيني', u'وحينكما', u'فحينها', u'حين', u'وحيننا', u'فحيننا', u'حينكم', u'فحينكما', u'حيننا', u'حينكما', u'فحينه', u'وحينهما', u'فحينك', u'فحينهما', u'وحيني', u'حينهما', u'فحيني', u'حينه', u'حينكن', u'حينك', u'وحينها', u'وحينه', u'حينهم', u'وحينك', u'حينهن', u'فحينكم', u'فحينكن', u'وحينكن', u'وحينكم', u'فحينهم', u'وحين', u'فحينهن']),
 u'ذيت': set([u'وذيت', u'فذيت', u'ذيت']),
 u'أيان': set([u'أيان', u'وأيان', u'فأيان']),
 u'قلما': set([u'ولقلما', u'أفلقلما', u'قلما', u'وقلما', u'ألقلما', u'لقلما', u'أفقلما', u'أوقلما', u'فقلما', u'فلقلما', u'أولقلما', u'أقلما']),
 u'مازالا': set([u'فمازالا', u'مازالا', u'ومازالا']),
 u'خ': set([u'خ']),
 u'إزاء': set([u'فإزاء', u'وإزاء', u'إزاء']),
 u'بعض': set([u'فلبعضكن', u'كبعضكن', u'فبعضكم', u'فبعضكن', u'كبعضهن', u'كبعضهم', u'أكبعضك', u'وكبعضهن', u'وكبعضهم', u'أكبعضي', u'أفكبعضها', u'أببعض', u'وكبعضهما', u'أفكبعضه', u'أفكبعضك', u'أفكبعض', u'كبعضي', u'بعضنا', u'كبعضه', u'كبعضنا', u'كبعضكما', u'أوكبعضهم', u'كبعضك', u'فلبعضكما', u'وكبعضكن', u'وكبعضنا', u'أوبعضهم', u'أوبعضهن', u'أببعضها', u'كبعضهما', u'أوكبعضكم', u'أولبعض', u'ولبعضها', u'أفلبعضكم', u'أفلبعضكن', u'أولبعضكن', u'أفبعضك', u'وكبعضكما', u'أوببعضكم', u'أكبعضهما', u'أفبعضه', u'أوبعضي', u'أفبعضي', u'ببعضكن', u'أفبعضهما', u'ببعضكم', u'أوكبعض', u'أببعضهم', u'أببعضهن', u'أوبعضها', u'أفكبعضكم', u'أبعض', u'ولبعضهن', u'ولبعضهم', u'فببعضنا', u'أوبعضنا', u'ألبعضهم', u'ألبعضهن', u'كبعضها', u'أوببعضهما', u'ألبعض', u'فكبعض', u'أوكبعضي', u'أوكبعضكن', u'وكبعضها', u'أفكبعضهم', u'أكبعضه', u'أكبعضكما', u'أوبعضك', u'ولبعضنا', u'وببعض', u'أفبعضهن', u'أفبعضهم', u'وببعضي', u'أببعضكما', u'وببعضك', u'وببعضه', u'أفكبعضهن', u'بعضي', u'ولبعض', u'أوببعض', u'بعضكن', u'بعضك', u'أفببعضها', u'فببعضكما', u'بعضه', u'أوكبعضك', u'فببعضها', u'أولبعضكما', u'أولبعضنا', u'فكبعضها', u'ببعض', u'أكبعضنا', u'أكبعضها', u'ألبعضك', u'فكبعضهن', u'أفلبعضك', u'فببعضهن', u'ألبعضكن', u'فببعضهم', u'لبعضكن', u'وبعض', u'فكبعضهم', u'لبعضكم', u'وببعضكما', u'لبعض', u'أولبعضها', u'وبعضهما', u'فلبعضك', u'فكبعضي', u'لبعضي', u'فلبعضه', u'فلبعضنا', u'أوببعضكن', u'فلبعضي', u'لبعضه', u'فكبعضك', u'وبعضكما', u'لبعضك', u'فكبعضه', u'أفببعضك', u'ألبعضها', u'أبعضكن', u'أبعضكم', u'فلبعضهم', u'وببعضكن', u'وببعضكم', u'أفبعض', u'أوكبعضهما', u'فكبعضنا', u'وبعضكن', u'أفببعضكما', u'وبعضكم', u'أولبعضي', u'أكبعضهم', u'أفببعضهم', u'أفببعضهن', u'أكبعضهن', u'وببعضهما', u'ألبعضكما', u'أوكبعضه', u'أفلبعضه', u'أوكبعضكما', u'أفببعضكن', u'ببعضك', u'كبعضكم', u'ببعضه', u'وكبعضه', u'ببعضي', u'أفبعضنا', u'وكبعضكم', u'أفببعضنا', u'أفكبعضي', u'ولبعضكما', u'فبعضهم', u'فبعضهن', u'فلبعضها', u'أفلبعضي', u'وببعضهم', u'ببعضها', u'أفببعض', u'أوبعضكما', u'أوكبعضهن', u'أفلبعضهم', u'فلبعضكم', u'أوبعضكم', u'أوبعضكن', u'فببعضهما', u'ببعضهما', u'فكبعضهما', u'أفلبعضهن', u'فبعضنا', u'بعض', u'فببعضكن', u'أوبعضهما', u'ببعضكما', u'أوببعضها', u'ببعضهن', u'أفبعضها', u'وببعضهن', u'ببعضهم', u'أولبعضهم', u'وكبعض', u'أبعضي', u'أبعضها', u'أبعضه', u'أبعضنا', u'أوببعضنا', u'أبعضك', u'ولبعضكن', u'ولبعضكم', u'أفلبعضها', u'فبعضي', u'فبعضه', u'أببعضهما', u'فلبعضهما', u'فبعضك', u'أوببعضك', u'ألبعضهما', u'ببعضنا', u'فببعضكم', u'ولبعضهما', u'أفكبعضكن', u'أفكبعضكما', u'أولبعضكم', u'أوببعضهم', u'ألبعضكم', u'فبعضها', u'أفلبعض', u'فلبعضهن', u'بعضكم', u'أبعضكما', u'أوبعض', u'كبعض', u'أفكبعضهما', u'أفببعضه', u'أكبعضكم', u'وبعضها', u'أكبعض', u'أكبعضكن', u'أوكبعضنا', u'وكبعضك', u'لبعضكما', u'بعضهم', u'أفببعضكم', u'فبعضكما', u'بعضهن', u'وكبعضي', u'أفبعضكن', u'أفبعضكم', u'أفلبعضنا', u'فببعضه', u'لبعضهما', u'فببعضك', u'فبعضهما', u'أبعضهما', u'أببعضه', u'فببعضي', u'أولبعضهن', u'أببعضك', u'أولبعضك', u'أببعضي', u'فكبعضكما', u'أوكبعضها', u'أفببعضهما', u'ولبعضه', u'لبعضها', u'ولبعضك', u'أببعضكم', u'وببعضها', u'أفبعضكما', u'أوببعضكما', u'أوبعضه', u'أببعضكن', u'ولبعضي', u'وبعضنا', u'أفلبعضهما', u'بعضهما', u'ألبعضنا', u'أولبعضه', u'أولبعضهما', u'بعضكما', u'لبعضهن', u'فكبعضكن', u'فكبعضكم', u'لبعضهم', u'فلبعض', u'فبعض', u'أفكبعضنا', u'وبعضهن', u'وبعضك', u'وبعضهم', u'وبعضه', u'وبعضي', u'بعضها', u'أوببعضهن', u'أبعضهن', u'أبعضهم', u'أوببعضه', u'أفلبعضكما', u'ألبعضي', u'أببعضنا', u'فببعض', u'لبعضنا', u'أفببعضي', u'وببعضنا', u'أوببعضي', u'ألبعضه']),
 u'فيما': set([u'وفيما', u'فيما', u'ففيما']),
 u'لنا': set([u'ألنا', u'أفلنا', u'ولنا', u'لنا', u'أولنا', u'فلنا']),
 u'مكانكن': set([u'مكانكن', u'ومكانكن', u'فمكانكن']),
 u'تلكم': set([u'أكتلكم', u'فكتلكم', u'أوبتلكم', u'أفلتلكم', u'كتلكم', u'أفبتلكم', u'وكتلكم', u'أوتلكم', u'أوكتلكم', u'فبتلكم', u'أتلكم', u'وبتلكم', u'أفكتلكم', u'فتلكم', u'فلتلكم', u'أفتلكم', u'تلكم', u'أولتلكم', u'ألتلكم', u'وتلكم', u'لتلكم', u'ولتلكم', u'أبتلكم', u'بتلكم']),
 u'ذين': set([u'فبذين', u'فكذين', u'ألذين', u'أولذين', u'وذين', u'أفكذين', u'أفبذين', u'أوبذين', u'فلذين', u'أفذين', u'وكذين', u'فذين', u'أذين', u'ذين', u'أفلذين', u'أوذين', u'كذين', u'أكذين', u'أوكذين', u'ولذين', u'بذين', u'لذين', u'أبذين', u'وبذين']),
 u'اللائي': set([u'فكاللائي', u'باللائي', u'فباللائي', u'اللائي', u'فللائي', u'كاللائي', u'فاللائي', u'وباللائي', u'وللائي', u'وكاللائي', u'للائي', u'واللائي']),
 u'تلقاء': set([u'وبتلقاءها', u'ولتلقاءنا', u'فتلقاءنا', u'بتلقاءكما', u'لتلقاءهم', u'فكتلقاءكم', u'فكتلقاءكن', u'لتلقاءهن', u'لتلقاءنا', u'ولتلقاءهم', u'ولتلقاءهن', u'لتلقاء', u'وكتلقاء', u'فبتلقاءكما', u'ولتلقاءها', u'وتلقاءنا', u'تلقاءكما', u'فبتلقاءهما', u'وبتلقاءهم', u'وبتلقاءهن', u'فكتلقاءكما', u'فبتلقاءكم', u'فكتلقاءهن', u'فبتلقاءكن', u'فلتلقاء', u'لتلقاءكم', u'بتلقاء', u'تلقاءنا', u'لتلقاءها', u'فكتلقاءك', u'كتلقاءي', u'وتلقاءها', u'كتلقاءه', u'وتلقاءهما', u'فكتلقاء', u'وكتلقاءي', u'وكتلقاءها', u'وكتلقاءك', u'وكتلقاءه', u'فتلقاءكن', u'فلتلقاءها', u'فتلقاءكم', u'فلتلقاءهن', u'وتلقاءكما', u'تلقاءها', u'وبتلقاءك', u'فلتلقاءهم', u'وبتلقاءه', u'كتلقاءنا', u'وبتلقاءي', u'كتلقاءهما', u'فلتلقاءه', u'وكتلقاءنا', u'فلتلقاءك', u'تلقاءهن', u'فلتلقاءي', u'وبتلقاء', u'فلتلقاءنا', u'وتلقاءهم', u'كتلقاءهم', u'كتلقاءهن', u'وتلقاءهن', u'بتلقاءنا', u'وتلقاءه', u'وكتلقاءهن', u'وتلقاءك', u'كتلقاءكما', u'وتلقاءي', u'وبتلقاءكما', u'فبتلقاءها', u'وكتلقاءهما', u'فكتلقاءه', u'بتلقاءه', u'فكتلقاءهم', u'لتلقاءهما', u'لتلقاءكن', u'بتلقاءك', u'وبتلقاءهما', u'بتلقاءي', u'بتلقاءها', u'وكتلقاءكما', u'فكتلقاءنا', u'ولتلقاءكم', u'ولتلقاءكن', u'كتلقاء', u'فبتلقاءنا', u'كتلقاءها', u'بتلقاءهم', u'بتلقاءهن', u'تلقاء', u'كتلقاءك', u'فبتلقاءهم', u'فبتلقاءي', u'فبتلقاءهن', u'فكتلقاءهما', u'لتلقاءكما', u'فبتلقاءك', u'فبتلقاءه', u'وبتلقاءكم', u'وبتلقاءكن', u'فكتلقاءها', u'ولتلقاءه', u'فلتلقاءهما', u'ولتلقاء', u'فتلقاءهن', u'فتلقاءهم', u'تلقاءي', u'بتلقاءهما', u'وتلقاء', u'تلقاءه', u'تلقاءك', u'فلتلقاءكما', u'وكتلقاءهم', u'فلتلقاءكم', u'فبتلقاء', u'ولتلقاءهما', u'بتلقاءكم', u'بتلقاءكن', u'ولتلقاءكما', u'فتلقاءهما', u'فتلقاءي', u'وبتلقاءنا', u'فتلقاءك', u'فتلقاءه', u'تلقاءكن', u'لتلقاءي', u'تلقاءكم', u'وتلقاءكم', u'كتلقاءكم', u'كتلقاءكن', u'وتلقاءكن', u'لتلقاءك', u'فكتلقاءي', u'فلتلقاءكن', u'لتلقاءه', u'فتلقاءكما', u'ولتلقاءي', u'فتلقاء', u'تلقاءهما', u'تلقاءهم', u'ولتلقاءك', u'فتلقاءها', u'وكتلقاءكم', u'وكتلقاءكن']),
 u'خلا': set([u'خلاها', u'فخلاي', u'خلانا', u'فخلاه', u'وخلانا', u'فخلاك', u'فخلاكم', u'فخلاكن', u'فخلانا', u'فخلاهم', u'فخلاهما', u'فخلاهن', u'وخلاهن', u'وخلاهم', u'وخلاكن', u'وخلاكم', u'خلاهم', u'فخلاها', u'وخلاها', u'خلا', u'وخلا', u'خلاهما', u'خلاكما', u'خلاك', u'خلاهن', u'خلاه', u'وخلاهما', u'خلاي', u'فخلا', u'خلاكم', u'خلاكن', u'وخلاي', u'وخلاكما', u'وخلاك', u'فخلاكما', u'وخلاه']),
 u'حيث': set([u'وحيث', u'فبحيث', u'فلحيث', u'فكحيث', u'وكحيث', u'ولحيث', u'فحيث', u'بحيث', u'لحيث', u'وبحيث', u'حيث', u'كحيث']),
 u'مافتئوا': set([u'فمافتئوا', u'ومافتئوا', u'مافتئوا']),
 u'صار': set([u'فلصار', u'لصار', u'وصار', u'ولصار', u'صار', u'فصار']),
 u'أينما': set([u'وأينما', u'أينما', u'فأينما']),
 u'يمين': set([u'ليمينه', u'أليميني', u'أوليمينهن', u'ليمينك', u'فليمينكن', u'ليميني', u'فليمينكم', u'أفليمينك', u'يميننا', u'ويمينهم', u'أفليمينكم', u'ويمينهن', u'أيمينك', u'أليمينك', u'أيمينه', u'فليمين', u'أيميني', u'أفيمينكما', u'أيمينهما', u'ويمينها', u'أويمين', u'أفليميننا', u'أفيمينكن', u'أفيمينكم', u'أيمينكما', u'أوليمينكم', u'أوليمينكن', u'أوليمينكما', u'أوليمينهما', u'وليمينكما', u'فليمينه', u'فليمينك', u'وليمينها', u'فليميني', u'أفيمينهما', u'ويميننا', u'يمينكن', u'يمين', u'فيمينكم', u'فيمينكن', u'وليمينهما', u'وليميننا', u'ليمينكم', u'أويمينك', u'ليمينكن', u'أويمينكن', u'أويمينكم', u'أويميني', u'أفيميني', u'أيمينكن', u'أيمينكم', u'أفيمينك', u'أوليميننا', u'أفيمينه', u'ليمينهم', u'فيمينه', u'أفليمين', u'أفليمينه', u'فيمينك', u'فيميني', u'أليميننا', u'وليمينكم', u'أفليميني', u'وليميني', u'أويمينه', u'وليمينه', u'فليمينكما', u'وليمينك', u'فليمينهم', u'أليمين', u'فليمينهن', u'فليمينهما', u'يمينهم', u'أفيمينها', u'أوليميني', u'أفليمينها', u'ليمينكما', u'أوليمين', u'أوليمينك', u'أليمينها', u'ليمين', u'أوليمينه', u'ويمينكم', u'ويمينكن', u'فليميننا', u'أفيمينهن', u'أفيمينهم', u'أفليمينهن', u'أفليمينهم', u'أليمينهن', u'أليمينهم', u'فيمينهما', u'ويمينكما', u'وليمينهن', u'فيمينكما', u'أويميننا', u'أيميننا', u'يمينكم', u'أوليمينها', u'يمينهما', u'ليمينهما', u'وليمينهم', u'أليمينه', u'ويمينهما', u'أليمينكما', u'أوليمينهم', u'فليمينها', u'أليمينهما', u'أفيميننا', u'أفليمينهما', u'وليمين', u'يمينهن', u'أليمينكن', u'فيميننا', u'أليمينكم', u'أفيمين', u'أويمينها', u'يمينكما', u'أيمين', u'فيمينهم', u'فيمينهن', u'أفليمينكن', u'ليمينها', u'فيمين', u'أويمينهن', u'أويمينهم', u'يمينك', u'يمينه', u'أيمينهن', u'يميني', u'أيمينهم', u'فيمينها', u'وليمينكن', u'ليمينهن', u'أفليمينكما', u'يمينها', u'أويمينكما', u'أويمينهما', u'ويميني', u'ليميننا', u'أيمينها', u'ويمينك', u'ويمين', u'ويمينه']),
 u'رب': set([u'ورب', u'رب', u'فرب']),
 u'ماذا': set([u'أفماذا', u'وماذا', u'أماذا', u'أوماذا', u'فماذا', u'ماذا']),
 u'لست': set([u'ألست', u'لست', u'أفلست', u'ولست', u'فلست', u'أولست']),
 u'مافتئن': set([u'فمافتئن', u'ومافتئن', u'مافتئن']),
 u'ذان': set([u'ذان', u'فذان', u'وذان']),
 u'إياه': set([u'وإياه', u'إياه', u'فإياه']),
 u'ذاك': set([u'أوكذاك', u'ألذاك', u'وبذاك', u'أوذاك', u'وذاك', u'أكذاك', u'كذاك', u'ذاك', u'ولذاك', u'أوبذاك', u'أفذاك', u'فذاك', u'أذاك', u'أفلذاك', u'وكذاك', u'فبذاك', u'فلذاك', u'فكذاك', u'أفكذاك', u'أفبذاك', u'بذاك', u'أبذاك', u'أولذاك', u'لذاك']),
 u'ة': set([u'ة']),
 u'ن': set([u'ن']),
 u'حذار': set([u'وحذار', u'حذار', u'فحذار']),
 u'ماانفكتا': set([u'فماانفكتا', u'ماانفكتا', u'وماانفكتا']),
 u'ع': set([u'ع']),
 u'مادمتم': set([u'ومادمتم', u'مادمتم', u'فمادمتم']),
 u'مادمتن': set([u'فمادمتن', u'مادمتن', u'ومادمتن']),
 u'مابرحنا': set([u'فمابرحنا', u'ومابرحنا', u'مابرحنا']),
 u'ى': set([u'ى']),
 u'ذات': set([u'وبذاتنا', u'وكذاتكن', u'وذاتهم', u'وذاتهن', u'بذاتنا', u'كذاتك', u'وذات', u'فكذاتهم', u'ولذاتهما', u'فكذاتهن', u'فذاتك', u'وذاتها', u'كذات', u'ذاتكما', u'ولذاتنا', u'كذاتكما', u'فكذاتها', u'وكذاتكم', u'ولذاتها', u'ولذاتهم', u'وبذاتي', u'ولذاتهن', u'وبذاتك', u'فكذاتي', u'لذاتك', u'وبذاته', u'فذاتنا', u'وذاتنا', u'بذاتكم', u'بذاتكن', u'بذات', u'لذاتها', u'ذاتها', u'لذاتهما', u'لذاتكما', u'فبذاتكن', u'وذاتك', u'فذاتهن', u'فذاتهم', u'وذاته', u'فكذاتك', u'وذاتي', u'فكذاته', u'وكذاته', u'وكذاتك', u'وبذاتكم', u'وبذاتكن', u'وكذاتي', u'فذاتها', u'ولذاتكما', u'وكذات', u'لذاتنا', u'كذاتي', u'ولذاته', u'فكذاتنا', u'فبذاته', u'ولذاتك', u'فبذاتك', u'ولذاتي', u'فبذاتي', u'كذاته', u'كذاتكم', u'لذاتهم', u'لذاتهن', u'كذاتكن', u'ذاتهن', u'ذاتهم', u'فكذاتكما', u'وذاتهما', u'فكذات', u'لذات', u'فبذاتكم', u'وكذاتهم', u'وكذاتهن', u'ذاتنا', u'كذاتهما', u'وذاتكم', u'وذاتكن', u'وكذاتنا', u'فلذاتكما', u'وذاتكما', u'فلذاتهما', u'ولذات', u'فلذاتنا', u'فبذاتهما', u'فذات', u'فبذاتكما', u'فكذاتهما', u'ذاتي', u'ولذاتكم', u'ولذاتكن', u'بذاتهما', u'ذاتك', u'ذاته', u'وبذات', u'وكذاتها', u'كذاتهم', u'بذاتهم', u'بذاتهن', u'كذاتهن', u'ذاتكن', u'ذاتكم', u'فبذاتنا', u'وكذاتكما', u'ذاتهما', u'فلذاتها', u'وبذاتهما', u'فذاتكن', u'فذاتكم', u'بذاتكما', u'وبذاتهم', u'فبذاتهم', u'فبذاتهن', u'وبذاتهن', u'فذاته', u'فبذات', u'لذاتي', u'فلذات', u'لذاته', u'فذاتي', u'فذاتهما', u'بذاتك', u'بذاته', u'فكذاتكم', u'بذاتي', u'فكذاتكن', u'ذات', u'وبذاتها', u'فبذاتها', u'وبذاتكما', u'فلذاتك', u'فلذاته', u'فلذاتي', u'كذاتنا', u'وكذاتهما', u'كذاتها', u'بذاتها', u'لذاتكم', u'لذاتكن', u'فلذاتكم', u'فلذاتهم', u'فلذاتهن', u'فذاتكما', u'فلذاتكن']),
 u'واها': set([u'واها']),
 u'أما': set([u'أما', u'فأما', u'وأما']),
 u'جدا': set([u'جدا']),
 u'أمد': set([u'أمد', u'فأمد', u'وأمد']),
 u'اللواتي': set([u'وكاللواتي', u'للواتي', u'وباللواتي', u'فباللواتي', u'باللواتي', u'اللواتي', u'واللواتي', u'فللواتي', u'وللواتي', u'كاللواتي', u'فاللواتي', u'فكاللواتي']),
 u'أمس': set([u'فأمس', u'وأمس', u'أمس']),
 u'لسن': set([u'فلسن', u'أولسن', u'أفلسن', u'ولسن', u'لسن', u'ألسن']),
 u'معاذ': set([u'فمعاذهم', u'فمعاذهن', u'فمعاذك', u'ومعاذها', u'فمعاذه', u'ومعاذكما', u'فمعاذكم', u'فمعاذكن', u'معاذنا', u'فمعاذنا', u'معاذهم', u'معاذهن', u'فمعاذكما', u'ومعاذنا', u'معاذكم', u'معاذكن', u'فمعاذي', u'ومعاذهما', u'فمعاذ', u'ومعاذ', u'معاذها', u'فمعاذها', u'ومعاذهم', u'معاذكما', u'ومعاذك', u'معاذهما', u'معاذ', u'ومعاذه', u'ومعاذهن', u'ومعاذي', u'فمعاذهما', u'ومعاذكم', u'معاذي', u'ومعاذكن', u'معاذك', u'معاذه']),
 u'الذين': set([u'وكالذين', u'والذين', u'فكالذين', u'فللذين', u'الذين', u'كالذين', u'بالذين', u'للذين', u'فالذين', u'وبالذين', u'وللذين', u'فبالذين']),
 u'حيثما': set([u'حيثما', u'وحيثما', u'فحيثما']),
 u'تحت': set([u'أتحت', u'لتحتنا', u'أفتحتها', u'تحت', u'ألتحت', u'أوتحتكما', u'أولتحتهما', u'أولتحتنا', u'أوتحتهن', u'أوتحتهم', u'أفتحته', u'أفتحتك', u'وتحتهما', u'أولتحتهم', u'أفلتحتها', u'أوتحتنا', u'أولتحت', u'أفتحتي', u'فلتحتي', u'أفتحتنا', u'فلتحتك', u'فلتحته', u'وتحته', u'أولتحتها', u'وتحتك', u'فتحتنا', u'أتحتنا', u'وتحتي', u'أفتحتهم', u'أفتحتهن', u'فلتحتكم', u'فلتحتكن', u'أوتحتهما', u'أفلتحتهن', u'أفلتحتهم', u'تحتك', u'وتحتكما', u'ألتحتكن', u'أوتحتها', u'ألتحتكم', u'وتحتهم', u'أفتحتكما', u'ولتحتهم', u'أتحتها', u'ولتحتهن', u'ألتحتهن', u'وتحتها', u'أفلتحتنا', u'لتحتكم', u'لتحتكن', u'ألتحتهما', u'تحتي', u'تحته', u'أفلتحتهما', u'ولتحتهما', u'ولتحتي', u'وتحتهن', u'أفلتحتكما', u'فتحتهما', u'ولتحته', u'ألتحتنا', u'أوتحتي', u'أوتحته', u'أفتحتهما', u'أوتحتك', u'ولتحتكما', u'وتحتنا', u'ولتحت', u'فتحت', u'تحتكن', u'تحتكم', u'فتحتي', u'فلتحتنا', u'فتحته', u'أتحتهم', u'فتحتهن', u'فتحتهم', u'أتحتهن', u'ولتحتنا', u'أفلتحتكن', u'أفلتحتكم', u'أوتحتكن', u'ألتحتها', u'أوتحتكم', u'وتحت', u'لتحتك', u'لتحته', u'لتحتي', u'لتحت', u'وتحتكم', u'وتحتكن', u'فلتحتكما', u'تحتنا', u'أفتحت', u'أولتحتهن', u'أتحتكما', u'ألتحتكما', u'أفلتحت', u'أتحتهما', u'أفتحتكم', u'أفتحتكن', u'فلتحتهم', u'فلتحتهن', u'فلتحتها', u'أولتحتك', u'أولتحتي', u'أولتحته', u'ألتحتي', u'ألتحتهم', u'أفلتحتك', u'ألتحتك', u'ألتحته', u'لتحتهما', u'أوتحت', u'تحتها', u'تحتهما', u'تحتكما', u'لتحتهم', u'لتحتهن', u'ولتحتكم', u'فتحتها', u'ولتحتكن', u'فلتحتهما', u'لتحتكما', u'لتحتها', u'أولتحتكن', u'أولتحتكم', u'أتحته', u'فتحتك', u'أتحتك', u'أتحتي', u'فلتحت', u'أفلتحتي', u'أولتحتكما', u'فتحتكما', u'أفلتحته', u'أتحتكم', u'فتحتكن', u'فتحتكم', u'أتحتكن', u'ولتحتها', u'تحتهن', u'تحتهم', u'ولتحتك']),
 u'غير': set([u'أفلغيركن', u'ألغيرهما', u'أولغير', u'فكغيركما', u'أوغيركما', u'فبغيرهم', u'وبغيركن', u'وبغيركم', u'أوغيرنا', u'بغير', u'ألغيره', u'كغيري', u'كغيره', u'أوكغيرهم', u'غير', u'أفلغيرنا', u'فغيرهما', u'أوكغيره', u'أوبغيركم', u'أفلغيرهما', u'أوبغيركن', u'ألغيري', u'أفغيرها', u'فغيركما', u'كغيرهن', u'فكغيرهما', u'ألغيركم', u'ألغيركن', u'أبغيرك', u'ولغير', u'لغيرها', u'أبغيره', u'أبغيري', u'غيركم', u'غيركن', u'ألغير', u'أفكغيرهن', u'أغيرهما', u'ألغيركما', u'أوغيرها', u'لغيرهن', u'وكغير', u'لغيرهم', u'لغيره', u'أفبغيركم', u'لغيرك', u'كغيرهم', u'وبغيرهما', u'أكغير', u'أوكغيرنا', u'فغيرنا', u'أغيركم', u'أوغيرك', u'وبغيركما', u'لغيرنا', u'أغيري', u'أغيره', u'أغيركما', u'أغيرك', u'أوكغيرها', u'أفلغيرك', u'وغيرهما', u'أفغيرهن', u'ألغيرك', u'أولغيرها', u'أبغيرهما', u'فكغيرها', u'أبغيرهم', u'ولغيره', u'وغيركما', u'أوغيره', u'ولغيرك', u'وكغيركن', u'وكغيركم', u'ولغيرها', u'أوغيري', u'فبغيرك', u'فلغيرها', u'فكغيره', u'أغيركن', u'ألغيرنا', u'أكغيرها', u'أوبغيركما', u'أبغيرنا', u'وكغيره', u'فغيرها', u'أفغيرهم', u'أفبغيرنا', u'كغيرك', u'وكغيري', u'فلغيرهن', u'فبغيره', u'وبغيري', u'أوبغيره', u'أفكغير', u'أكغيرهم', u'فبغيري', u'غيركما', u'أفبغير', u'كغير', u'أولغيري', u'وكغيرهما', u'فغيرهم', u'أفغيره', u'فغيرهن', u'وغيركن', u'أفبغيركما', u'أفلغيرها', u'وغيركم', u'فكغير', u'أفبغيرهما', u'أغيرنا', u'كغيركما', u'فبغيرهن', u'فبغيرهما', u'غيرك', u'أفبغيركن', u'أكغيرهن', u'أفلغيري', u'أولغيرهم', u'أكغيرنا', u'أفبغيري', u'أولغيرهن', u'فكغيرهن', u'فكغيرهم', u'فكغيرنا', u'بغيركن', u'فلغيرهم', u'بغيركم', u'أفغيرك', u'وكغيركما', u'أوغيرهما', u'ولغيرهن', u'غيرهما', u'ولغيركما', u'وبغيرهن', u'وبغيرهم', u'ولغيرهما', u'لغيركما', u'أوبغيرهن', u'أفغيرنا', u'أولغيرهما', u'أفكغيره', u'أوكغيركم', u'أوكغيركن', u'لغيرهما', u'أفكغيرك', u'غيري', u'أوكغيركما', u'أوبغيري', u'أغيرها', u'أوبغيرنا', u'غيرهم', u'أفكغيرنا', u'أفغير', u'أفلغيرهن', u'بغيرهما', u'كغيرهما', u'أفكغيرها', u'أوغيرهن', u'بغيري', u'غيرهن', u'أفبغيرهم', u'أوبغيرهم', u'بغيرك', u'ولغيرنا', u'أكغيركم', u'بغيره', u'ألغيرهن', u'فبغيرها', u'وكغيرك', u'أوغيركم', u'فلغير', u'لغيركن', u'لغيركم', u'أولغيره', u'لغير', u'كغيركن', u'غيرها', u'أفبغيرك', u'أولغيركن', u'أبغير', u'بغيركما', u'أوبغيرها', u'أفبغيرها', u'ألغيرها', u'وبغيرها', u'أبغيركما', u'فلغيرهما', u'أفلغيرهم', u'وبغير', u'كغيرها', u'أغير', u'أبغيرهن', u'ألغيرهم', u'فغيرك', u'وغير', u'أكغيركما', u'فغيره', u'أوغيركن', u'فبغيركما', u'فلغيركما', u'فغيري', u'أوكغيري', u'أكغيركن', u'أفغيركما', u'أغيرهن', u'أغيرهم', u'أفكغيري', u'وكغيرنا', u'فبغير', u'أفغيري', u'بغيرها', u'فلغيره', u'غيرنا', u'فكغيرك', u'أولغيركم', u'أوغيرهم', u'فغير', u'فكغيري', u'أبغيركم', u'أبغيركن', u'أولغيرك', u'أفكغيرهما', u'وبغيرنا', u'وكغيرهن', u'أكغيري', u'وكغيرهم', u'أكغيره', u'وغيرها', u'فلغيرنا', u'أوكغيرك', u'أكغيرك', u'ولغيركم', u'أفلغيركم', u'فبغيركن', u'أفكغيركما', u'أبغيرها', u'أفكغيركم', u'أفغيركن', u'أفغيركم', u'أفكغيركن', u'أفغيرهما', u'ولغيري', u'أوبغيرهما', u'أفكغيرهم', u'وبغيرك', u'فبغيركم', u'أكغيرهما', u'وكغيرها', u'وبغيره', u'أولغيرنا', u'وغيرهن', u'بغيرنا', u'وغيرهم', u'فلغيركن', u'فلغيركم', u'وغيري', u'أفلغيركما', u'غيره', u'أولغيركما', u'أفلغير', u'وغيرك', u'أوكغيرهن', u'فغيركم', u'وغيره', u'أوكغيرهما', u'فغيركن', u'فلغيري', u'أوكغير', u'أوبغيرك', u'أوبغير', u'أفبغيره', u'بغيرهن', u'فلغيرك', u'وغيرنا', u'بغيرهم', u'كغيركم', u'أفبغيرهن', u'ولغيركن', u'فبغيرنا', u'أفلغيره', u'ولغيرهم', u'أوغير', u'لغيري', u'كغيرنا', u'فكغيركن', u'فكغيركم']),
 u'حاشا': set([u'فحاشاهما', u'وحاشاكما', u'وحاشاه', u'فحاشاها', u'حاشا', u'حاشاها', u'حاشاهما', u'حاشاكن', u'وحاشاها', u'فحاشا', u'حاشاكم', u'حاشاهم', u'حاشاهن', u'فحاشاي', u'فحاشاهن', u'وحاشاكم', u'وحاشاكن', u'حاشاه', u'فحاشانا', u'وحاشاي', u'حاشاك', u'وحاشاهم', u'وحاشاهن', u'وحاشاك', u'حاشاي', u'حاشانا', u'فحاشاكما', u'فحاشاكم', u'فحاشاكن', u'وحاشاهما', u'فحاشاهم', u'وحاشا', u'حاشاكما', u'فحاشاه', u'وحاشانا', u'فحاشاك']),
 u'مافتئ': set([u'مافتئ', u'فمافتئ', u'ومافتئ']),
 u'مابرحتن': set([u'مابرحتن', u'فمابرحتن', u'ومابرحتن']),
 u'مابرحتم': set([u'مابرحتم', u'ومابرحتم', u'فمابرحتم']),
 u'أمام': set([u'لأمامكن', u'لأمامكم', u'ولأمامها', u'ألأمامكما', u'أفلأمامي', u'أولأمام', u'فلأمامهم', u'أفلأمامك', u'أفلأمامه', u'أمامها', u'أفلأمامها', u'أولأمامك', u'فلأمامهما', u'ألأمامنا', u'أفلأمامكن', u'أمامهن', u'أمامهم', u'أأمامهما', u'ألأمامكم', u'ألأمامكن', u'ألأمامهما', u'ولأمامهم', u'ولأمامهن', u'وأمامنا', u'فلأمامها', u'فلأمامهن', u'أوأمام', u'فأمامكن', u'فأمامكم', u'ولأمام', u'وأمامي', u'أفأمام', u'أأمامهم', u'أأمامهن', u'وأمامك', u'أأمامكما', u'وأمامه', u'أوأمامهن', u'ولأمامه', u'وأمامها', u'فلأمامنا', u'ألأمامه', u'أفلأمامكم', u'أولأمامه', u'ألأمامك', u'ولأمامك', u'أولأمامي', u'ألأمامي', u'أفأمامكما', u'وأمامهن', u'أوأمامهما', u'وأمامهم', u'أولأمامكن', u'أولأمامكم', u'أفلأمامهما', u'لأمام', u'أفأمامكم', u'أمام', u'أفأمامهما', u'أوأمامك', u'أأمامها', u'أوأمامه', u'أفأمامك', u'أوأمامي', u'أفأمامه', u'أوأمامها', u'فلأمامكن', u'فلأمامكم', u'لأمامهن', u'ولأمامهما', u'لأمامهم', u'فأمامها', u'فأمامك', u'فأمامه', u'أفلأمامكما', u'فأمامي', u'أأمام', u'لأمامكما', u'لأمامي', u'أوأمامكما', u'لأمامه', u'لأمامنا', u'لأمامك', u'ألأمامها', u'لأمامهما', u'أأمامنا', u'ولأمامكما', u'أوأمامنا', u'أفأمامنا', u'أفأمامي', u'ألأمامهم', u'ألأمامهن', u'فأمامنا', u'ولأمامكم', u'أمامكن', u'أمامكم', u'ولأمامكن', u'فأمام', u'أولأمامها', u'لأمامها', u'أأمامك', u'فأمامهن', u'فأمامهم', u'أأمامه', u'أفلأمام', u'أأمامي', u'ولأمامي', u'فأمامكما', u'أولأمامهما', u'أوأمامكم', u'أوأمامكن', u'فلأمامي', u'ألأمام', u'فلأمامه', u'فلأمامك', u'أفأمامها', u'أأمامكم', u'أأمامكن', u'وأمامكما', u'أولأمامكما', u'أوأمامهم', u'فأمامهما', u'أفأمامكن', u'فلأمام', u'أفلأمامهم', u'أفلأمامهن', u'أمامك', u'أمامهما', u'أمامه', u'أمامي', u'ولأمامنا', u'فلأمامكما', u'أمامكما', u'أولأمامنا', u'وأمامكن', u'وأمامكم', u'أمامنا', u'أفلأمامنا', u'وأمام', u'وأمامهما', u'أولأمامهن', u'أولأمامهم', u'أفأمامهم', u'أفأمامهن']),
 u'ج': set([u'ج']),
 u'أضحى': set([u'فأضحى', u'وأضحى', u'ولأضحى', u'لأضحى', u'فلأضحى', u'أضحى']),
 u'اللتيا': set([u'فللتيا', u'فباللتيا', u'وباللتيا', u'وللتيا', u'باللتيا', u'فاللتيا', u'اللتيا', u'للتيا', u'وكاللتيا', u'فكاللتيا', u'واللتيا', u'كاللتيا']),
 u'هاتان': set([u'أهاتان', u'وهاتان', u'أفهاتان', u'فهاتان', u'أوهاتان', u'هاتان']),
 u'هكذا': set([u'أهكذا', u'فهكذا', u'هكذا', u'أوهكذا', u'وهكذا', u'أفهكذا']),
 u'مابرحتا': set([u'مابرحتا', u'فمابرحتا', u'ومابرحتا']),
 u'كلتا': set([u'أوبكلتا', u'فككلتا', u'ككلتا', u'أبكلتا', u'وككلتا', u'أفبكلتا', u'ولكلتا', u'أولكلتا', u'ألكلتا', u'بكلتا', u'كلتا', u'فلكلتا', u'فكلتا', u'لكلتا', u'وكلتا', u'فبكلتا', u'أوككلتا', u'أكلتا', u'أوكلتا', u'أفككلتا', u'وبكلتا', u'أككلتا', u'أفلكلتا', u'أفكلتا']),
 u'بضع': set([u'أفبضعه', u'أوبضعهن', u'وبضعكما', u'فبضعي', u'فبضعهن', u'وبضع', u'أبضعكم', u'فبضعها', u'فبضعك', u'أبضعكن', u'وبضعنا', u'وبضعي', u'فبضعه', u'فبضعنا', u'فبضع', u'أفبضعك', u'بضعكم', u'أبضعهم', u'بضعنا', u'أبضعه', u'أبضع', u'وبضعه', u'وبضعكم', u'وبضعكن', u'وبضعك', u'بضعكن', u'أفبضع', u'فبضعكن', u'وبضعهم', u'وبضعهن', u'أبضعك', u'بضعهن', u'بضعهم', u'أبضعهن', u'أوبضعكما', u'أبضعي', u'أفبضعنا', u'أوبضعه', u'فبضعكما', u'أفبضعكم', u'وبضعهما', u'فبضعكم', u'أفبضعكن', u'أفبضعهم', u'أفبضعهن', u'أفبضعي', u'بضع', u'وبضعها', u'أوبضع', u'بضعها', u'أوبضعهم', u'بضعهما', u'فبضعهم', u'بضعكما', u'أوبضعها', u'أبضعكما', u'أوبضعهما', u'أوبضعكن', u'أفبضعكما', u'أوبضعكم', u'أفبضعهما', u'أبضعهما', u'أبضعنا', u'أوبضعك', u'أفبضعها', u'أبضعها', u'أوبضعنا', u'بضعي', u'أوبضعي', u'فبضعهما', u'بضعه', u'بضعك']),
 u'انقلب': set([u'ولانقلب', u'لانقلب', u'انقلب', u'فلانقلب', u'وانقلب', u'فانقلب']),
 u'اللتين': set([u'فللتين', u'فباللتين', u'باللتين', u'وباللتين', u'وللتين', u'فاللتين', u'اللتين', u'للتين', u'وكاللتين', u'فكاللتين', u'واللتين', u'كاللتين']),
 u'ساء': set([u'ساء', u'فساء', u'وساء']),
 u'لستما': set([u'لستما', u'فلستما', u'أولستما', u'أفلستما', u'ولستما', u'ألستما']),
 u'إليكن': set([u'فإليكن', u'إليكن', u'وإليكن']),
 u'إليكم': set([u'فإليكم', u'وإليكم', u'إليكم']),
 u'غدا': set([u'فلغدا', u'غدا', u'ولغدا', u'فغدا', u'وغدا', u'لغدا']),
 u'حاي': set([u'حاي']),
 u'كلما': set([u'أكلما', u'كلما', u'وكلما', u'أفكلما', u'فكلما', u'أوكلما']),
 u'تبدل': set([u'لتبدل', u'فتبدل', u'تبدل', u'ولتبدل', u'فلتبدل', u'وتبدل']),
 u'مكانكم': set([u'ومكانكم', u'مكانكم', u'فمكانكم']),
 u'كذلك': set([u'كذلك', u'أكذلك', u'أفكذلك', u'وكذلك', u'أوكذلك', u'فكذلك']),
 u'شتان': set([u'وشتان', u'شتان', u'فشتان']),
 u'الآن': set([u'والآن', u'الآن', u'فالآن']),
 u'أولالك': set([u'أفلأولالك', u'أوبأولالك', u'أفأولالك', u'أكأولالك', u'وبأولالك', u'وكأولالك', u'أولالك', u'أأولالك', u'فلأولالك', u'ولأولالك', u'أفبأولالك', u'فأولالك', u'كأولالك', u'أوكأولالك', u'ألأولالك', u'لأولالك', u'بأولالك', u'أوأولالك', u'فكأولالك', u'فبأولالك', u'وأولالك', u'أفكأولالك', u'أولأولالك', u'أبأولالك']),
 u'إياي': set([u'فإياي', u'إياي', u'وإياي']),
 u'ممن': set([u'ممن', u'وممن', u'فممن']),
 u'إياك': set([u'فإياك', u'وإياك', u'إياك']),
 u'كيت': set([u'كيت', u'فكيت', u'وكيت']),
 u'بعدما': set([u'بعدما', u'وبعدما', u'فبعدما']),
 u'اخلولق': set([u'ولاخلولق', u'اخلولق', u'فلاخلولق', u'واخلولق', u'فاخلولق', u'لاخلولق']),
 u'حرى': set([u'ولحرى', u'فلحرى', u'حرى', u'وحرى', u'لحرى', u'فحرى']),
 u'مادمنا': set([u'فمادمنا', u'ومادمنا', u'مادمنا']),
 u'ط': set([u'ط']),
 u'ه': set([u'ه']),
 u'عاد': set([u'لعاد', u'وعاد', u'عاد', u'ولعاد', u'فعاد', u'فلعاد']),
 u'كيف': set([u'كيف', u'وكيف', u'فكيف']),
 u'إياكم': set([u'إياكم', u'وإياكم', u'فإياكم']),
 u'إياكن': set([u'وإياكن', u'إياكن', u'فإياكن']),
 u'سبحان': set([u'سبحانكن', u'سبحانكم', u'وسبحاننا', u'فسبحاننا', u'سبحانهن', u'سبحانهم', u'سبحانهما', u'وسبحانكم', u'وسبحانكن', u'فسبحانهم', u'وسبحان', u'فسبحاني', u'فسبحانهما', u'وسبحانهم', u'وسبحانهن', u'فسبحانك', u'سبحاننا', u'سبحاني', u'سبحانك', u'سبحانكما', u'سبحان', u'فسبحانهن', u'فسبحانها', u'فسبحانكما', u'وسبحانها', u'فسبحانه', u'فسبحانكن', u'فسبحانكم', u'وسبحانكما', u'سبحانه', u'وسبحاني', u'فسبحان', u'وسبحانه', u'سبحانها', u'وسبحانهما', u'وسبحانك']),
 u'هذان': set([u'أفهذان', u'وهذان', u'أهذان', u'أوهذان', u'هذان', u'فهذان']),
 u'أقبل': set([u'فأقبل', u'لأقبل', u'وأقبل', u'ولأقبل', u'فلأقبل', u'أقبل']),
 u'الألاء': set([u'وللألاء', u'وكالألاء', u'كالألاء', u'فالألاء', u'للألاء', u'وبالألاء', u'الألاء', u'فللألاء', u'فكالألاء', u'فبالألاء', u'بالألاء', u'والألاء']),
 u'مما': set([u'أمما', u'فمما', u'أومما', u'أفمما', u'ومما', u'مما']),
 u'ليسوا': set([u'ليسوا', u'أوليسوا', u'فليسوا', u'وليسوا', u'أفليسوا', u'أليسوا']),
 u'لما': set([u'ألما', u'ولما', u'أفلما', u'أولما', u'فلما', u'لما']),
 u'ضحوة': set([u'ضحوة', u'وضحوة', u'فضحوة']),
 u'مابرحا': set([u'ومابرحا', u'مابرحا', u'فمابرحا']),
 u'آها': set([u'آها']),
 u'ماداموا': set([u'ماداموا', u'وماداموا', u'فماداموا']),
 u'آ': set([u'آ']),
 u'كاد': set([u'فلكاد', u'كاد', u'وكاد', u'ولكاد', u'لكاد', u'فكاد']),
 u'عل': set([u'فعل', u'وعل', u'عل']),
 u'عن': set([u'أفلعنكما', u'لعني', u'لعنه', u'لعنك', u'أفلعنهن', u'أولعنهما', u'وعنها', u'أفعني', u'ألعنكن', u'ألعنكم', u'أولعنكم', u'أولعنكن', u'فعنه', u'فلعنهما', u'ألعنه', u'عننا', u'ألعني', u'فلعنكما', u'ألعنكما', u'لعنهما', u'ولعن', u'أعننا', u'أفعنها', u'لعنكم', u'وعننا', u'لعنكن', u'أوعنكما', u'أولعنك', u'أولعنه', u'أولعني', u'أعنكما', u'ألعنهما', u'لعنكما', u'وعنهم', u'أفلعنهما', u'وعنهن', u'فلعنك', u'عنه', u'فلعنه', u'عنك', u'فلعني', u'فلعنكم', u'أعنها', u'عني', u'ولعنهم', u'وعنهما', u'أفلعنه', u'وعن', u'أوعنهما', u'عنهما', u'أفلعنهم', u'أفلعني', u'عنكما', u'أوعنها', u'فلعن', u'أولعنهم', u'أفلعنها', u'عنكم', u'عنكن', u'ألعن', u'أوعن', u'أفعنهم', u'أوعنهن', u'أوعنهم', u'أوعننا', u'أفلعن', u'أولعنكما', u'أعنهن', u'ولعنها', u'أعنهم', u'فعنكم', u'فعنكن', u'أفعننا', u'أولعننا', u'فلعنهم', u'وعنكم', u'لعنها', u'وعنكن', u'أفلعننا', u'أفعنهن', u'ولعنكم', u'ألعنهن', u'ألعنهم', u'أعنهما', u'أعنه', u'أولعنهن', u'أعنك', u'أعني', u'ألعنك', u'ولعننا', u'عن', u'ألعننا', u'ولعنه', u'أولعنها', u'ولعنك', u'ولعنهن', u'ولعني', u'فعننا', u'لعن', u'فلعنكن', u'وعني', u'وعنكما', u'لعنهم', u'لعنهن', u'وعنك', u'أفعنكم', u'وعنه', u'ألعنها', u'ولعنكن', u'أفعن', u'فلعنهن', u'أفعنك', u'أفعنه', u'أوعني', u'أوعنه', u'أوعنك', u'لعننا', u'فلعننا', u'أفلعنكم', u'عنها', u'فعنها', u'عنهم', u'عنهن', u'أفعنكما', u'أفلعنكن', u'فعنهما', u'فعنهم', u'أوعنكن', u'أوعنكم', u'أعنكن', u'فلعنها', u'أعنكم', u'أفعنكن', u'أفلعنك', u'أولعن', u'فعن', u'ولعنكما', u'أعن', u'فعني', u'أفعنهما', u'ولعنهما', u'فعنكما', u'فعنهن', u'فعنك']),
 u'مافتئتما': set([u'ومافتئتما', u'مافتئتما', u'فمافتئتما']),
 u'ز': set([u'ز']),
 u'لازلت': set([u'أفلازلت', u'ولازلت', u'فلازلت', u'أولازلت', u'لازلت', u'ألازلت']),
 u'بيد': set([u'بيد', u'فبيد', u'وبيد']),
 u'ق': set([u'ق']),
 u'ظ': set([u'ظ']),
 u'ماداما': set([u'ماداما', u'وماداما', u'فماداما']),
 u'كان': set([u'وكان', u'ولكان', u'فلكان', u'كان', u'فكان', u'لكان']),
 u'كلاهما': set([u'فكلاهما', u'أوكلاهما', u'كلاهما', u'أكلاهما', u'أفكلاهما', u'وكلاهما']),
 u'بين': set([u'بيننا', u'وبين', u'وبينكن', u'وبينكم', u'فبينهم', u'فبينهن', u'بينكم', u'بينكن', u'وبينكما', u'وبينهن', u'وبينهم', u'فبينكم', u'فبينكن', u'فبين', u'بينهم', u'بينهن', u'بينه', u'بينك', u'فبيننا', u'وبيننا', u'بيني', u'بينهما', u'بينها', u'فبينها', u'بين', u'وبيني', u'فبينهما', u'وبينه', u'وبينك', u'وبينهما', u'فبينك', u'بينكما', u'فبينه', u'فبيني', u'وبينها', u'فبينكما']),
 u'هيهات': set([u'هيهات']),
 u'إذا': set([u'إذا', u'فإذا', u'وإذا']),
 u'إياكما': set([u'وإياكما', u'إياكما', u'فإياكما']),
 u'الذي': set([u'كالذي', u'فكالذي', u'فللذي', u'الذي', u'وكالذي', u'وللذي', u'بالذي', u'للذي', u'فالذي', u'فبالذي', u'والذي', u'وبالذي']),
 u'بل': set([u'بل']),
 u'نخ': set([u'نخ']),
 u'طاق': set([u'طاق']),
 u'أبو': set([u'فأبوهما', u'فأبوها', u'أبو', u'وأبونا', u'فأبونا', u'فأبو', u'أبونا', u'وأبوكم', u'وأبوكن', u'أبوه', u'أبوكن', u'أبوكم', u'وأبوكما', u'وأبوهم', u'وأبوهن', u'أبوي', u'أبوهن', u'أبوهم', u'فأبوكما', u'وأبوه', u'أبوهما', u'وأبوي', u'وأبو', u'وأبوها', u'وأبوك', u'أبوها', u'أبوكما', u'فأبوكن', u'فأبوكم', u'فأبوهن', u'أبوك', u'فأبوهم', u'وأبوهما', u'فأبوه', u'فأبوك', u'فأبوي']),
 u'أبي': set([u'فأبي', u'لأبيي', u'وبأبيهن', u'وبأبيهم', u'فبأبيكن', u'كأبيكما', u'فبأبيكم', u'بأبيهن', u'لأبيه', u'وأبينا', u'بأبيهم', u'فلأبيي', u'لأبيهن', u'فلأبيك', u'لأبيهم', u'فلأبيكن', u'فلأبيه', u'فلأبيكم', u'فكأبيك', u'وأبيه', u'وبأبيها', u'وأبيك', u'وأبيي', u'بأبيها', u'ولأبيكم', u'لأبيها', u'فأبيكم', u'فأبيكن', u'لأبي', u'وكأبينا', u'بأبي', u'وكأبيهما', u'كأبينا', u'وأبيكن', u'وأبيكم', u'وبأبينا', u'وبأبيهما', u'بأبينا', u'بأبيكما', u'أبيهم', u'أبيي', u'أبيهن', u'أبيه', u'لأبينا', u'بأبيهما', u'أبيك', u'وكأبيكما', u'وكأبيها', u'ولأبي', u'لأبيكم', u'فلأبيهما', u'وبأبيكما', u'كأبيها', u'ولأبيها', u'وكأبيهن', u'وكأبيهم', u'فكأبيكن', u'فكأبيكم', u'فكأبي', u'فكأبيي', u'فكأبيه', u'كأبيهن', u'كأبيهم', u'كأبيكن', u'كأبيكم', u'وأبيكما', u'فأبيك', u'فأبينا', u'فأبيه', u'أبيها', u'لأبيك', u'فأبيي', u'وأبيهما', u'ولأبيك', u'ولأبيه', u'ولأبيي', u'فلأبينا', u'فبأبينا', u'وبأبيكن', u'وبأبيكم', u'وبأبي', u'بأبيكن', u'بأبيه', u'بأبيكم', u'بأبيك', u'فلأبيكما', u'بأبيي', u'فلأبيهن', u'فكأبيكما', u'فأبيها', u'فلأبيهم', u'فبأبيهن', u'أبينا', u'فبأبيهم', u'وكأبيكن', u'ولأبيكما', u'وكأبيكم', u'ولأبيهن', u'ولأبيهم', u'وأبي', u'ولأبيهما', u'كأبي', u'فأبيهم', u'فلأبيها', u'فأبيهن', u'فبأبيها', u'فبأبيك', u'ولأبينا', u'أبيكم', u'أبي', u'أبيكن', u'وأبيهن', u'وأبيهم', u'وكأبيه', u'وكأبيك', u'كأبيي', u'كأبيه', u'وكأبيي', u'كأبيك', u'فأبيهما', u'لأبيكما', u'فكأبيهما', u'فبأبيكما', u'فأبيكما', u'فكأبيها', u'فبأبيهما', u'لأبيكن', u'أبيكما', u'وبأبيي', u'وبأبيه', u'وبأبيك', u'ولأبيكن', u'فلأبي', u'أبيهما', u'فكأبيهن', u'فكأبيهم', u'لأبيهما', u'فبأبيه', u'فبأبي', u'فبأبيي', u'وأبيها', u'كأبيهما', u'وكأبي', u'فكأبينا']),
 u'هذا': set([u'بهذا', u'هذا', u'لهذا', u'أولهذا', u'أبهذا', u'أفلهذا', u'أوبهذا', u'كهذا', u'أكهذا', u'وكهذا', u'أوهذا', u'ولهذا', u'فبهذا', u'أفهذا', u'فكهذا', u'أهذا', u'فهذا', u'أفكهذا', u'أفبهذا', u'وهذا', u'أوكهذا', u'فلهذا', u'ألهذا', u'وبهذا']),
 u'لاسيما': set([u'لاسيما', u'ولاسيما', u'فلاسيما']),
 u'هنا': set([u'أهنا', u'فهنا', u'وهنا', u'أفهنا', u'أوهنا', u'هنا']),
 u'ساءما': set([u'فساءما', u'وساءما', u'ساءما']),
 u'ذينك': set([u'أوبذينك', u'أفبذينك', u'بذينك', u'أوذينك', u'ولذينك', u'أولذينك', u'ذينك', u'فبذينك', u'ألذينك', u'كذينك', u'وبذينك', u'وكذينك', u'أفلذينك', u'فذينك', u'لذينك', u'أذينك', u'أفكذينك', u'أفذينك', u'فكذينك', u'وذينك', u'أكذينك', u'أبذينك', u'أوكذينك', u'فلذينك']),
 u'آه': set([u'وآه', u'آه', u'فآه']),
 u'ساعة': set([u'وكساعة', u'لساعتكما', u'بساعتكم', u'كساعتنا', u'بساعتكن', u'لساعة', u'ساعتكما', u'وبساعتها', u'ولساعتي', u'فكساعتكن', u'فكساعتي', u'فكساعتها', u'كساعتهن', u'فكساعته', u'كساعتهم', u'فكساعتك', u'فكساعتكم', u'وبساعتي', u'وبساعته', u'وبساعتك', u'فكساعتهن', u'فكساعتهم', u'كساعتها', u'فلساعتكما', u'وبساعتنا', u'لساعتهما', u'فلساعتنا', u'فكساعتنا', u'فساعتكما', u'ولساعتك', u'فبساعتهم', u'وكساعتنا', u'وبساعتهما', u'وبساعتهن', u'فلساعتهما', u'وبساعتهم', u'فساعتهما', u'ساعتنا', u'ساعتكم', u'ساعتكن', u'ولساعته', u'فبساعتنا', u'فكساعتهما', u'وكساعتها', u'وبساعة', u'ولساعتها', u'فلساعتها', u'وساعتهم', u'فبساعتي', u'وساعتهن', u'فبساعتك', u'فبساعته', u'فبساعتهن', u'فلساعتهم', u'فلساعتهن', u'لساعتكم', u'لساعتكن', u'ساعتهما', u'وساعتها', u'ولساعتنا', u'فبساعتها', u'فكساعتكما', u'ولساعتكما', u'فلساعتي', u'بساعتكما', u'فلساعته', u'فساعتكم', u'فساعتكن', u'وكساعتهم', u'وكساعتهن', u'ولساعتهن', u'ولساعتهم', u'فبساعتكما', u'ساعتهم', u'ساعتهن', u'وكساعتهما', u'بساعتهم', u'بساعتهن', u'وساعتنا', u'وساعته', u'وساعتك', u'بساعتهما', u'وساعتي', u'وبساعتكما', u'فبساعتهما', u'كساعتكن', u'كساعتكم', u'فساعة', u'لساعتهم', u'لساعتهن', u'بساعته', u'وكساعتي', u'بساعتك', u'كساعتك', u'وكساعتك', u'وكساعته', u'بساعتي', u'فبساعة', u'فساعتنا', u'لساعتها', u'وبساعتكن', u'وبساعتكم', u'ساعتي', u'ساعتها', u'بساعة', u'فلساعة', u'بساعتها', u'فساعتي', u'فساعته', u'فساعتك', u'ولساعة', u'وساعتكما', u'فلساعتك', u'كساعة', u'ولساعتكن', u'وساعة', u'ولساعتكم', u'وكساعتكما', u'فساعتها', u'لساعتي', u'ساعة', u'وساعتكن', u'لساعتك', u'كساعتهما', u'لساعته', u'فبساعتكم', u'فبساعتكن', u'بساعتنا', u'ولساعتهما', u'كساعتكما', u'وساعتهما', u'فلساعتكم', u'فلساعتكن', u'وساعتكم', u'وكساعتكم', u'لساعتنا', u'وكساعتكن', u'كساعته', u'فكساعة', u'كساعتي', u'ساعته', u'ساعتك', u'فساعتهم', u'فساعتهن']),
 u'ح': set([u'ح']),
 u'ابتدأ': set([u'ولابتدأ', u'ابتدأ', u'لابتدأ', u'فابتدأ', u'وابتدأ', u'فلابتدأ']),
 u'صباح': set([u'فصباح', u'وصباح', u'صباح']),
 u'ضمن': set([u'وضمنه', u'وضمنك', u'فضمن', u'ضمنكن', u'ضمنكم', u'فضمنكن', u'فضمنكم', u'ضمني', u'ضمنهن', u'ضمنه', u'فضمنكما', u'ضمنهم', u'ضمنك', u'وضمنكما', u'وضمن', u'ضمن', u'وضمنها', u'فضمنهم', u'فضمننا', u'ضمنهما', u'ضمننا', u'ضمنكما', u'وضمنكم', u'وضمنكن', u'وضمنهم', u'وضمنهن', u'فضمنهن', u'وضمني', u'فضمني', u'فضمنه', u'فضمنك', u'وضمنهما', u'فضمنهما', u'وضمننا', u'ضمنها', u'فضمنها']),
 u'لكيلا': set([u'لكيلا', u'ولكيلا', u'فلكيلا']),
 u'بمن': set([u'بمن', u'وبمن', u'فبمن']),
 u'كيفما': set([u'فكيفما', u'كيفما', u'وكيفما']),
 u'سوى': set([u'أكسويكم', u'أكسوى', u'أكسوي', u'أكسويكن', u'وكسويكن', u'أولسويهم', u'وكسويكم', u'فسويكم', u'أولسويه', u'أسويكما', u'فسويكن', u'فسويهن', u'وبسويها', u'أكسوينا', u'أسويهما', u'أفبسويهم', u'أفبسويهن', u'بسويها', u'فلسوينا', u'ولسويها', u'أوسويهن', u'أفبسويكن', u'أوسوينا', u'لسويهن', u'لسويهم', u'ألسويهم', u'ألسويهن', u'أفبسويهما', u'ألسوى', u'أولسويك', u'ولسويك', u'ألسوي', u'أوبسويكما', u'ولسويه', u'أفلسويهم', u'أفلسويهن', u'فبسوينا', u'أبسويك', u'أفسويهما', u'فسوى', u'فسوي', u'أبسويه', u'لسويها', u'أبسويكم', u'أبسويكن', u'ألسويها', u'أفبسوينا', u'أوسويك', u'وبسوينا', u'أوسويهم', u'أفبسوي', u'أفسويه', u'وبسويه', u'بسوينا', u'أفلسويها', u'أسويكن', u'أسويكم', u'ألسويه', u'أفكسويكم', u'وسويكما', u'ألسويك', u'أفكسويكما', u'أفكسويكن', u'أفسويهم', u'أفسويكما', u'أوبسويكم', u'وبسويهن', u'وبسويهم', u'أوبسويكن', u'أفبسويها', u'بسويهن', u'أوبسويها', u'أفكسويهما', u'بسويهم', u'كسويكن', u'كسويكم', u'أبسوى', u'فبسويها', u'فكسويهم', u'أبسوي', u'أوبسويهن', u'لسوينا', u'ألسويكم', u'فبسويهما', u'فكسويكما', u'أكسويهن', u'أفكسوينا', u'أسويها', u'وسويهن', u'أوكسويها', u'وسويهم', u'فلسويها', u'سويهما', u'أفلسوي', u'سويها', u'كسويه', u'كسويكما', u'كسويك', u'أولسويهن', u'وكسويهما', u'أولسوينا', u'فسويهما', u'كسويهما', u'فبسويكما', u'أوبسويهما', u'أفسويهن', u'فسويكما', u'فلسويهن', u'أفكسويه', u'أولسويهما', u'فلسويهم', u'سويهم', u'سويهن', u'أسوينا', u'أولسويها', u'ولسويهن', u'ولسويهم', u'أفلسويك', u'أوكسويكم', u'سويكما', u'أفلسويه', u'ألسويهما', u'أفسويها', u'ألسويكما', u'أفسويكم', u'أبسوينا', u'فلسوي', u'فلسوى', u'أوسوى', u'سوينا', u'فبسويهم', u'فكسوي', u'أبسويهما', u'فبسويه', u'ولسوينا', u'أفسوي', u'فبسويك', u'أفسوى', u'فكسوى', u'كسوي', u'وسويها', u'كسوى', u'فسويك', u'وسويهما', u'فسويه', u'أفبسويكم', u'فكسويها', u'وكسويه', u'أوبسويهم', u'وكسويكما', u'أفبسوى', u'أوبسوينا', u'بسويه', u'وكسويهن', u'بسويك', u'أكسويها', u'وكسويهم', u'أفلسوى', u'أفكسويها', u'أفبسويه', u'أوكسويه', u'وكسويك', u'فكسويهن', u'فسوينا', u'ألسويكن', u'أبسويها', u'أفكسويك', u'أفكسوى', u'أفكسوي', u'فكسوينا', u'سويه', u'أسوي', u'سويك', u'أوسويكم', u'أوسويكن', u'أوسويهما', u'أفلسويكم', u'وكسوينا', u'لسويكن', u'أوبسوى', u'أكسويهما', u'لسويكم', u'سويكم', u'سويكن', u'وسوينا', u'أبسويهم', u'أبسويهن', u'أفبسويك', u'أوبسوي', u'ألسوينا', u'لسوي', u'لسوى', u'أفسويك', u'فبسويهن', u'أفلسويكن', u'فكسويهما', u'ولسويهما', u'فسويها', u'فلسويهما', u'أوكسوي', u'أوسويه', u'وبسويكن', u'وبسويكم', u'أوسوي', u'أسويهن', u'أسويهم', u'بسويكن', u'أبسويكما', u'بسويكم', u'أكسويهم', u'وكسويها', u'فلسويكما', u'أفكسويهم', u'لسويك', u'أفكسويهن', u'لسويه', u'أوكسويهن', u'أوكسويكن', u'وبسوي', u'بسويهما', u'كسويهن', u'كسويهم', u'أوكسويك', u'وسويكن', u'وسويكم', u'أكسويه', u'فبسوي', u'فبسوى', u'وكسوي', u'أولسويكم', u'أولسويكن', u'أولسويكما', u'وكسوى', u'أفلسويهما', u'وبسويكما', u'أفلسوينا', u'كسوينا', u'فسويهم', u'أفسويكن', u'أكسويك', u'بسوي', u'بسوى', u'أفبسويكما', u'ولسوي', u'سوى', u'سوي', u'ولسوى', u'وبسويهما', u'وبسويك', u'بسويكما', u'أفسوينا', u'أولسوى', u'أولسوي', u'أفلسويكما', u'أوكسوينا', u'أسويه', u'فلسويكن', u'أوكسويهما', u'أسويك', u'فلسويكم', u'أوبسويه', u'أوسويكما', u'أوبسويك', u'وسوي', u'وسوى', u'أوكسويكما', u'فبسويكن', u'أوكسويهم', u'فبسويكم', u'أوكسوى', u'ولسويكن', u'ولسويكم', u'أسوى', u'أكسويكما', u'ولسويكما', u'لسويهما', u'فلسويك', u'فكسويه', u'كسويها', u'فلسويه', u'فكسويك', u'وبسوى', u'وسويه', u'أوسويها', u'لسويكما', u'وسويك', u'فكسويكن', u'فكسويكم']),
 u'إياها': set([u'فإياها', u'وإياها', u'إياها']),
 u'تانك': set([u'تانك', u'كتانك', u'فكتانك', u'وكتانك', u'فبتانك', u'لتانك', u'فتانك', u'وبتانك', u'ولتانك', u'وتانك', u'بتانك', u'فلتانك']),
 u'أقل': set([u'فأقلها', u'وأقلكما', u'وبأقل', u'كأقلكما', u'أقلهم', u'أقلهن', u'فبأقلها', u'بأقلهما', u'فلأقلها', u'فأقل', u'لأقلكما', u'بأقلها', u'لأقلهما', u'ولأقل', u'لأقله', u'لأقلك', u'وأقلهما', u'فلأقلهن', u'فلأقلي', u'فلأقلهم', u'بأقلهن', u'بأقلهم', u'فأقلهم', u'فلأقل', u'فأقلهن', u'فلأقلك', u'بأقلكما', u'فبأقل', u'بأقلنا', u'كأقل', u'أقلها', u'فبأقلهن', u'فبأقلهم', u'فكأقل', u'فكأقلي', u'فكأقلك', u'فكأقله', u'فلأقله', u'وأقلها', u'فأقلهما', u'ولأقلك', u'ولأقلها', u'فأقلكما', u'ولأقلي', u'فأقلك', u'فأقله', u'فأقلي', u'بأقلك', u'فبأقلكما', u'بأقله', u'بأقلي', u'أقلنا', u'وكأقلكن', u'أقلي', u'وكأقلكم', u'أقلك', u'فكأقلكما', u'وكأقلهما', u'أقله', u'وأقلنا', u'وأقل', u'ولأقلنا', u'كأقلنا', u'فكأقلكن', u'فكأقلكم', u'لأقلكن', u'لأقلكم', u'وأقلهن', u'وأقلهم', u'وبأقلكن', u'وبأقلكم', u'فكأقلهما', u'ولأقلهن', u'ولأقلهم', u'ولأقلهما', u'كأقله', u'كأقلك', u'فكأقلهم', u'كأقلي', u'أقلكم', u'ولأقله', u'أقلكن', u'وبأقلهما', u'ولأقلكما', u'وبأقلي', u'لأقلي', u'وبأقلك', u'وبأقلكما', u'وكأقل', u'وبأقله', u'كأقلهن', u'كأقلهم', u'فبأقلهما', u'فلأقلكن', u'فلأقلكم', u'بأقل', u'بأقلكن', u'بأقلكم', u'وكأقلكما', u'وكأقلنا', u'فأقلكم', u'لأقل', u'فأقلكن', u'فبأقلكن', u'فبأقلكم', u'فبأقلي', u'وكأقله', u'فبأقله', u'فبأقلك', u'وأقله', u'أقلكما', u'وبأقلها', u'وأقلك', u'لأقلها', u'وأقلي', u'فلأقلنا', u'وكأقلها', u'أقلهما', u'فلأقلكما', u'فكأقلها', u'كأقلكن', u'كأقلكم', u'فأقلنا', u'أقل', u'وبأقلنا', u'وكأقلهن', u'وكأقلهم', u'لأقلنا', u'كأقلها', u'فكأقلهن', u'فبأقلنا', u'كأقلهما', u'فلأقلهما', u'وكأقلي', u'وبأقلهن', u'وبأقلهم', u'وكأقلك', u'ولأقلكن', u'ولأقلكم', u'لأقلهن', u'لأقلهم', u'فكأقلنا', u'وأقلكن', u'وأقلكم']),
 u'إليكما': set([u'إليكما', u'وإليكما', u'فإليكما']),
 u'لئلا': set([u'ولئلا', u'لئلا', u'فلئلا']),
 u'كذا': set([u'وكذا', u'أفكذا', u'أكذا', u'كذا', u'أوكذا', u'فكذا']),
 u'آض': set([u'ولآض', u'آض', u'فآض', u'فلآض', u'وآض', u'لآض']),
 u'بما': set([u'أوبما', u'فبما', u'أبما', u'بما', u'وبما', u'أفبما']),
 u'ماانفكا': set([u'ماانفكا', u'وماانفكا', u'فماانفكا']),
 u'فيم': set([u'وفيم', u'فيم', u'ففيم']),
 u'إياهن': set([u'وإياهن', u'إياهن', u'فإياهن']),
 u'فا': set([u'فاهم', u'فاهن', u'ففاهم', u'فاكم', u'ففانا', u'ففاكما', u'فاكن', u'ففاهما', u'ففاهن', u'ففاه', u'ففاكن', u'ففاك', u'فاي', u'فا', u'فاه', u'وفاها', u'فاك', u'ففاي', u'فاهما', u'وفا', u'فاكما', u'وفاهن', u'ففاكم', u'وفاك', u'وفاهما', u'وفاه', u'وفاهم', u'وفاي', u'فاها', u'ففاها', u'وفاكما', u'وفاكم', u'وفاكن', u'فانا', u'ففا', u'وفانا']),
 u'هذي': set([u'كهذي', u'فكهذي', u'فبهذي', u'هذي', u'بهذي', u'فلهذي', u'وبهذي', u'ولهذي', u'وهذي', u'وكهذي', u'فهذي', u'لهذي']),
 u'أبا': set([u'وأباك', u'فأبانا', u'أبانا', u'وأبانا', u'أباها', u'وأبا', u'فأباهم', u'فأباهن', u'فأباكم', u'فأباكن', u'أباهم', u'أباهن', u'وأباهما', u'وأباه', u'وأباهن', u'وأباهم', u'وأباي', u'أباكم', u'أباكن', u'فأباها', u'وأباكما', u'وأباكن', u'وأباكم', u'فأباكما', u'فأباهما', u'أباي', u'فأباك', u'أبا', u'أباك', u'أباهما', u'أباه', u'وأباها', u'فأباي', u'أباكما', u'فأبا', u'فأباه']),
 u'هذه': set([u'وهذه', u'أوكهذه', u'فكهذه', u'فلهذه', u'ألهذه', u'وبهذه', u'فبهذه', u'أفهذه', u'أهذه', u'أفكهذه', u'أفلهذه', u'أفبهذه', u'أوبهذه', u'فهذه', u'كهذه', u'أكهذه', u'وكهذه', u'أوهذه', u'ولهذه', u'بهذه', u'هذه', u'لهذه', u'أولهذه', u'أبهذه']),
 u'تجاه': set([u'وتجاهكن', u'وتجاهكم', u'فتجاهها', u'تجاهي', u'وتجاهها', u'تجاهك', u'فتجاهي', u'تجاهه', u'فتجاه', u'تجاهكما', u'وتجاهكما', u'تجاهها', u'فتجاهكما', u'فتجاهكم', u'فتجاهنا', u'وتجاهك', u'تجاههم', u'فتجاههما', u'وتجاهه', u'وتجاهنا', u'وتجاهي', u'وتجاه', u'وتجاههما', u'تجاههما', u'تجاهكن', u'تجاهكم', u'فتجاهكن', u'فتجاهه', u'فتجاهك', u'تجاههن', u'فتجاههن', u'فتجاههم', u'تجاهنا', u'تجاه', u'وتجاههن', u'وتجاههم']),
 u'شطر': set([u'وشطرهما', u'وشطر', u'بشطري', u'بشطر', u'فلشطركم', u'وكشطركما', u'فشطري', u'فبشطره', u'وشطركن', u'ولشطره', u'فبشطرها', u'فشطركما', u'وشطركما', u'كشطرهم', u'ولشطري', u'فكشطره', u'فشطرك', u'فبشطرهن', u'فبشطرهم', u'فشطره', u'ولشطرك', u'بشطره', u'فكشطركما', u'كشطرها', u'بشطرك', u'شطرنا', u'شطرهما', u'كشطر', u'فبشطرنا', u'فكشطركن', u'فشطرهما', u'فكشطركم', u'لشطركن', u'لشطركم', u'وشطرنا', u'فبشطرك', u'بشطرهن', u'بشطرهم', u'ولشطركم', u'وبشطره', u'فلشطرهم', u'وبشطرك', u'شطرها', u'وبشطري', u'بشطرنا', u'وشطرهن', u'وشطرهم', u'فلشطرها', u'فشطركم', u'فشطركن', u'فشطر', u'شطرهم', u'شطرهن', u'وكشطرنا', u'فكشطرك', u'كشطرهما', u'وشطرها', u'وكشطري', u'وبشطركن', u'وكشطره', u'وبشطركم', u'وكشطرهما', u'وكشطرك', u'وكشطركن', u'وكشطركم', u'بشطرها', u'كشطركما', u'فلشطرهما', u'لشطرك', u'فلشطرنا', u'فكشطرهن', u'لشطره', u'فكشطرهم', u'فبشطركما', u'لشطري', u'فلشطركما', u'فبشطرهما', u'فكشطرنا', u'فكشطري', u'فكشطرهما', u'كشطركن', u'كشطركم', u'فكشطر', u'فشطرهن', u'شطركم', u'شطركن', u'فشطرهم', u'فبشطركن', u'فبشطركم', u'فبشطر', u'وبشطرنا', u'فشطرها', u'ولشطرهن', u'فكشطرها', u'لشطر', u'كشطرهن', u'بشطرهما', u'ولشطرهم', u'وكشطر', u'شطركما', u'لشطرهما', u'وكشطرهن', u'وكشطرهم', u'فلشطر', u'لشطرهن', u'لشطرهم', u'لشطركما', u'بشطركن', u'بشطركم', u'شطره', u'وبشطرها', u'شطرك', u'فشطرنا', u'بشطركما', u'شطري', u'فلشطرك', u'وبشطر', u'فلشطره', u'لشطرنا', u'ولشطركن', u'فلشطري', u'فلشطركن', u'ولشطرنا', u'ولشطر', u'وشطركم', u'ولشطرهما', u'كشطرنا', u'وشطري', u'وشطره', u'وشطرك', u'فلشطرهن', u'فبشطري', u'كشطره', u'كشطرك', u'كشطري', u'وكشطرها', u'ولشطركما', u'لشطرها', u'وبشطركما', u'ولشطرها', u'شطر', u'وبشطرهن', u'وبشطرهم', u'وبشطرهما']),
 u'حينئذ': set([u'وحينئذ', u'حينئذ', u'فحينئذ']),
 u'أيضا': set([u'فأيضا', u'أيضا', u'وأيضا']),
 u'شرق': set([u'شرق', u'وكشرقنا', u'فكشرقهن', u'فكشرقهم', u'بشرقكن', u'بشرقكم', u'فلشرقكما', u'وكشرقهن', u'وكشرقهم', u'فلشرقها', u'وبشرقكن', u'وبشرقكم', u'ولشرقنا', u'كشرقنا', u'وبشرقنا', u'وكشرقها', u'وبشرق', u'فبشرقكما', u'وكشرقهما', u'بشرقهما', u'فلشرقي', u'شرقكم', u'وشرقها', u'فشرقكما', u'شرقكن', u'بشرقك', u'وبشرقي', u'بشرقه', u'فشرقهما', u'بشرقي', u'وبشرقك', u'وشرقكن', u'ولشرقهن', u'وبشرقه', u'وشرقكم', u'كشرقهما', u'كشرقها', u'فبشرقي', u'لشرقي', u'لشرقهم', u'لشرقه', u'وكشرق', u'فلشرقهما', u'فلشرق', u'ولشرقها', u'بشرقكما', u'كشرقكما', u'فكشرقنا', u'فبشرقها', u'فكشرقي', u'فكشرقك', u'فكشرقه', u'فكشرقها', u'شرقنا', u'فبشرقهن', u'فبشرقنا', u'فبشرقهم', u'ولشرقهم', u'كشرقهن', u'كشرقهم', u'فشرقكم', u'فشرقكن', u'ولشرقكن', u'كشرقه', u'فبشرقكم', u'لشرقها', u'كشرقك', u'بشرق', u'وبشرقكما', u'كشرقي', u'شرقي', u'شرقك', u'شرقه', u'بشرقهن', u'وشرقك', u'ولشرقه', u'بشرقهم', u'وشرقه', u'ولشرقك', u'وشرقي', u'ولشرقهما', u'فلشرقه', u'ولشرقي', u'وكشرقكن', u'وكشرقكم', u'فكشرقكن', u'فكشرقكم', u'وبشرقهن', u'وبشرقهم', u'وبشرقهما', u'لشرقنا', u'فشرق', u'شرقكما', u'وشرقكما', u'وبشرقها', u'فبشرق', u'وكشرقك', u'وشرقنا', u'فشرقنا', u'شرقهم', u'وشرق', u'شرقهن', u'فلشرقكن', u'شرقها', u'فلشرقكم', u'وشرقهن', u'بشرقها', u'ولشرقكم', u'وشرقهم', u'فشرقي', u'شرقهما', u'فشرقه', u'لشرقهن', u'فشرقك', u'وكشرقي', u'لشرقكن', u'وكشرقه', u'لشرقكم', u'فكشرقكما', u'لشرق', u'وكشرقكما', u'كشرق', u'فشرقها', u'فبشرقه', u'فبشرقك', u'لشرقك', u'ولشرقكما', u'بشرقنا', u'ولشرق', u'فكشرقهما', u'فلشرقك', u'وشرقهما', u'فكشرق', u'لشرقكما', u'فبشرقكن', u'لشرقهما', u'كشرقكن', u'كشرقكم', u'فلشرقهن', u'فبشرقهما', u'فلشرقنا', u'فلشرقهم', u'فشرقهم', u'فشرقهن']),
 u'رجع': set([u'رجع', u'لرجع', u'فرجع', u'ولرجع', u'ورجع', u'فلرجع']),
 u'عامة': set([u'أوكعامتها', u'ألعامتكم', u'عامتكن', u'أولعامة', u'عامتكم', u'وبعامتهما', u'عامة', u'أفكعامتها', u'فعامته', u'أوبعامتكما', u'عامتي', u'فعامتك', u'أفلعامتها', u'فبعامة', u'عامته', u'أفبعامتكما', u'أفلعامتكم', u'فعامتي', u'عامتك', u'أوكعامتك', u'فعامتها', u'وكعامتهما', u'فلعامتهم', u'ألعامتكما', u'أبعامتي', u'أفعامتنا', u'وعامتكن', u'وعامتكم', u'أوبعامتكم', u'ألعامته', u'أوكعامته', u'وبعامتكما', u'بعامتها', u'أوبعامتها', u'ولعامتهن', u'أبعامتكم', u'فلعامتنا', u'فعامتهن', u'بعامتك', u'فعامتهم', u'فلعامتها', u'أكعامتهم', u'فبعامتكن', u'فبعامتكم', u'كعامتكم', u'كعامتكن', u'أوكعامتي', u'أوكعامتكم', u'بعامتهن', u'بعامتهم', u'ألعامتكن', u'فكعامتها', u'أعامتهم', u'أعامتهن', u'أوكعامتكن', u'أعامة', u'أكعامتي', u'أوكعامتنا', u'أفلعامتهن', u'أوكعامتهم', u'أكعامته', u'أوكعامتهن', u'أكعامتك', u'بعامتنا', u'أفبعامتكم', u'لعامتك', u'أولعامتهما', u'ألعامتها', u'لعامته', u'لعامتي', u'أوعامتنا', u'وكعامتنا', u'أفكعامتكم', u'أفلعامتكما', u'بعامة', u'أفكعامتي', u'أفلعامتهما', u'أفعامتكم', u'أفعامتكن', u'لعامتهما', u'أفلعامة', u'أفلعامتي', u'أوعامتهم', u'وبعامتهم', u'وبعامتهن', u'أوعامتهن', u'أفكعامتهن', u'وكعامتهن', u'وكعامتهم', u'أوبعامتك', u'لعامتكما', u'ولعامتها', u'فعامتكن', u'أفلعامتهم', u'فعامتكم', u'أفلعامتنا', u'أعامتكم', u'أفكعامتكن', u'أفبعامتهن', u'فكعامتكم', u'فكعامتكن', u'فلعامتهما', u'وكعامتها', u'أوعامتها', u'وبعامتها', u'فكعامة', u'لعامتكن', u'لعامتكم', u'أفكعامتك', u'ألعامتك', u'أبعامتها', u'وعامته', u'أفعامة', u'ولعامتهم', u'وعامتك', u'ألعامتي', u'فكعامته', u'وعامتي', u'أفبعامتك', u'وكعامتك', u'ألعامتهن', u'أفبعامته', u'أعامتهما', u'وكعامته', u'أفعامتكما', u'كعامتنا', u'أفبعامتي', u'أولعامتنا', u'وكعامتي', u'أفبعامتهما', u'فعامتهما', u'فبعامتك', u'أكعامتهما', u'ولعامتنا', u'أفبعامتنا', u'أوبعامة', u'فلعامتهن', u'أعامتكما', u'أكعامتهن', u'فبعامتي', u'أولعامتكما', u'أعامتكن', u'أفعامتي', u'فبعامتنا', u'لعامة', u'فكعامتي', u'أفكعامة', u'فلعامتي', u'وبعامتنا', u'فلعامته', u'أفلعامتكن', u'فلعامتك', u'أوبعامتهما', u'بعامتكما', u'أكعامتنا', u'عامتهن', u'فلعامتكن', u'فلعامتكم', u'عامتهم', u'أوبعامته', u'فعامتكما', u'أبعامتكما', u'أوبعامتنا', u'أفعامتك', u'أوبعامتكن', u'أفعامتهما', u'أولعامتها', u'كعامتها', u'أفبعامتهم', u'أبعامتهما', u'أكعامتكن', u'فكعامتك', u'فبعامتها', u'وعامتهن', u'وعامتهم', u'أوبعامتهم', u'أفبعامتها', u'أبعامتهن', u'كعامتهما', u'وبعامتي', u'عامتكما', u'أولعامتهن', u'كعامتهم', u'كعامتهن', u'وبعامته', u'أولعامتك', u'وبعامتك', u'وكعامتكما', u'بعامتكن', u'بعامتكم', u'عامتهما', u'أبعامتك', u'أوعامة', u'أفكعامتكما', u'كعامتكما', u'ألعامتهما', u'وعامتها', u'فبعامتهن', u'فبعامتهم', u'أفلعامته', u'بعامتهما', u'وكعامة', u'أوبعامتهن', u'أفعامتهن', u'أفكعامتنا', u'أعامتها', u'أفكعامتهما', u'أولعامتكن', u'ألعامتهم', u'عامتها', u'فعامة', u'وعامة', u'أفبعامة', u'ولعامة', u'ولعامتي', u'أبعامتهم', u'فكعامتكما', u'ولعامتك', u'ولعامته', u'أفعامتهم', u'كعامتي', u'أوعامتكم', u'وبعامتكم', u'وبعامتكن', u'أوعامتكن', u'أفلعامتك', u'كعامتك', u'وبعامة', u'فكعامتهما', u'كعامته', u'لعامتها', u'وكعامتكن', u'وكعامتكم', u'فبعامتكما', u'أفبعامتكن', u'فبعامتهما', u'أبعامتنا', u'أوعامته', u'بعامته', u'أفعامته', u'أوعامتك', u'أبعامة', u'عامتنا', u'أولعامتكم', u'فلعامتكما', u'أكعامتها', u'وعامتنا', u'أوعامتي', u'أوكعامتهما', u'بعامتي', u'لعامتهن', u'لعامتهم', u'أولعامتهم', u'وعامتهما', u'فبعامته', u'أعامتنا', u'أفكعامته', u'أبعامتكن', u'كعامة', u'ولعامتكما', u'أوعامتهما', u'أفكعامتهم', u'ألعامتنا', u'أكعامتكم', u'أكعامة', u'ألعامة', u'فكعامتهن', u'أبعامته', u'فعامتنا', u'لعامتنا', u'أولعامته', u'أولعامتي', u'ولعامتكم', u'ولعامتكن', u'فلعامة', u'أوكعامة', u'أكعامتكما', u'وعامتكما', u'أعامتي', u'أفعامتها', u'أوبعامتي', u'فكعامتهم', u'فكعامتنا', u'ولعامتهما', u'أوعامتكما', u'أعامتك', u'أوكعامتكما', u'أعامته']),
 u'إذن': set([u'إذن', u'فإذن', u'وإذن']),
 u'غروب': set([u'كغروبكن', u'لغروبها', u'كغروبكم', u'فلغروبها', u'فبغروبه', u'غروبكم', u'غروبكن', u'غروب', u'فبغروبك', u'وبغروبها', u'فبغروبي', u'فكغروبه', u'فغروبي', u'وكغروبكم', u'غروبكما', u'وكغروبكن', u'فبغروبها', u'فغروبك', u'فغروبه', u'لغروبه', u'لغروبك', u'وبغروبهما', u'وغروبهم', u'لغروبي', u'وغروبهن', u'غروبك', u'لغروبنا', u'غروبه', u'فبغروبهم', u'وبغروبكن', u'غروبي', u'فبغروبهن', u'فغروبهما', u'وبغروبنا', u'فغروبنا', u'وبغروبكم', u'فكغروبكن', u'وغروبها', u'فكغروبكم', u'لغروبهم', u'لغروبهن', u'بغروبكم', u'بغروبكن', u'وبغروبهن', u'وبغروبهم', u'كغروب', u'ولغروبكما', u'ولغروبها', u'فلغروبهن', u'فلغروبك', u'وبغروبك', u'فلغروبه', u'وبغروبه', u'لغروبكما', u'فلغروبنا', u'وبغروبي', u'فلغروبي', u'فلغروب', u'فغروبها', u'وغروبي', u'ولغروبهما', u'فكغروبهما', u'وغروبك', u'بغروب', u'وغروبه', u'فلغروبكم', u'فبغروبكم', u'فبغروبكن', u'ولغروبنا', u'فلغروبكن', u'لغروبهما', u'وغروبنا', u'ولغروبهن', u'ولغروبهم', u'فكغروبكما', u'فبغروبهما', u'فغروبكما', u'فغروبهم', u'فغروبهن', u'وبغروبكما', u'فكغروبها', u'بغروبهما', u'وبغروب', u'وغروبكما', u'ولغروبي', u'غروبهم', u'غروبهن', u'فكغروبك', u'ولغروبه', u'وغروب', u'كغروبهن', u'ولغروبك', u'كغروبهم', u'فبغروبكما', u'وكغروبنا', u'فغروبكم', u'بغروبكما', u'كغروبكما', u'كغروبي', u'كغروبه', u'كغروبنا', u'كغروبك', u'فكغروبي', u'كغروبهما', u'وكغروبهم', u'فلغروبهم', u'وكغروبهن', u'لغروب', u'بغروبنا', u'فكغروبهن', u'فكغروبهم', u'فكغروب', u'لغروبكم', u'لغروبكن', u'وكغروبها', u'بغروبهم', u'وغروبهما', u'بغروبهن', u'فكغروبنا', u'غروبها', u'كغروبها', u'فلغروبكما', u'بغروبها', u'فبغروب', u'بغروبي', u'ولغروب', u'فغروبكن', u'بغروبك', u'بغروبه', u'وكغروبي', u'فلغروبهما', u'غروبنا', u'وكغروبكما', u'وكغروبهما', u'وغروبكم', u'وغروبكن', u'ولغروبكن', u'ولغروبكم', u'وكغروبه', u'وكغروبك', u'وكغروب', u'غروبهما', u'فبغروبنا', u'فغروب']),
 u'عندما': set([u'فعندما', u'عندما', u'وعندما']),
 u'وراءك': set([u'وراءك']),
 u'إذ': set([u'فإذ', u'وإذ', u'إذ']),
 u'ألا': set([u'ألا', u'وألا', u'فألا']),
 u'لكي': set([u'فلكي', u'ولكي', u'لكي']),
 u'مابرحت': set([u'فمابرحت', u'مابرحت', u'ومابرحت']),
 u'لكن': set([u'فلكنها', u'لكنه', u'فلكني', u'لكنك', u'فلكنك', u'ولكننا', u'فلكنه', u'لكني', u'ولكنكم', u'ولكنكن', u'فلكنهن', u'فلكنهم', u'ولكني', u'أفلكن', u'لكن', u'ولكنهم', u'ولكنهن', u'فلكنكن', u'فلكنكم', u'لكنها', u'ولكنكما', u'فلكننا', u'فلكن', u'ولكنه', u'لكنكن', u'لكنكم', u'ولكن', u'ولكنها', u'فلكنهما', u'ولكنك', u'لكنهن', u'لكنهم', u'ألكن', u'فلكنكما', u'لكنهما', u'أولكن', u'ولكنهما', u'لكنكما', u'لكننا']),
 u'لكم': set([u'أولكم', u'فلكم', u'ولكم', u'أفلكم', u'لكم', u'ألكم']),
 u'يومئذ': set([u'فيومئذ', u'يومئذ', u'ويومئذ']),
 u'لكنما': set([u'فلكنما', u'ولكنما', u'لكنما']),
 u'قبلما': set([u'فقبلما', u'وقبلما', u'قبلما']),
 u'بي': set([u'فبي', u'أبي', u'أوبي', u'بي', u'وبي', u'أفبي']),
 u'ذ': set([u'ذ']),
 u'ماانفككنا': set([u'فماانفككنا', u'وماانفككنا', u'ماانفككنا']),
 u'بك': set([u'فبك', u'أبك', u'أوبك', u'وبك', u'أفبك', u'بك']),
 u'بن': set([u'بن']),
 u'به': set([u'أوبه', u'فبه', u'أبه', u'أفبه', u'وبه', u'به']),
 u'اللتان': set([u'فاللتان', u'اللتان', u'واللتان']),
 u'ماانفككتم': set([u'ماانفككتم', u'فماانفككتم', u'وماانفككتم']),
 u'تارة': set([u'وتارة', u'تارة', u'فتارة']),
 u'بس': set([u'وبس', u'بس', u'فبس']),
 u'مابرحن': set([u'مابرحن', u'ومابرحن', u'فمابرحن']),
 u'فقط': set([u'وفقط', u'ففقط', u'فقط']),
 u'أنشأ': set([u'أنشأ', u'فلأنشأ', u'ولأنشأ', u'فأنشأ', u'وأنشأ', u'لأنشأ']),
 u'ماانفككتن': set([u'وماانفككتن', u'ماانفككتن', u'فماانفككتن']),
 u'بخ': set([u'فبخ', u'بخ', u'وبخ']),
 u'مثلما': set([u'مثلما', u'أومثلما', u'فمثلما', u'أمثلما', u'ومثلما', u'أفمثلما']),
 u'شبه': set([u'شبههن', u'شبههم', u'أوشبهك', u'وشبهي', u'أوشبهه', u'وشبهه', u'أوشبهي', u'ألشبهنا', u'وشبهك', u'لشبهنا', u'فلشبهكن', u'فبشبهها', u'أوشبهكما', u'لشبهها', u'كشبه', u'أفكشبهي', u'أولشبهه', u'بشبه', u'فشبهكن', u'فشبهكم', u'بشبهنا', u'أوشبهنا', u'ألشبههن', u'ولشبهنا', u'ألشبههم', u'لشبههما', u'فكشبههما', u'أوكشبهي', u'أفبشبهها', u'أفلشبههما', u'وبشبهه', u'أوبشبهك', u'أكشبهكن', u'كشبهكما', u'أفلشبهه', u'أفكشبهكما', u'أوبشبهي', u'بشبههما', u'فكشبهه', u'ألشبهها', u'أفكشبهك', u'فكشبهك', u'ألشبههما', u'شبه', u'أوكشبههما', u'أفبشبههن', u'فكشبهي', u'أولشبهك', u'أفبشبههم', u'شبهها', u'أشبهي', u'وبشبهك', u'فلشبهكم', u'أشبهك', u'أفشبهكم', u'أشبهه', u'وبشبهي', u'فبشبهكن', u'أولشبهكن', u'أفكشبهكن', u'أفكشبهكم', u'وكشبهك', u'لشبههم', u'لشبههن', u'وكشبهه', u'أفلشبه', u'كشبههما', u'أولشبههما', u'كشبهي', u'أوبشبه', u'وشبه', u'كشبهك', u'وبشبههما', u'أوشبهكم', u'كشبهه', u'أوكشبهها', u'فبشبهكم', u'وبشبهها', u'لشبهك', u'أوبشبهكن', u'لشبهه', u'ولشبهكم', u'لشبهي', u'ولشبهكن', u'أوشبههما', u'أفبشبهنا', u'أبشبهه', u'فكشبهها', u'أفلشبههم', u'كشبهكم', u'أبشبهك', u'شبهنا', u'أفكشبهها', u'أوكشبهكما', u'أبشبهي', u'أولشبههن', u'أولشبههم', u'فلشبهه', u'أكشبهكم', u'فلشبههن', u'فلشبهك', u'أكشبههن', u'أكشبههم', u'أفلشبهها', u'فلشبهي', u'فبشبهنا', u'أفلشبهي', u'فكشبههن', u'أشبهكم', u'أوشبه', u'أشبهكن', u'أفكشبههما', u'أوكشبهنا', u'أولشبهها', u'ألشبه', u'أفلشبهنا', u'أفلشبهكما', u'وبشبهنا', u'أفلشبهك', u'أكشبهها', u'أوبشبهه', u'وشبهكم', u'وشبهكن', u'أفكشبهنا', u'أكشبه', u'فكشبهنا', u'أفشبه', u'أبشبهكن', u'أبشبهكم', u'أوكشبههن', u'فكشبهكما', u'أوبشبهنا', u'وبشبههم', u'أوكشبهه', u'وبشبههن', u'لشبهكما', u'بشبهكم', u'بشبهكن', u'وكشبهكن', u'لشبهكم', u'لشبهكن', u'لشبه', u'أفبشبهكما', u'أوبشبهكما', u'أفشبهك', u'ولشبهي', u'فشبهنا', u'أفبشبههما', u'ولشبهك', u'أشبهنا', u'أشبههما', u'أكشبهنا', u'ولشبهه', u'فلشبههم', u'فكشبه', u'وكشبهكما', u'فلشبه', u'أفشبهي', u'فبشبه', u'أفشبهه', u'أفشبهها', u'أكشبهكما', u'وكشبههما', u'وكشبهكم', u'ألشبهي', u'أوشبهكن', u'أفكشبه', u'فشبههن', u'فشبههم', u'فكشبهكن', u'شبهكما', u'فكشبهكم', u'أفكشبههن', u'أشبههن', u'فلشبهنا', u'ألشبهه', u'أشبه', u'ألشبهكم', u'وشبهها', u'أوكشبههم', u'أفشبههم', u'أفبشبهي', u'أفشبههن', u'أوبشبههن', u'ولشبههما', u'أشبههم', u'أبشبهنا', u'فشبهها', u'ألشبهك', u'أكشبههما', u'وبشبهكم', u'أشبهها', u'فبشبههم', u'فبشبههن', u'أشبهكما', u'بشبهي', u'فبشبهكما', u'ألشبهكن', u'بشبهه', u'أبشبههن', u'بشبهك', u'وكشبهنا', u'وشبهكما', u'أولشبهنا', u'أوبشبههم', u'شبهكن', u'شبهكم', u'أوبشبهها', u'وشبههما', u'أوبشبههما', u'كشبهكن', u'أفكشبههم', u'فلشبهها', u'أفبشبهه', u'أفشبههما', u'أبشبهكما', u'أفبشبهك', u'ألشبهكما', u'بشبههم', u'بشبههن', u'وكشبه', u'ولشبههم', u'أوبشبهكم', u'ولشبههن', u'بشبهكما', u'شبهه', u'أوشبههن', u'أبشبهها', u'شبهك', u'أوشبههم', u'كشبههم', u'كشبههن', u'فبشبههما', u'شبهي', u'فبشبهك', u'فشبهكما', u'أبشبه', u'فبشبهه', u'فبشبهي', u'أفبشبه', u'أكشبهه', u'فشبههما', u'أفبشبهكن', u'ولشبهكما', u'وكشبهها', u'أفلشبهكن', u'أوكشبهك', u'أفلشبهكم', u'كشبهنا', u'أولشبهي', u'وبشبهكما', u'أوكشبه', u'أولشبهكم', u'أفشبهكن', u'أولشبه', u'أفلشبههن', u'أفبشبهكم', u'أفشبهنا', u'أفكشبهه', u'وشبهنا', u'وبشبه', u'وكشبههم', u'وكشبههن', u'أكشبهي', u'وكشبهي', u'أوكشبهكن', u'ولشبه', u'أوكشبهكم', u'أفشبهكما', u'فلشبههما', u'فشبهه', u'فشبه', u'فشبهك', u'وبشبهكن', u'وشبههم', u'وشبههن', u'بشبهها', u'فلشبهكما', u'ولشبهها', u'فشبهي', u'أولشبهكما', u'شبههما', u'أوشبهها', u'أبشبههم', u'كشبهها', u'فكشبههم', u'أكشبهك', u'أبشبههما']),
 u'بها': set([u'وبها', u'أفبها', u'أبها', u'أوبها', u'فبها', u'بها']),
 u'مازلتما': set([u'فمازلتما', u'مازلتما', u'ومازلتما']),
 u'فوق': set([u'فلفوقكما', u'فوقهما', u'فلفوقهما', u'ولفوقكما', u'ففوقها', u'ولفوقكم', u'ولفوقكن', u'ألفوقكن', u'ألفوقكم', u'أولفوقه', u'أولفوقك', u'أفلفوق', u'أففوقكم', u'أففوقكن', u'وفوقكما', u'أفلفوقكن', u'أوفوق', u'أفلفوقكم', u'فوقكما', u'أولفوقهن', u'لفوقنا', u'وفوقه', u'وفوقك', u'ففوق', u'وفوقي', u'أوفوقها', u'أفوقك', u'أفوقه', u'أفوقي', u'ففوقهن', u'ففوقهم', u'أففوقه', u'أففوقك', u'وفوقهما', u'ألفوق', u'لفوق', u'أففوقي', u'وفوقها', u'أوفوقي', u'فلفوقهم', u'أفوق', u'أوفوقه', u'أوفوقك', u'أولفوقكن', u'أولفوقكم', u'أفوقنا', u'فوقها', u'ألفوقهما', u'أففوق', u'فلفوقنا', u'أفلفوقهن', u'أفلفوقهم', u'ألفوقكما', u'أفلفوقكما', u'فوقهن', u'فوقهم', u'أفوقهما', u'أوفوقكن', u'أفلفوقك', u'أوفوقكم', u'وفوقنا', u'أفلفوقه', u'أفلفوقي', u'أفلفوقها', u'أفوقكم', u'أوفوقنا', u'أفوقكن', u'ألفوقك', u'ألفوقه', u'ألفوقي', u'فوقنا', u'ولفوقك', u'وفوقهم', u'وفوقهن', u'ولفوقه', u'فلفوقها', u'أولفوق', u'ولفوقي', u'ألفوقهم', u'ولفوقهما', u'ألفوقنا', u'ولفوقهم', u'أفلفوقنا', u'ولفوقهن', u'لفوقي', u'فلفوقه', u'ألفوقهن', u'لفوقك', u'أفوقكما', u'لفوقه', u'أففوقها', u'فوق', u'لفوقها', u'فوقكن', u'فوقكم', u'ففوقهما', u'لفوقكم', u'لفوقكن', u'أولفوقي', u'أففوقهم', u'أوفوقكما', u'أوفوقهم', u'فلفوق', u'ففوقكن', u'ففوقكم', u'أففوقنا', u'ولفوقها', u'ففوقي', u'ففوقه', u'ففوقكما', u'ففوقك', u'فلفوقهن', u'فلفوقكم', u'فلفوقكن', u'لفوقكما', u'أولفوقنا', u'ولفوق', u'أولفوقكما', u'أففوقكما', u'فوقي', u'فوقه', u'فوقك', u'أفوقها', u'ألفوقها', u'أولفوقهما', u'ولفوقنا', u'أولفوقهم', u'لفوقهم', u'لفوقهن', u'أفلفوقهما', u'وفوق', u'أفوقهم', u'لفوقهما', u'أفوقهن', u'فلفوقي', u'أولفوقها', u'ففوقنا', u'أوفوقهن', u'فلفوقك', u'وفوقكم', u'وفوقكن', u'أففوقهما', u'أوفوقهما', u'أففوقهن']),
 u'شهر': set([u'وكشهركن', u'وكشهركم', u'وكشهر', u'وشهرهن', u'وشهرهم', u'فلشهرنا', u'فكشهرها', u'وكشهري', u'وكشهره', u'وكشهرك', u'بشهركن', u'بشهركم', u'كشهر', u'وشهري', u'وشهره', u'وشهرنا', u'وشهركما', u'فلشهرهم', u'وشهرك', u'ولشهركم', u'وشهرهما', u'فبشهر', u'ولشهر', u'ولشهرهما', u'فلشهركما', u'فشهرهم', u'فشهرهن', u'وكشهرنا', u'وبشهره', u'فشهر', u'وبشهرك', u'ولشهركما', u'فبشهركما', u'وبشهري', u'شهر', u'فشهرنا', u'فبشهرنا', u'وشهرها', u'فلشهرهما', u'فكشهرهن', u'فكشهركما', u'فكشهرهم', u'وبشهرهم', u'فشهرك', u'وبشهرهن', u'بشهري', u'بشهره', u'بشهرك', u'فلشهر', u'وبشهرنا', u'لشهركن', u'لشهركم', u'فبشهري', u'شهركم', u'شهركن', u'فبشهرك', u'وبشهر', u'فلشهركن', u'فلشهركم', u'فكشهره', u'وبشهركما', u'فكشهر', u'كشهركن', u'كشهره', u'كشهركم', u'وبشهرها', u'فشهرها', u'كشهري', u'فكشهرك', u'لشهر', u'وشهركن', u'وشهركم', u'فبشهرهما', u'بشهرنا', u'وكشهرهن', u'وكشهرهم', u'ولشهرهن', u'ولشهرهم', u'فبشهرها', u'شهركما', u'فشهره', u'بشهرهن', u'بشهرهم', u'شهرهما', u'فشهري', u'ولشهرنا', u'ولشهركن', u'ولشهرها', u'فبشهرهن', u'فبشهرهم', u'وكشهركما', u'بشهركما', u'ولشهره', u'فشهركم', u'فشهركن', u'فلشهره', u'بشهرهما', u'فلشهري', u'وكشهرهما', u'كشهرك', u'شهره', u'شهرك', u'فكشهركن', u'فكشهركم', u'شهري', u'وكشهرها', u'وشهر', u'فكشهرهما', u'ولشهري', u'ولشهرك', u'كشهرها', u'شهرنا', u'لشهرهن', u'لشهرهم', u'بشهر', u'فشهرهما', u'وبشهرهما', u'فلشهرهن', u'لشهرك', u'شهرهم', u'شهرهن', u'لشهرنا', u'فبشهركن', u'فبشهركم', u'لشهري', u'فكشهري', u'لشهركما', u'بشهرها', u'كشهرنا', u'كشهركما', u'فلشهرها', u'وبشهركن', u'فكشهرنا', u'شهرها', u'كشهرهما', u'فشهركما', u'لشهره', u'كشهرهن', u'فلشهرك', u'كشهرهم', u'لشهرهما', u'لشهرها', u'وبشهركم', u'فبشهره']),
 u'ماانفكت': set([u'فماانفكت', u'وماانفكت', u'ماانفكت']),
 u'إي': set([u'فإي', u'وإي', u'إي']),
 u'اللاتي': set([u'وللاتي', u'فكاللاتي', u'واللاتي', u'اللاتي', u'كاللاتي', u'وكاللاتي', u'فللاتي', u'فباللاتي', u'باللاتي', u'فاللاتي', u'وباللاتي', u'للاتي']),
 u'مازال': set([u'ومازال', u'مازال', u'فمازال']),
 u'إن': set([u'أإننا', u'أفلإنها', u'أفلإنهما', u'فإنهم', u'فإنهن', u'أفإنهن', u'أولإنكما', u'أفإنهم', u'أإنهن', u'أإنهم', u'أولإنك', u'ولإنهن', u'ولإنهم', u'فإننا', u'أولإني', u'لإنك', u'لإنه', u'وكإن', u'فإن', u'لإني', u'وإنهم', u'وإنهن', u'فلإنكم', u'أإنها', u'فلإنكن', u'ولإنها', u'أفلإنهم', u'أوإننا', u'ألإننا', u'وبإن', u'وإنها', u'أفإنكما', u'أولإنهما', u'إن', u'بإن', u'أفإنه', u'فلإنكما', u'فإنها', u'أفإنك', u'أفإني', u'أفإنها', u'فلإنهما', u'أفلإننا', u'ولإننا', u'أوإنها', u'ألإنها', u'إنها', u'وإننا', u'أولإنه', u'ألإن', u'أفلإنكما', u'أفإنهما', u'وإن', u'فإنهما', u'لإنها', u'أفإننا', u'كإن', u'وإنهما', u'لإنهم', u'لإنهن', u'إننا', u'أإن', u'أولإنكن', u'ألإنكما', u'فلإننا', u'فبإن', u'ألإنهما', u'لإننا', u'أوإنهم', u'أولإن', u'إنهم', u'إنهن', u'وإنكما', u'فإني', u'أفإنكن', u'أفإنكم', u'فإنكم', u'فإنكن', u'إنكما', u'أإنكن', u'فكإن', u'فلإنها', u'أإنكم', u'وإنكم', u'إنهما', u'إني', u'وإنكن', u'ولإنكن', u'أإنكما', u'ولإنكم', u'إنك', u'إنه', u'فلإنه', u'فلإنك', u'أولإنكم', u'فلإنهم', u'فلإني', u'فلإنهن', u'ولإن', u'أفلإني', u'ألإنكم', u'أفإن', u'أفلإنكم', u'أفلإنك', u'أفلإنه', u'أإنك', u'أإنه', u'أإني', u'فإنكما', u'ولإني', u'ألإنكن', u'ولإنك', u'ولإنه', u'أولإنها', u'أوإن', u'لإنهما', u'ألإنه', u'ألإنك', u'أوإنهن', u'ألإني', u'أوإني', u'أفلإنهن', u'لإن', u'ألإنهن', u'لإنكما', u'ألإنهم', u'أوإنكما', u'أولإننا', u'وإنه', u'فلإن', u'أإنهما', u'وإنك', u'فإنك', u'لإنكم', u'وإني', u'فإنه', u'لإنكن', u'ولإنهما', u'إنكم', u'إنكن', u'أولإنهم', u'أولإنهن', u'أفلإن', u'ولإنكما', u'أوإنكم', u'أوإنك', u'أوإنهما', u'أوإنكن', u'أوإنه', u'أفلإنكن']),
 u'كأن': set([u'وكأننا', u'أوكأنكم', u'أوكأنكن', u'ولكأنهن', u'أفكأنه', u'ولكأنهم', u'أفكأنك', u'أفكأني', u'وكأنهن', u'وكأنهم', u'لكأن', u'ولكأننا', u'كأنها', u'ولكأن', u'وكأنه', u'وكأنك', u'أكأننا', u'وكأني', u'وكأنهما', u'أفلكأننا', u'أولكأني', u'أولكأن', u'وكأنها', u'ألكأنكما', u'لكأنها', u'لكأنهن', u'لكأنهم', u'أولكأنك', u'كأنهم', u'كأنهن', u'أولكأنه', u'ألكأنه', u'ألكأنك', u'فكأنكم', u'فكأنكن', u'ألكأني', u'ولكأنها', u'وكأنكما', u'ألكأنهما', u'أوكأنكما', u'أكأنكن', u'ألكأنها', u'أكأنكم', u'أولكأنهم', u'أولكأنهن', u'أفلكأنها', u'أفلكأنكما', u'فكأن', u'فلكأنكما', u'أوكأنهما', u'أفكأنكن', u'أفكأنكم', u'فلكأنكن', u'فلكأنكم', u'وكأن', u'أكأن', u'فلكأنهما', u'أكأنكما', u'ولكأني', u'أوكأنك', u'أوكأنه', u'كأنكما', u'أفكأنهما', u'ألكأنهم', u'فكأنهما', u'ألكأنهن', u'أكأنك', u'أولكأنها', u'كأنهما', u'أكأني', u'ألكأننا', u'أولكأنكما', u'ولكأنهما', u'وكأنكن', u'وكأنكم', u'أفكأنكما', u'ولكأنكن', u'أوكأنها', u'ولكأنكم', u'فلكأني', u'فلكأنك', u'أكأنهما', u'فكأنكما', u'فلكأنه', u'أولكأننا', u'فلكأنهن', u'فلكأنهم', u'فكأنها', u'فكأننا', u'كأنكم', u'كأنكن', u'أوكأني', u'لكأنكن', u'لكأنكم', u'أولكأنهما', u'فلكأنها', u'فكأنهم', u'فكأنهن', u'فلكأن', u'كأني', u'ولكأنكما', u'كأنه', u'كأنك', u'أفكأن', u'أوكأنهم', u'أوكأنهن', u'فكأني', u'فكأنك', u'فكأنه', u'أفلكأن', u'ألكأنكن', u'أفكأنهن', u'فلكأننا', u'أكأنهن', u'أكأنهم', u'أوكأننا', u'أكأنه', u'أولكأنكم', u'أولكأنكن', u'أفكأنهم', u'أفكأنها', u'كأن', u'أوكأن', u'لكأنك', u'لكأنهما', u'لكأنه', u'لكأني', u'ألكأن', u'لكأنكما', u'ولكأنك', u'ولكأنه', u'أفكأننا', u'ألكأنكم', u'لكأننا', u'كأننا', u'أفلكأنهم', u'أفلكأنكم', u'أفلكأني', u'أفلكأنهما', u'أفلكأنكن', u'أفلكأنك', u'أفلكأنهن', u'أفلكأنه', u'أكأنها']),
 u'كليهما': set([u'وكليهما', u'أوبكليهما', u'ككليهما', u'فكليهما', u'وبكليهما', u'ولكليهما', u'فككليهما', u'بكليهما', u'فبكليهما', u'أكليهما', u'أفلكليهما', u'أبكليهما', u'أولكليهما', u'لكليهما', u'أككليهما', u'فلكليهما', u'وككليهما', u'أوكليهما', u'أفكليهما', u'ألكليهما', u'كليهما', u'أفبكليهما', u'أوككليهما', u'أفككليهما']),
 u'مافتئا': set([u'فمافتئا', u'مافتئا', u'ومافتئا']),
 u'كليكما': set([u'فكليكما', u'ولكليكما', u'وكليكما', u'ككليكما', u'أوبكليكما', u'أفلكليكما', u'وككليكما', u'بكليكما', u'فككليكما', u'أكليكما', u'فبكليكما', u'فلكليكما', u'أفبكليكما', u'أبكليكما', u'أفككليكما', u'أوككليكما', u'ألكليكما', u'أولكليكما', u'وبكليكما', u'أوكليكما', u'أككليكما', u'كليكما', u'أفكليكما', u'لكليكما']),
 u'شرع': set([u'فشرع', u'وشرع', u'فلشرع', u'ولشرع', u'لشرع', u'شرع']),
 u'ليسا': set([u'ليسا', u'فليسا', u'أوليسا', u'وليسا', u'أفليسا', u'أليسا']),
 u'مكانك': set([u'ومكانك', u'فمكانك', u'مكانك']),
 u'ليست': set([u'فليست', u'أوليست', u'ليست', u'أليست', u'وليست', u'أفليست']),
 u'وي': set([u'وي']),
 u'أعلى': set([u'أعليكم', u'لأعليهن', u'لأعليك', u'لأعليه', u'وأعليكم', u'وأعليكن', u'أعليهم', u'أعليهن', u'فبأعليه', u'فبأعلى', u'لأعلينا', u'فبأعليها', u'ولأعليك', u'فبأعليك', u'أعلينا', u'ولأعليه', u'وكأعليها', u'فبأعليهم', u'فبأعليهن', u'فكأعليهما', u'فكأعليكن', u'فكأعليكم', u'وكأعليهم', u'وكأعليهن', u'ولأعليهما', u'فأعليهما', u'ولأعلينا', u'وبأعليهما', u'لأعليها', u'بأعليكم', u'بأعليكن', u'وبأعليكما', u'أعليها', u'فلأعلى', u'فلأعلي', u'كأعلي', u'كأعلى', u'كأعليهن', u'كأعليهم', u'أعلى', u'أعلي', u'وكأعلى', u'فأعليهن', u'فأعليكما', u'وبأعلي', u'وكأعلينا', u'وبأعلى', u'فلأعليها', u'فبأعلينا', u'أعليكما', u'وبأعلينا', u'بأعلى', u'بأعلي', u'أعليهما', u'فلأعليهم', u'فلأعليهن', u'فبأعليكما', u'بأعلينا', u'لأعلى', u'فلأعليك', u'فلأعليه', u'فكأعلينا', u'كأعليها', u'بأعليكما', u'فكأعليكما', u'وبأعليها', u'ولأعليهن', u'فأعليها', u'بأعليهما', u'أعليه', u'أعليكن', u'أعليك', u'فبأعلي', u'لأعليكم', u'لأعليكن', u'وكأعليكما', u'وأعليهم', u'وأعليهن', u'بأعليها', u'كأعليكما', u'فكأعليها', u'فأعلى', u'فأعلي', u'كأعلينا', u'ولأعليكما', u'وبأعليه', u'وأعلينا', u'فبأعليهما', u'وبأعليك', u'فلأعليهما', u'فأعلينا', u'فكأعليهن', u'فكأعليه', u'لأعليهم', u'فكأعليك', u'لأعلي', u'فبأعليكم', u'فبأعليكن', u'ولأعلى', u'فلأعلينا', u'وأعليه', u'وكأعليكم', u'وكأعليكن', u'وأعليك', u'وكأعليهما', u'وبأعليهن', u'وبأعليهم', u'فأعليك', u'فأعليه', u'بأعليهم', u'بأعليهن', u'وأعليها', u'فأعليهم', u'وأعليكما', u'ولأعليكن', u'ولأعليكم', u'وكأعلي', u'فكأعليهم', u'وأعليهما', u'وبأعليكن', u'وبأعليكم', u'فأعليكم', u'فأعليكن', u'فلأعليكما', u'لأعليكما', u'وكأعليه', u'وكأعليك', u'لأعليهما', u'ولأعليها', u'ولأعليهم', u'فكأعلي', u'فكأعلى', u'وأعلى', u'فلأعليكم', u'فلأعليكن', u'وأعلي', u'كأعليه', u'كأعليهما', u'كأعليك', u'كأعليكن', u'كأعليكم', u'بأعليه', u'ولأعلي', u'بأعليك']),
 u'لسنا': set([u'ألسنا', u'لسنا', u'أفلسنا', u'ولسنا', u'أولسنا', u'فلسنا']),
 u'ثمة': set([u'أثمة', u'ثمة', u'أفثمة', u'وثمة', u'فثمة', u'أوثمة']),
 u'لات': set([u'لات', u'فلات', u'ولات']),
 u'حسبما': set([u'وحسبما', u'أفحسبما', u'أوحسبما', u'فحسبما', u'حسبما', u'أحسبما']),
 u'ث': set([u'ث']),
 u'طالما': set([u'وطالما', u'أفطالما', u'أفلطالما', u'لطالما', u'طالما', u'ولطالما', u'أوطالما', u'فطالما', u'فلطالما', u'ألطالما', u'أطالما', u'أولطالما']),
 u'ذوا': set([u'فذوا', u'وذوا', u'ذوا']),
 u'مع': set([u'لمعنا', u'أفمع', u'أولمعنا', u'أمعهم', u'أمعهن', u'أولمعها', u'أومعهما', u'لمعهن', u'لمعهم', u'لمعها', u'معكما', u'ولمعكم', u'ولمعكن', u'ومعكن', u'ومعكم', u'معهما', u'أومعكم', u'ألمعنا', u'أفمعهما', u'لمعي', u'أمعها', u'أومعها', u'أومعهن', u'أولمعهم', u'أفلمعهم', u'ألمعك', u'أفلمعهن', u'ألمعه', u'ومعهما', u'معنا', u'ألمعكما', u'فمعهن', u'فمعهم', u'فلمعهما', u'أفمعكما', u'أومعهم', u'معهن', u'معهم', u'أمعنا', u'مع', u'فلمعها', u'ألمعكم', u'ألمعكن', u'ومعكما', u'أولمعهن', u'أفلمعكن', u'ومعنا', u'أفلمعنا', u'أومعكما', u'معها', u'فلمعهن', u'فلمعهم', u'ألمعها', u'لمع', u'أومعه', u'أفمعنا', u'أومعك', u'فمع', u'ولمعنا', u'أومعي', u'فمعها', u'أفلمعي', u'فلمعنا', u'أفلمعك', u'أفلمعه', u'ومعها', u'أفلمعها', u'أمعكم', u'أمعكن', u'أفمعها', u'ولمعها', u'فلمعكما', u'لمعكن', u'ومع', u'لمعكم', u'فمعنا', u'أفلمعكما', u'ومعي', u'ألمعي', u'أفمعهن', u'ولمعهم', u'ومعه', u'ولمعهما', u'ولمعهن', u'ومعك', u'أومع', u'ولمعكما', u'أمعهما', u'أفلمعهما', u'لمعك', u'ومعهن', u'لمعه', u'أومعكن', u'ومعهم', u'فمعكما', u'أولمعكن', u'أولمعكم', u'أفلمع', u'أمعك', u'أمعه', u'أمعي', u'ألمع', u'فمعكن', u'فمعكم', u'أفمعك', u'ولمعي', u'ولمعك', u'أفمعهم', u'ولمعه', u'معكن', u'معكم', u'فمعهما', u'أولمعكما', u'أمعكما', u'ألمعهم', u'ألمعهن', u'أولمعي', u'أفمعكم', u'أولمعه', u'أفمعكن', u'أولمعهما', u'أولمعك', u'فمعه', u'فمعك', u'فلمعكن', u'فلمعكم', u'فلمع', u'ولمع', u'فمعي', u'لمعهما', u'فلمعي', u'أفلمعكم', u'فلمعه', u'فلمعك', u'لمعكما', u'ألمعهما', u'معك', u'أفمعي', u'معه', u'أفمعه', u'معي', u'أولمع', u'أومعنا', u'أمع']),
 u'ماانفك': set([u'وماانفك', u'ماانفك', u'فماانفك']),
 u'نفس': set([u'أوبنفسي', u'أفنفسهم', u'ونفسها', u'أفنفسك', u'لنفسنا', u'بنفس', u'أفنفسه', u'ولنفسنا', u'أفنفسي', u'أفكنفسكم', u'أفنفسهن', u'وكنفسها', u'أكنفسكن', u'وكنفسكما', u'أكنفسكم', u'فكنفسكما', u'أبنفسكم', u'أفبنفس', u'لنفسي', u'أفنفسنا', u'أفكنفسها', u'وبنفسي', u'لنفسهم', u'أونفسهم', u'ونفس', u'لنفسهن', u'أوبنفس', u'وبنفسك', u'أوكنفسنا', u'وكنفسهما', u'وبنفسه', u'ولنفسهما', u'أوبنفسك', u'أكنفسها', u'فبنفسهم', u'ولنفسكما', u'فبنفسهن', u'أفكنفسهن', u'أونفسهن', u'أفكنفسهم', u'لنفسها', u'أفلنفسهن', u'أفبنفسكما', u'أوبنفسه', u'وكنفسنا', u'أنفسكن', u'أفنفسها', u'نفسكن', u'وبنفسهما', u'نفسكم', u'وبنفسنا', u'فبنفسها', u'أوكنفسهن', u'ونفسهم', u'بنفسنا', u'أفلنفسهم', u'ونفسهن', u'أونفسها', u'أوكنفسهم', u'أونفسي', u'أونفسه', u'وكنفسهم', u'أونفسك', u'وكنفسهن', u'ألنفس', u'كنفسكم', u'كنفسكن', u'أكنفسكما', u'أفبنفسهما', u'أوكنفسك', u'أوكنفسكم', u'أفكنفسنا', u'فلنفسهم', u'بنفسك', u'ولنفسه', u'أنفسكم', u'ولنفسك', u'أوكنفس', u'أفبنفسك', u'أولنفسكما', u'أكنفس', u'ولنفسي', u'ونفسهما', u'فنفسهما', u'فكنفسكم', u'فكنفسكن', u'أبنفسكن', u'أفكنفس', u'وبنفسها', u'ونفسكما', u'ونفسك', u'فبنفسي', u'بنفسها', u'ونفسه', u'أونفسنا', u'فبنفسك', u'ونفسي', u'أفبنفسكم', u'أفبنفسكن', u'فبنفسه', u'أوبنفسها', u'أولنفسك', u'فلنفسكما', u'بنفسي', u'أكنفسهم', u'أولنفسي', u'أولنفس', u'بنفسهم', u'بنفسهن', u'بنفسه', u'لنفسهما', u'أبنفسي', u'كنفسهما', u'أبنفسه', u'أبنفسك', u'أوبنفسهن', u'ألنفسي', u'أوبنفسنا', u'فلنفسكن', u'فنفسكن', u'أفنفسكما', u'ألنفسك', u'فنفسكم', u'أونفسكم', u'فلنفس', u'أبنفسهن', u'فبنفسنا', u'فلنفسها', u'كنفسك', u'أفبنفسي', u'أنفسكما', u'كنفسه', u'أولنفسه', u'كنفسي', u'ألنفسنا', u'أوكنفسهما', u'ولنفسها', u'كنفس', u'وبنفسكما', u'وبنفسهم', u'لنفسكما', u'أوكنفسه', u'فبنفسكما', u'أوكنفسها', u'كنفسكما', u'كنفسها', u'لنفسه', u'فبنفس', u'لنفسك', u'أفنفسكم', u'أفنفسكن', u'فكنفس', u'فلنفسه', u'أولنفسكن', u'ولنفس', u'فلنفسك', u'أفكنفسك', u'لنفسكم', u'لنفسكن', u'أكنفسهن', u'فلنفسي', u'وبنفسكم', u'أونفسهما', u'أولنفسكم', u'فلنفسنا', u'أبنفسهم', u'أنفسها', u'نفسها', u'أبنفسنا', u'فكنفسهما', u'أكنفسك', u'وكنفسي', u'ألنفسه', u'فكنفسهم', u'وكنفسك', u'وكنفس', u'وكنفسه', u'أنفسي', u'أبنفس', u'أفلنفسهما', u'أبنفسها', u'أنفسهم', u'أنفسهن', u'أفنفس', u'كنفسنا', u'أنفسهما', u'نفسهما', u'ولنفسهم', u'أنفس', u'أفكنفسكن', u'ولنفسهن', u'أفبنفسه', u'نفسكما', u'أوبنفسكن', u'أولنفسهما', u'أكنفسنا', u'فبنفسهما', u'أولنفسها', u'فلنفسهن', u'كنفسهم', u'كنفسهن', u'أكنفسهما', u'أنفسنا', u'أوبنفسكم', u'ونفسكم', u'أفلنفسكن', u'أفلنفسكم', u'ونفسكن', u'أفلنفس', u'وكنفسكم', u'أونفسكن', u'فلنفسهما', u'وكنفسكن', u'نفسنا', u'أوبنفسهما', u'ولنفسكم', u'ولنفسكن', u'أنفسك', u'فنفسي', u'فنفسها', u'وبنفسكن', u'أنفسه', u'ألنفسهما', u'فنفسه', u'فكنفسهن', u'أبنفسهما', u'فنفسك', u'أفكنفسهما', u'نفسي', u'أفبنفسهن', u'أفبنفسهم', u'أونفسكما', u'نفسك', u'ألنفسكما', u'نفسه', u'أفلنفسه', u'أوبنفسكما', u'أفلنفسها', u'أفلنفسك', u'أوكنفسكن', u'فكنفسنا', u'أفلنفسكما', u'أفلنفسي', u'وبنفسهن', u'نفسهن', u'أوكنفسي', u'أفبنفسنا', u'أبنفسكما', u'أفبنفسها', u'ألنفسهن', u'أفنفسهما', u'ونفسنا', u'نفسهم', u'فنفسنا', u'فبنفسكم', u'نفس', u'أولنفسنا', u'فبنفسكن', u'بنفسكم', u'أفلنفسنا', u'بنفسكن', u'أفكنفسي', u'فكنفسي', u'أكنفسي', u'ألنفسكن', u'ألنفسكم', u'ألنفسهم', u'أكنفسه', u'فكنفسك', u'فنفس', u'أوبنفسهم', u'فكنفسه', u'فنفسهن', u'فنفسهم', u'لنفس', u'فكنفسها', u'أولنفسهن', u'أولنفسهم', u'ألنفسها', u'بنفسهما', u'أفكنفسكما', u'فلنفسكم', u'فنفسكما', u'أوكنفسكما', u'أفكنفسه', u'أونفس', u'بنفسكما', u'وبنفس']),
 u'مذ': set([u'فمذ', u'ومذ', u'مذ']),
 u'بكما': set([u'أوبكما', u'فبكما', u'أبكما', u'أفبكما', u'وبكما', u'بكما']),
 u'ذوي': set([u'وذويي', u'فكذوي', u'وذويك', u'وكذويهما', u'وذويه', u'لذوينا', u'وذويهم', u'وذويهن', u'بذويي', u'فذويي', u'كذويي', u'بذويك', u'فذويه', u'كذويه', u'بذويه', u'فذويك', u'كذويك', u'فلذويي', u'ذويهما', u'لذويهم', u'لذويهن', u'فذويكن', u'وذوينا', u'فلذوي', u'فذويكم', u'فلذويه', u'وبذويكم', u'وبذويكن', u'ذويكما', u'كذويهم', u'كذويهن', u'وكذوي', u'لذويها', u'بذوينا', u'بذويهما', u'فكذوينا', u'وكذويكم', u'وكذويكن', u'كذوينا', u'فلذويكما', u'كذويكم', u'ولذويه', u'ولذويك', u'فلذويكم', u'وذويها', u'فلذويكن', u'ولذوينا', u'ولذويي', u'ذويك', u'ذويه', u'فكذويهم', u'ذويي', u'ذويكن', u'كذويهما', u'ذويكم', u'بذويها', u'وذوي', u'فكذويها', u'وكذويكما', u'فذوي', u'كذويكن', u'ولذويها', u'ذوي', u'فكذويهن', u'فكذويك', u'فكذويه', u'فكذويي', u'كذويكما', u'ولذويهم', u'ولذويهن', u'ولذوي', u'وبذوي', u'بذويهم', u'بذويهن', u'وبذويكما', u'كذويها', u'وبذويهما', u'فلذويها', u'وبذوينا', u'وكذويها', u'وبذويك', u'وبذويه', u'وبذويي', u'ولذويهما', u'فبذويها', u'وذويكم', u'بذويكما', u'وذويكن', u'لذويكم', u'لذويكما', u'لذويكن', u'ولذويكما', u'فلذويهما', u'وبذويهم', u'وبذويهن', u'لذويهما', u'فبذويهم', u'فبذويهن', u'فلذويك', u'وبذويها', u'وكذوينا', u'فبذوينا', u'فلذويهم', u'فلذويهن', u'وكذويهم', u'وكذويهن', u'لذوي', u'فلذوينا', u'ذويهن', u'ذويهم', u'بذويكم', u'بذويكن', u'فبذوي', u'ذوينا', u'فذويهما', u'فذويها', u'فبذويكم', u'لذويي', u'فبذويكن', u'لذويه', u'فبذويهما', u'لذويك', u'فذويهن', u'وذويكما', u'فذويهم', u'فكذويكم', u'فكذويكن', u'فبذويه', u'ولذويكم', u'ولذويكن', u'فبذويك', u'فذويكما', u'فبذويي', u'وكذويه', u'ذويها', u'وكذويك', u'فذوينا', u'كذوي', u'وكذويي', u'فكذويكما', u'فبذويكما', u'وذويهما', u'فكذويهما', u'بذوي']),
 u'ذوو': set([u'ذووه', u'ذووكما', u'ذووك', u'ذووكم', u'ذووكن', u'وذوونا', u'ذووي', u'ذووهما', u'فذووها', u'ذووهم', u'ذووهن', u'فذووكما', u'وذوو', u'وذووكن', u'وذووكم', u'وذووي', u'وذووهن', u'وذووهم', u'ذوونا', u'فذووه', u'فذووك', u'وذووه', u'فذووي', u'فذوو', u'ذوو', u'فذوونا', u'فذووهما', u'وذووكما', u'وذووها', u'وذووك', u'فذووكن', u'وذووهما', u'فذووهم', u'فذووهن', u'ذووها', u'فذووكم']),
 u'مه': set([u'مه']),
 u'من': set([u'أولمنكم', u'أولمنكن', u'أولمنه', u'أولمنك', u'ولمنهن', u'ولمنهم', u'فكمن', u'أولمني', u'ولمني', u'لمننا', u'ولمنك', u'ومنهم', u'ولمنه', u'أومنكم', u'ومنهن', u'أمنها', u'أولمنهما', u'أفلمنهما', u'فلمن', u'أفلمني', u'أفلمنك', u'أفمنهن', u'أفلمنه', u'أفمنهم', u'أمنهن', u'أمنهم', u'أفلمننا', u'لمنكما', u'أبمن', u'أفمنها', u'ومنكما', u'ومنكم', u'أومنكما', u'ولمنها', u'أوكمن', u'ومننا', u'ومنه', u'أمنهما', u'ومنك', u'أفمن', u'ومني', u'ومنها', u'أمنكما', u'أفلمنها', u'ألمنهن', u'فمن', u'أولمنها', u'لمن', u'أفكمن', u'فلمنكم', u'كمن', u'فلمنكن', u'أومنهما', u'ومنهما', u'أومنكن', u'أكمن', u'منكم', u'لمنكم', u'وبمن', u'لمنكن', u'أفمنك', u'أفمنهما', u'فمنكما', u'منكن', u'من', u'مني', u'أومني', u'فبمن', u'ألمنكن', u'منك', u'أومنه', u'منه', u'فلمنه', u'فلمنك', u'أفلمنهن', u'أفلمنهم', u'فلمني', u'فمني', u'لمنهما', u'ألمنكم', u'فمنك', u'فمنكم', u'فمنكن', u'فمنه', u'ألمن', u'ألمنهم', u'أولمنهم', u'أولمنهن', u'أفلمن', u'أومنهن', u'أومنهم', u'ومنكن', u'ولمنكن', u'ولمنكم', u'ألمننا', u'أومنك', u'أفمنكن', u'أولمننا', u'أومننا', u'أومن', u'أفمنكم', u'وكمن', u'أمنك', u'ألمنه', u'ألمنكما', u'أمنه', u'ألمنك', u'ولمنهما', u'أمني', u'فمننا', u'أمنكم', u'لمنك', u'ومن', u'ولمنكما', u'لمنه', u'لمني', u'أفبمن', u'فلمنهما', u'أفلمنكما', u'أوبمن', u'أومنها', u'فمنها', u'أمن', u'منكما', u'فلمننا', u'منهما', u'أولمن', u'فلمنهم', u'فلمنهن', u'لمنهم', u'ولمن', u'بمن', u'لمنهن', u'ألمنها', u'أفمننا', u'منها', u'أولمنكما', u'أمنكن', u'فلمنها', u'أفمنه', u'لمنها', u'منهم', u'منهن', u'ألمني', u'أفمني', u'ألمنهما', u'أمننا', u'فلمنكما', u'فمنهما', u'فمنهم', u'فمنهن', u'مننا', u'أفلمنكن', u'أفلمنكم', u'أفمنكما', u'ولمننا']),
 u'حبذا': set([u'فحبذا', u'حبذا', u'وحبذا']),
 u'مادام': set([u'ومادام', u'مادام', u'فمادام']),
 u'عدا': set([u'عداكن', u'عداكم', u'وعدانا', u'فعداهم', u'عداهن', u'عداهم', u'وعداكم', u'وعداكن', u'فعدانا', u'فعداها', u'عداهما', u'وعداي', u'وعداهم', u'وعداهن', u'وعداكما', u'عدانا', u'فعداهن', u'عداه', u'وعداه', u'عداك', u'وعدا', u'وعداها', u'فعداكن', u'فعداكم', u'عداي', u'وعداك', u'فعدا', u'فعداي', u'عداكما', u'فعداك', u'فعداهما', u'وعداهما', u'فعداه', u'عداها', u'عدا', u'فعداكما']),
 u'بينما': set([u'فبينما', u'بينما', u'وبينما']),
 u'وراء': set([u'فوراءهن', u'أفوراءكم', u'أفوراءكن', u'فوراءهم', u'فلوراءكن', u'فلوراءكم', u'وراءهن', u'وراءهم', u'وراءي', u'أفلوراءكم', u'أفلوراءكن', u'ولوراءكما', u'أولوراءنا', u'وراءه', u'أفلوراء', u'فوراء', u'ألوراءها', u'أولوراءك', u'ولوراءنا', u'أولوراءهن', u'أولوراءهم', u'لوراءنا', u'ألوراءهم', u'ألوراءهن', u'أفوراءهما', u'أفوراءهن', u'أولوراءها', u'أووراءكم', u'فوراءها', u'أووراءكن', u'وراءها', u'أوراءك', u'أفوراءكما', u'أوراءه', u'ووراءكما', u'أوراءي', u'أفلوراءك', u'أووراء', u'أووراءهم', u'لوراءكن', u'لوراءكم', u'وراءك', u'أفوراءها', u'ووراءهن', u'ووراءهم', u'وراءنا', u'ووراءها', u'أووراءي', u'أفلوراءه', u'أووراءك', u'أفلوراءي', u'أووراءه', u'لوراءكما', u'لوراء', u'أولوراءكن', u'أوراءكم', u'أوراءكن', u'ألوراءكما', u'ولوراءي', u'ولوراءه', u'ولوراءهما', u'ولوراءك', u'ألوراءهما', u'لوراءه', u'ولوراءكم', u'ولوراءكن', u'لوراءي', u'ووراءهما', u'أووراءهما', u'ووراءنا', u'فوراءكن', u'أفوراءهم', u'أووراءها', u'فوراءكم', u'وراءكن', u'أوراءهما', u'أووراءكما', u'وراءكم', u'فلوراءهن', u'فلوراءهم', u'فوراءي', u'أوراءكما', u'فوراءهما', u'لوراءهما', u'أولوراءكم', u'أفلوراءهم', u'فوراءك', u'أفلوراءهن', u'فوراءه', u'فوراءكما', u'فلوراءنا', u'وراءهما', u'أفلوراءها', u'ألوراءكم', u'ألوراءكن', u'وراءكما', u'فلوراءي', u'فلوراءه', u'فلوراءك', u'أولوراءكما', u'أولوراءهما', u'ألوراءي', u'ألوراءه', u'أفوراء', u'ألوراءك', u'أووراءهن', u'أوراءنا', u'فلوراءها', u'أولوراء', u'ولوراء', u'فلوراءكما', u'ووراء', u'ولوراءهم', u'ولوراءهن', u'أوراء', u'أفلوراءهما', u'فلوراءهما', u'لوراءهن', u'لوراءهم', u'ووراءك', u'ووراءه', u'أووراءنا', u'ووراءي', u'أفوراءنا', u'ووراءكن', u'ووراءكم', u'وراء', u'أوراءها', u'أولوراءه', u'أولوراءي', u'أفلوراءكما', u'ألوراء', u'أفوراءك', u'لوراءك', u'أفوراءه', u'أفوراءي', u'أوراءهم', u'أوراءهن', u'فلوراء', u'فوراءنا', u'ألوراءنا', u'ولوراءها', u'أفلوراءنا', u'لوراءها']),
 u'بات': set([u'وبات', u'لبات', u'بات', u'ولبات', u'فبات', u'فلبات']),
 u'عدس': set([u'عدس']),
 u'وا': set([u'وا']),
 u'كلا': set([u'كلا', u'أكلا', u'أوكلا', u'فكلا', u'وكلا', u'أفكلا']),
 u'على': set([u'أعليكم', u'فلعلى', u'أفعليهما', u'فلعلي', u'ألعلي', u'أوعلى', u'عليها', u'أعليك', u'فعليك', u'فعليه', u'لعليها', u'ولعليهم', u'ولعليهن', u'وعليهم', u'وعليهن', u'عليهما', u'ولعليكما', u'لعليهما', u'لعليهم', u'لعليهن', u'ألعلى', u'ولعليه', u'أعليهم', u'ولعليها', u'ولعليك', u'وعليها', u'ألعليه', u'ألعليك', u'أفعليك', u'أعليهن', u'أفعليه', u'فعليكن', u'فعليكم', u'ولعليهما', u'لعلينا', u'أوعلي', u'أفلعليه', u'أفلعليك', u'أعليها', u'فعلي', u'أفعليكما', u'فعلى', u'عليهن', u'عليهم', u'أولعليك', u'أوعليكن', u'أولعليه', u'أوعليكم', u'ألعليهن', u'ألعليكم', u'فلعليهم', u'فلعليهن', u'ولعلينا', u'وعلينا', u'أعلى', u'عليك', u'عليه', u'أفعلى', u'لعلى', u'أفعلي', u'لعلي', u'ألعلينا', u'فلعلينا', u'أعليكما', u'أوعليهما', u'لعليكم', u'لعليكن', u'أعليهما', u'أوعلينا', u'لعليه', u'لعليك', u'أفعليكم', u'فلعليك', u'فعليهما', u'فلعليه', u'ألعليها', u'فلعليها', u'فعلينا', u'عليكما', u'لعليكما', u'أولعليكم', u'أعليه', u'عليكن', u'عليكم', u'أعليكن', u'علي', u'فلعليهما', u'على', u'أعلينا', u'أوعليها', u'فلعليكما', u'ولعليكم', u'ولعليكن', u'أفلعلينا', u'ألعليكما', u'أفلعلي', u'أفلعلى', u'فعليكما', u'ألعليهم', u'فعليها', u'وعليكم', u'وعليكن', u'أفلعليهما', u'أفعليكن', u'أوعليكما', u'علينا', u'فعليهن', u'فعليهم', u'وعليكما', u'أفلعليها', u'وعليهما', u'أفلعليهن', u'أولعليهما', u'أعلي', u'أوعليهن', u'أوعليهم', u'أولعليكما', u'أوعليك', u'أوعليه', u'أولعليها', u'فلعليكم', u'فلعليكن', u'أولعلينا', u'أفعليها', u'ألعليهما', u'أفلعليكما', u'أفلعليهم', u'ولعلى', u'ولعلي', u'أفعليهم', u'أفعليهن', u'ألعليكن', u'أولعليكن', u'وعلي', u'أولعليهن', u'أولعليهم', u'أولعلي', u'أولعلى', u'أفلعليكن', u'أفعلينا', u'أفلعليكم', u'وعلى', u'وعليك', u'وعليه']),
 u'علق': set([u'فلعلق', u'علق', u'ولعلق', u'وعلق', u'لعلق', u'فعلق']),
 u'مازلن': set([u'فمازلن', u'مازلن', u'ومازلن']),
 u'حار': set([u'فحار', u'ولحار', u'حار', u'فلحار', u'لحار', u'وحار']),
 u'وراءكن': set([u'وراءكن']),
 u'مازالتا': set([u'ومازالتا', u'مازالتا', u'فمازالتا']),
 u'وراءكم': set([u'وراءكم']),
 u'مادمت': set([u'فمادمت', u'ومادمت', u'مادمت']),
 u'أخي': set([u'ولأخيه', u'وأخيك', u'بأخيكما', u'بأخيها', u'وأخيي', u'فكأخيهم', u'فكأخيهن', u'أخيك', u'لأخيي', u'لأخيها', u'ولأخي', u'لأخيك', u'فبأخيكما', u'بأخينا', u'لأخيهم', u'لأخيهن', u'وكأخيكما', u'فبأخي', u'فكأخي', u'وكأخيهما', u'كأخيي', u'بأخيهم', u'بأخيهن', u'وكأخي', u'وبأخيكم', u'ولأخيهما', u'وبأخيكن', u'لأخينا', u'فبأخيهما', u'فكأخيها', u'كأخيك', u'فلأخيكما', u'ولأخيهن', u'فلأخي', u'فلأخينا', u'فلأخيي', u'كأخيه', u'فأخينا', u'فلأخيه', u'لأخيهما', u'فلأخيك', u'فكأخيي', u'فكأخيك', u'فكأخيه', u'فبأخيكم', u'فبأخيكن', u'فأخيه', u'فلأخيهم', u'فأخيك', u'وأخيها', u'وأخيه', u'وبأخي', u'فلأخيها', u'أخيها', u'وكأخيكم', u'وكأخيكن', u'فأخيي', u'فكأخينا', u'ولأخيها', u'لأخيكم', u'لأخيكن', u'كأخيكم', u'وأخيهم', u'وأخيهن', u'كأخيكن', u'أخيهن', u'أخيهم', u'ولأخيهم', u'لأخيكما', u'وأخي', u'فكأخيهما', u'ولأخيكما', u'كأخيكما', u'وأخينا', u'فأخيكن', u'فأخيكم', u'أخينا', u'ولأخينا', u'وبأخيهما', u'وكأخيك', u'أخيهما', u'لأخيه', u'ولأخيك', u'ولأخيي', u'فكأخيكم', u'كأخينا', u'كأخيهما', u'فكأخيكن', u'أخي', u'وبأخيكما', u'وأخيهما', u'فكأخيكما', u'فبأخيك', u'فبأخيه', u'كأخيهم', u'فبأخيي', u'كأخيهن', u'كأخي', u'وبأخينا', u'أخيي', u'كأخيها', u'وبأخيهم', u'أخيه', u'وبأخيهن', u'وأخيكما', u'بأخيه', u'بأخيكم', u'بأخيكن', u'وبأخيها', u'وكأخيه', u'أخيكما', u'وكأخيي', u'وكأخينا', u'وبأخيي', u'وبأخيك', u'وبأخيه', u'فبأخيهم', u'فبأخيهن', u'فأخيها', u'فلأخيكم', u'فلأخيكن', u'وكأخيهم', u'وكأخيهن', u'فأخي', u'فبأخينا', u'فبأخيها', u'فلأخيهما', u'وكأخيها', u'ولأخيكم', u'ولأخيكن', u'بأخيهما', u'وأخيكم', u'وأخيكن', u'أخيكن', u'أخيكم', u'بأخيك', u'فأخيكما', u'فلأخيهن', u'لأخي', u'بأخيي', u'فأخيهما', u'بأخي', u'فأخيهن', u'فأخيهم']),
 u'أخو': set([u'فأخوها', u'وأخونا', u'أخونا', u'فأخوهما', u'أخو', u'فأخوك', u'فأخوه', u'فأخو', u'وأخوهن', u'فأخوي', u'وأخوهم', u'أخوهم', u'أخوهن', u'وأخوكن', u'فأخوكما', u'وأخوكم', u'أخوكم', u'أخوكن', u'فأخونا', u'وأخوها', u'أخوكما', u'أخوك', u'وأخو', u'أخوها', u'أخوه', u'أخوي', u'فأخوهم', u'فأخوهن', u'وأخوهما', u'فأخوكم', u'فأخوكن', u'وأخوي', u'وأخوكما', u'وأخوك', u'وأخوه', u'أخوهما']),
 u'قام': set([u'قام', u'فلقام', u'فقام', u'ولقام', u'لقام', u'وقام']),
 u'ئ': set([u'ئ']),
 u'إذما': set([u'وإذما', u'إذما', u'فإذما']),
 u'أين': set([u'فأين', u'وأين', u'أين']),
 u'بطآن': set([u'فبطآن', u'وبطآن', u'بطآن']),
 u'الألى': set([u'فالألى', u'وبالألى', u'والألى', u'فللألى', u'وكالألى', u'فكالألى', u'الألى', u'كالألى', u'للألى', u'وللألى', u'فبالألى', u'بالألى']),
 u'ض': set([u'ض']),
 u'ذلكم': set([u'أفكذلكم', u'فلذلكم', u'أفذلكم', u'أذلكم', u'أفلذلكم', u'أكذلكم', u'أوكذلكم', u'أولذلكم', u'وذلكم', u'أفبذلكم', u'أوبذلكم', u'أوذلكم', u'ذلكم', u'بذلكم', u'وبذلكم', u'فبذلكم', u'وكذلكم', u'ألذلكم', u'فذلكم', u'كذلكم', u'ولذلكم', u'لذلكم', u'فكذلكم', u'أبذلكم']),
 u'ذلكن': set([u'أفكذلكن', u'أفذلكن', u'فلذلكن', u'أذلكن', u'أفلذلكن', u'أكذلكن', u'أوذلكن', u'وذلكن', u'أولذلكن', u'أوكذلكن', u'أفبذلكن', u'أوبذلكن', u'ذلكن', u'بذلكن', u'وبذلكن', u'فبذلكن', u'ألذلكن', u'وكذلكن', u'كذلكن', u'ولذلكن', u'لذلكن', u'فذلكن', u'أبذلكن', u'فكذلكن']),
 u'أية': set([u'فكأيتي', u'فأيتكما', u'فكأيتك', u'كأيتنا', u'أيتنا', u'فلأية', u'وبأية', u'وكأيتها', u'ولأيتهن', u'بأيتكما', u'لأيتكما', u'لأيتهما', u'وأيتها', u'كأيتهم', u'كأيتهن', u'كأية', u'فأيتي', u'فأيتهما', u'وأيتهما', u'وأيتهم', u'وأيتهن', u'فبأيتهما', u'كأيتها', u'لأيتنا', u'فأية', u'بأيتهما', u'كأيتك', u'لأيتها', u'فلأيتكم', u'فلأيتكن', u'كأيته', u'وأيتنا', u'فبأية', u'لأيتهم', u'لأيتهن', u'فأيته', u'وكأيتهن', u'ولأيتهم', u'بأيتها', u'فبأيتنا', u'فكأية', u'فبأيتي', u'فبأيته', u'كأيتي', u'وأية', u'أيتكن', u'أيتكم', u'ولأية', u'فبأيتهم', u'فبأيتهن', u'فبأيتها', u'أيتكما', u'وبأيتي', u'وأيتكن', u'وبأيته', u'ولأيتنا', u'وبأيتك', u'فأيتكن', u'فأيتكم', u'فبأيتكما', u'ولأيتكم', u'بأيتنا', u'ولأيتها', u'أيتي', u'أيته', u'أيتك', u'كأيتكما', u'وأيته', u'ولأيتهما', u'وأيتك', u'فكأيتكم', u'وأيتي', u'فكأيتكن', u'بأيتهم', u'بأيتهن', u'وبأيتكم', u'وبأيتكن', u'فلأيتنا', u'فلأيتك', u'وكأيتي', u'فلأيته', u'وأيتكما', u'فلأيتي', u'وكأيته', u'وكأيتك', u'ولأيتكما', u'كأيتكم', u'كأيتكن', u'لأيتي', u'فلأيتها', u'كأيتهما', u'لأية', u'لأيتك', u'لأيته', u'أية', u'فلأيتهم', u'فلأيتهن', u'فبأيتك', u'وكأيتكم', u'وكأيتكن', u'وأيتكم', u'لأيتكم', u'لأيتكن', u'فكأيتكما', u'وكأيتهم', u'أيتهما', u'فكأيتها', u'فأيتنا', u'وبأيتهما', u'فبأيتكم', u'وبأيتها', u'فبأيتكن', u'فلأيتكما', u'فكأيتهما', u'أيتهن', u'أيتهم', u'فلأيتهما', u'وبأيتكما', u'فأيتهن', u'فأيتهم', u'بأيته', u'بأيتك', u'وكأية', u'ولأيته', u'فأيتك', u'بأية', u'بأيتي', u'أيتها', u'ولأيتكن', u'فكأيتنا', u'فأيتها', u'وكأيتنا', u'بأيتكم', u'بأيتكن', u'ولأيتي', u'وبأيتنا', u'وكأيتكما', u'فكأيتهم', u'فكأيتهن', u'ولأيتك', u'فكأيته', u'وبأيتهم', u'وكأيتهما', u'وبأيتهن']),
 u'نعم': set([u'ونعم', u'فنعم', u'نعم']),
 u'أيا': set([u'وأيا', u'أيا', u'فأيا']),
 u'هاك': set([u'هاك']),
 u'ذواتي': set([u'بذواتي', u'أبذواتي', u'فبذواتي', u'وذواتي', u'وبذواتي', u'أفكذواتي', u'أذواتي', u'أكذواتي', u'ذواتي', u'أفذواتي', u'أفلذواتي', u'وكذواتي', u'أفبذواتي', u'كذواتي', u'فذواتي', u'ألذواتي', u'أولذواتي', u'أوكذواتي', u'فلذواتي', u'أوبذواتي', u'ولذواتي', u'أوذواتي', u'لذواتي', u'فكذواتي']),
 u'مازلت': set([u'مازلت', u'ومازلت', u'فمازلت']),
 u'آنئذ': set([u'فآنئذ', u'آنئذ', u'وآنئذ']),
 u'أخذ': set([u'أخذ', u'وأخذ', u'فلأخذ', u'ولأخذ', u'لأخذ', u'فأخذ']),
 u'ذلك': set([u'فبذلك', u'أفبذلك', u'كذلك', u'أكذلك', u'أفكذلك', u'أبذلك', u'بذلك', u'أوبذلك', u'أولذلك', u'وكذلك', u'ذلك', u'وذلك', u'فلذلك', u'فذلك', u'أفذلك', u'لذلك', u'أوكذلك', u'أفلذلك', u'ألذلك', u'وبذلك', u'أوذلك', u'فكذلك', u'أذلك', u'ولذلك']),
 u'عندئذ': set([u'فعندئذ', u'وعندئذ', u'عندئذ']),
 u'أخا': set([u'فأخاها', u'أخاهما', u'فأخاكن', u'أخاكما', u'أخاك', u'أخانا', u'أخاه', u'أخاي', u'وأخانا', u'وأخاهما', u'أخاهن', u'أخاهم', u'وأخاهم', u'وأخاهن', u'أخاكن', u'وأخا', u'أخاكم', u'فأخانا', u'وأخاكم', u'وأخاكن', u'فأخا', u'فأخاي', u'فأخاهما', u'أخاها', u'وأخاها', u'فأخاكما', u'فأخاهن', u'وأخاي', u'فأخاهم', u'فأخاه', u'وأخاكما', u'وأخاك', u'وأخاه', u'فأخاكم', u'أخا', u'فأخاك']),
 u'ويكأن': set([u'ويكأنكما', u'ويكأن', u'ويكأنهما', u'ويكأنها', u'ويكأننا', u'ويكأنهم', u'ويكأنهن', u'ويكأنك', u'ويكأنه', u'ويكأني', u'ويكأنكم', u'ويكأنكن']),
 u'إيانا': set([u'إيانا', u'فإيانا', u'وإيانا']),
 u'كرب': set([u'كرب', u'وكرب', u'ولكرب', u'فلكرب', u'لكرب', u'فكرب']),
 u'لي': set([u'لي', u'ألي', u'أفلي', u'أولي', u'فلي', u'ولي']),
 u'لو': set([u'لو', u'ألو', u'أفلو', u'أولو', u'فلو', u'ولو']),
 u'لن': set([u'ألن', u'لن', u'فلن', u'ولن', u'أفلن', u'أولن']),
 u'له': set([u'أله', u'له', u'وله', u'فله', u'أوله', u'أفله']),
 u'لم': set([u'ألم', u'لم', u'ولم', u'فلم', u'أولم', u'أفلم']),
 u'لك': set([u'ألك', u'لك', u'أولك', u'أفلك', u'ولك', u'فلك']),
 u'بلا': set([u'بلا', u'فبلا', u'وبلا']),
 u'مادمن': set([u'ومادمن', u'مادمن', u'فمادمن']),
 u'ذانك': set([u'أذانك', u'أوكذانك', u'أوذانك', u'وذانك', u'وكذانك', u'كذانك', u'فكذانك', u'أبذانك', u'أفذانك', u'وبذانك', u'أولذانك', u'ألذانك', u'فبذانك', u'أفلذانك', u'أفبذانك', u'فلذانك', u'أكذانك', u'أوبذانك', u'ذانك', u'ولذانك', u'فذانك', u'بذانك', u'أفكذانك', u'لذانك']),
 u'إما': set([u'إما', u'وإما', u'فإما']),
 u'هنالك': set([u'فهنالك', u'لهنالك', u'بهنالك', u'ولهنالك', u'هنالك', u'أهنالك', u'أفكهنالك', u'أكهنالك', u'أوهنالك', u'وبهنالك', u'أوكهنالك', u'وهنالك', u'فبهنالك', u'أفبهنالك', u'كهنالك', u'أولهنالك', u'أبهنالك', u'وكهنالك', u'أوبهنالك', u'ألهنالك', u'أفهنالك', u'فكهنالك', u'فلهنالك', u'أفلهنالك']),
 u'مادامت': set([u'ومادامت', u'مادامت', u'فمادامت']),
 u'ء': set([u'ء']),
 u'ريث': set([u'ريث', u'وريث', u'فريث']),
 u'طق': set([u'طق']),
 u'جميع': set([u'أولجميعك', u'أفكجميعهما', u'أوكجميعكم', u'فلجميعها', u'لجميعنا', u'أفكجميعنا', u'أوبجميعهما', u'وجميعهما', u'أفكجميعكما', u'وجميعنا', u'أجميعهن', u'أجميعهم', u'ألجميعهن', u'ألجميعهم', u'أبجميعي', u'بجميعكم', u'بجميعكن', u'أفلجميعي', u'أبجميعك', u'وكجميع', u'أبجميعه', u'أكجميعهن', u'لجميعهما', u'أوكجميعكما', u'أكجميعهما', u'أولجميعي', u'وجميعهم', u'وجميعهن', u'أوبجميعهن', u'لجميعكما', u'فبجميعهن', u'وجميع', u'أكجميعه', u'ألجميعه', u'فجميعكما', u'ألجميعكم', u'أبجميعكن', u'ألجميعك', u'أبجميعكم', u'ألجميعي', u'أولجميعهما', u'أولجميعهن', u'أفكجميعك', u'أولجميعكم', u'أفبجميع', u'أولجميعكن', u'ولجميع', u'أفلجميعنا', u'وجميعها', u'أفجميع', u'فبجميعها', u'أفبجميعكما', u'أوبجميعكما', u'ألجميع', u'لجميعها', u'أولجميعهم', u'أفلجميعه', u'أوكجميعنا', u'أجميعها', u'أولجميعكما', u'ألجميعها', u'فلجميع', u'أوكجميعكن', u'لجميعه', u'أوكجميعي', u'ولجميعكن', u'ولجميعكم', u'لجميعك', u'فلجميعهم', u'أفكجميع', u'أفكجميعكم', u'لجميعهم', u'لجميعهن', u'فكجميعنا', u'أوجميعهن', u'أوجميعهم', u'فلجميعكما', u'أفلجميعها', u'أفبجميعهما', u'فبجميعنا', u'فجميعها', u'أوكجميع', u'أوبجميعهم', u'أفكجميعكن', u'أفكجميعي', u'فلجميعهن', u'أفلجميعك', u'أفكجميعه', u'أفجميعها', u'كجميعكما', u'فكجميعهن', u'فكجميعهم', u'وكجميعها', u'أبجميعهن', u'أبجميعهم', u'أوبجميعي', u'أوجميعك', u'أوبجميعه', u'ألجميعنا', u'أجميعنا', u'أوبجميعك', u'أفجميعك', u'أوجميعهما', u'أوجميعي', u'أجميعي', u'أكجميعكم', u'كجميعكن', u'كجميعكم', u'أكجميعكن', u'بجميعكما', u'أجميعك', u'أفجميعنا', u'فكجميعها', u'وكجميعهم', u'وكجميعهن', u'أوجميعه', u'أبجميعها', u'فبجميعك', u'أجميعه', u'فبجميعه', u'كجميعهما', u'فبجميعي', u'ولجميعك', u'أبجميعهما', u'أفلجميعكم', u'فكجميعك', u'أوجميعكما', u'أفبجميعك', u'فكجميعه', u'أوجميع', u'أفجميعكم', u'فكجميعي', u'جميعكم', u'جميعكن', u'وبجميعكن', u'وبجميعكم', u'بجميعهما', u'أفلجميعهن', u'أفلجميعهم', u'فجميعهم', u'فجميعهن', u'بجميعي', u'ألجميعهما', u'ولجميعكما', u'أفجميعهم', u'أكجميع', u'ألجميعكن', u'أولجميعها', u'بجميعك', u'لجميعكن', u'أوجميعنا', u'بجميعه', u'جميعهما', u'لجميع', u'ولجميعهما', u'بجميعهم', u'بجميعهن', u'فبجميع', u'ولجميعه', u'جميعكما', u'جميعك', u'فجميعنا', u'كجميعي', u'جميعه', u'أجميعكن', u'أجميعكم', u'فلجميعنا', u'جميعي', u'كجميعك', u'كجميعه', u'فبجميعكم', u'فبجميعكن', u'أفجميعهما', u'أوكجميعه', u'بجميعنا', u'كجميعهن', u'أوبجميع', u'وكجميعي', u'وبجميعكما', u'جميعنا', u'أكجميعك', u'أوكجميعهم', u'أوكجميعهن', u'أكجميعكما', u'وبجميعهما', u'أكجميعي', u'أوكجميعك', u'فكجميعكما', u'أوبجميعكن', u'أفبجميعهم', u'لجميعي', u'أفلجميع', u'كجميعها', u'أوبجميعنا', u'أوجميعها', u'فكجميعهما', u'كجميعهم', u'أولجميع', u'وبجميعنا', u'كجميع', u'فجميعي', u'وجميعي', u'فكجميع', u'أفلجميعكما', u'فجميعك', u'وجميعك', u'فجميعه', u'أبجميعنا', u'وجميعه', u'أفبجميعه', u'أفبجميعكم', u'أوبجميعها', u'أفجميعكن', u'بجميعها', u'أكجميعنا', u'لجميعكم', u'جميعها', u'وكجميعك', u'وكجميعه', u'فجميعكم', u'أبجميع', u'فبجميعكما', u'فجميعكن', u'أجميعكما', u'أوكجميعها', u'أوكجميعهما', u'ولجميعهن', u'ولجميعهم', u'كجميعنا', u'وبجميعها', u'فجميعهما', u'بجميع', u'وكجميعهما', u'فكجميعكم', u'أوجميعكن', u'جميع', u'أوجميعكم', u'أفبجميعهن', u'أفكجميعهم', u'فبجميعهم', u'أفجميعكما', u'أفكجميعهن', u'وبجميع', u'وكجميعكما', u'أولجميعنا', u'أجميعهما', u'أكجميعها', u'ولجميعنا', u'أفبجميعنا', u'أجميع', u'وكجميعكم', u'وكجميعكن', u'أفجميعي', u'وجميعكم', u'وجميعكن', u'فكجميعكن', u'أفكجميعها', u'فجميع', u'أفجميعه', u'وكجميعنا', u'وبجميعك', u'ولجميعي', u'أفجميعهن', u'وبجميعه', u'أفبجميعي', u'أكجميعهم', u'وبجميعي', u'أفبجميعها', u'جميعهم', u'أوبجميعكم', u'أفلجميعهما', u'جميعهن', u'أفلجميعكن', u'فلجميعي', u'ألجميعكما', u'وجميعكما', u'فلجميعه', u'أولجميعه', u'فلجميعهما', u'فلجميعك', u'فبجميعهما', u'أبجميعكما', u'فلجميعكم', u'فلجميعكن', u'ولجميعها', u'أفبجميعكن', u'وبجميعهن', u'وبجميعهم']),
 u'حول': set([u'وحوله', u'وحولك', u'فحول', u'فحولك', u'وحولي', u'فحولهن', u'حولنا', u'وحول', u'فحولها', u'حولكم', u'حول', u'حولكن', u'وحولها', u'وحولكما', u'فحولهم', u'حولهم', u'حولهن', u'وحولهما', u'فحولهما', u'وحولكن', u'وحولكم', u'فحوله', u'فحولي', u'وحولهن', u'وحولهم', u'حولها', u'فحولكن', u'فحولنا', u'حولكما', u'وحولنا', u'حولهما', u'حولي', u'حوله', u'حولك', u'فحولكما', u'فحولكم']),
 u'ر': set([u'ر']),
 u'مهما': set([u'أمهما', u'فمهما', u'أومهما', u'مهما', u'ومهما', u'أفمهما']),
 u'تي': set([u'كتي', u'وبتي', u'فبتي', u'فكتي', u'بتي', u'فتي', u'فلتي', u'ولتي', u'تي', u'لتي', u'وكتي', u'وتي']),
 u'كأي': set([u'وكأي', u'فكأي', u'كأي']),
 u'لوما': set([u'لوما', u'ولوما', u'فلوما']),
 u'ته': set([u'فبته', u'كته', u'وبته', u'بته', u'لته', u'وكته', u'ولته', u'وته', u'ته', u'فكته', u'فلته', u'فته']),
 u'ف': set([u'ف']),
 u'فو': set([u'وفو', u'فو', u'ففو']),
 u'في': set([u'لفيك', u'لفيه', u'ألفيي', u'لفيي', u'ألفيه', u'أولفيهم', u'بفيها', u'أفلفي', u'أولفيه', u'فكفيهن', u'ألفيهم', u'فكفيهم', u'ففينا', u'وكفيهما', u'فلفيهن', u'ألفي', u'أففيكن', u'أففيه', u'لفيها', u'كفيهما', u'أففيك', u'ولفي', u'أوفي', u'ففيهم', u'ففيهن', u'أففيي', u'لفيهما', u'كفيكما', u'ولفيهن', u'وكفيهم', u'لفيكما', u'وكفيهن', u'أفيكن', u'وكفي', u'أفيكم', u'لفيهم', u'وفي', u'لفيهن', u'فكفيكما', u'فبفيهم', u'أوفيهن', u'فبفيهما', u'ففيها', u'بفينا', u'فلفيكما', u'فكفيهما', u'ألفيك', u'فبفيكما', u'وكفيها', u'أفيكما', u'فلفيهما', u'بفيه', u'لفينا', u'بفيك', u'بفيهم', u'بفيي', u'بفيهن', u'كفينا', u'أوفيهم', u'فكفيها', u'أوفيها', u'ولفيكن', u'ولفيك', u'فيكما', u'أولفيهما', u'ولفيكم', u'وفيهم', u'فلفينا', u'وفيهن', u'فيهما', u'أولفي', u'وكفينا', u'فبفيك', u'أوفيهما', u'أولفيها', u'فبفيه', u'ألفيكن', u'بفي', u'وبفيهما', u'وبفيها', u'فلفيهم', u'ولفيه', u'كفيها', u'فلفي', u'فكفينا', u'فيها', u'أولفيكما', u'أوفيي', u'وبفيهن', u'وبفيهم', u'ألفيكما', u'فبفي', u'كفيهن', u'كفيهم', u'فيهم', u'فيهن', u'وبفيكما', u'ألفيهما', u'وبفينا', u'وفيها', u'أفي', u'فينا', u'أفلفيكن', u'أفلفيكم', u'فبفيها', u'أففيكم', u'أولفيكن', u'أفيهما', u'أولفيك', u'فكفيكن', u'أولفينا', u'فكفيكم', u'فكفي', u'أولفيي', u'وبفيك', u'ولفيي', u'أفيك', u'أفينا', u'فكفيي', u'أفيه', u'أفيي', u'فكفيه', u'فكفيك', u'وبفيي', u'أفلفيهما', u'وبفيه', u'أففيهن', u'وفينا', u'أففيهم', u'أفيهن', u'أفيهم', u'ففيكم', u'ففيكن', u'وبفيكن', u'أفلفيك', u'وبفيكم', u'أفلفيكما', u'أفلفيه', u'وفيه', u'وفيك', u'لفيكم', u'وفيي', u'بفيكما', u'لفيكن', u'أفيها', u'فبفيكم', u'أوفيكن', u'أوفيكم', u'فبفيكن', u'أفلفيي', u'بفيهما', u'أففيكما', u'بفيكم', u'وكفيي', u'بفيكن', u'أففي', u'فبفيي', u'وكفيك', u'ولفيها', u'أولفيهن', u'أوفينا', u'وكفيه', u'كفيك', u'كفيه', u'أفلفيهن', u'كفيي', u'أفلفيهم', u'وفيكم', u'وفيكن', u'أفلفيها', u'ألفينا', u'أففينا', u'ففي', u'كفي', u'أفلفينا', u'أففيهما', u'فلفيكم', u'فلفيكن', u'ففيهما', u'ولفينا', u'ولفيهما', u'ألفيهن', u'لفي', u'ففيكما', u'أولفيكم', u'وبفي', u'أوفيك', u'فبفيهن', u'وكفيكم', u'أوفيه', u'وكفيكن', u'ولفيهم', u'فيكم', u'فيكن', u'في', u'ألفيها', u'ألفيكم', u'أففيها', u'أوفيكما', u'فيي', u'فيه', u'فيك', u'كفيكن', u'كفيكم', u'فلفيه', u'ففيك', u'فلفيك', u'وكفيكما', u'ففيه', u'فبفينا', u'ففيي', u'فلفيي', u'وفيكما', u'فلفيها', u'ولفيكما', u'وفيهما']),
 u'أ': set([u'أ']),
 u'أول': set([u'فأول', u'وأول', u'أول']),
 u'مافتئنا': set([u'فمافتئنا', u'مافتئنا', u'ومافتئنا']),
 u'مساء': set([u'فمساء', u'مساء', u'ومساء']),
 u'بماذا': set([u'وبماذا', u'بماذا', u'فبماذا']),
 u'عين': set([u'فلعينها', u'أفبعينهم', u'أفبعينهن', u'ألعيننا', u'وبعين', u'بعينها', u'أفبعيني', u'أفعيننا', u'أكعينك', u'بعينه', u'أوعينكن', u'لعينكما', u'بعيني', u'عيننا', u'أولعينه', u'وكعينكم', u'أكعيني', u'أفبعينه', u'عينكما', u'أوعينك', u'أوكعينكم', u'أكعيننا', u'لعيننا', u'أولعينهما', u'أعين', u'ولعينهن', u'ولعينهم', u'أبعيننا', u'أبعينكم', u'أبعينكن', u'أعيني', u'أعينه', u'أوعينه', u'أفكعينهم', u'أعينهن', u'أعينك', u'فلعينك', u'أفعينكما', u'فلعينه', u'أفلعين', u'فلعيني', u'فعيننا', u'فلعينهما', u'كعين', u'أفكعينه', u'بعيننا', u'أفكعينك', u'عينهما', u'بعين', u'فكعيننا', u'أعينها', u'أفكعيني', u'فلعينكما', u'أولعينك', u'أكعينه', u'أبعينك', u'ولعين', u'ألعينهما', u'بعينك', u'فبعينكن', u'أولعيني', u'فعينهما', u'فبعينكم', u'أوبعيننا', u'بعينهن', u'بعينهم', u'فعينكما', u'وعين', u'فكعينهم', u'أبعينه', u'أوعينكم', u'فبعينهما', u'ولعينكما', u'أفلعينهم', u'أوكعيني', u'أوكعين', u'ألعينه', u'أوعينهما', u'ألعينك', u'أعينهما', u'بعينكن', u'فعينها', u'بعينكما', u'أفكعينكن', u'ألعينهم', u'ألعيني', u'أوعين', u'وعينهن', u'وكعينكن', u'وعينهم', u'ولعينهما', u'كعيني', u'أفعين', u'أوعينكما', u'كعينه', u'أوبعينهن', u'أفبعينكم', u'كعينك', u'أعينكن', u'فكعين', u'عيني', u'أعيننا', u'أفبعيننا', u'أولعينها', u'عينك', u'عينه', u'أفكعيننا', u'أفكعين', u'أولعينكم', u'أفكعينها', u'أولعينكن', u'أعينكما', u'أفعينكن', u'أفعينكم', u'بعينهما', u'فلعينهم', u'أوبعينكن', u'أبعينهما', u'أفلعينهن', u'ولعينكن', u'وكعينكما', u'ولعينكم', u'أوعيننا', u'أوكعينكما', u'أفعينهم', u'كعينكن', u'كعينكم', u'فلعينكن', u'فكعينهن', u'أفكعينكما', u'أكعينهما', u'وعينهما', u'لعينهما', u'لعيني', u'فعينهم', u'لعينه', u'أوبعينهم', u'فعينهن', u'لعينك', u'فعين', u'ألعينها', u'وعينك', u'أكعينكم', u'وعينه', u'وبعينكم', u'أكعينكن', u'وعيني', u'أوكعينهما', u'أوبعينها', u'لعينكم', u'أوكعينهم', u'أوبعينه', u'أوعينهن', u'وكعيننا', u'أوبعينك', u'فكعينكن', u'فكعينكم', u'فبعيننا', u'أوعينهم', u'أولعين', u'فلعينكم', u'أوبعيني', u'فبعينكما', u'أفبعينك', u'أوكعينكن', u'ألعين', u'فبعينها', u'أوبعينكم', u'أفبعينكن', u'ولعيني', u'أفلعيننا', u'فبعينه', u'ولعينه', u'وكعينهن', u'فبعين', u'ولعينك', u'وكعينهم', u'وبعينهما', u'أبعينهم', u'أبعينهن', u'وعينكما', u'فبعيني', u'أعينكم', u'أبعين', u'وكعينه', u'وعيننا', u'وبعيني', u'أكعين', u'أبعينكما', u'وبعينك', u'وبعينكما', u'وبعينه', u'وكعينك', u'أوكعينك', u'عينكم', u'وكعينها', u'فكعينها', u'عينكن', u'أفبعينهما', u'أبعينها', u'أفلعيني', u'وكعينهما', u'أفعينك', u'أفلعينها', u'ألعينهن', u'أفعينه', u'ولعيننا', u'كعينكما', u'أفبعينكما', u'فكعيني', u'فلعيننا', u'وكعيني', u'فكعينك', u'أوعينها', u'فكعينكما', u'فكعينه', u'ألعينكما', u'فعيني', u'فبعينهن', u'أعينهم', u'فبعينهم', u'فعينك', u'أفعينهما', u'كعيننا', u'فعينه', u'لعين', u'بعينكم', u'أكعينهم', u'ألعينكم', u'ألعينكن', u'أكعينهن', u'لعينهن', u'لعينهم', u'وبعينها', u'أولعيننا', u'أوبعينكما', u'أفلعينكم', u'أفلعينكن', u'فكعينهما', u'أفلعينه', u'أفكعينهن', u'فبعينك', u'وعينكن', u'أوبعينهما', u'وعينكم', u'أولعينهم', u'وعينها', u'كعينهما', u'فلعين', u'أفلعينك', u'أفكعينهما', u'أولعينكما', u'أفعينهن', u'أبعيني', u'أفبعين', u'أكعينكما', u'أوكعينها', u'عينهم', u'أوكعيننا', u'أفعيني', u'عينهن', u'كعينها', u'أفكعينكم', u'وبعينكن', u'أوبعين', u'فلعينهن', u'ولعينها', u'وبعيننا', u'أفعينها', u'لعينكن', u'وكعين', u'أوكعينهن', u'عينها', u'كعينهن', u'كعينهم', u'أفلعينكما', u'أكعينها', u'أفبعينها', u'لعينها', u'عين', u'وبعينهن', u'وبعينهم', u'أولعينهن', u'أوكعينه', u'أوعيني', u'فعينكم', u'أفلعينهما', u'فعينكن']),
 u'لا': set([u'ألا', u'لا', u'ولا', u'فلا', u'أولا', u'أفلا']),
 u'جنب': set([u'جنبنا', u'فجنبكما', u'فكجنبهما', u'فجنبهما', u'وجنبهما', u'وبجنبها', u'فبجنبك', u'وكجنبهما', u'كجنبنا', u'بجنبها', u'فلجنبهن', u'وكجنبهم', u'وكجنبهن', u'جنبهن', u'فبجنبكما', u'جنبهم', u'فبجنب', u'فكجنبكما', u'وكجنبها', u'جنبها', u'فجنبكن', u'فجنبكم', u'فجنب', u'فبجنبي', u'وجنبكم', u'وجنبكن', u'بجنبك', u'بجنبي', u'فلجنب', u'وبجنبهم', u'وبجنبهن', u'بجنبهم', u'فبجنبهما', u'فلجنبها', u'بجنبهن', u'فلجنبنا', u'وكجنبنا', u'لجنبهم', u'لجنبهن', u'وجنبكما', u'فلجنبهم', u'كجنبكم', u'كجنبكن', u'فبجنبها', u'لجنبنا', u'كجنبي', u'فكجنبي', u'جنبهما', u'فكجنبه', u'فلجنبكما', u'فكجنبك', u'فبجنبهم', u'فبجنبهن', u'كجنب', u'فكجنبكم', u'فكجنبكن', u'كجنبهما', u'كجنبكما', u'ولجنبكم', u'ولجنبكن', u'وكجنبه', u'وكجنبك', u'فبجنبنا', u'وبجنبي', u'لجنبها', u'وبجنبه', u'وجنبنا', u'وبجنبك', u'فبجنبه', u'جنبي', u'جنبه', u'جنبك', u'ولجنبكما', u'وكجنبكم', u'وكجنبكن', u'جنبكن', u'جنبكم', u'ولجنبهما', u'لجنب', u'ولجنبك', u'ولجنبه', u'فلجنبكم', u'ولجنبي', u'فلجنبكن', u'فجنبها', u'وجنبها', u'ولجنبنا', u'فلجنبي', u'فكجنبنا', u'لجنبكما', u'ولجنبهم', u'فلجنبك', u'فلجنبه', u'فجنبهن', u'فجنبهم', u'فجنبه', u'وجنبهم', u'فجنبك', u'وجنبهن', u'وجنب', u'وبجنبكم', u'وبجنبكن', u'فكجنبهم', u'بجنبكم', u'بجنبكن', u'فلجنبهما', u'فجنبنا', u'لجنبهما', u'كجنبه', u'كجنبك', u'لجنبي', u'بجنب', u'ولجنبها', u'فكجنبها', u'لجنبك', u'لجنبه', u'لجنبكم', u'لجنبكن', u'فكجنب', u'كجنبهم', u'كجنبهن', u'وبجنب', u'بجنبكما', u'فبجنبكم', u'فبجنبكن', u'بجنبهما', u'وبجنبنا', u'وكجنبكما', u'وبجنبهما', u'كجنبها', u'بجنبنا', u'بجنبه', u'ولجنبهن', u'جنبكما', u'وبجنبكما', u'فكجنبهن', u'ولجنب', u'جنب', u'وكجنبي', u'وجنبه', u'وجنبك', u'فجنبي', u'وجنبي', u'وكجنب']),
 u'تلك': set([u'أوكتلك', u'أولتلك', u'ألتلك', u'أفتلك', u'وكتلك', u'أوتلك', u'أتلك', u'لتلك', u'فكتلك', u'فلتلك', u'أكتلك', u'وبتلك', u'أبتلك', u'كتلك', u'فبتلك', u'بتلك', u'أفبتلك', u'أفكتلك', u'أفلتلك', u'أوبتلك', u'تلك', u'وتلك', u'فتلك', u'ولتلك']),
 u'بله': set([u'بله', u'فبله', u'وبله']),
 u'منذ': set([u'منذ', u'فمنذ', u'ومنذ']),
 u'أنتما': set([u'أفلأنتما', u'ولأنتما', u'فلأنتما', u'فأنتما', u'أوأنتما', u'أأنتما', u'أولأنتما', u'ألأنتما', u'لأنتما', u'أنتما', u'أفأنتما', u'وأنتما']),
 u'وراءكما': set([u'وراءكما']),
 u'لازلن': set([u'أفلازلن', u'ولازلن', u'لازلن', u'ألازلن', u'فلازلن', u'أولازلن']),
 u'ما': set([u'ما', u'وما', u'فما']),
 u'بلى': set([u'بلى'])}
